package Tutorial::Elastic::Search::With::Perl::First::Steps::Cheat::Sheet::Geo::Point::Distance;
use Moose;
use ElasticSearch;
use Data::Printer;
use Try::Tiny;
use File::Slurp;
use utf8;

=pod

=head1 Elastic search example of geo point usage

Quickly create an index and start inserting some stuff, and see for yourself if it works or not.

=head2 More tutorials

Tutorial::Elastic::Search::With::Perl::First::Steps::Cheat::Sheet
Tutorial::Elastic::Search::With::Perl::First::Steps::Cheat::Sheet::Geo::Point::Distance

=head2 Dependencys

Make sure you have these installed before executing this module.

    Moose;
    ElasticSearch;
    Data::Printer;
    Try::Tiny;
    File::Slurp;

=head2 How to use

This module has code also, so you can read the methos and see how they are executed.

    $ perl lib/Tutorial/Elastic/Search/With/Perl/First/Steps/Cheat/Sheet/Geo/Point/Distance.pm

    This will:
    - delete index: 'world'
    - create index: 'world'
    - alter mapping so we can insert some coordinates properly
    - insert some objects of type 'city' in our index called 'world'.

    I included some cities on the source code of this tutorial. (from maxmind.com)
    If you want more cities, you can replace with a list from: http://www.maxmind.com/en/worldcities
    I chose brasilian cities.. if you want a place you know, replace the content and execute some querys

    Then after inserting the cities, you usually want to search them... and there is an example of:

    - Search using latitude and longitude values. Define a point and give it some distance. That will be the radio distance of the area you are searching.
    - Show results sorted by distance. and you get to know the distance as well. This is cool!

=head2 Delete an index

    use Try::Tiny;
    ...

    sub delete_index {
        try {
            my $result = $es->delete_index( index => 'world',  );
        } catch {
            warn "$_";
        }
    }

=head2 Create an index

    sub create_index {
        my $result = $es->create_index(
            index      => 'world',
            "settings" => {
            }
        );
    }

=head2 Modify mapping, so you can use latitude longitue points

    sub alter_mapping_for_geo_point_distance {
        my $result = $es->put_mapping(
            index               => 'world',
            type                => 'cidade',
            mapping             => {
                "properties" => {
                    "location" => {
                        "type" => "geo_point",
                    }
                }
            },
            ignore_conflicts    => 0 | 1
        );
        warn p $result; sleep 1;
    }

=head2 Insert some data into elastic search

    sub insert_cities {
        my $cidades = &cidades();
    #   my @lines = read_file("/home/youruser/Downloads/worldcitiespop.txt"); #get at maxmind.com
        my @lines = split /\n/, $cidades;
        my @rows;
        my $id = 0;
          foreach my $line ( @lines ) {
              $line =~ s/\n//g;
              my @row = split ",", $line; #quick hack... not safe at all
              my $obj = {
                  country     => $row[0], #Country,
                  city        => $row[1], #City,
                  accentcity  => $row[2], #AccentCity,
                  region      => $row[3], #Region,
                  population  => $row[4], #Population,
                  location => {
                      lat    => $row[5], #Latitude,
                      lon    => $row[6], #Longitude
                  },
              };
              crud_create( $id++, $obj );
          }
    }


=head2 Search by proximity using latitude longitude

    sub search_by_proximity {
        my $item = $es->search(
            {
                index => 'world',
                type  => 'cidade',
                "query" => {
                    "match_all" => {}
                },
                "filter" => {
                    "geo_distance" => {
                        "distance" => "5km",
                        "location" => {
    #                       São Paulo
    #                       "lat" => -23.473293,
    #                       "lon" => -46.665803

    #                       Lapa
                            lat => -23.53333,
                            lon => -46.7,
                        }
                    }
                },
                size => 50,
                "sort" => [
                    {
                        "_geo_distance" => {
                            "location" => {
                                lat => -23.53333,
                                lon => -46.7,
                            },
                            "order" => "asc",
                            "unit" => "km"
                        }
                    }
                ],
            }
        );
    }

=head2 Distance between 2 coordinate points

    use GIS::Distance;
    my $gis = GIS::Distance->new(); # defaults to Haversine formula!u can change
    #$gis->formula( 'Polar' );# This is optional. Allows to change the formula.
    my $distance = $gis->distance( $lat1,$lon1 => $lat2,$lon2 );
    print $distance->meters();

=head2 What is Haversine

From wikipedia: http://en.wikipedia.org/wiki/Haversine_formula

The haversine formula is an equation important in navigation, giving great-circle distances between two points on a sphere from their longitudes and latitudes. It is a special case of a more general formula in spherical trigonometry, the law of haversines, relating the sides and angles of spherical "triangles".

=head2 AUTHOR

    If you liked this article, i am accepting donations at:
    Hernan Lopes  C<< <hernanlopes____gmail.com> >>

=cut

my $es = ElasticSearch->new(
    servers      => 'localhost:9200',
    transport    => 'http',
    max_requests => 10_000,
    trace_calls  => 1, # or 'log_file'
    no_refresh   => 0 | 1,
);

sub delete_index {
    try {
        my $result = $es->delete_index( index => 'world',  );
    } catch {
        warn "$_";
    }
}

sub create_index {
    my $result = $es->create_index(
        index      => 'world',
        "settings" => {

        }
    );
}

delete_index();sleep 1;
create_index();sleep 1;
alter_mapping_for_geo_point_distance();
insert_cities();
sleep 1; search_by_proximity();

sub alter_mapping_for_geo_point_distance {
    my $result = $es->put_mapping(
        index               => 'world',
        type                => 'cidade',
        mapping             => {
            "properties" => {
                "location" => {
                    "type" => "geo_point",
                }
            }
        },
        ignore_conflicts    => 0 | 1
    );
    warn p $result; sleep 1;
}

sub crud_create {
    my ( $id, $object ) = @_;
    my $result = $es->create(
        index => 'world',
        type  => 'cidade',
        data  => $object,
        id    => $id,
    );
}

sub insert_cities {
    my $cidades = &cidades();
    my @lines = split /\n/, $cidades;
    my @rows;
    my $id = 0;
    foreach my $line ( @lines ) {
        $line =~ s/\n//g;
        my @row = split ",", $line;
        my $obj = {
            country     => $row[0], #Country,
            city        => $row[1], #City,
            accentcity  => $row[2], #AccentCity,
            region      => $row[3], #Region,
            population  => $row[4], #Population,
            location => {
                lat     => $row[5], #Latitude,
                lon     => $row[6], #Longitude
            },
        };
        crud_create( $id++, $obj );
    }
}

sub search_by_proximity {
    my $item = $es->search(
        {
            index => 'world',
            type  => 'cidade',
            "query" => {
                "match_all" => {}
            },
            "filter" => {
                "geo_distance" => {
                    "distance" => "5km",
                    "location" => {
#                       São Paulo
#                       "lat" => -23.473293,
#                       "lon" => -46.665803

#                       Lapa
                        lat => -23.53333,
                        lon => -46.7,
                    }
                }
            },
#           from => 30,
            size => 50,
            "sort" => [
                {
                    "_geo_distance" => {
                        "location" => {
                            lat => -23.53333,
                            lon => -46.7,
                        },
                        "order" => "asc",
                        "unit" => "km"
                    }
                }
            ],
        }
    );

}

sub cidades {
my $world_city_maxmind = <<'CITY';
br,10 de novembro,10 de Novembro,26,,-27.033333,-50.933333
br,13 de maio,13 de Maio,26,,-28.583333,-49.166667
br,14 de julho,14 de Julho,21,,-22.764965,-43.289678
br,14 de maio,14 de Maio,11,,-22.533333,-54.35
br,15 de novembro,15 de Novembro,23,,-28.75,-53.1
br,21 de abril,21 de Abril,23,,-28.633333,-54.116667
br,23 de julho,23 de Julho,23,,-27.966667,-54.616667
br,25 de julio,25 de Julio,08,,-19.766667,-40.6
br,28 de setembro,28 de Setembro,23,,-29.1,-51.866667
br,2 de julho,2 de Julho,05,,-12.066667,-38.966667
br,2 de novembro,2 de Novembro,24,,-8.85,-62.283333
br,3 buritys,3 Buritys,24,,-12.166667,-60.083333
br,3 de maio,3 de Maio,23,,-27.783333,-54.233333
br,3 do maio,3 do Maio,23,,-27.783333,-54.233333
br,3 ilhas,3 Ilhas,15,,-22.032222,-43.489444
br,3 vendas,3 Vendas,23,,-29.85,-53.016667
br,4a legua,4a Légua,23,,-29.2444,-51.1402
br,5a legua,5a Légua,23,,-29.2238,-51.1732
br,7 voltas,7 Voltas,11,,-21.783333,-55.183333
br,a. alvarenga,A. Alvarenga,15,,-20.7,-45.366667
br,aba,Aba,17,,-6.716667,-37.983333
br,abacate,Abacate,03,,.316667,-50.883333
br,abacate,Abacate,04,,-3.946389,-62.903889
br,abacate,Abacate,16,,-1.116667,-49.65
br,abacaxi,Abacaxí,04,,-3.916667,-58.75
br,abacaxis,Abacaxis,04,,-3.916667,-58.75
br,abacaxy,Abacaxy,04,,-3.916667,-58.75
br,aba da serra,Aba da Serra,06,,-5.916667,-39.516667
br,abade,Abade,16,,-.7,-47.883333
br,abadia,Abadia,05,,-11.566667,-37.5
br,abadia,Abadia,15,,-17.716667,-43.1
br,abadia,Abadia,21,,-21.733333,-41.233333
br,abadia de pitangui,Abadia de Pitanguí,15,,-19.333333,-45.216667
br,abadia do pitangui,Abadia do Pitanguí,15,,-19.333333,-45.216667
br,abadia dos dourados,Abadia dos Dourados,15,,-18.466667,-47.4
br,abadiania,Abadiânia,29,7062,-16.1,-48.8
br,abaete,Abaeté,15,20371,-19.15,-45.45
br,abaete,Abaeté,16,,-1.7,-48.9
br,abaetetuba,Abaetetuba,16,78052,-1.7,-48.9
br,abaetezinho,Abaetèzinho,16,,-1.033333,-47.7
br,abaiara,Abaiara,06,,-7.35,-39.05
br,abaiba,Abaíba,15,,-21.6,-42.5
br,abaira,Abaíra,05,,-13.283333,-41.7
br,abaitinga,Abaitinga,27,,-24.033333,-48.05
br,abapa,Abapã,18,,-24.95,-49.816667
br,abapan,Abapan,18,,-24.95,-49.816667
br,a. barauna,A. Baraúna,17,,-7.116667,-36.95
br,a. barbosa,A. Barbosa,11,,-21.633333,-55.533333
br,abare,Abaré,05,,-8.716667,-39.116667
br,abarracamento,Abarracamento,21,,-22.2,-43.5
br,abate,Abaté,23,,-28.1,-52.916667
br,abatia,Abatiá,18,,-23.316667,-50.3
br,abaulado,Abaulado,27,,-23.071781,-47.873628
br,abbadia,Abbadia,05,,-11.566667,-37.5
br,abbadia,Abbadia,15,,-19.333333,-45.216667
br,abbadia dos dourados,Abbadia dos Dourados,15,,-18.466667,-47.4
br,abdon batista,Abdon Batista,26,,-27.616667,-50.983333
br,abel,Abel,15,,-22.9,-46.133333
br,abelardo luz,Abelardo Luz,26,,-26.6,-52.35
br,abelar do luz,Abelar do Luz,26,,-27.35,-51.683333
br,abelha,Abelha,11,,-21.333333,-57.7
br,abelha,Abelha,26,,-26.690898,-49.984099
br,abelhas,Abelhas,11,,-21.333333,-57.7
br,abelhas,Abelhas,22,,-5.948056,-36.061944
br,abertao,Abertão,15,,-22.3,-45.783333
br,abertinha,Abertinha,27,,-24.8867,-48.5365
br,abico,Ábico,04,,-3.15,-64.266667
br,abismo,Abismo,01,,-10.716667,-70.45
br,abobora,Abóbora,06,,-5.85,-40.416667
br,abobora,Abóbora,20,,-10.704167,-45.055833
br,abobora,Abóbora,27,,-24.637699,-48.172946
br,aboboras,Abóboras,05,,-9.816667,-40.05
br,aboboras,Abóboras,20,,-10.704167,-45.055833
br,aboboras,Abóboras,30,,-7.866667,-38.233333
br,abobral,Abobral,11,,-21.2,-56.833333
br,abolicao,Abolição,14,,-15.733333,-55.666667
br,abolicao,Abolição,21,,-22.882414,-43.301796
br,abolicao,Abolição,23,,-30.866667,-52.25
br,aborrecido,Aborrecido,06,,-2.893889,-40.918611
br,abraao,Abraão,21,,-23.133333,-44.166667
br,abraao,Abraão,24,,-9,-63.266667
br,abrahao,Abrahão,21,,-23.133333,-44.166667
br,abrahao,Abrahão,24,,-9,-63.266667
br,abranches,Abranches,18,,-25.266667,-49.816667
br,abrantes,Abrantes,05,,-12.816667,-38.266667
br,abre campo,Abre Campo,15,,-20.3,-42.483333
br,abreu,Abreu,13,,-3.350278,-42.419722
br,abreu,Abreu,18,,-23.327092,-49.807253
br,abreu,Abreu,20,,-7.8,-45.5
br,abreu,Abreu,23,,-29.933333,-57.183333
br,abreu e lima,Abreu e Lima,30,81960,-7.9,-34.883333
br,abreulandia,Abreulândia,31,,-9.565556,-49.056389
br,abreus,Abreus,05,,-10.183333,-40.966667
br,abreus,Abreus,15,,-21,-43.3
br,abrigo do bom pastor,Abrigo do Bom Pastor,27,,-23.629246,-47.825019
br,abucari,Abucari,04,,-5.016667,-62.783333
br,abufari,Abufari,04,,-5.396389,-63.090556
br,abufary,Abufary,04,,-5.396389,-63.090556
br,abuna,Abunã,24,,-9.7,-65.383333
br,abunai,Abunaí,04,,-1.833333,-66.55
br,abunan,Abunan,24,,-9.7,-65.383333
br,abundancia,Abundância,13,,-4.116667,-44.6
br,abura,Aburá,17,,-7.35,-35.433333
br,abutari,Abutari,04,,-5.396389,-63.090556
br,acaa,Acaã,05,,-12.366667,-43.3
br,acaam,Acaam,05,,-12.366667,-43.3
br,acacias,Acácias,21,,-22.44,-44.3228
br,academia,Academia,04,,-6.95,-71.251111
br,acaiaca,Acaiaca,15,,-20.35,-43.15
br,acai,Açaí,01,,-8.266667,-73.1
br,acai,Açaí,18,,-23.366667,-50.816667
br,acai,Açaí,27,,-21.383333,-48.983333
br,acaituba,Açaituba,04,,-7.016667,-64.583333
br,acaituba,Açaituba,25,,.65,-61.55
br,acaju,Acaju,05,,-13.033333,-39.533333
br,acajutiba,Acajutiba,05,14349,-11.666667,-38.016667
br,acampamento,Acampamento,01,,-7.45,-73.666667
br,acampamento,Acampamento,13,,-3.648333,-42.9625
br,acampamento,Acampamento,16,,-1,-57.016667
br,acampamento grande,Acampamento Grande,03,,.3,-53.066667
br,acampamonte,Acampamonte,20,,-6.983333,-41.166667
br,acapucai,Açapucaí,23,,-29.833333,-51.15
br,acara,Acará,04,,-4.369444,-59.660278
br,acara,Acará,13,,-3.416667,-45.316667
br,acara,Acará,16,12803,-1.95,-48.183333
br,acarahu,Acarahú,06,,-2.883333,-40.116667
br,acarahy,Acarahy,04,,-3.416667,-68.25
br,acarai,Acaraí,04,,-3.416667,-68.25
br,acarai,Acaraí,05,,-13.95,-39.116667
br,acarai,Acaraí,06,,-3.016667,-39.633333
br,acarai,Açaraí,15,,-19.583333,-41.483333
br,acara-mirim,Acará-Mirim,13,,-3.533333,-45.366667
br,acara-mirim,Acará-Mirim,16,,-2.4,-48.283333
br,acarape,Acarape,06,,-3.666667,-40.966667
br,acarau,Acaraú,06,28389,-2.883333,-40.116667
br,acare,Açaré,06,,-6.866667,-39.866667
br,acari,Acari,05,,-9.133333,-40.083333
br,acari,Acari,16,,-1.616667,-47.55
br,acari,Acari,21,,-22.824605,-43.341365
br,acari,Acari,22,9159,-6.516667,-36.633333
br,acari,Acari,25,,3.833333,-61.4
br,acary,Acary,22,,-6.516667,-36.633333
br,a. cassara,A. Cassara,24,,-13.216667,-62.1
br,acaua,Acauã,13,,-2.683333,-45.15
br,acaua,Acauã,20,,-8.2,-41.083333
br,acaua,Acauã,30,,-7.883333,-39.133333
br,acau,Acaú,17,,-7.116667,-35.35
br,acaua de baixo,Acauã de Baixo,30,,-7.9,-39.15
br,accioly,Accioly,08,,-19.666667,-40.466667
br,acegua,Aceguá,23,,-31.866667,-54.15
br,aceme,Aceme,30,,-8.133333,-38.95
br,acesita,Acesita,15,,-19.533333,-42.633333
br,aciline,Aciline,03,,-.383333,-52.1
br,acima,Acimã,04,,-7.716667,-65.883333
br,acioli,Acióli,08,,-19.666667,-40.466667
br,acopiara,Acopiara,06,24562,-6.1,-39.45
br,acoriana,Açoriana,23,,-32.1168,-52.5985
br,acorizal,Acorizal,14,,-15.2,-56.366667
br,acotea,Açotéa,23,,-31.766667,-53.8
br,acoteia,Açotéia,23,,-31.766667,-53.8
br,acougue,Açougue,05,,-11.983333,-40.416667
br,acougue,Açougue,06,,-3.45,-40.066667
br,acre,Acre,20,,-10.883333,-45.083333
br,acua,Açuã,20,,-8.2,-41.083333
br,acu,Açu,04,,-4.132222,-62.34
br,acu,Açu,05,,-12.5,-38.966667
br,acu,Açu,13,,-2.166667,-44.633333
br,acu,Açu,22,36126,-5.577222,-36.9075
br,acuarana,Açuarana,02,,-9.633333,-36.95
br,acucar,Açúcar,27,,-24.853518,-48.230402
br,acucena,Açucena,15,14506,-19.066667,-42.533333
br,acu da torre,Acu da Torre,05,,-12.55,-38
br,acude,Açude,02,,-9.416667,-36.633333
br,acude,Açude,05,,-13.833333,-41.4
br,acude,Açude,06,,-3.166667,-40.433333
br,acude,Açude,13,,-4.116667,-44.933333
br,acude,Açude,15,,-20.783333,-46.45
br,acude,Açude,17,,-6.833333,-38.016667
br,acude,Açude,20,,-4.6,-41.466667
br,acude,Açude,21,,-22.960392,-43.289884
br,acude,Açude,30,,-8.033333,-37.666667
br,acude angelim,Açude Angelim,30,,-8.883333,-36.283333
br,acude de baixo,Açude de Baixo,30,,-8.016667,-38.6
br,acude de leite,Açude de Leite,17,,-6.65,-37.75
br,acude de macaubas,Açude de Macaúbas,05,,-13,-42.533333
br,acude do mado,Açude do Mado,06,,-7.416667,-38.766667
br,acude do meio,Açude do Meio,30,,-7.883333,-37.366667
br,acude dos alves,Açude dos Alves,17,,-7.516667,-38.416667
br,acude dos carlos,Acude dos Carlos,30,,-7.75,-37.883333
br,acude do severino,Açude do Severino,17,,-7.366667,-37.833333
br,acude novo,Açude Nôvo,06,,-6.083333,-38.483333
br,acude novo,Açude Nôvo,22,,-5.918056,-37.086111
br,acudes,Açudes,22,,-6.25,-37.8
br,acude tapuio,Açude Tapuio,22,,-6.133333,-38.083333
br,acude velho,Açude Velho,06,,-3.75,-40.216667
br,acude velho,Açude Velho,17,,-7.116667,-36.366667
br,acude velho,Açude Velho,20,,-3.718056,-42.243889
br,acude velho,Açude Velho,22,,-5.871667,-36.078056
br,acudina,Açudina,05,,-13.2,-44.166667
br,acudinho,Açudinho,06,,-3.383333,-39.933333
br,acudinho,Açudinho,17,,-7.716667,-38.583333
br,acudinho,Açudinho,20,,-6.616667,-40.65
br,acudinho,Açudinho,30,,-8.1,-36.416667
br,acungui,Açungui,18,,-24.983333,-49.5
br,acupe,Acupe,05,,-12.65,-38.75
br,acuria,Acuriá,01,,-9.066667,-72.65
br,acurizal,Acurizal,14,,-15.2,-56.366667
br,acurizal,Acurizal,24,,-13.516667,-61.733333
br,acurui,Acuruí,15,,-20.2,-43.733333
br,acuru tendi,Acuru Tendi,11,,-23.716667,-54.783333
br,acutinga,Acutinga,05,,-12.616667,-38.816667
br,acutuba,Açutuba,04,,-4.073889,-62.445833
br,adalberto,Adalberto,21,,-22.316667,-41.9
br,adamantina,Adamantina,27,31079,-21.683333,-51.066667
br,adao candido lima,Adão Cândido Lima,15,,-20.85,-46.266667
br,adelia,Adélia,04,,-6.876389,-71.123333
br,adelino,Adelino,15,,-21.066667,-45.816667
br,adelino franca,Adelino França,15,,-16.45,-41.883333
br,adeque,Adequê,22,,-6.033333,-36.95
br,adiquinhao,Adiquinhão,22,,-5.948056,-37.372222
br,adolfo,Adolfo,26,,-26.733333,-51.033333
br,adolfo,Adolfo,27,,-21.233333,-49.65
br,adolfo,Adolfo,31,,-11.63,-49.2225
br,adolfo conder,Adolfo Cónder,26,,-26.733333,-51.033333
br,adolfo correia,Adolfo Correia,15,,-20.4,-45.083333
br,adolfo konder,Adolfo Konder,26,,-26.733333,-51.033333
br,adolpho conder,Adolpho Conder,26,,-26.733333,-51.033333
br,adolpho condor,Adolpho Condor,26,,-27.2,-49.8
br,adonis,Adônis,15,,-20.266667,-41.933333
br,adrianopolis,Adrianópolis,18,,-24.659641,-48.99079
br,adrianopolis,Adrianópolis,21,,-22.657778,-43.487222
br,adustina,Adustina,05,,-10.533333,-38.116667
br,aelegrete,Aelegrete,11,,-21.383333,-54.75
br,afeto,Afeto,20,,-8.233333,-40.783333
br,affligidos,Affligidos,05,,-12.483333,-38.85
br,affonso,Affonso,14,,-14.5,-57
br,affonso arinos,Affonso Arinos,15,,-15.916667,-46.066667
br,affonso camargo,Affonso Camargo,18,,-23.504,-49.9239
br,affonso claudio,Affonso Claudio,08,,-20.083333,-41.133333
br,affonso penha,Affonso Penha,08,,-19.683333,-41.016667
br,affonso penna,Affonso Penna,05,,-12.8,-39.2
br,affonso penna,Affonso Penna,06,,-6.1,-39.45
br,affua,Affua,16,,-.166667,-50.383333
br,afligidos,Afligidos,05,,-12.483333,-38.85
br,afogados,Afogados,30,,-7.75,-37.65
br,afogados da ingazeira,Afogados da Ingàzeira,30,25060,-7.75,-37.65
br,afonso,Afonso,11,,-21.95,-53.516667
br,afonso,Afonso,14,,-14.5,-57
br,afonso,Afonso,15,,-16.416667,-40.866667
br,afonso,Afonso,21,,-22.4,-42.6
br,afonso arinos,Afonso Arinos,21,,-22.009722,-43.338889
br,afonso bezerra,Afonso Bezerra,22,6947,-5.498056,-36.509167
br,afonso claudio,Afonso Cláudio,08,13543,-20.083333,-41.133333
br,afonso de paula,Afonso de Paula,15,,-20.016667,-45.283333
br,afonso martins,Afonso Martins,15,,-16.483333,-40.916667
br,afonso nonato,Afonso Nonato,15,,-16.25,-40.55
br,afonso pena,Afonso Pena,05,,-12.8,-39.2
br,afonso-pena,Afonso-Pena,06,,-6.1,-39.45
br,afonso pena,Afonso Pena,08,,-19.683333,-41.016667
br,afonsopolis,Afonsópolis,05,,-18.133333,-39.783333
br,afonso souto,Afonso Souto,23,,-29.966667,-55.2
br,afranio,Afrânio,30,,-8.516667,-41
br,afranio peixoto,Afrânio Peixoto,05,,-12.283333,-41.416667
br,afua,Afuá,16,7031,-.166667,-50.383333
br,agachi,Agachi,11,,-20.066667,-56.3
br,agarrado,Agarrado,04,,-5.373611,-59.973056
br,agenor alves,Agenor Alves,15,,-19.383333,-50.066667
br,agiota,Agiota,30,,-8.033333,-38.416667
br,agisse,Agissê,27,,-22.516667,-50.916667
br,agostinho,Agostinho,01,,-9.95,-68.55
br,agostinho,Agostinho,11,,-18.266667,-55.283333
br,agostinho,Agostinho,27,,-21.4,-47.55
br,agostinho,Agostinho,30,,-7.833333,-37.266667
br,agostinho porto,Agostinho Porto,21,,-22.787918,-43.377155
br,agostinho rodrigues,Agostinho Rodrigues,11,,-19.45,-56.566667
br,agreate,Agreate,06,,-5.583333,-40.6
br,agreste,Agreste,02,,-9.583333,-37.283333
br,agreste,Agreste,05,,-13.866667,-43.233333
br,agreste,Agreste,06,,-5.9,-39.833333
br,agreste,Agreste,30,,-8.35,-36.866667
br,agrestina,Agrestina,30,14453,-8.45,-35.95
br,agrinco,Agrinco,18,,-24.916667,-53.016667
br,agrioes,Agriões,21,,-22.418257,-42.974767
br,agropastoril papal do ceu,Agropastoril Papal do Céu,18,,-23.550578,-50.579507
br,agro-pecuaria palmeirense,Agro-Pecuária Palmeirense,18,,-25.52433,-50.35314
br,agrovila,Agrovila,18,,-25.4094,-50.5715
br,agua amarela,Água Amarela,03,,.383333,-52.183333
br,agua amarela,Água Amarela,31,,-5.766667,-48.05
br,agua amarela de baixo,Água Amarela de Baixo,18,,-25.8851,-50.180098
br,agua amarela de cima,Água Amarela de Cima,18,,-25.897993,-50.039159
br,agua amarela do meio,Água Amarela do Meio,18,,-25.892423,-50.111217
br,agua amarla do meio,Água Amarla do Meio,18,,-25.88441,-50.121859
br,agua azul,Água Azul,11,,-21.933333,-56.183333
br,agua azul,Água Azul,18,,-25.863209,-50.145768
br,agua azul,Agua Azul,20,,-6.183333,-41.583333
br,agua azul de baixo,Água Azul de Baixo,18,,-25.813198,-50.145404
br,agua azul de cima,Água Azul de Cima,18,,-25.829931,-50.121164
br,agua azul de meio,Água Azul de Meio,18,,-25.820023,-50.133088
br,agua azulzinha,Água Azulzinha,18,,-25.8479,-50.152161
br,agua bela,Água Bela,05,,-14.333333,-40.7
br,agua bela,Água Bela,15,,-16.166667,-40.816667
br,agua bela,Água Bela,17,,-6.766667,-37.933333
br,agua bela,Água Bela,20,,-5.816667,-42.833333
br,agua boa,Água Boa,05,,-12.416667,-44.616667
br,agua boa,Água Boa,06,,-3.05,-40.433333
br,agua boa,Água Boa,08,,-19.766667,-40.283333
br,agua boa,Água Boa,15,,-17.983333,-42.4
br,agua boa,Água Boa,18,,-23.5,-52.166667
br,agua boa,Água Boa,25,,2.666667,-60.766667
br,agua bonita,Água Bonita,27,,-22.733333,-47.75
br,agua bonita,Água Bonita,31,,-13.033333,-49.816667
br,agua branca,Água Branca,02,5161,-9.283333,-37.916667
br,agua branca,Água Branca,05,,-12.566667,-38.45
br,agua branca,Agua Branca,06,,-6.433333,-38.783333
br,agua branca,Água Branca,13,,-3.0825,-42.037778
br,agua branca,Água Branca,14,,-16.25,-55.466667
br,agua branca,Água Branca,15,,-14.75,-43.416667
br,agua branca,Água Branca,17,,-7.516667,-37.666667
br,agua branca,Água Branca,18,,-23.712166,-50.037343
br,agua-branca,Água-Branca,18,,-24.679441,-48.839312
br,agua branca,Água Branca,20,13912,-5.883333,-42.633333
br,agua branca,Água Branca,22,,-6.033333,-37.833333
br,agua branca,Água Branca,27,,-23.174735,-47.930774
br,agua-branca,Água-Branca,27,,-23.232136,-47.626292
br,agua branca,Água Branca,27,,-23.429777,-47.924835
br,agua branca,Agua Branca,30,,-7.833333,-37.583333
br,agua branca de baixo,Água Branca de Baixo,27,,-23.410557,-47.853598
br,agua branca de cima,Água Branca de Cima,18,,-25.69739,-50.42745
br,agua branca de cima,Água Branca de Cima,20,,-5.166667,-41.266667
br,agua branca de cima,Água Branca de Cima,27,,-23.440545,-47.862891
br,aguacerita,Aguacerita,14,,-15.816667,-58.75
br,agua clara,Água Clara,11,,-20.45,-52.866667
br,agua clara,Água Clara,18,,-23.326366,-52.59526
br,agua clara,Água Clara,26,,-27.116667,-48.916667
br,agua clara,Agua Clará,27,,-21.533333,-50.566667
br,agua clara de baixo,Água Clara de Baixo,18,,-25.956825,-49.422122
br,agua comprida,Água Comprida,05,,-12.316667,-37.9
br,agua comprida,Água Comprida,15,,-20.066667,-48.133333
br,agua comprida,Água Comprida,18,,-25.607999,-50.182499
br,aguacu,Aguaçu,11,,-19.45,-57.7
br,aguacu,Aguaçu,14,,-15.15,-56.016667
br,aguacuzinho,Aguaçuzinho,11,,-19.2,-56.466667
br,aguada,Aguada,05,,-12.716667,-42.233333
br,agua da fortuna,Água da Fortuna,18,,-25.0923,-53.9021
br,agua da mula,Água da Mula,18,,-23.342991,-49.794705
br,aguada nova,Aguada Nova,05,,-11.45,-41.8
br,aguada nova,Aguada Nova,15,,-16.3,-41.183333
br,agua da pedra,Água da Pedra,27,,-23.099043,-47.761872
br,agua da peroba,Água da Peroba,18,,-23.575174,-49.99037
br,agua da rega,Água da Rega,05,,-12.116667,-41.733333
br,agua da romana,Água da Romana,18,,-25.0576,-53.8151
br,agua da rosa,Água da Rosa,27,,-22.716667,-48.616667
br,agua das palmeiras,Água das Palmeiras,18,,-23.6513,-49.845
br,agua de rega,Água de Rega,05,,-12.116667,-41.733333
br,agua de rego,Água de Rêgo,05,,-12.116667,-41.733333
br,aguado,Aguado,05,,-12.716667,-42.233333
br,agua do barreirinho,Água do Barreirinho,18,,-23.116297,-49.990839
br,agua do barreiro,Água do Barreiro,18,,-23.8335,-50.8471
br,agua do boi,Água do Boi,18,,-23.0113,-50.1186
br,agua do cacador,Água do Caçador,18,,-23.928526,-50.512746
br,agua doce,Água Doce,03,,2.6,-50.833333
br,agua doce,Água Doce,05,,-14.8,-39.833333
br,agua doce,Água Dôce,06,,-5.316667,-39.266667
br,agua doce,Água Doce,08,,-18.55,-40.983333
br,agua doce,Água Doce,17,,-7.666667,-36.683333
br,agua doce,Água Doce,26,,-27,-51.55
br,agua doce,Água Doce,29,,-15.183333,-56.816667
br,agua doce do mantena,Água Doce do Mantena,08,,-18.55,-40.983333
br,agua do coriango,Água do Coriango,18,,-23.548612,-50.619678
br,agua do noratinho,Água do Noratinho,18,,-23.806027,-50.836333
br,agua do peixe,Água do Peixe,18,,-23.1413,-50.0282
br,agua dos coqueiros,Água dos Coqueiros,18,,-23.0271,-50.1315
br,agua emendada,Água Emendada,14,,-15.9,-54.3
br,agua ferro,Água Ferro,21,,-22.955,-43.908889
br,agua fetida,Água Fétida,05,,-12.533333,-43.566667
br,agua fina,Água Fina,14,,-14.266667,-55.966667
br,agua fria,Água Fria,05,,-11.85,-38.766667
br,agua fria,Água Fria,06,,-6.366667,-39.05
br,agua fria,Água Fria,08,,-18.433333,-40.4
br,agua fria,Água Fria,11,,-21.383333,-55.3
br,agua fria,Água Fria,13,,-3.169722,-43.479722
br,agua fria,Água Fria,14,,-15.183333,-55.75
br,agua fria,Água Fria,15,,-18.566667,-47.766667
br,agua fria,Água Fria,17,,-6.883333,-37.5
br,agua fria,Água Fria,27,,-23.35,-46.883333
br,agua fria,Água Fria,30,,-7.916667,-40.5
br,agua grande,Água Grande,05,,-12.316667,-38.433333
br,agua grande,Água Grande,18,,-23.7469,-49.7795
br,aguai,Aguaí,27,27503,-22.066667,-46.966667
br,agua limpa,Água Limpa,05,,-17.383333,-40.166667
br,agua limpa,Água Limpa,08,,-18.833333,-40.666667
br,agua limpa,Água Limpa,11,,-19.35,-54.7
br,agua limpa,Água Limpa,13,,-3.408889,-43.439444
br,agua limpa,Água Limpa,14,,-14.383333,-57.75
br,agua limpa,Água Limpa,15,,-19.15,-48.333333
br,agua limpa,Água Limpa,20,,-6.216667,-41.366667
br,agua limpa,Água Limpa,27,,-22.166667,-48.85
br,agua-limpa,Água-Limpa,29,,-17.1,-50.116667
br,agua limpa,Água Limpa,29,,-18.1,-48.766667
br,aguamare,Aguamare,22,,-5.106389,-36.320278
br,agua negra,Água Negra,26,,-26.9177,-49.0125
br,aguanil,Aguanil,15,,-20.95,-45.383333
br,agua nova,Agua Nova,22,,-5.331111,-36.535
br,aguapaba,Aguapaba,17,,-7.6,-35.583333
br,agua parada,Água Parada,27,,-24.647747,-48.099655
br,agua paranhos,Água Paranhos,18,,-23.397625,-52.709511
br,aguape,Aguapé,06,,-2.944444,-40.953056
br,aguape,Aguapé,15,,-21.9,-45.266667
br,aguape,Aguapé,30,,-8.616667,-38.383333
br,aguapei,Aguapeí,14,,-16.2,-59.716667
br,aguapei do alto,Aguapeí do Alto,27,,-21.6,-51.2
br,agua preta,Água Preta,04,,-8.833333,-66.166667
br,agua preta,Agua Preta,05,,-14.583333,-39.266667
br,agua preta,Água Preta,30,16444,-8.7,-35.516667
br,agua quente,Água Quente,05,,-13.183333,-44.3
br,agua quente,Água Quente,14,,-15.833333,-55.433333
br,agua quente,Água Quente,15,,-17.016667,-41.033333
br,agua quente,Água Quente,27,,-24.8814,-48.5078
br,agua quente,Água Quente,29,,-14.55,-48.933333
br,agua rasa,Água Rasa,15,,-20.433333,-45.166667
br,agua rica,Água Rica,13,,-3.693889,-43.018056
br,agua rosa,Agua Rosa,15,,-20.433333,-45.166667
br,agua santa,Água Santa,15,,-20.866667,-42.166667
br,agua santa,Água Santa,21,,-22.909708,-43.308343
br,agua santa,Água Santa,23,,-28.166667,-52.033333
br,agua santa,Água Santa,27,,-22.662,-45.5611
br,aguas belas,Águas Belas,05,,-12.5,-41.2
br,aguas belas,Águas Belas,06,,-4.05,-38.183333
br,aguas belas,Águas Belas,15,,-16.1,-41.05
br,aguas belas,Águas Belas,17,,-6.933333,-38.383333
br,aguas belas,Aguas Belas,20,,-7.033333,-42.283333
br,aguas belas,Águas Belas,30,22563,-9.116667,-37.116667
br,aguas bellas,Aguas Bellas,06,,-4.9,-40.766667
br,aguas bellas,Aguas Bellas,15,,-17.083333,-40.95
br,aguas bellas,Aguas Bellas,30,,-9.116667,-37.116667
br,aguas boas,Águas Boas,13,,-1.966667,-45.816667
br,aguas brancas,Águas Brancas,05,,-12.566667,-38.45
br,aguas brancas,Águas Brancas,23,,-28.583333,-50.4
br,aguas brancas,Águas Brancas,26,,-27.95,-49.583333
br,aguas claras,Águas Claras,08,,-18.85,-40.833333
br,aguas claras,Águas Claras,18,,-23.333313,-52.620215
br,aguas claras,Águas Claras,26,,-27.116667,-48.916667
br,aguas claras do sul,Águas Claras do Sul,27,,-21.416667,-51.183333
br,aguas da prata,Águas da Prata,27,,-21.933333,-46.716667
br,aguas de chapeco,Águas de Chapecó,26,,-27.083333,-52.983333
br,aguas de contendas,Águas de Contendas,15,,-21.9,-45.016667
br,aguas de lindoia,Águas de Lindóia,27,18806,-22.483333,-46.65
br,aguas de sao pedro,Águas de São Pedro,27,,-22.6,-47.883333
br,aguas do pardo,Aguas do Pardo,23,,-27.133333,-53.4
br,aguas do paulista,Águas do Paulista,05,,-12.5,-43.1
br,aguas do vere,Águas do Verê,18,,-25.766667,-52.95
br,aguas formosas,Águas Formosas,15,11512,-17.083333,-40.95
br,aguas lindas,Aguas Lindas,21,,-22.711389,-43.722778
br,aguas m. de ibira,Águas M. de Ibira,27,,-21.116667,-49.2
br,aguas pretas,Aguas Pretas,17,,-7.066667,-36.116667
br,aguas santas,Águas Santas,15,,-21.1,-44.216667
br,agua suja,Água Suja,05,,-14.033333,-44.45
br,agua suja,Água Suja,11,,-21.95,-54.466667
br,agua suja,Agua Suja,15,,-18.883333,-47.633333
br,agua suja,Água Suja,18,,-23.0442,-50.1685
br,agua sumida,Água Sumida,27,,-22.3,-52.216667
br,aguas vermelhas,Aguas Vermelhas,05,,-13.866667,-39.85
br,aguas vermelhas,Águas Vermelhas,15,16410,-15.75,-41.466667
br,agua verde,Água Verde,06,,-4.166667,-38.7
br,agua verde,Água Verde,18,,-23.367,-49.882
br,agua verde,Água Verde,20,,-7.366667,-41.716667
br,agua vermelha,Água Vermelha,05,,-13.866667,-39.85
br,agua vermelha,Água Vermelha,06,,-7.4,-38.933333
br,agua vermelha,Água Vermelha,13,,-6.483333,-43.133333
br,agua vermelha,Agua Vermelha,15,,-15.75,-41.466667
br,agua vermelha,Água Vermelha,27,,-21.9,-47.883333
br,agua viva,Água Viva,15,,-21.683333,-42.55
br,aguazinha,Águazinha,17,,-7.9,-36.7
br,agudo,Agudo,23,,-29.633333,-53.25
br,agudos,Agudos,18,,-25.9892,-49.3342
br,agudos,Agudos,27,30808,-22.466667,-49
br,agudos do sul,Agudos do Sul,18,,-25.9892,-49.3342
br,aguia,Águia,04,,-6.5,-69.433333
br,aguia branca,Águia Branca,08,2554,-18.983333,-40.733333
br,aguiar,Aguiar,17,,-7.083333,-38.183333
br,aguiar,Aguiar,23,,-2.7,-54.2
br,aguiar velho,Aguiar Velho,17,,-7.1,-38.1
br,aguilhadas,Aguilhadas,06,,-6.533333,-40.366667
br,aguinhas,Aguinhas,26,,-27,-52.95
br,agulha,Agulha,27,,-21.35,-48.7
br,agulhas negras,Agulhas Negras,21,,-22.4548,-44.4377
br,aguti,Aguti,26,,-27.3,-49.15
br,aiapua,Aiapuá,04,,-4.463333,-62.055278
br,aideia do prata,Aideia do Prata,15,,-16.816667,-40.616667
br,aimin,Aimin,04,,-4.803889,-62.451667
br,aimores,Aimorés,05,,-17.833333,-40.166667
br,aimores,Aimorés,15,19133,-19.5,-41.066667
br,aiparuca,Aiparuça,04,,-2.981111,-60.608056
br,aiquara,Aiquara,05,,-14.116667,-39.866667
br,airao,Airão,04,,-1.95,-61.366667
br,airi,Airi,04,,-6.9,-58.283333
br,airi,Airi,30,,-8.533333,-38.183333
br,airituba,Airituba,08,,-20.95,-41.666667
br,airoes,Airões,15,,-20.8,-42.966667
br,airy,Airy,04,,-6.9,-58.283333
br,aito calcado,Aito Calçado,08,,-20.95,-41.616667
br,aiua,Aiuá,06,,-3.45,-40.466667
br,aiuaba,Aiuaba,06,,-6.633333,-40.116667
br,aiure,Aiuré,26,,-28.1,-49.3
br,aiuruoca,Aiuruoca,15,,-21.966667,-44.6
br,ajacio,Ajácio,15,,-16.1,-40.35
br,ajapi,Ajapi,27,,-22.283333,-47.55
br,ajara,Ajará,04,,-4.428333,-62.268889
br,ajaru,Ajaru,04,,-2.211389,-61.114444
br,ajerico,Ajericó,16,,-.833333,-51.816667
br,ajuda,Ajuda,05,,-16.5,-39.083333
br,ajudante,Ajudante,27,,-23.166667,-47.316667
br,ajura,Ajurá,04,,-3.904444,-62.732222
br,ajuricaba,Ajuricaba,04,,-7.583333,-66.616667
br,ajuricaba,Ajuricaba,23,,-28.25,-53.766667
br,ajurical,Ajurical,04,,-7.583333,-66.616667
br,ajuritiba,Ajuritiba,27,,-23.133333,-46.466667
br,ajusta conta,Ajusta Conta,14,,-15.75,-57.633333
br,ajusta-contas,Ajusta-Contas,14,,-15.75,-57.633333
br,akotipa,Akotipa,16,,1.916667,-55.55
br,alagacico,Alagaciço,05,,-9.533333,-38.366667
br,alagadico,Alagadiço,05,,-10.666667,-41.283333
br,alagadico,Alagadiço,06,,-5.25,-40.966667
br,alagadico,Alagadiço,15,,-15.1,-43.666667
br,alagadico,Alagadiço,20,,-3.75,-42.533333
br,alagadico,Alagadiço,25,,3.383333,-60.616667
br,alagadico grande,Alagadico Grande,22,,-5.816667,-35.416667
br,alagamar,Alagamar,06,,-4.2,-38.4
br,alagoa,Alagoa,15,,-22.166667,-44.633333
br,alagoa,Alagoa,27,,-23.502437,-47.013252
br,alagoa da serra negra,Alagôa da Serra Negra,05,,-10.033333,-37.9
br,alagoa de baixo,Alagoa de Baixo,30,,-8.083333,-37.266667
br,alagoa de roca,Alagoa de Roça,17,,-7.083333,-35.866667
br,alagoado,Alagoado,20,,-6.033333,-42.283333
br,alagoa do monteiro,Alagôa do Monteiro,17,,-7.883333,-37.116667
br,alagoa grande,Alagoa Grande,17,16406,-7.05,-35.633333
br,alagoa grande,Alagoa Grande,20,,-8.416667,-44.166667
br,alagoa nova,Alagoa Nova,17,9182,-7.066667,-35.766667
br,alagoas,Alagôas,02,,-9.716667,-35.9
br,alagoas,Alagoas,05,,-12.433333,-40.3
br,alagoas,Alagoas,13,,-3.771389,-43.408056
br,alagoas,Alagoas,15,,-18.633333,-46.666667
br,alagoas,Alagoas,29,,-13.8,-47.816667
br,alagoinha,Alagoinha,02,,-10.166667,-36.383333
br,alagoinha,Alagoinha,05,,-11.683333,-41.333333
br,alagoinha,Alagoinha,06,,-6.783333,-38.716667
br,alagoinha,Alagoinha,13,,-3.077778,-42.026111
br,alagoinha,Alagoinha,17,7474,-6.933333,-35.55
br,alagoinha,Alagoinha,20,,-6.933333,-41.716667
br,alagoinha,Alagoinha,22,,-5.066667,-37.4
br,alagoinha,Alagoinha,30,,-8.483333,-36.783333
br,alagoinhas,Alagoinhas,02,,-10.166667,-36.383333
br,alagoinhas,Alagoinhas,05,122692,-12.116667,-38.433333
br,alagoinhas,Alagoinhas,20,,-4.033333,-41.85
br,alagoinhas de santana,Alagoinhas de Santana,05,,-13.983333,-41.533333
br,alamao,Alamão,05,,-12.783333,-38.85
br,alamari,Alamari,27,,-23.5521,-47.8989
br,alambari,Alambari,27,,-20.583333,-47.233333
br,alambary,Alambary,27,,-23.5521,-47.8989
br,alambique,Alambique,08,,-20.083333,-41.133333
br,alambique,Alambique,18,,-23.4221,-52.545324
br,alambique,Alambique,23,,-29.769,-50.7919
br,alamoique,Alamoique,16,,1.983056,-55.166667
br,alasca,Alasca,24,,-13.297222,-60.370833
br,alaska,Alaska,24,,-13.297222,-60.370833
br,alavanca,Alavanca,11,,-21.55,-54.3
br,alazao,Alazão,05,,-12.7,-44.666667
br,alazao,Alazão,30,,-7.766667,-37.483333
br,alazao dos cardosos,Alazão dos Cardosos,13,,-3.992778,-42.906111
br,albano,Albano,04,,-2.45,-57.55
br,albano,Albano,14,,-15.75,-55.583333
br,albertina,Albertina,15,,-22.2,-46.616667
br,albertina,Albertina,26,,-27.25,-49.65
br,alberto isaacson,Alberto Isaacson,15,,-19.5,-45.066667
br,alberto moreira,Alberto Moreira,27,,-20.433333,-48.583333
br,albertos,Albertos,15,,-20.583333,-45.483333
br,alberto torres,Alberto Tôrres,21,,-22.236111,-43.096389
br,albino,Albino,13,,-3.609722,-42.987778
br,albino,Albino,15,,-18.45,-48.583333
br,albino alves garcia,Albino Alves Garcia,15,,-20.45,-45.2
br,albinopolis,Albinópolis,27,,-21.733333,-47.533333
br,albuquerque,Albuquerque,04,,-6.887222,-58.340833
br,albuquerque,Albuquerque,06,,-4.583333,-37.766667
br,albuquerque,Albuquerque,11,,-19.383333,-57.433333
br,albuquerque,Albuquerque,21,,-22.385802,-42.908931
br,albuquerque,Albuquerque,27,,-20.983333,-48.833333
br,albuquerque,Albuquerque,30,,-8.016667,-37.4
br,albuquerque de fora,Albuquerque de Fora,22,,-6.383333,-38.2
br,albuquerque lins,Albuquerque Lins,27,,-21.666667,-49.75
br,albuquerque ne,Albuquerque Né,30,,-8.016667,-37.4
br,alcacus,Alcaçus,22,,-6.016667,-35.133333
br,alcantara,Alcântara,13,5655,-2.4,-44.4
br,alcantara,Alcântara,21,,-22.824444,-43.035278
br,alcantaras,Alcântaras,06,,-3.583333,-40.5
br,alcantilado,Alcantilado,14,,-16.383333,-53.516667
br,alcantil,Alcantil,17,,-7.733333,-36.05
br,alceu garcia,Alceu Garcia,15,,-18.55,-49.183333
br,alcibiades vargas,Alcibiades Vargas,11,,-23.383333,-54.65
br,alcides batista,Alcides Batista,15,,-17.516667,-40.65
br,alcidio,Alcídio,27,,-21.033333,-47.55
br,alcobaca,Alcobaça,05,,-17.5,-39.216667
br,alcobaca,Alcobaça,16,,-3.7,-49.7
br,alcobaco,Alcobaço,27,,-23.47624,-46.614322
br,aldeamento,Aldeamento,08,,-19.266667,-40.733333
br,aldeamento,Aldeamento,15,,-19.383333,-41.316667
br,aldeia 20 de septembro,Aldeia 20 de Septembro,14,,-12.883333,-59.3
br,aldeia,Aldeia,05,,-12.366667,-40
br,aldeia,Aldeia,11,,-18.2,-55.166667
br,aldeia,Aldeia,13,,-3.013889,-42.004167
br,aldeia,Aldeia,14,,-15.116667,-56.383333
br,aldeia,Aldeia,15,,-16.033333,-41.3
br,aldeia,Aldeia,17,,-7.35,-36.3
br,aldeia,Aldeia,20,,-7.383333,-40.85
br,aldeia,Aldeia,27,,-23.5,-46.85
br,aldeia,Aldeia,28,,-10.783333,-36.966667
br,aldeia,Aldeia,30,,-7.833333,-35.116667
br,aldeia,Aldeia,31,,-7.916667,-48.233333
br,aldeia amanajas tauai,Aldeia Amanajás Tauaí,13,,-4.533333,-47.366667
br,aldeia amanajaz tauai,Aldeia Amanajaz Tauaí,13,,-4.533333,-47.366667
br,aldeia amanajaz taudi,Aldeia Amanajaz Taudí,13,,-4.533333,-47.366667
br,aldeia bacaeri,Aldeia Bacaeri,14,,-13.1,-54.1
br,aldeia bacaery,Aldeia Bacaery,14,,-14.2,-55.083333
br,aldeia bakairi,Aldeia Bakairi,14,,-14.2,-55.083333
br,aldeia cabixi,Aldeia Cabixí,14,,-12.983333,-60.2
br,aldeia cabixy,Aldeia Cabixy,14,,-12.983333,-60.2
br,aldeia caiabi,Aldeia Caiabi,14,,-11.616667,-55.683333
br,aldeia campista,Aldeia Campista,21,,-22.917417,-43.237362
br,aldeia capitao carutu,Aldeia Capitão Carutú,14,,-14.316667,-54.7
br,aldeia caraja,Aldeia Carajá,14,,-10.5,-50.55
br,aldeia caraja,Aldeia Carajá,31,,-7.066667,-49.183333
br,aldeia caraja do capitao maloe,Aldeia Caraja do Capitão Maloé,31,,-11.566667,-50.666667
br,aldeia curipi,Aldeia Curipi,03,,3.716667,-51.683333
br,aldeia de bororo,Aldeia de Borôro,14,,-16.566667,-57.866667
br,aldeia de pedra,Aldeia de Pedra,13,,-5.833333,-45.933333
br,aldeia do cabo,Aldeia do Cabo,21,,-22.966667,-42.016667
br,aldeia do capitao chimang,Aldeia do Capitão Chimang,13,,-2.866667,-46.583333
br,aldeia do capitao mariquinhas,Aldeia do Capitão Mariquinhas,13,,-3.216667,-46.233333
br,aldeia do capitao piarru,Aldeia do Capitão Piarru,13,,-3.066667,-46.3
br,aldeia do inacio,Aldeia do Inácio,14,,-16.866667,-57.483333
br,aldeia do meio,Aldeia do Meio,31,,-7.066667,-49.183333
br,aldeia do meio caraja,Aldeia do Meio Carajá,31,,-7.066667,-49.183333
br,aldeia do prata,Aldeia do Prata,15,,-16.816667,-40.616667
br,aldeia do ranchao,Aldeia do Ranchão,14,,-12.883333,-59.016667
br,aldeia dos bororos,Aldeia dos Bororos,14,,-16.566667,-57.866667
br,aldeia dos caiapos,Aldeia dos Caiapós,15,,-19.85,-50.25
br,aldeia dos indios,Aldeia dos Índios,16,,-8.1,-54.616667
br,aldeia dos machacalis,Aldeia dos Machacalis,15,,-16.883333,-40.633333
br,aldeia fichada,Aldeia Fichada,16,,-7.35,-49.466667
br,aldeia indigena catuquina,Aldeia Indígena Catuquina,01,,-8.294444,-71.665833
br,aldeia indigena espirro,Aldeia Indígena Espirro,14,,-12.725,-59.966667
br,aldeia indigena ipixuna,Aldeia Indígena Ipixuna,16,,-4.773333,-52.505833
br,aldeia indigena man-azde,Aldeia Indígena Man-Âzde,14,,-13.051389,-59.870833
br,aldeia indigena serra azul,Aldeia Indígena Serra Azul,14,,-13.670833,-59.5875
br,aldeia jose coroado,Aldeia José Coroado,14,,-14.3,-54.7
br,aldeia manau,Aldeia Manau,16,,-8.75,-49.65
br,aldeia manuel antonio,Aldeia Manuel Antônio,16,,-3.15,-46.733333
br,aldeiamento,Aldeiamento,08,,-19.266667,-40.733333
br,aldeiamento,Aldeiamento,15,,-19.383333,-41.316667
br,aldeia nambikwara,Aldeia Nambikwara,14,,-12.75,-59.8
br,aldeia nhambiquara,Aldeia Nhambiquara,14,,-12.85,-59.3
br,aldeia palikur,Aldeia Palikur,03,,3.45,-51.5
br,aldeia paracanti,Aldeia Paracanti,16,,-8.455556,-49.583333
br,aldeia paracaty,Aldeia Paracaty,16,,-8.455556,-49.583333
br,aldeia parakana,Aldeia Parakanã,16,,-4.423889,-49.9775
br,aldeia pequena,Aldeia Pequena,16,,-8.416667,-49.833333
br,aldeia pirizal,Aldeia Pirizal,14,,-16.833333,-56.133333
br,aldeia queimada,Aldeia Queimada,14,,-14.45,-58.116667
br,aldeia ranchao,Aldeia Ranchão,14,,-12.883333,-59.016667
br,aldeias das canoas,Aldeias das Canoas,16,,.8,-55.85
br,aldeia toliri,Aldeia Tolirí,14,,-14.633333,-58.4
br,aldeia toloiri,Aldeia Toloiri,14,,-14.633333,-58.4
br,aldeia velha,Aldeia Velha,11,,-20.866667,-57.833333
br,aldeia velha,Aldeia Velha,13,,-5.15,-45.583333
br,aldeia velha,Aldeia Velha,14,,-14.683333,-59.183333
br,aldeia velha,Aldeia Velha,15,,-16.85,-40.583333
br,aldeia velha,Aldeia Velha,16,,-8.338056,-50.464444
br,aldeia velha,Aldeia Velha,17,,-7.083333,-35.866667
br,aldeia velha,Aldeia Velha,21,,-22.466667,-42.3
br,aldeia velha,Aldeia Velha,30,,-8.2,-36.466667
br,aldeia velha,Aldeia Velha,31,,-6.033333,-48.3
br,aldeia vila batista,Aldeia Vila Batista,04,,-1.933611,-61.203889
br,aldeia vinte de setembro,Aldeia Vinte de Setembro,14,,-12.883333,-59.3
br,aldeia waikiso,Aldeia Waikiso,14,,-14.1875,-59.683333
br,aldeia xada,Aldeia Xadá,04,,-4.540278,-59.168056
br,aldeia zamaicara,Aldeia Zamaicara,14,,-14.633333,-58.55
br,aldeia zamaicare,Aldeia Zamaicare,14,,-14.633333,-58.55
br,aldeia zamicare,Aldeia Zamicaré,14,,-14.633333,-58.55
br,aldeinha,Aldeinha,13,,-5.95,-45.033333
br,aldeola,Aldeola,01,,-8.216667,-72.966667
br,alecrim,Alecrim,02,,-9.566667,-37.316667
br,alecrim,Alecrim,05,,-12.583333,-38.933333
br,alecrim,Alecrim,06,,-3.466667,-40.133333
br,alecrim,Alecrim,15,,-16.465556,-44.8125
br,alecrim,Alecrim,18,,-23.6149,-49.7811
br,alecrim,Alecrim,20,,-6.95,-40.5
br,alecrim,Alecrim,22,,-5.512222,-37.413889
br,alecrim,Alecrim,23,,-27.65,-54.766667
br,alecrim,Alecrim,27,,-24.283333,-47.233333
br,alecrim,Alecrim,30,,-7.9,-39.583333
br,alegre,Alegre,04,,-5.816667,-61.416667
br,alegre,Alegre,05,,-10.316667,-41.45
br,alegre,Alegre,06,,-3.616667,-40.283333
br,alegre,Alegre,08,19758,-20.766667,-41.533333
br,alegre,Alegre,11,,-18.616667,-55.116667
br,alegre,Alegre,13,,-1.833333,-44.75
br,alegre,Alegre,14,,-15.247778,-59.833333
br,alegre,Alegre,15,,-18.3,-47.016667
br,alegre,Alegre,16,,-2.2,-48.5
br,alegre,Alegre,20,,-5.766667,-41.783333
br,alegre,Alegre,26,,-26.997859,-49.990577
br,alegre,Alegre,27,,-24.116667,-48.9
br,alegre,Alegre,30,,-7.916667,-38.216667
br,alegre de cima,Alegre de Cima,15,,-22.556896,-45.668764
br,alegres,Alegres,05,,-10.516667,-38.233333
br,alegres,Alegres,06,,-5.95,-40.1
br,alegrete,Alegrete,04,,-5.166667,-60.4
br,alegrete,Alegrete,11,,-20.766667,-55.4
br,alegrete,Alegrete,14,,-15.166667,-56.416667
br,alegrete,Alegrete,20,,-7.233333,-40.85
br,alegrete,Alegrete,23,77540,-29.766667,-55.766667
br,alegrete,Alegrete,29,,-17.3,-49.916667
br,alegre velho,Alegre Velho,20,,-6.833333,-42.35
br,alegria,Alegria,03,,.316667,-51.2
br,alegria,Alegria,04,,-2.633333,-67.45
br,alegria,Alegria,05,,-13.416667,-39.95
br,alegria,Alegria,08,,-19.416667,-40.616667
br,alegria,Alegria,11,,-19.683333,-55.65
br,alegria,Alegria,13,,-3.698889,-43.354444
br,alegria,Alegria,14,,-8.85,-58.466667
br,alegria,Alegria,15,,-15.5,-42.066667
br,alegria,Alegria,16,,-.6,-47.666667
br,alegria,Alegria,18,,-26.219167,-53.5325
br,alegria,Alegria,20,,-3.835278,-42.253889
br,alegria,Alegria,22,,-5.616667,-36.683333
br,alegria,Alegria,23,,-27.8,-54.066667
br,alegria,Alegria,27,,-22.516667,-50.916667
br,alegria nova,Alegria Nova,11,,-21.183333,-57.15
br,alegrias,Alegrias,23,,-31.833333,-53.416667
br,alegria velha,Alegria Velha,11,,-21.166667,-57.116667
br,aleixo,Aleixo,14,,-15.166667,-56.216667
br,aleixo,Aleixo,22,,-5.721389,-37.343056
br,aleixo,Aleixo,26,,-28.25,-50.45
br,aleluia,Aleluia,21,,-21.8,-41.633333
br,aleluia,Aleluia,27,,-23.260704,-47.92205
br,aleluia de baixo,Aleluia de Baixo,27,,-23.230149,-47.9321
br,alemao,Alemão,22,,-5.233611,-36.796111
br,alemao do francisco,Alemão do Francisco,05,,-12.783333,-38.85
br,alemoa,Alemôa,18,,-23.55,-49.7
br,alem parahyba,Alem Parahyba,15,,-21.866667,-42.683333
br,alem paraiba,Além Paraíba,15,33907,-21.866667,-42.683333
br,alemquer,Alemquer,16,,-1.933333,-54.766667
br,alem tejo,Além Tejo,20,,-6.033333,-41.966667
br,alencar,Alencar,06,,-6.4,-39.15
br,alenquer,Alenquer,16,26291,-1.933333,-54.766667
br,alexandra,Alexandra,18,,-25.566667,-48.616667
br,alexandre,Alexandre,14,,-8.7,-58.016667
br,alexandre bode,Alexandre Bode,08,,-20.133333,-40.95
br,alexandre de gusmao,Alexandre de Gusmão,23,,-28.816667,-51.8
br,alexandre mendes,Alexandre Mendes,20,,-3.779444,-42.443056
br,alexandria,Alexandria,22,9769,-6.416667,-38.016667
br,alexandria,Alexandria,30,,-8.183333,-39.7
br,alexandrina,Alexandrina,04,,.866667,-66.9
br,alexandrina,Alexandrina,30,,-8.183333,-39.7
br,alexandrita,Alexandrita,15,,-19.7,-50.45
br,alexrandina,Alexrandina,30,,-8.183333,-39.7
br,alfa barra,Alfa Barra,21,,-23.008452,-43.369043
br,alfenas,Alfenas,15,71407,-21.433333,-45.95
br,alferes,Alferes,06,,-5.95,-40.1
br,alferez,Alferez,06,,-5.95,-40.1
br,alfeu,Alfeu,23,,-28.95,-52.633333
br,alfonso bezerra,Alfonso Bezerra,22,,-5.498056,-36.509167
br,alfredo,Alfredo,15,,-17.066667,-40.816667
br,alfredo brener,Alfredo Brener,23,,-28.566667,-53.133333
br,alfredo brenner,Alfredo Brenner,23,,-28.566667,-53.133333
br,alfredo castilho,Alfredo Castilho,27,,-20.866667,-51.483333
br,alfredo chaves,Alfredo Chaves,08,6422,-20.633333,-40.75
br,alfredo chaves,Alfredo Chaves,23,,-28.95,-51.55
br,alfredo chavez,Alfredo Chavez,08,,-20.633333,-40.75
br,alfredo dantas,Alfredo Dantas,31,,-7.116667,-48.35
br,alfredo dutra,Alfredo Dutra,06,,-4.383333,-38.883333
br,alfredo guedes,Alfredo Guedes,27,,-22.583333,-48.716667
br,alfredo manso,Alfredo Manso,15,,-21.45,-46.133333
br,alfredo marcondes,Alfredo Marcondes,27,,-21.95,-51.416667
br,alfredo silveira,Alfredo Silveira,23,,-30.35,-52.083333
br,alfredo teixeira,Alfredo Teixeira,08,,-20.233333,-40.45
br,alfredo wagner,Alfredo Wagner,26,,-27.7,-49.333333
br,algeria,Algeria,15,,-15.5,-42.066667
br,algodao,Algodão,05,,-12.416667,-40.583333
br,algodao,Algodão,06,,-3.433333,-40.416667
br,algodao,Algodão,17,,-6.9,-36
br,algodao,Algodão,30,,-7.883333,-36.166667
br,algodoal,Algodoal,16,,-.6,-47.583333
br,algodoes,Algodões,05,,-10.2,-41.95
br,algodoes,Algodões,06,,-3.516667,-41.4
br,algodoes,Algodões,20,,-7.033333,-42.683333
br,algodoes,Algodões,30,,-7.666667,-39.6
br,algoinhas,Algoinhas,30,,-8.483333,-36.783333
br,alhandra,Alhandra,17,10788,-7.433333,-34.9
br,alho,Alho,05,,-16.933333,-39.716667
br,alianca,Aliança,04,,-2.917222,-69.685556
br,alianca,Aliança,05,,-12.466667,-38.683333
br,alianca,Alianca,06,,-4.733333,-38.516667
br,alianca,Aliança,11,,-19.05,-55.266667
br,alianca,Aliança,14,,-9.1,-60.583333
br,alianca,Aliança,15,,-19.6,-43.433333
br,alianca,Aliança,21,,-22.276667,-43.53
br,alianca,Aliança,24,,-8.616667,-63.533333
br,alianca,Aliança,26,,-27.2,-48.916667
br,alianca,Aliança,27,,-20.5,-47.316667
br,alianca,Aliança,30,17329,-7.583333,-35.216667
br,alianca do tocantins,Aliança do Tocantins,31,,-11.3375,-48.850278
br,alianca velha,Aliança Velha,18,,-25.966172,-50.249492
br,aliatar,Aliatar,26,,-28.7,-49.3
br,alice,Alice,03,,3.65,-51.983333
br,alipio,Alípio,27,,-21,-47.216667
br,alipio paca,Alípio Paca,15,,-17.15,-40.65
br,alivio,Alívio,06,,-5.083333,-38.716667
br,alivio,Alívio,13,,-4.9,-44.583333
br,alivio,Alívio,17,,-6.583333,-38.15
br,alivio,Alívio,20,,-3.869444,-42.303333
br,alivio,Alívio,22,,-5.636944,-36.141111
br,aljezur,Aljezur,21,,-22.666667,-43.6
br,aljubarrota,Aljubarrota,04,,-4.297222,-69.5375
br,allemoa,Allemõa,18,,-23.55,-49.7
br,allianca,Alliança,04,,-6.583333,-64.35
br,allianca,Alliança,14,,-9.1,-60.583333
br,allianca,Alliança,15,,-19.6,-43.433333
br,allianca,Allianca,24,,-8.616667,-63.533333
br,allianca,Alliança,26,,-27.2,-48.916667
br,allianca,Alliança,30,,-7.583333,-35.216667
br,almadina,Almadina,05,,-14.7,-39.633333
br,almas,Almas,05,,-10.3,-41.4
br,almas,Almas,06,,-2.895,-41.275833
br,almas,Almas,13,,-3.780278,-42.829167
br,almas,Almas,15,,-19.15,-44.633333
br,almas,Almas,17,,-6.65,-37.683333
br,almas,Almas,20,,-3.579167,-42.0275
br,almas,Almas,30,,-7.85,-37.883333
br,almas,Almas,31,,-11.626111,-47.101667
br,almecega,Almécega,20,,-7.016667,-42.516667
br,almecegas,Almécegas,13,,-5.866667,-43.1
br,almecegas,Almécegas,20,,-5.85,-43.083333
br,almecega velha,Almécega Velha,06,,-2.9,-40
br,almeida,Almeida,05,,-13.45,-39.433333
br,almeida,Almeida,13,,-5.916667,-44.15
br,almeida,Almeida,15,,-19.433333,-43.833333
br,almeida,Almeida,18,,-25.331473,-48.4179
br,almeida,Almeida,20,,-5.566667,-42.366667
br,almeida,Almeida,21,,-21.2,-41.716667
br,almeida,Almeida,30,,-7.7,-37.833333
br,almeidas,Almeidas,15,,-22.366667,-46.533333
br,almeirim,Almeirim,16,20464,-1.533333,-52.566667
br,almenara,Almenara,15,29333,-16.183333,-40.7
br,almendra,Almendra,25,,-1.3,-61.7
br,almeriana,Almeriana,03,,2.3,-50.75
br,almerim,Almerim,16,,-1.533333,-52.566667
br,almesca,Almesca,13,,-5.866667,-43.1
br,almescar,Almescar,13,,-5.866667,-43.1
br,almesquinha,Almesquinha,13,,-6.016667,-43.066667
br,almesquinho,Almesquinho,13,,-6.016667,-43.066667
br,almfala,Almfala,06,,-2.933333,-39.816667
br,almino affonso,Almino Affonso,22,,-6.15,-37.766667
br,almino afonso,Almino Afonso,22,,-6.15,-37.766667
br,almirante tamandare,Almirante Tamandaré,18,89500,-25.3,-49.316667
br,almirante tamandare,Almirante Tamandaré,23,,-28.1,-52.916667
br,almoco,Almôço,16,,-1.25,-46.916667
br,almofada,Almofada,06,,-3.033333,-39.883333
br,almofala,Almofala,06,,-3.033333,-39.883333
br,aloandia,Aloândia,29,,-17.716667,-49.483333
br,alpercata,Alpercata,13,,-3.655833,-43.483056
br,alpercata,Alpercata,15,,-19.016667,-41.983333
br,alpes da cantareira,Alpes da Cantareira,27,,-23.411082,-46.647701
br,alpes de caieiras,Alpes de Caieiras,27,,-23.378383,-46.677328
br,alpestre,Alpestre,23,,-27.25,-53.033333
br,alpinino,Alpinino,30,,-8.533333,-36.4
br,alpinopolis,Alpinópolis,15,13286,-20.866667,-46.383333
br,alta,Alta,06,,-3.333333,-40.083333
br,alta floresta,Alta Floresta,14,40468,-9.9,-55.9
br,altair,Altair,27,,-20.516667,-49.066667
br,altamira,Altamira,04,,1.666667,-67.2
br,altamira,Altamira,05,,-11.066667,-45.416667
br,altamira,Altamira,07,,-15.616667,-47.666667
br,altamira,Altamira,13,,-5.733333,-45.6
br,altamira,Altamira,15,,-19.55,-43.566667
br,altamira,Altamira,16,70890,-3.2,-52.2
br,altamira,Altamira,20,,-3.767222,-42.578889
br,altamira do maranhao,Altamira do Maranhão,13,,-4.166667,-45.483333
br,alta mir,Alta Mir,07,,-15.616667,-47.666667
br,altaneira,Altaneira,06,,-6.983333,-39.733333
br,altaneira,Altaneira,18,,-23.166667,-52.033333
br,altaneiras,Altaneiras,18,,-23.166667,-52.033333
br,alteado,Alteado,15,,-14.633333,-44.866667
br,alter do chao,Alter do Chão,16,,-2.516667,-54.95
br,alterosa,Alterosa,15,9277,-21.25,-46.133333
br,altidao,Altidão,20,,-4.75,-41.8
br,altinho,Altinho,20,,-3.905278,-42.022222
br,altinho,Altinho,30,11913,-8.483333,-36.066667
br,altino,Altino,15,,-16.416667,-40.333333
br,altinopolis,Altinópolis,27,14616,-21.025278,-47.374444
br,alto alegre,Alto Alegre,01,,-10.616667,-68.183333
br,alto alegre,Alto Alegre,05,,-11.666667,-39.85
br,alto alegre,Alto Alegre,13,,-3.116667,-45.666667
br,alto alegre,Alto Alegre,18,,-22.866667,-51.866667
br,alto alegre,Alto Alegre,20,,-4.016667,-41.433333
br,alto alegre,Alto Alegre,22,,-5.8225,-37.410556
br,alto alegre,Alto Alegre,23,,-28.783333,-53
br,alto alegre,Alto Alegre,24,,-12.133333,-61.858333
br,alto alegre,Alto Alegre,27,,-21.566667,-50.166667
br,alto alegre,Alto Alegre,30,,-7.683333,-39.6
br,alto alegre dos parecis,Alto Alegre dos Parecis,24,,-12.133333,-61.858333
br,alto allegre,Alto Allegre,23,,-30.7232,-52.3438
br,alto,Alto,02,,-9.266667,-38.033333
br,alto,Alto,05,,-12.683333,-39.35
br,alto,Alto,13,,-3.014444,-42.079722
br,alto,Alto,21,,-22.44165,-42.98381
br,alto,Alto,30,,-8.3,-38.566667
br,alto amparo,Alto Amparo,18,,-24.783333,-50.533333
br,alto araguaia,Alto Araguaia,14,8780,-17.316667,-53.2
br,alto atafona,Alto Atafona,26,,-27.12944,-49.506696
br,alto bela alianca,Alto Bela Aliança,26,,-27.2261,-49.5749
br,alto bela vista,Alto Bela Vista,26,,-27.433333,-51.866667
br,alto belo,Alto Belo,20,,-5.983333,-42.316667
br,alto bergamo,Alto Bergamo,08,,-19.766667,-40.45
br,alto bergano,Alto Bergano,08,,-19.766667,-40.45
br,alto bonito,Alto Bonito,02,,-9.383333,-38.066667
br,alto bonito,Alto Bonito,05,,-11.733333,-40.4
br,alto bonito,Alto Bonito,06,,-3.833333,-41.283333
br,alto bonito,Alto Bonito,13,,-3.133333,-42.2
br,alto bonito,Alto Bonito,16,,-4.116667,-51.916667
br,alto bonito,Alto Bonito,20,,-3.555278,-42.243056
br,alto bonito,Alto Bonito,30,,-8.516667,-35.8
br,alto calcado,Alto Calçado,08,,-20.95,-41.616667
br,alto caminho da paz,Alto Caminho da Paz,26,,-26.978721,-49.835948
br,alto caminho do anum,Alto Caminho do Anum,26,,-26.947504,-49.778617
br,alto cananeia,Alto Cananéia,26,,-26.8391,-49.0063
br,alto capim,Alto Capim,15,,-19.85,-41.25
br,alto capivari,Alto Capivari,26,,-26.796349,-49.538043
br,alto cascavel,Alto Cascavel,18,,-25.4,-51.533333
br,alto coite,Alto Coité,14,,-15.783333,-54.333333
br,alto cutia,Alto Cutia,26,,-27.233112,-49.520823
br,alto da betania,Alto da Betânia,20,,-6.033333,-41.983333
br,alto da boa vista,Alto da Boa Vista,21,,-22.96519,-43.276055
br,alto da conceicao,Alto da Conceição,15,,-21.833333,-42.866667
br,alto da conceicao,Alto da Conceição,30,,-8.816667,-36.033333
br,alto da cruz,Alto da Cruz,20,,-5.3,-42.8
br,alto da doca,Alto da Doca,13,,-5.716667,-46.4
br,alto da gloria,Alto da Glória,18,,-25.60307,-50.69018
br,alto da grota funda,Alto da Grota Funda,02,,-9.733333,-37.433333
br,alto da jurema,Alto da Jurema,05,,-11.166667,-41.883333
br,alto da manela,Alto da Manela,20,,-6.333333,-41.95
br,alto da nova,Alto Da Nova,30,,-7.9,-38.683333
br,alto da piedade,Alto da Piedade,27,,-23.747202,-47.426103
br,alto da serra,Alto da Serra,18,,-25.8522,-48.9256
br,alto da serra,Alto da Serra,21,,-22.883333,-44.233333
br,alto da serra,Alto da Serra,27,,-23.783333,-46.316667
br,alto das pedras,Alto das Pedras,13,,-4.05,-44.933333
br,alto das piabas,Alto das Piabas,05,,-14.25,-39.95
br,alto da uniao,Alto da União,23,,-28.45,-53.866667
br,alto da varzea,Alto da Várzea,06,,-6.516667,-38.666667
br,alto de pedra,Alto de Pedra,13,,-4.05,-44.933333
br,alto de pedro,Alto de Pedro,30,,-7.983333,-38.033333
br,alto de santa helena,Alto de Santa Helena,15,,-18.6,-41.616667
br,alto de santa maria,Alto de Santa Maria,08,,-20.15,-40.9
br,alto de santo antonio,Alto de Santo Antônio,30,,-8.75,-36.183333
br,alto de sao antonio,Alto de São Antônio,08,,-19.833333,-40.65
br,alto de sao joao,Alto de São João,15,,-18.566667,-48.316667
br,alto do amparo,Alto do Amparo,18,,-24.783333,-50.533333
br,alto do bagre,Alto do Bagre,06,,-5.016667,-37.933333
br,alto do bonfim,Alto do Bonfim,05,,-9.666667,-43.366667
br,alto do catingueiro,Alto do Catingueiro,30,,-8.916667,-37.316667
br,alto do cobre,Alto do Cobre,18,,-25.116667,-52.133333
br,alto do coqueiro,Alto do Coqueiro,13,,-5.85,-43.183333
br,alto do doca,Alto do Doca,13,,-5.716667,-46.4
br,alto do feto,Alto do Feto,05,,-13.483333,-40.183333
br,alto do gloria,Alto do Glória,18,,-25.615365,-50.692288
br,alto do maranhao,Alto do Maranhão,15,,-20.566667,-43.866667
br,alto do matias,Alto do Matias,30,,-8.366667,-36.433333
br,alto do meio,Alto do Meio,20,,-6.416667,-42
br,alto do melo,Alto do Melo,05,,-12.4,-40.083333
br,alto do peba,Alto do Peba,02,,-9.25,-37.816667
br,alto do rodrigues,Alto do Rodrigues,22,,-5.289444,-36.761111
br,alto do sabia,Alto do Sabía,27,,-23.512018,-47.004669
br,alto dos coelhos,Alto dos Coelhos,17,,-7.366667,-38.166667
br,alto dos coelhos,Alto dos Coelhos,20,,-9.366667,-37.916667
br,alto dos gomes,Alto dos Gomes,17,,-6.566667,-38.45
br,alto dos pareiros,Alto dos Pareiros,20,,-9.366667,-37.916667
br,alto dos pereiras,Alto dos Pereiras,20,,-9.366667,-37.916667
br,alto do velame,Alto do Velame,06,,-4.95,-37.966667
br,alto do vista,Alto do Vista,20,,-6.25,-42.383333
br,alto faxinal,Alto Faxinal,26,,-26.875065,-49.929655
br,alto formoso,Alto Formoso,13,,-3.399444,-42.618611
br,alto formoso,Alto Formoso,20,,-6.9,-42.216667
br,alto garcas,Alto Garças,14,,-16.933333,-53.533333
br,alto garcia,Alto Garcia,26,,-26.9882,-49.085
br,alto grande,Alto Grande,06,,-4.05,-38.9
br,alto grande,Alto Grande,20,,-7.9,-41.3
br,alto grande,Alto Grande,22,,-5.866667,-37.254167
br,alto guandu,Alto Guandu,15,,-20.033333,-41.35
br,alto itauna,Alto Itaúna,08,,-18.1,-40.516667
br,alto itaunas,Alto Itaúnas,08,,-18.1,-40.516667
br,alto itoupava,Alto Itoupava,26,,-27.142099,-49.656141
br,alto lajeado,Alto Lajeado,27,,-20.2,-47.333333
br,alto leblon,Alto Leblon,21,,-22.984687,-43.233344
br,alto lindo,Alto Lindo,13,,-3.405278,-42.605556
br,alto longa,Alto Longá,20,4435,-5.25,-42.2
br,alto madeira,Alto Madeira,24,,-8.8,-63.933333
br,alto maranhao,Alto Maranhão,15,,-20.566667,-43.866667
br,alto mimaso,Alto Mimaso,20,,-5.6,-42.133333
br,alto mutum preto,Alto Mutum Prêto,08,,-19.266667,-40.9
br,altona,Altona,26,,-27.116667,-49.5
br,altonia,Altônia,18,11242,-23.933333,-53.9
br,alto nova esperanca,Alto Nova Esperança,26,,-26.992078,-49.806155
br,alto novo,Alto Novo,05,,-12.266667,-39.333333
br,alto novo,Alto Novo,20,,-5.616667,-42.216667
br,alto padre andre,Alto Padre André,27,,-24.620278,-48.0475
br,alto palmital,Alto Palmital,26,,-26.9007,-49.9145
br,alto paraguai,Alto Paraguai,14,6149,-14.5,-56.516667
br,alto paraguai do diamantino,Alto Paraguai do Diamantino,14,,-14.416667,-56.45
br,alto paraiso de goias,Alto Paraíso de Goiás,29,,-14.116667,-47.516667
br,alto parana,Alto Paraná,18,10888,-23.083333,-52.366667
br,alto parnaiba,Alto Parnaíba,13,,-9.1,-45.95
br,alto patrao mor,Alto Patrão Mor,08,,-19.45,-40.45
br,alto pau d'alho,Alto Pau d'Alho,18,,-23.516667,-50.883333
br,alto perimbo,Alto Perimbó,26,,-27.533333,-49.7
br,alto pimenta,Alto Pimenta,27,,-21.283333,-50.8
br,alto piquiri,Alto Piquiri,18,10039,-24.016667,-53.466667
br,alto pora,Alto Porã,27,,-20.066667,-47.5
br,alto quatipuru,Alto Quatipurú,16,,-1.083333,-46.9
br,alto queiroga,Alto Queiroga,15,,-19.216667,-41.916667
br,alto rafael,Alto Rafael,26,,-26.961875,-49.53026
br,alto ribeirao cambara,Alto Ribeirão Cambará,26,,-26.9134,-49.8399
br,alto ribeirao da laje,Alto Ribeirão da Laje,26,,-26.893382,-49.581326
br,alto rio bravo,Alto Rio Bravo,26,,-28.016667,-49.066667
br,alto rio doce,Alto Rio Doce,15,,-21.033333,-43.416667
br,alto rio forcacao,Alto Rio Forcação,26,,-26.747923,-49.632976
br,alto rio krauel,Alto Rio Krauel,26,,-26.973,-49.9346
br,alto rio novo,Alto Rio Novo,08,,-19.066667,-41.016667
br,alto rio preto,Alto Rio Preto,26,,-26.569104,-49.605047
br,alto rio scharlach,Alto Rio Scharlach,26,,-26.921018,-49.563472
br,altos,Altos,06,,-7.25,-40.15
br,altos,Altos,20,28769,-5.05,-42.466667
br,altos,Altos,22,,-5.3,-35.716667
br,alto santa helena,Alto Santa Helena,15,,-18.6,-41.616667
br,alto santa maria,Alto Santa Maria,08,,-19.9,-40.75
br,alto santa maria do rio doce,Alto Santa Maria do Rio Doce,08,,-19.9,-40.75
br,alto santo,Alto Santo,01,,-9.954722,-67.863889
br,alto santo,Alto Santo,06,,-5.516667,-38.25
br,alto santo antonio,Alto Santo Antônio,30,,-8.75,-36.183333
br,alto sao francisco,Alto São Francisco,08,,-18.85,-41.033333
br,alto sao joao,Alto São João,15,,-18.566667,-48.316667
br,alto seco,Alto Sêco,05,,-13.083333,-39.516667
br,alto sereno,Alto Sereno,20,,-6.983333,-42.4
br,alto sucuriu,Alto Sucuriú,11,,-19.316667,-52.783333
br,altos verdes,Altos Verdes,28,,-10.416667,-37.65
br,alto turi,Alto Turi,13,,-2.9,-45.633333
br,alto uru,Alto Uru,26,,-27.0151,-49.6723
br,alto uruguai,Alto Uruguai,23,,-27.3,-54.133333
br,alto uruguay,Alto Uruguay,23,,-27.3,-54.133333
br,alto verde,Alto Verde,20,,-5.633333,-41.283333
br,alto vere,Alto Verê,18,,-25.916667,-52.983333
br,alto vigante,Alto Vigante,26,,-26.825337,-49.608486
br,alto xarqueada,Alto Xarqueada,23,,-29.1729,-51.2185
br,alunas,Alunas,05,,-13.2,-39.3
br,alvacao,Alvação,13,,-6.7,-43.883333
br,alvacao,Alvação,15,,-16.432778,-44.283611
br,alvalhado,Alvalhado,20,,-7.266667,-41.6
br,alvaraes,Alvarães,04,5527,-3.2,-64.833333
br,alvareda,Alvareda,15,,-20.716667,-42.15
br,alvarenga,Alvarenga,15,,-19.416667,-41.733333
br,alvares florence,Álvares Florence,27,,-20.316667,-49.9
br,alvares machado,Álvares Machado,27,21642,-22.133333,-51.5
br,alvaro,Álvaro,04,,-7.283333,-72.35
br,alvaro de carvalho,Álvaro de Carvalho,27,,-22.1,-49.716667
br,alvaro melo,Álvaro Melo,15,,-21.166667,-47.066667
br,alvejado,Alvejado,22,,-5.938056,-36.790833
br,alvellos,Alvellos,04,,-4.1,-63.3
br,alvelos,Alvelos,04,,-4.1,-63.3
br,alves,Alves,15,,-18.166667,-42.75
br,alves,Alves,23,,-29.366667,-54.733333
br,alves,Alves,27,,-23.671212,-47.664083
br,alves lima,Alves Lima,27,,-21.916667,-50.233333
br,alvim fabricio,Alvim Fabrício,15,,-20.85,-45.633333
br,alvimlandia,Alvimlândia,27,,-22.45,-49.766667
br,alvinandia,Alvinândia,27,,-22.45,-49.766667
br,alvinlandia,Alvinlândia,27,,-22.45,-49.766667
br,alvino,Alvino,05,,-12.183333,-37.933333
br,alvinopolis,Alvinópolis,15,12068,-20.1,-43.05
br,alvino vieira,Alvino Vieira,15,,-17.066667,-41.65
br,alvorada,Alvorada,04,,-5.431389,-60.459167
br,alvorada,Alvorada,05,,-16.516667,-39.35
br,alvorada,Alvorada,06,,-5.933333,-40.55
br,alvorada,Alvorada,11,,-17.216667,-56.033333
br,alvorada,Alvorada,15,,-19.333333,-48.333333
br,alvorada,Alvorada,20,,-6.066667,-41.883333
br,alvorada,Alvorada,22,,-5.95,-35.55
br,alvorada,Alvorada,23,,-28.666667,-52.15
br,alvorada,Alvorada,31,10232,-12.47,-49.082222
br,alvorada do sul,Alvorada do Sul,18,,-22.783333,-51.183333
br,amacia,Amaciã,04,,-5.605833,-64.215278
br,amadeu amaral,Amadeu Amaral,27,,-22.366667,-50.05
br,amado bahia,Amado Bahia,05,,-12.55,-38.3
br,amado baia,Amado Baía,05,,-12.55,-38.3
br,amados,Amados,18,,-25.855418,-50.043221
br,amambai,Amambaí,11,20261,-23.083333,-55.216667
br,amambera,Amamberá,23,,-28.366667,-53.25
br,amana,Amaná,08,,-20.933333,-41.15
br,amanaiara,Amanaiara,06,,-4.066667,-40.533333
br,amanaju,Amanaju,06,,-5.5,-39.366667
br,aman,Aman,21,,-22.3922,-44.4823
br,amanari,Amanari,06,,-4.016667,-38.866667
br,amancio bento,Amâncio Bento,15,,-20.133333,-45.133333
br,amanda,Amanda,15,,-19.366667,-43.883333
br,amandaba,Amandaba,27,,-21.083333,-51.15
br,amanhece,Amanhece,15,,-18.55,-48.233333
br,amaniu,Amaniú,05,,-10.333333,-41.833333
br,amaniutuba,Amaniutuba,06,,-6.666667,-38.883333
br,amapa,Amapá,01,,-10.3,-69.3
br,amapa,Amapá,03,6256,2.05,-50.8
br,amapa,Amapá,04,,-5.45,-60.583333
br,amapa,Amapá,13,,-3.140556,-43.293333
br,amapa,Amapá,20,,-5.666667,-41.716667
br,amapari,Amapari,03,,.616667,-51.65
br,amapora,Amaporã,18,,-23.033333,-52.833333
br,amaragi,Amaragi,30,,-8.4,-35.45
br,amaragi d'agua,Amaragi d'Agua,30,,-8.4,-35.433333
br,amaragy,Amaragy,30,,-8.4,-35.45
br,amaraji,Amaraji,30,16660,-8.4,-35.45
br,amaraji d'agua,Amaraji d'Agua,30,,-8.4,-35.433333
br,amaral ferrador,Amaral Ferrador,23,,-30.866667,-52.25
br,amaralina,Amaralina,05,,-13.016667,-38.466667
br,amarante,Amarante,15,,-20.316667,-43.716667
br,amarante,Amarante,20,8828,-6.233333,-42.833333
br,amarante do grajau,Amarante do Grajau,13,,-5.6,-46.75
br,amarante do maranhao,Amarante do Maranhão,13,11510,-5.6,-46.75
br,amarantina,Amarantina,15,,-20.316667,-43.716667
br,amarela,Amarela,06,,-2.936111,-41.042222
br,amarelao,Amarelão,22,,-5.5,-35.9
br,amarelo,Amarelo,20,,-6.866667,-41.016667
br,amarelo ferrado,Amarelo Ferrado,20,,-6.85,-40.933333
br,amarelos,Amarelos,08,,-20.533333,-40.483333
br,amargosa,Amargosa,02,,-9.616667,-37.183333
br,amargosa,Amargosa,05,22531,-13.033333,-39.6
br,amargosa,Amargosa,20,,-6.1,-41.183333
br,amargoso,Amargoso,22,,-5.229722,-36.562778
br,amarilis,Amarílis,27,,-22.3,-50.283333
br,amaro,Amaro,06,,-6.816667,-39.683333
br,amaro,Amaro,11,,-21.716667,-56.583333
br,amaro,Amaro,18,,-25.889924,-50.027985
br,amaro,Amaro,25,,4.5,-60.116667
br,amaro,Amaro,30,,-8.783333,-37.05
br,amaro leite,Amaro Leite,13,,-8.966667,-46.866667
br,amaro leite,Amaro Leite,29,,-13.966667,-49.15
br,amaropolis,Amarópolis,23,,-29.933333,-51.9
br,amaro ribeiro,Amaro Ribeiro,15,,-20.7,-43.816667
br,amaro tempo,Amaro Tempo,15,,-17.083333,-40.816667
br,amarracao,Amarração,05,,-13.116667,-40.233333
br,amarracao,Amarracão,06,,-6.666667,-38.666667
br,amarracao,Amarração,20,,-2.883611,-41.666111
br,amatari,Amatari,04,,-3.266667,-58.883333
br,amataura,Amataurá,04,,-3.483333,-68.1
br,amatura,Amaturá,04,,-3.483333,-68.1
br,amazonas,Amazonas,05,,-12.466667,-40.883333
br,amazonas,Amazonas,17,,-6.1,-37.266667
br,amazonas,Amazonas,21,,-22.05,-41.833333
br,amazonas,Amazonas,22,,-5.291111,-36.009722
br,amazonia,Amazônia,05,,-12.166667,-39.333333
br,ambe,Ambé,03,,.333333,-50.916667
br,ambe,Ambé,16,,-3.15,-52.216667
br,ambicao,Ambição,11,,-21.366667,-56.216667
br,ambo,Ambó,17,,-7.683333,-36.216667
br,ambo,Ambó,30,,-7.383333,-37.266667
br,ambrosio aires,Ambrósio Aires,04,,-3.583333,-59.133333
br,ambrosio,Ambrósio,04,,-2.866667,-68.35
br,ambrosio,Ambrósio,05,,-10.983333,-39.216667
br,ambrosio,Ambrósio,20,,-7.85,-44.55
br,ambrosio,Ambrósio,25,,2.8,-60.25
br,ambrosio,Ambrósio,26,,-28.033333,-48.7
br,ambrosio,Ambrósio,30,,-8.816667,-38.566667
br,ambrosio vicente,Ambrósio Vicente,15,,-17.3,-41.683333
br,ambrozio,Ambrózio,30,,-7.583333,-39.866667
br,ameixa,Ameixa,17,,-6.516667,-37.7
br,ameixa,Ameixa,22,,-5.283333,-35.866667
br,ameixa,Ameixa,30,,-8.1,-35.783333
br,ameixas,Ameixas,30,,-8.1,-35.783333
br,amelia,Amelia,01,,-10.466667,-68.05
br,ameliopolis,Ameliópolis,27,,-21.833333,-51.3
br,amendoim,Amendoim,15,,-17.933333,-45.666667
br,america,América,04,,-5.166667,-60.433333
br,america,América,05,,-13.683333,-40.116667
br,america,América,08,,-21.166667,-41.433333
br,america,América,18,,-25.516667,-48.883333
br,america de baixo,América de Baixo,18,,-25.48983,-48.854266
br,america de cima,América de Cima,18,,-25.47675,-48.863254
br,america dourada,América Dourada,05,14018,-11.466667,-41.433333
br,americana,Americana,27,196026,-22.740278,-47.334444
br,americaninhas,Americaninhas,15,,-17.133333,-41.2
br,americano,Americano,16,,-1.316667,-48.066667
br,americano,Americano,27,,-23.325906,-47.776798
br,americano brasil,Americano Brasil,29,,-16.333333,-50.016667
br,americano do brasil,Americano do Brasil,29,,-16.333333,-50.016667
br,americas park,Américas Park,21,,-23.000375,-43.390957
br,americo alves,Américo Alves,05,,-9.683333,-41.583333
br,americo brasiliense,Américo Brasiliense,27,34332,-21.716667,-48.116667
br,americo de campos,Américo de Campos,27,,-20.3,-49.716667
br,americo v rech,Américo V Rech,23,,-29.0491,-51.1167
br,ametista,Ametista,08,,-18.883333,-41.1
br,ametista,Ametista,15,,-18.683333,-41.2
br,ametistas,Ametistas,23,,-28.316667,-52.05
br,amianto,Amianto,05,,-12.25,-40.666667
br,amianto,Amianto,15,,-20.116,-43.8795
br,amizade,Amizade,16,,-1.166667,-49.633333
br,amola faca,Amola Faca,26,,-27.783333,-50.483333
br,amolar,Amolar,02,,-9.183333,-36.133333
br,amolar,Amolar,11,,-18.016667,-57.5
br,amolar,Amolar,20,,-7.383333,-42.916667
br,amolar,Amolar,30,,-7.75,-39.283333
br,amontada,Amontada,06,13520,-3.383333,-39.833333
br,amontoado,Amontoado,21,,-21.333333,-41.05
br,amora preta,Amora Preta,18,,-23.899618,-50.294824
br,amoreira,Amoreira,05,,-13.95,-41.966667
br,amoreira,Amoreira,18,,-23.466667,-50.75
br,amoreira,Amoreira,27,,-20.433333,-48.583333
br,amorim,Amorim,08,,-20.533333,-41.416667
br,amorinha,Amorinha,18,,-23.889158,-50.243729
br,amorinopolis,Amorinópolis,29,,-16.6,-51.133333
br,amoro,Amoro,05,,-12.916667,-39.266667
br,amoroso,Amoroso,22,,-5.033333,-37.383333
br,amparinho,Amparinho,17,,-7.65,-37.016667
br,amparo,Amparo,05,,-11.05,-38.433333
br,amparo,Amparo,11,,-19.45,-55.566667
br,amparo,Amparo,15,,-19.7,-43.466667
br,amparo,Amparo,17,,-7.566667,-37.05
br,amparo,Amparo,18,,-24.783333,-50.533333
br,amparo,Amparo,21,,-21.75,-41.133333
br,amparo,Amparo,27,41498,-22.7,-46.783333
br,amparo,Ampáro,28,,-10.133333,-36.916667
br,amparo da serra,Amparo da Serra,15,,-20.516667,-42.816667
br,amparo de sao francisco,Amparo de São Francisco,28,,-10.133333,-36.916667
br,amparo do sao francisco,Amparo do São Francisco,28,,-10.133333,-36.916667
br,amparo do sitio,Amparo do Sítio,15,,-16.35,-41.983333
br,amparro da serra,Amparro da Serra,15,,-20.516667,-42.816667
br,ampere,Ampère,18,14275,-25.916667,-53.466667
br,amuamuaipe,Amuamuaipe,16,,1.916667,-54.966667
br,amuamuatpe,Amuamuatpe,16,,1.916667,-54.966667
br,amuri camaizore,Amuri Camaizorê,14,,-14.75,-58.05
br,amuri camalzore,Amuri Camalzorê,14,,-14.75,-58.05
br,anacetaba,Anacetaba,06,,-3.6,-38.966667
br,anacleto,Anacleto,15,,-20.033333,-46.366667
br,anacory,Anacory,04,,-5.664167,-63.131667
br,anadia,Anadia,02,9574,-9.7,-36.3
br,ana dias,Ana Dias,27,,-24.3,-47.066667
br,anafama,Anafamá,04,,-7.083333,-64.6
br,ana farias da luz,Ana Farias da Luz,23,,-30.583333,-55.816667
br,anage,Anagé,05,3762,-14.6,-41.133333
br,ana gomes,Ana Gomes,15,,-20.133333,-45
br,anaja,Anajá,13,,-3.673611,-43.2975
br,anaja,Anajá,20,,-3.599167,-42.444167
br,anaja dos pereiras,Anajá dos Pereiras,20,,-3.544444,-42.46
br,anajas,Anajás,16,,-.983333,-49.95
br,anajateua,Anajateua,16,,-3.1,-46.7
br,anajatuba,Anajatuba,04,,-7.016667,-57.833333
br,anajatuba,Anajatuba,13,5627,-3.266667,-44.616667
br,anajatuba,Anajatuba,16,,-4.116667,-56.6
br,anajazal,Anajazal,13,,-3.554722,-43.175
br,anajaz,Anajaz,16,,-.983333,-49.95
br,anajazinho,Anajazinho,13,,-3.371667,-42.503056
br,anaje,Anaje,05,,-14.6,-41.133333
br,analandia,Analândia,27,,-22.133333,-47.65
br,anama,Anamã,04,,-3.583333,-61.366667
br,anaman,Anamãn,04,,-3.583333,-61.366667
br,ananas,Ananás,13,,-3.659167,-43.297222
br,ananas,Ananás,20,,-9.905833,-45.038611
br,ananas,Ananás,31,8874,-6.360278,-47.91
br,ananatuba,Ananatuba,16,,-.583333,-49.183333
br,ananindeua,Ananindeua,16,433956,-1.366667,-48.383333
br,anapolandia,Anapolândia,31,,-7.1,-48.133333
br,anapolis,Anápolis,27,,-22.133333,-47.65
br,anapolis,Anápolis,28,,-10.733333,-37.816667
br,anapolis,Anápolis,29,319592,-16.333333,-48.966667
br,anapurus,Anapurus,13,,-3.205278,-42.408889
br,ana rech,Ana Rech,23,,-29.1119,-51.087
br,anastacio,Anastácio,11,18817,-20.516667,-55.8
br,anastacio,Anastácio,15,,-17.366667,-41.3
br,anastacio,Anastácio,20,,-6.933333,-40.883333
br,anati,Anati,04,,1.016667,-67.45
br,anaua,Anauá,06,,-7.25,-38.633333
br,anaurilandia,Anaurilândia,11,,-22.05,-52.75
br,ancari,Ancari,04,,-5.664167,-63.131667
br,anchieta,Anchieta,04,,.566667,-69.8
br,anchieta,Anchieta,05,,-13.15,-41.8
br,anchieta,Anchieta,08,,-20.8,-40.65
br,anchieta,Anchieta,20,,-6.866667,-40.75
br,anchieta,Anchieta,21,,-22.82327,-43.396679
br,anchieta,Anchieta,26,,-26.55,-53.283333
br,ancora,Ancora,17,,-7.55,-37.783333
br,ancori,Ancori,04,,-5.664167,-63.131667
br,ancuri,Ancuri,06,,-3.866667,-38.516667
br,andaia,Andaiá,05,,-12.866667,-39.35
br,andaia,Andaiá,15,,-20.116667,-41.566667
br,andarahy,Andarahy,04,,-5.65,-63.183333
br,andarahy,Andarahy,05,,-12.8,-41.333333
br,andarai,Andaraí,04,,-5.589444,-63.289167
br,andarai,Andaraí,05,,-11.733333,-40.616667
br,andarai,Andaraí,13,,-5.083333,-45.883333
br,andarai,Andaraí,21,,-22.931086,-43.253221
br,andarico,Andarico,11,,-22.1,-56.266667
br,anderai,Anderai,04,,-5.65,-63.183333
br,andes,Andes,08,,-20.983333,-41.283333
br,andira,Andira,04,,-2.85,-57
br,andira,Andirá,18,20758,-23.0488,-50.2276
br,andiroba,Andiroba,04,,-3.551111,-60.471944
br,andiroba,Andiroba,13,,-3.5075,-43.246944
br,andirobal,Andirobal,13,,-3.8,-45.166667
br,andorinha,Andorinha,05,,-10.366667,-39.816667
br,andorinhas,Andorinhas,18,,-23.833333,-51.266667
br,andradas,Andradas,15,26773,-22.066667,-46.566667
br,andradas,Andradas,21,,-22.276375,-42.969252
br,andrade,Andrade,04,,-4.508889,-63.556944
br,andrade,Andrade,15,,-21.016667,-42.966667
br,andrade,Andrade,21,,-22.243056,-43.424167
br,andrade araujo,Andrade Araujo,21,,-22.754546,-43.416973
br,andrade costa,Andrade Costa,21,,-22.254167,-43.364444
br,andrade pinto,Andrade Pinto,21,,-22.243056,-43.424167
br,andradina,Andradina,27,52407,-20.9,-51.383333
br,andre,André,20,,-7.083333,-40.75
br,andre da rocha,André da Rocha,23,,-28.633333,-51.566667
br,andre fernandes,André Fernandes,15,,-15.95,-41.5
br,andrelandia,Andrelândia,15,10079,-21.733333,-44.3
br,andre machado,André Machado,23,,-29.9,-56.516667
br,andrequice,Andrequicé,15,,-18.283333,-44.983333
br,andre resende,André Resende,15,,-21.566667,-45.183333
br,andre rodrigues,André Rodrigues,17,,-7.5,-36.5
br,andresa,Andresa,17,,-7.466667,-38.05
br,andres,Andrés,27,,-23.279659,-47.874478
br,andre siqueira,André Siqueira,31,,-11.733333,-49.083333
br,andreza,Andreza,06,,-4.333333,-38.15
br,andreza,Andreza,13,,-3.111944,-42.864444
br,andreza,Andreza,17,,-7.466667,-38.05
br,anel,Anel,02,,-9.35,-36.3
br,anelio,Anélio,16,,-1.983333,-46.55
br,anemutu,Anemutu,25,,4.083333,-59.883333
br,angai,Angaí,18,,-25.5122,-50.45927
br,angatuba,Angatuba,27,14476,-23.483333,-48.416667
br,angaturama,Angaturama,15,,-21.483333,-42.4
br,angeim,Angeim,20,,-5.366667,-41.2
br,angelica,Angelica,17,,-7.25,-37.5
br,angelim,Angelim,03,,1.35,-50.933333
br,angelim,Angelim,05,,-12.2,-40.25
br,angelim,Angelim,06,,-3.283333,-39.433333
br,angelim,Angelim,08,,-18.5,-39.866667
br,angelim,Angelim,13,,-3.048056,-42.1475
br,angelim,Angelim,17,,-7.216667,-38.5
br,angelim,Angelim,18,,-24.785933,-48.879113
br,angelim,Angelim,20,,-10.833333,-44.833333
br,angelim,Angelim,21,,-22.666667,-42.066667
br,angelim,Angelim,22,,-5.400278,-36.277222
br,angelim,Angelim,30,,-8.883333,-36.283333
br,angelina,Angelina,26,,-27.583333,-48.983333
br,angelo,Ângelo,05,,-17.366667,-40.333333
br,angelo,Ângelo,15,,-16.133333,-41.633333
br,angelo rios,Ángelo Rios,15,,-20.233333,-45.1
br,angelo saocal,Ángelo Saocal,23,,-29.766667,-54.083333
br,angical,Angical,05,,-11.233333,-41.75
br,angical,Angical,13,,-3.3575,-43.150556
br,angical,Angical,15,,-15.766667,-45.683333
br,angical,Angical,20,,-3.533333,-41.666667
br,angical,Angical,30,,-7.766667,-39.733333
br,angical,Angical,31,,-11.9,-48.55
br,angical do piaui,Angical do Piauí,20,,-6.083333,-42.733333
br,angicalinho,Angicalinho,13,,-3.345,-43.1375
br,angicao,Angicão,05,,-11.1,-41.383333
br,angicao,Angicão,15,,-15.45,-41.85
br,angico,Angico,05,,-10.033333,-43.1
br,angico,Angico,06,,-3.5,-39.966667
br,angico,Angico,13,,-3.753056,-43.449444
br,angico,Angico,17,,-6.85,-38.1
br,angico,Angico,22,,-5.166667,-35.683333
br,angico,Angico,27,,-21.783333,-47.733333
br,angico,Angico,28,,-10.266667,-37.55
br,angico,Angico,30,,-8.333333,-37.616667
br,angico,Angico,31,,-6.401389,-47.693611
br,angico branco,Angico Branco,13,,-3.060278,-42.180278
br,angico branco,Angico Branco,20,,-3.458333,-42.488889
br,angico branco,Angico Branco,31,,-6.533333,-47.45
br,angico branco i,Angico Branco I,20,,-3.424167,-42.198611
br,angico branco ii,Angico Branco II,20,,-3.519167,-42.0575
br,angico da escora,Angico da Escora,17,,-7.266667,-38.45
br,angico das araras,Angico das Araras,20,,-3.891111,-42.298889
br,angico de minas,Angico de Minas,15,,-16.083333,-44.416944
br,angico grosso,Angico Grosso,06,,-5.2,-37.966667
br,angicos,Angicos,05,,-10.183333,-38.866667
br,angicos,Angicos,06,,-4.466667,-41.066667
br,angicos,Angicos,13,,-8.466667,-45.966667
br,angicos,Angicos,15,,-16.083333,-44.416944
br,angicos,Angicos,17,,-7.116667,-37.716667
br,angicos,Angicos,20,,-6.966667,-41.716667
br,angicos,Angicos,22,7729,-5.666389,-36.600833
br,angicos,Angicos,30,,-7.816667,-37.883333
br,angico torto,Angico Tôrto,17,,-7.133333,-38.1
br,angico torto,Angico Torto,22,,-6.416667,-36.083333
br,angico torto,Angico Torto,30,,-7.883333,-39.016667
br,angico velho,Angico Velho,06,,-7.05,-40.416667
br,angola,Angola,15,,-21.533333,-46.433333
br,angola,Angola,21,,-21.25,-42.083333
br,angoritaba,Angoritaba,15,,-21.033333,-43.583333
br,angostura,Angostura,15,,-21.75,-42.683333
br,angra,Angra,21,,-23,-44.3
br,angra dos reis,Angra dos Reis,21,153637,-23,-44.3
br,anguera,Anguera,05,,-12.15,-39.216667
br,anguereta,Angueretá,15,,-19.15,-44.633333
br,angulo,Ângulo,18,,-23.183333,-51.916667
br,angustura,Angustura,15,,-21.75,-42.683333
br,angustura,Angustura,24,,-8.9,-62.266667
br,anhaia,Anháia,18,,-25.5245,-48.843
br,anhandui,Anhanduí,11,,-20.983333,-54.483333
br,anhanduizinho,Anhanduìzinho,11,,-20.75,-54.383333
br,anhanga,Anhangá,16,,-1.183333,-47.816667
br,anhanguara,Anhanguara,27,,-24.573974,-48.409735
br,anhanguera,Anhanguera,29,,-18.316667,-48.233333
br,anhema,Anhema,27,,-24.8515,-48.4807
br,anhembi,Anhembi,27,,-22.8,-48.116667
br,anhemby,Anhemby,27,,-22.8,-48.116667
br,anhoma,Anhoma,11,,-20.3,-55.916667
br,anhuma,Anhuma,11,,-20.3,-55.916667
br,anhumas,Anhumas,02,,-9.15,-36.116667
br,anhumas,Anhumas,11,,-20.3,-55.916667
br,anhumas,Anhumas,14,,-16.933333,-54.666667
br,anhumas,Anhumas,27,,-22.283333,-51.416667
br,anibal,Aníbal,15,,-20.066667,-41.433333
br,aniceto,Aniceto,06,,-5.166667,-40.016667
br,aniceto,Aniceto,15,,-15.033333,-45.633333
br,anicuns,Anicuns,29,15685,-16.466667,-49.966667
br,anil,Anil,06,,-4.05,-40.45
br,anil,Anil,13,,-2.533333,-44.233333
br,anil,Anil,21,,-22.95402,-43.334707
br,anil,Anil,30,,-8.466667,-38.533333
br,aninga,Aninga,13,,-3.226667,-42.205556
br,aninga,Aninga,20,,-3.424722,-42.185278
br,aningal,Aningal,25,,2.833333,-61.016667
br,aningas,Aningas,06,,-2.933333,-40.166667
br,aningas,Aningas,22,,-5.533333,-35.3
br,aninha,Aninha,15,,-14.466667,-44.733333
br,aninim,Aninim,04,,-4.035278,-59.379722
br,anisio de morais,Anisio de Morais,27,,-23.224167,-47.701389
br,anita garibaldi,Anita Garibaldi,26,,-27.616667,-51.083333
br,anitapolis,Anitápolis,26,,-27.9,-49.133333
br,anjelina,Anjelina,26,,-27.583333,-48.983333
br,anjico,Anjico,30,,-8.65,-38.7
br,anjico velho,Anjico Velho,22,,-5.233333,-35.75
br,anjinho,Anjinho,06,,-7.1,-39.883333
br,anjinho,Anjinho,20,,-3.956389,-42.083611
br,anna dias,Anna Dias,27,,-24.3,-47.066667
br,annapolis,Annapolis,27,,-22.133333,-47.65
br,annapolis,Annapolis,28,,-10.733333,-37.816667
br,annapolis,Annapolis,29,,-16.333333,-48.966667
br,anna reck,Anna Reck,23,,-29.1119,-51.087
br,annel,Annel,02,,-9.35,-36.3
br,annitapolis,Annitapolis,26,,-27.9,-49.133333
br,annory,Annory,04,,-3.783333,-61.633333
br,ano nuevo,Ano Nuevo,11,,-21.8,-54.15
br,anori,Anori,04,8064,-3.783333,-61.633333
br,anory,Anory,04,,-3.783333,-61.633333
br,anselmi,Anselmi,23,,-32.85,-52.733333
br,anselmos,Anselmos,27,,-23.057519,-47.513737
br,anta,Anta,05,,-15.75,-41.1
br,anta,Anta,15,,-19.5,-41.966667
br,anta,Anta,18,,-23.881522,-50.004666
br,anta gorda,Anta Gorda,05,,-12.716667,-39.9
br,anta gorda,Anta Gorda,13,,-3.4975,-43.299444
br,anta gorda,Anta Gorda,23,,-28.983333,-52.016667
br,anta gorda,Anta Gorda,26,,-26.95,-51.233333
br,anta gorda,Anta Gorda,27,,-24.683173,-48.745738
br,antari,Antari,05,,-12.15,-42.033333
br,antas,Antas,05,,-10.383333,-38.333333
br,antas,Antas,06,,-7.25,-38.666667
br,antas,Antas,18,,-24.133333,-50.516667
br,antas,Antas,21,,-22.335772,-42.788471
br,antas,Antas,26,,-26.6,-52.3
br,antas,Antas,27,,-20.866667,-47.25
br,antenor navarro,Antenor Navarro,17,,-6.733333,-38.45
br,antero,Antero,15,,-16.65,-40.533333
br,antiga aldeia pacarandi,Antiga Aldeia Pacarandi,16,,-8.455556,-49.583333
br,antiga,Antiga,11,,-22.216667,-55.883333
br,antiga colonia dourados,Antiga Coloniá Dourados,11,,-22.216667,-55.883333
br,antiga colonia sao lourenco,Antiga Colônia São Lourenço,14,,-16.666667,-55.25
br,antiga senzala,Antiga Senzala,15,,-20.1178,-43.9945
br,antigo aldeia do ignacio,Antigo Aldeia do Ignacio,14,,-16.866667,-57.483333
br,antigo aldeia lania,Antigo Aldeia Lania,11,,-20.55,-55.983333
br,antigo arraial de lavrinhas,Antigo Arraial de Lavrinhas,14,,-15.3,-59.233333
br,antigo arraial de santa barbara,Antigo Arraial de Santa Barbara,14,,-15.65,-59.15
br,antigo porto cunha bueno,Antigo Pôrto Cunha Bueno,27,,-21.7,-47.816667
br,antigo santa gertrudes,Antigo Santa Gertrudes,11,,-21.516667,-55.433333
br,antimari,Antimari,04,,-9.05,-67.4
br,antinha,Antinha,18,,-24.95,-49
br,antioa colonia sao lourenco,Antióa Colonia São Lourenço,14,,-16.666667,-55.25
br,antoniao,Antonião,13,,-4.816667,-45.316667
br,antonina,Antonina,18,16152,-25.4314,-48.7184
br,antonina,Antonina,27,,-20.566667,-50.616667
br,antonina,Antonina,31,,-6.1,-48.333333
br,antonina do norte,Antonina do Norte,06,,-6.716667,-39.966667
br,antonio alves,Antônio Alves,15,,-19.05,-48.583333
br,antonio amaral,Antônio Amaral,15,,-16.25,-41.6
br,antonio,Antônio,05,,-12.666667,-41.1
br,antonio,Antônio,25,,2.616667,-60.366667
br,antonio arangueiro,Antônio Arangueiro,15,,-19.033333,-48.433333
br,antonio barbosa,Antônio Barbosa,15,,-20.083333,-46.3
br,antonio bastos,Antônio Bastos,23,,-29.983333,-56.883333
br,antonio bernardo,Antônio Bernardo,05,,-16.933333,-39.766667
br,antonio bezerra,Antônio Bezerra,06,,-3.733333,-38.583333
br,antonio borges,Antônio Borges,05,,-12.333333,-41.066667
br,antonio borges,Antônio Borges,15,,-20.633333,-46.8
br,antonio borges,Antônio Borges,31,,-6.2,-48.416667
br,antonio bueno,Antônio Bueno,15,,-20.983333,-46.666667
br,antonio caetano,Antônio Caetano,15,,-18.466667,-48.033333
br,antonio candido da silva,Antônio Cândido da Silva,14,,-15.966667,-54.616667
br,antonio carlos,Antônio Carlos,15,,-18.4,-48.366667
br,antonio carlos,Antônio Carlos,26,,-27.466667,-48.85
br,antonio carmo,Antônio Carmo,15,,-17.266667,-41.916667
br,antonio cipriano,Antônio Cipriano,05,,-16.433333,-39.166667
br,antonio correia,Antônio Correia,15,,-16.883333,-41.516667
br,antonio da barra,Antonio da Barra,27,,-21.55,-46.533333
br,antonio da luiz,Antonio da Luiz,16,,-8.7,-49.616667
br,antonio danieli,Antonio Danieli,23,,-29.0981,-51.2171
br,antonio de alencar,Antônio de Alencar,31,,-6.8,-48.033333
br,antonio dias,Antônio Dias,15,,-16.516667,-41.883333
br,antonio diogo,Antônio Diogo,06,,-4.3,-38.75
br,antonio do azeite,Antônio do Azeite,15,,-21.55,-44.183333
br,antonio domingues,Antônio Domingues,15,,-20.7,-46.416667
br,antonio dos santos,Antônio dos Santos,15,,-19.783333,-43.566667
br,antonio duarte,Antônio Duarte,15,,-17.266667,-41.7
br,antonio eduardo,Antônio Eduardo,15,,-20.883333,-45.866667
br,antonio elias,Antônio Elias,15,,-16.583333,-40.733333
br,antonio fernandes,Antônio Fernandes,15,,-16.933333,-40.966667
br,antonio ferraz,Antônio Ferraz,15,,-16.266667,-40.333333
br,antonio ferreira,Antônio Ferreira,15,,-17.916667,-41.916667
br,antonio ferreira,Antônio Ferreira,17,,-7.016667,-36.55
br,antonio filinto,Antônio Filinto,04,,-1.75,-59.616667
br,antonio fonseca,Antônio Fonseca,15,,-20.283333,-45.283333
br,antonio fortunato,Antônio Fortunato,15,,-20.583333,-46.2
br,antonio franco,Antônio Franco,15,,-19.466667,-49.983333
br,antonio frotao,Antônio Frotão,15,,-20.65,-46.05
br,antonio garcia,Antônio Garcia,15,,-20.966667,-46.733333
br,antonio goncalves,Antônio Gonçalves,15,,-16.366667,-41.683333
br,antonio gusmao,Antônio Gusmão,15,,-16.416667,-41.85
br,antonio inacio,Antônio Inácio,26,,-27.9,-50.75
br,antonio joao,Antônio João,11,,-23.25,-55.516667
br,antonio laurindo,Antônio Laurindo,15,,-20.466667,-46.566667
br,antonio lemos,Antônio Lemos,16,,-1.366667,-50.833333
br,antonio lima,Antônio Lima,15,,-17.366667,-40.666667
br,antonio lopes,Antônio Lopes,15,,-21.3,-46.4
br,antonio manuel,Antônio Manuel,29,,-15.65,-48.6
br,antonio mariano,Antônio Mariano,21,,-21.183333,-41.633333
br,antonio martins,Antônio Martins,22,,-6.2,-37.883333
br,antonio matos,Antônio Matos,16,,-1.116667,-47.95
br,antonio melo,Antônio Melo,15,,-16.85,-41.75
br,antonio nonato,Antônio Nonato,05,,-12.4,-40.7
br,antonio olimpio,Antônio Olímpio,15,,-14.4,-44.383333
br,antonio olinto,Antônio Olinto,15,,-16.783333,-43.833333
br,antonio olinto,Antônio Olinto,18,,-25.98521,-50.196377
br,antonio olinto,Antônio Olinto,30,,-8.316667,-36.3
br,antonio olyntho,Antonio Olyntho,30,,-8.316667,-36.3
br,antonio ourives,Antônio Ourives,15,,-21.65,-45.566667
br,antonio pardinho,Antônio Pardinho,15,,-16.2,-39.933333
br,antonio pereira,Antônio Pereira,15,,-20.3,-43.483333
br,antonio pinheiro,Antônio Pinheiro,05,,-16.516667,-39.933333
br,antonio pinto,Antônio Pinto,14,,-15.916667,-54.666667
br,antonio pinto,Antônio Pinto,15,,-17.75,-40.8
br,antonio porto jatai,Antônio Pôrto Jataí,27,,-21.633333,-47.833333
br,antonio prado,Antônio Prado,15,,-21.016667,-42.1
br,antonio prado,Antônio Prado,23,,-28.85,-51.283333
br,antonio primo da silva,Antônio Primo da Silva,15,,-14.783333,-43.233333
br,antonio raimundo,Antônio Raimundo,05,,-12.333333,-41.05
br,antonio rocha,Antônio Rocha,15,,-17.416667,-41.5
br,antonio rocha,Antônio Rocha,21,,-22.65,-44.15
br,antonio rodrigues,Antônio Rodrigues,15,,-17.166667,-40.733333
br,antonio rodrigues de sousa,Antônio Rodrigues de Sousa,15,,-17.583333,-40.616667
br,antonio rondon,Antônio Rondon,11,,-19.483333,-56.416667
br,antonio roque,Antônio Roque,15,,-21.1,-46.616667
br,antonio rosa,Antônio Rosa,15,,-20.25,-45.516667
br,antonio sampaio,Antônio Sampaio,05,,-12.416667,-41.066667
br,antonio severino,Antônio Severino,15,,-20.233333,-45.35
br,antonio spineli,Antônio Spineli,15,,-21.166667,-46.666667
br,antonio taborda,Antônio Taborda,18,,-25.083333,-53.866667
br,antonio varga,Antônio Varga,08,,-20.333333,-41.25
br,antonio velho,Antônio Velho,02,,-9.783333,-37.183333
br,antonio vicente,Antônio Vicente,25,,3.2,-59.916667
br,antonio vieira,Antônio Vieira,15,,-16.133333,-39.883333
br,antonopolis,Antonópolis,06,,-4.8,-37.733333
br,antuerpia,Antuérpia,24,,-10.533333,-63.183333
br,antunes,Antunes,02,,-8.966667,-35.2
br,antunes,Antunes,15,,-19.9,-44.7
br,antunes de baixo,Antunes de Baixo,15,,-22.505208,-45.532931
br,anuan,Anuan,25,,2.95,-61
br,anuao,Anuão,25,,2.95,-61
br,anutiba,Anutiba,08,,-20.6,-41.466667
br,a. oliveira,A. Oliveira,11,,-19.683333,-55.183333
br,apa da brisa,Apa da Brisa,21,,-22.990106,-43.653849
br,apajatuba,Apajatuba,13,,-2.616667,-43.8
br,aparados da serra,Aparados da Serra,23,,-28.7,-50.4
br,aparaju,Aparaju,05,,-17.633333,-39.316667
br,apare,Apare,05,,-8.716667,-39.116667
br,aparecida,Aparecida,04,,-3.129722,-60.024444
br,aparecida,Aparecida,08,,-20.7,-41.666667
br,aparecida,Aparecida,14,,-14.666667,-56.75
br,aparecida,Aparecida,17,,-6.783333,-38.066667
br,aparecida,Aparecida,20,,-6.2,-41.883333
br,aparecida,Aparecida,21,,-22.033333,-42.8
br,aparecida,Aparecida,22,,-6.4,-38.383333
br,aparecida,Aparecida,27,34237,-22.8418,-45.2287
br,aparecida,Aparecida,29,,-15.883333,-48.483333
br,aparecida de goias,Aparecida de Goiás,29,,-14.95,-49.783333
br,aparecida de minas,Aparecida de Minas,15,,-20.133333,-49.233333
br,aparecida de monte alto,Aparecida de Monte Alto,27,,-21.25,-48.633333
br,aparecida de sao manuel,Aparecida de São Manuel,27,,-22.716667,-48.616667
br,aparecida d'oeste,Aparecida d'Oeste,18,,-23.9,-52.816667
br,aparecida d'oeste,Aparecida d'Oeste,27,,-20.466667,-50.883333
br,aparecida do rio negro,Aparecida do Rio Negro,31,,-9.941111,-47.853889
br,aparecida do taboado,Aparecida do Taboado,11,17332,-20.083333,-51.083333
br,aparecida do tabuado,Aparecida do Tabuado,11,,-20.083333,-51.083333
br,aparicio,Aparicio,04,,-2.95,-69.216667
br,apeca,Apecã,30,,-8.833333,-36.066667
br,apehu,Apehú,16,,-1.3,-47.983333
br,aperibe,Aperibé,21,,-21.616667,-42.1
br,apertado,Apertado,06,,-7.2,-40.433333
br,apertado do morro,Apertado do Morro,05,,-13.833333,-40.95
br,apeu,Apeú,16,,-1.3,-47.983333
br,apiaba,Apiaba,18,,-25.333333,-50.783333
br,apiaca,Apiacá,08,,-21.133333,-41.566667
br,apiahy,Apiahy,27,,-24.511926,-48.844671
br,apiai,Apiaí,27,18260,-24.511926,-48.844671
br,apicum,Apicum,05,,-12.716667,-38.75
br,apinage,Apinagé,31,,-11.523889,-48.301667
br,apinaje,Apinajé,31,,-11.523889,-48.301667
br,apipucos,Apipucos,30,,-8.033333,-34.933333
br,apiques,Apiques,06,,-3.1,-39.516667
br,apiuna,Apiúna,26,,-27.033333,-49.416667
br,apodi,Apodi,22,16757,-5.65,-37.8
br,apodi,Apodi,30,,-8.066667,-35.4
br,apody,Apody,22,,-5.65,-37.8
br,apolinario,Apolinário,16,,-3.55,-47.05
br,apolinario,Apolinário,27,,-23.371696,-46.603889
br,apolinario,Apolinário,30,,-8.083333,-36.433333
br,apolo xi,Apolo XI,21,,-22.716431,-43.33265
br,apora,Aporá,05,,-11.65,-38.083333
br,apore,Aporé,29,,-18.966667,-52.016667
br,aporema,Aporema,03,,1.233333,-50.816667
br,aposento,Aposento,20,,-3.976944,-42.115556
br,apoti,Apoti,30,,-8.066667,-35.4
br,apparecida,Apparecida,20,,-7.633333,-43.95
br,apparecida,Apparecida,27,,-22.8418,-45.2287
br,apparecida,Apparecida,29,,-16.816667,-49.25
br,apparecida dos corregos,Apparecida dos Corregos,15,,-18.883333,-43.516667
br,apparecido de monte alto,Apparecido de Monte Alto,27,,-21.25,-48.633333
br,aprasive,Aprasive,20,,-6.383333,-41.966667
br,aprazivel,Aprazível,20,,-4.833333,-42.716667
br,aprigio,Aprígio,15,,-16.166667,-39.95
br,aproaga,Aproaga,16,,-1.95,-47.783333
br,apua,Apuá,30,,-7.883333,-35.333333
br,apuarema,Apuarema,05,,-13.9,-39.75
br,apucarana,Apucarana,18,107086,-23.55,-51.483333
br,apucaraninha,Apucaraninha,18,,-23.7757,-50.9554
br,apucarena,Apucarena,18,,-24.783333,-51.166667
br,apuhy,Apuhy,16,,-4.533333,-56.2
br,apui,Apuí,04,,-.1,-65.083333
br,apui,Apuí,16,,-1.483333,-47.466667
br,apuiares,Apuiarés,06,,-3.933333,-39.4
br,apuires,Apuirés,06,,-3.933333,-39.4
br,apurima,Apurimá,04,,-3.75,-66.233333
br,aqua preta,Aqua Preta,04,,-8.833333,-66.166667
br,aquidaba,Aquidabã,02,,-9.033333,-35.25
br,aquidaba,Aquidabã,04,,-6.5,-69.683333
br,aquidaba,Aquidabã,11,,-22.383333,-55.716667
br,aquidaba,Aquidabã,13,,-2.183333,-44.833333
br,aquidaba,Aquidabã,18,,-23.6,-51.85
br,aquidaba,Aquidabã,26,,-27.033333,-49.416667
br,aquidaba,Aquidabã,28,10596,-10.283333,-37.033333
br,aquidaban,Aquidaban,04,,-6.5,-69.683333
br,aquidaban,Aquidaban,26,,-27.033333,-49.416667
br,aquidaban,Aquidaban,28,,-10.283333,-37.033333
br,aquidauana,Aquidauana,11,35304,-20.466667,-55.8
br,aquidavana,Aquidavana,11,,-20.466667,-55.8
br,aqui-ferto,Aqui-Ferto,16,,-4.716667,-56.55
br,aquiles stengel,Aquiles Stengel,26,,-26.333333,-51.083333
br,aquiperto,Aquiperto,16,,-4.716667,-56.55
br,aquiraz,Aquiraz,06,65117,-3.9,-38.366667
br,ara,Ará,04,,-4.485833,-59.836389
br,araba,Arabá,27,,-19.85,-50.433333
br,arabela,Arabela,27,,-21.4,-51.716667
br,arabia,Arábia,22,,-5.543611,-36.312778
br,araboladi,Araboladí,16,,-6.616667,-57.566667
br,araborladit,Araborladit,16,,-6.616667,-57.566667
br,arabuta,Arabutã,26,,-27.166667,-52.116667
br,araca,Araçá,02,,-9.483333,-37.933333
br,araca,Aracá,04,,-4.963333,-60.256944
br,araca,Araça,05,,-13.033333,-38.983333
br,araca,Aracá,06,,-3.983333,-38.35
br,araca,Araçá,13,,-3.072778,-42.196667
br,araca,Araça,15,,-16.099444,-44.613056
br,araca,Araçá,17,,-6.25,-37.516667
br,araca,Araçá,20,,-3.489444,-42.491944
br,araca,Araçá,21,,-22.65,-42.1
br,araca,Araçá,23,,-28.666667,-51.75
br,araca,Araça,25,,4.216667,-60.9
br,araca,Araçá,30,,-8.766667,-36.666667
br,aracacu,Aracaçu,27,,-23.716667,-48.45
br,araca de baixo,Araçá de Baixo,05,,-13.333333,-43.483333
br,aracagi,Araçagi,15,,-15.85,-41.1
br,aracagi,Araçagi,17,,-6.85,-35.366667
br,aracai,Araçaí,15,,-19.2,-44.233333
br,aracaiba,Araçaíba,27,,-24.416667,-48.85
br,aracaji,Araçaji,17,,-6.85,-35.366667
br,aracaju,Aracaju,28,490184,-10.916667,-37.066667
br,aracarariguama,Araçarariguama,27,,-23.433333,-47.066667
br,aracari,Araçari,04,,-2.443056,-61.075278
br,aracariguama,Araçariguama,27,,-23.433333,-47.066667
br,aracas,Araçás,05,,-12.2,-38.2
br,aracassu,Aracassú,27,,-23.716667,-48.45
br,aracatiacu,Aracatiaçu,06,,-3.883333,-40.016667
br,aracatiara,Aracatiara,06,,-3.166667,-39.733333
br,aracati,Aracati,01,,-9.316667,-72.216667
br,aracati,Aracati,06,44294,-4.566667,-37.766667
br,aracati,Aracati,15,,-21.4,-42.6
br,aracati,Aracati,22,,-5.3,-35.65
br,aracati,Aracati,25,,-3.8,-61.333333
br,aracati,Aracati,29,,-16.183333,-49.083333
br,aracatiba,Araçatiba,08,,-20.466667,-40.5
br,aracatiba,Araçatiba,21,,-23.044606,-43.554555
br,aracatu,Aracatu,05,,-14.416667,-41.45
br,aracatuba,Araçatuba,04,,-2.516667,-66.416667
br,aracatuba,Araçatuba,15,,-16.416667,-40.966667
br,aracatuba,Araçatuba,26,,-28.116667,-48.7
br,aracatuba,Araçatuba,27,170028,-21.2,-50.416667
br,aracaty,Aracaty,01,,-9.316667,-72.216667
br,aracaty,Aracaty,06,,-4.566667,-37.766667
br,aracazinho,Araçazinho,04,,-5.191944,-60.387778
br,aracazinho,Aracazinho,06,,-3.966667,-38.316667
br,arace,Aracê,08,,-20.4,-41
br,araci,Araci,05,15089,-11.333333,-38.95
br,araci,Araci,15,,-21.516667,-42.933333
br,aracitaba,Aracitaba,15,,-21.333333,-43.383333
br,aracoiaba,Araçoiaba,01,,-8.540833,-73.102778
br,aracoiaba,Aracoiaba,06,13425,-4.383333,-38.816667
br,aracoiaba,Araçoiaba,30,13095,-7.8,-35.05
br,aracoiaba da serra,Araçoiaba da Serra,27,15395,-23.5049,-47.6185
br,aracoyaba,Aracoyaba,06,,-4.383333,-38.816667
br,aracruz,Aracruz,08,58272,-19.816667,-40.266667
br,aracuai,Araçuaí,15,22005,-16.866667,-42.066667
br,aracu,Araçu,29,,-16.366667,-49.683333
br,aracui,Aracuí,08,,-20.65,-41.2
br,aracupeva,Araçupeva,27,,-25.213889,-48.108611
br,aracy,Aracy,05,,-11.333333,-38.95
br,arado,Arado,27,,-23.622352,-47.485413
br,aragarcas,Aragarças,29,16781,-15.916667,-52.25
br,aragoiania,Aragoiânia,29,,-16.95,-49.5
br,aragominas,Aragominas,31,,-7.131389,-48.377222
br,araguacema,Araguacema,31,,-8.791944,-49.430556
br,araguaci,Araguaci,31,,-6.8,-48.616667
br,araguacu,Araguaçu,27,,-22.416667,-50.566667
br,araguacu,Araguaçu,31,7603,-12.894167,-49.773056
br,araguaia,Araguaia,08,,-20.5,-40.766667
br,araguaia,Araguaia,15,,-17.383333,-40.666667
br,araguaiana,Araguaiana,14,,-15.716667,-51.85
br,araguaina,Araguaína,31,114959,-7.16,-48.0575
br,araguainha,Araguainha,14,,-16.816667,-53.083333
br,araguana,Araguanã,31,,-6.589722,-48.473889
br,araguar,Araguar,15,,-18.633333,-48.183333
br,araguari,Araguari,03,,1.233333,-50.816667
br,araguari,Araguari,15,96567,-18.633333,-48.183333
br,araguary,Araguary,15,,-18.633333,-48.183333
br,araguatins,Araguatins,31,17106,-5.600278,-47.933056
br,araguaya,Araguaya,08,,-20.5,-40.766667
br,araguiana,Araguiana,14,,-15.716667,-51.85
br,araia,Araia,31,,-11.583333,-47.916667
br,arai,Araí,29,,-13.616667,-47.716667
br,araim,Araim,13,,-6.1,-43.766667
br,araioses,Araioses,13,8667,-2.89,-41.903611
br,araioses,Araioses,20,,-3.988889,-42.216944
br,araiporanga,Araiporanga,18,,-23.7222,-50.7389
br,arajara,Arajara,06,,-7.35,-39.4
br,aramanduba,Aramanduba,16,,-1.483333,-52.483333
br,aramari,Aramari,05,,-12.066667,-38.5
br,aramary,Aramary,05,,-12.066667,-38.5
br,arambare,Arambaré,23,,-30.916667,-51.483333
br,arame,Arame,20,,-3.268889,-42.118611
br,aramina,Aramina,27,,-20.1,-47.8
br,aramirim,Aramirim,15,,-19.016667,-42.466667
br,arana,Aranã,15,,-18.083333,-41.55
br,aranau,Aranaú,06,,-2.833333,-40.216667
br,arandu,Arandu,27,,-23.116667,-49.033333
br,aranha,Aranha,14,,-15.866667,-56.716667
br,aranha,Aranha,15,,-20.2,-44.116667
br,aranhas,Aranhas,13,,-8.5,-45.85
br,arantes,Arantes,15,,-21.466667,-44.2
br,arantina,Arantina,15,,-21.933333,-44.25
br,arantina,Arantina,29,,-17.616667,-50.266667
br,arapa,Arapá,06,,-3.616667,-40.883333
br,arapapa,Arapapá,04,,-4.238333,-62.258889
br,arapari,Arapari,04,,-3.447222,-61.809167
br,arapari,Arapari,06,,-3.55,-39.616667
br,arapari,Arapari,16,,-1.75,-54.4
br,arapari,Arapari,25,,3.1,-60.4
br,arapei,Arapeí,27,,-22.683333,-44.45
br,arapema,Arapema,13,,-3.716667,-44.233333
br,arapira,Arapirã,03,,3.283333,-51.333333
br,arapira,Arapirá,04,,.55,-69.166667
br,arapiraca,Arapiraca,02,166566,-9.75,-36.65
br,arapiraca,Arapiraca,17,,-7,-37.716667
br,arapiranga,Arapiranga,05,,-13.466667,-41.766667
br,arapixi,Arapixi,04,,-9.016667,-68.016667
br,arapixy,Arapixy,04,,-9.016667,-68.016667
br,arapoema,Arapoema,31,,-7.618889,-48.945556
br,araponga,Araponga,05,,-17.266667,-39.483333
br,araponga,Araponga,06,,-7.116667,-39.766667
br,araponga,Araponga,15,,-20.666667,-42.533333
br,araponga,Araponga,18,,-23.383333,-51.45
br,arapongas,Arapongas,18,97513,-23.383333,-51.45
br,arapora,Araporã,15,,-18.433333,-49.183333
br,araporanga,Araporanga,06,,-7.116667,-39.766667
br,arapoti,Arapoti,18,,-24.166667,-49.666667
br,arapua,Arapuá,02,,-9.716667,-37.5
br,arapua,Arapuá,06,,-4.683333,-41.116667
br,arapua,Arapuá,15,,-19.033333,-46.15
br,arapua,Arapuá,17,,-6.566667,-38.433333
br,arapua,Arapuá,22,,-5.458056,-36.855833
br,arapua,Arapuá,30,,-7.933333,-36.266667
br,arapuca,Arapuca,06,,-7.2,-40.333333
br,araqua,Araquã,16,,1.5,-54.633333
br,araquara,Araquara,27,,-24.566667,-47.516667
br,araquari,Araquari,26,35691,-26.3692,-48.7221
br,araquem,Araquém,06,,-3.633333,-40.816667
br,arara,Arara,04,,-2.566667,-65.8
br,arara,Arara,05,,-13.45,-40.25
br,arara,Arara,06,,-5.633333,-38.25
br,arara,Arara,13,,-3.083056,-42.278889
br,arara,Arara,17,7641,-6.833333,-35.75
br,arara,Arara,30,,-8.383333,-36.166667
br,arara,Arara,31,,-11.416667,-47.066667
br,arara de baixo,Arara de Baixo,06,,-2.935,-41.1725
br,ararai,Araraí,08,,-20.583333,-41.55
br,ararangua,Araranguá,26,43445,-28.933333,-49.483333
br,ararapari,Ararapari,23,,-27.6,-52.816667
br,ararapira,Ararapira,18,,-25.2288,-48.0301
br,araraquara,Araraquara,27,185191,-21.783333,-48.166667
br,araras,Araras,01,,-9.016667,-68.1
br,araras,Araras,04,,-2.566667,-65.8
br,araras,Araras,05,,-14.516667,-41.166667
br,araras,Araras,06,,-2.937778,-41.153889
br,araras,Araras,13,,-3.25,-44.466667
br,araras,Araras,14,,-15.166667,-56.65
br,araras,Araras,15,,-19.15,-42.766667
br,araras,Araras,16,,-3.783333,-51.783333
br,araras,Araras,17,,-7.333333,-38.533333
br,araras,Araras,24,,-10.45,-64.15
br,araras,Araras,27,107465,-22.366667,-47.383333
br,ararenda,Ararendá,06,,-4.75,-40.833333
br,arari,Arari,13,16777,-3.466667,-44.783333
br,arari,Arari,15,,-21.083333,-47.05
br,arari,Arari,16,,-2.416667,-47.8
br,ararica,Ararica,23,,-29.6,-50.916667
br,araripe,Araripe,06,11860,-7.2,-40.133333
br,araripe,Araripe,30,,-7.6,-39.7
br,araripe de baixo,Araripe de Baixo,05,,-12.833333,-38.8
br,araripina,Araripina,30,38570,-7.55,-40.566667
br,arariuna,Arariúna,16,,-1.016667,-48.966667
br,ararius,Arariús,06,,-3.883333,-40.6
br,araruama,Araruama,21,109638,-22.883333,-42.333333
br,araruna,Araruna,16,,-2.783333,-46.65
br,araruna,Araruna,17,7667,-6.533333,-35.733333
br,araruna,Araruna,18,,-23.9,-52.5
br,ararunaquara,Ararunaquara,16,,-3.5,-52.216667
br,araruva,Araruva,18,,-23.75,-51.316667
br,arary,Arary,04,,-7.8,-70.766667
br,arary,Arary,13,,-3.466667,-44.783333
br,arary,Arary,15,,-21.083333,-47.05
br,arary,Arary,31,,-11.416667,-47.066667
br,arasselva,Arasselva,11,,-22,-54.816667
br,arassoiaba,Arassoiaba,30,,-7.8,-35.05
br,arassuahy,Arassuahy,15,,-16.866667,-42.066667
br,arassuai,Arassuaí,15,,-16.866667,-42.066667
br,arassui,Arássuí,15,,-16.866667,-42.066667
br,arata,Arata,05,,-12.816667,-38.45
br,arataca,Arataca,05,,-15.25,-39.416667
br,aratama,Aratama,06,,-7.05,-39.85
br,arati,Arati,04,,-7.8,-70.766667
br,aratiba,Aratiba,23,,-27.4,-52.316667
br,araticu,Araticu,16,,-1.966667,-49.85
br,araticum,Araticum,05,,-12,-39.3
br,araticum,Araticum,06,,-3.8,-40.883333
br,araticum,Araticum,28,,-9.816667,-37.333333
br,aratinga,Aratinga,18,,-25.0084,-53.8422
br,aratinga,Aratinga,23,,-29.183333,-51.733333
br,aratingauba,Aratingaúba,26,,-28.3,-48.866667
br,aratu,Aratu,05,,-12.816667,-38.45
br,aratuba,Aratuba,05,,-13.1,-38.75
br,aratuba,Aratuba,06,,-4.383333,-39.05
br,aratuhype,Aratuhype,05,,-13.083333,-39
br,aratuipe,Aratuípe,05,,-13.083333,-39
br,araty,Araty,04,,-7.8,-70.766667
br,araua,Arauá,04,,-5.300833,-60.423611
br,araua,Arauá,28,4747,-11.266667,-37.616667
br,araucaria,Araucária,18,111303,-25.583333,-49.416667
br,araucumirim,Araucumirim,16,,-.616667,-47.65
br,araujo,Araujo,06,,-6.066667,-38.5
br,araujo,Araújo,25,,4.216667,-60.883333
br,araujos,Araújos,15,,-19.933333,-45.066667
br,arauna,Araúna,15,,-20.683333,-45.9
br,araxa,Araxá,15,82597,-19.583333,-46.916667
br,araxanas,Araxanas,27,,-21.933333,-51.533333
br,araxans,Araxans,27,,-21.933333,-51.533333
br,araxas,Araxãs,27,,-21.933333,-51.533333
br,arayoses,Arayoses,13,,-2.89,-41.903611
br,arayozes,Arayozes,13,,-2.89,-41.903611
br,arcadas,Arcadas,27,,-22.7,-46.866667
br,arcadia,Arcádia,21,,-22.512222,-43.523611
br,arcado,Arcado,27,,-24.6846,-48.3306
br,arcangelo,Arcângelo,15,,-21.3,-44.316667
br,arceburgo,Arceburgo,15,,-21.366667,-46.933333
br,arcelino,Arcelino,16,,-5.35,-55.8
br,arco iris,Arco Íris,27,,-21.766667,-50.466667
br,arcos,Arcos,15,33356,-20.283333,-45.533333
br,arco verde,Arco Verde,05,,-13.05,-39.4
br,arcoverde,Arcoverde,15,,-21.133333,-43.4
br,arco verde,Arco Verde,23,,-29.35,-51.566667
br,arcoverde,Arcoverde,26,,-27.283333,-51.433333
br,arcoverde,Arcoverde,30,57164,-8.416667,-36.916667
br,arcozelo,Arcozelo,21,,-22.403056,-43.423056
br,ardeira,Ardeira,20,,-3.659444,-42.622222
br,ardeiras,Ardeiras,20,,-3.649722,-42.046111
br,areadinho,Areadinho,27,,-24.633388,-48.169083
br,areado,Areado,05,,-10.333333,-43.266667
br,areado,Areado,15,10689,-21.35,-46.15
br,areado,Areado,27,,-24.558837,-48.04375
br,areal,Areal,05,,-12.116667,-44.566667
br,areal,Areal,13,,-3.233333,-44.616667
br,areal,Areal,21,11041,-22.228889,-43.106944
br,areal,Areal,23,,-31.75,-52.283333
br,arealva,Arealva,27,,-22.033333,-48.883333
br,areao,Areão,05,,-12.983333,-44.083333
br,areao,Areão,16,,-4.466667,-49.566667
br,areao,Areão,18,,-24.766667,-51.2
br,areao,Areão,31,,-11.583333,-47.916667
br,are,Aré,21,,-21.266667,-41.8
br,are,Aré,23,,-27.45,-52.85
br,area residencial da mineracao plumbum,Área Residencial da Mineração Plumbum,18,,-24.679336,-48.919977
br,areas,Áreas,15,,-22.5647,-45.7108
br,areas,Áreas,27,,-22.5905,-45.7256
br,aredeco,Aredecô,17,,-7.383333,-36.8
br,aredo,Aredo,15,,-16.266667,-41.466667
br,areia,Areia,05,,-11.583333,-45.05
br,areia,Areia,11,,-21.55,-57.183333
br,areia,Areia,13,,-3.076111,-42.211667
br,areia,Areia,15,,-16.1,-40.766667
br,areia,Areia,17,13825,-6.966667,-35.7
br,areia branca,Areia Branca,05,,-12.833333,-38.35
br,areia branca,Areia Branca,06,,-4.983333,-38.65
br,areia branca,Areia Branca,15,,-21.316667,-42.7
br,areia branca,Areia Branca,18,,-23.9032,-50.4609
br,areia branca,Areia Branca,20,,-7.05,-41
br,areia branca,Areia Branca,21,,-22.7525,-43.403333
br,areia branca,Areia Branca,22,18372,-4.953889,-37.132222
br,areia branca,Areia Branca,27,,-22.8,-46.85
br,areia branca,Areia Branca,28,7414,-10.766667,-37.316667
br,areia branca dos assis,Areia Branca dos Assis,18,,-25.8698,-49.365
br,areia comprida,Areia Comprida,22,,-5.88,-36.114167
br,areia da teixeira,Areia da Teixeira,05,,-12.3,-38.633333
br,areia de tabuleiro,Areia de Tabuleiro,22,,-6.183333,-38.016667
br,areia do rosario,Areia do Rosário,18,,-24.966667,-49.45
br,areia do teixeira,Areia do Teixeira,05,,-12.3,-38.633333
br,areia dourada,Areia Dourada,27,,-22.1,-51.933333
br,areia fina,Areia Fina,05,,-13.133333,-39.35
br,areial,Areial,02,,-9.166667,-37.35
br,areial,Areial,05,,-12.116667,-44.566667
br,areial,Areial,06,,-3.966667,-40.333333
br,areial,Areial,13,,-3.560278,-43.350278
br,areial,Areial,17,,-7.033333,-35.883333
br,areiao,Areião,05,,-12.983333,-44.083333
br,areiao,Areião,16,,-2.516667,-49.45
br,areiao,Areião,18,,-24.766667,-51.2
br,areiao,Areião,29,,-18.233333,-48.4
br,areiao,Areião,31,,-11.583333,-47.916667
br,areia preta,Areia Preta,27,,-24.672218,-48.130287
br,areia-preta,Areia-Preta,27,,-24.676315,-48.138465
br,areia-pretinha,Areia-Pretinha,27,,-24.684058,-48.142021
br,areias alvas,Areias Alvas,22,,-4.910556,-37.215
br,areias,Areias,05,,-12.8,-38.233333
br,areias,Areias,06,,-4.738889,-37.312222
br,areias,Areias,11,,-20.983333,-55.883333
br,areias,Areias,13,,-3.366667,-45.633333
br,areias,Areias,14,,-16.233333,-58.183333
br,areias,Areias,15,,-16.616667,-41.133333
br,areias,Areias,16,,-1.2,-51.25
br,areias,Areias,17,,-6.45,-38.433333
br,areias,Areias,20,,-5.166667,-42.8
br,areias,Areias,27,,-21.516667,-46.583333
br,areias,Areias,30,,-7.666667,-35.1
br,areias barauna,Areias Baraúna,17,,-7.116667,-36.933333
br,areias brancas,Areias Brancas,23,,-29.5,-49.866667
br,areias grandes,Areias Grandes,26,,-26.3796,-48.6685
br,areias pequenas,Areias Pequenas,26,,-26.3667,-48.6852
br,areia vermelha,Areia Vermelha,27,,-23.140884,-47.708828
br,areinhas,Areinhas,13,,-2.466667,-43.45
br,areiopolis,Areiópolis,27,,-22.666667,-48.7
br,areja,Areja,06,,-5.733333,-39.266667
br,arejas,Arejas,16,,-1.2,-51.25
br,arembepe,Arembepe,05,,-12.75,-38.166667
br,arenal,Arenal,01,,-9.233333,-72.683333
br,arenal,Arenal,04,,-7.566667,-72.616667
br,arenapolis,Arenápolis,14,9060,-14.433333,-56.816667
br,arencas,Arencas,06,,-3.266667,-39.733333
br,arengas,Arengas,06,,-3.316667,-40
br,arenosa,Arenosa,22,,-5.373611,-36.856389
br,areopolis,Areopolis,27,,-22.666667,-48.7
br,arequembaua,Arequembaua,16,,-2.716667,-49.733333
br,arere,Arerê,06,,-4.216667,-38.583333
br,arere,Arere,16,,-.266667,-53.866667
br,ares,Arês,22,7231,-6.183333,-35.15
br,arez,Arez,22,,-6.183333,-35.15
br,argenita,Argenita,15,,-19.7,-46.666667
br,argenta,Argenta,23,,-28.5,-52.2
br,argentina,Argentina,15,,-16.033333,-41.116667
br,argentina,Argentina,27,,-21.85,-47.8
br,argerita,Argerita,15,,-21.616667,-42.833333
br,argirita,Argirita,15,,-21.616667,-42.833333
br,argoim,Argoim,05,,-12.533333,-39.533333
br,argola,Argola,08,,-20.333333,-40.35
br,argolas,Argolas,08,,-20.333333,-40.35
br,argolo,Argôlo,05,,-17.866667,-40.016667
br,arguelho,Arguelho,11,,-22.7,-55.233333
br,argyrita,Argyrita,15,,-21.616667,-42.833333
br,ari acu,Ari Açu,23,,-28,-53.083333
br,ari,Ari,05,,-12.366667,-39.4
br,ariau,Ariaú,04,,-3.15,-57.233056
br,aribao,Aribão,22,,-5.3,-35.783333
br,aribice,Aribicé,05,,-10.566667,-38.783333
br,aricanduva,Aricanduva,15,,-17.833333,-42.583333
br,aricanduva,Aricanduva,18,,-23.466667,-51.416667
br,aricaria,Aricaria,16,,-2.683333,-52.05
br,aricobe,Aricobé,05,,-12.083333,-44.433333
br,aricura,Aricura,16,,-2.333333,-49.516667
br,arikemes,Arikemes,24,,-9.933333,-63.066667
br,arima,Arimã,04,,-5.791111,-63.633056
br,arimateia,Arimatéia,15,,-22.166667,-44.4
br,arinos,Arinos,14,,-14.033333,-56.466667
br,arinos,Arinos,15,10078,-15.916667,-46.066667
br,aripibu,Aripibu,30,,-8.433333,-35.35
br,aripuana,Aripuanã,14,27043,-9.166667,-60.633333
br,ariquemes,Ariquemes,04,,-5.039722,-59.891667
br,ariquemes,Ariquemes,24,58102,-9.933333,-63.066667
br,ariramba,Ariramba,04,,-5.394167,-59.725
br,ariranha,Ariranha,04,,-5.394167,-59.725
br,ariranha,Ariranha,27,,-21.183333,-48.783333
br,ariri,Ariri,27,,-25.2169,-48.0386
br,ariry,Ariry,27,,-25.2169,-48.0386
br,arisco,Arisco,06,,-4.516667,-39.666667
br,arisco,Arisco,22,,-5.524444,-36.039722
br,aristeu,Aristeu,15,,-15.933333,-46.2
br,aristeu braganca,Aristeu Bragança,23,,-30.7,-55.183333
br,aristides,Aristides,15,,-20.966667,-46.566667
br,aristides lobo,Aristides Lôbo,21,,-22.433333,-43.783333
br,arisuel,Arisuel,08,,-19.233333,-40.5
br,arisvel,Arisvel,08,,-19.233333,-40.5
br,aritagua,Aritaguá,05,,-14.716667,-39.1
br,arius,Ariús,17,,-7.033333,-35.883333
br,arizona,Arizona,05,,-12.8,-40.933333
br,arizona,Arizona,15,,-16.216667,-40.066667
br,arizona,Arizona,20,,-6.45,-41.583333
br,arizona,Arizona,22,,-5.283333,-35.7
br,arizona,Arizona,29,,-17.05,-48.3
br,arlindo gomes,Arlindo Gomes,15,,-18.8,-48.483333
br,armacao,Armaçao,05,,-17.733333,-39.233333
br,armacao,Armação,26,,-27.35,-48.566667
br,armacao dos buzios,Armação dos Búzios,21,23463,-22.75,-41.883333
br,armacao do tairu,Armação do Tairu,05,,-13.066667,-38.733333
br,armador,Armador,06,,-5.45,-38.183333
br,armazem,Armazém,13,,-3.082778,-43.113611
br,armazem,Armazém,23,,-28.916667,-52.583333
br,armazem,Armazém,26,,-28.266667,-49.016667
br,arneiroz,Arneiroz,06,,-6.333333,-40.133333
br,arnoni,Arnoni,23,,-33.616667,-53.45
br,arnoresco,Arnoresco,23,,-33.233333,-53.066667
br,arnoreso,Arnoreso,23,,-33.233333,-53.066667
br,aroaba,Aroaba,08,,-20.133333,-40.383333
br,aroases,Aroases,20,,-6.116667,-41.8
br,aroazes,Aroazes,20,,-6.116667,-41.8
br,aroeira,Aroeira,05,,-10.65,-44.083333
br,aroeira,Aroeira,06,,-2.966667,-40.383333
br,aroeira,Aroeira,11,,-21.683333,-54.416667
br,aroeira,Aroeira,13,,-3.824167,-43.323611
br,aroeira,Aroeira,15,,-19.216667,-48.283333
br,aroeira,Aroeira,17,,-7.7,-36.066667
br,aroeira,Aroeira,18,,-24.95,-53.4
br,aroeira,Aroeira,20,,-3.709167,-42.274722
br,aroeira,Aroeira,22,,-5.420278,-37.493056
br,aroeira,Aroeira,23,,-28.9,-53.1
br,aroeira de dentro,Aroeira de Dentro,20,,-6.816667,-41.083333
br,aroeira grande,Aroeira Grande,20,,-7.733333,-41.4
br,aroeira ii,Aroeira II,20,,-5.066667,-41.566667
br,aroeiral,Aroeiral,20,,-3.864722,-42.025556
br,aroeiras altas,Aroeiras Altas,22,,-5.698611,-37.210278
br,aroeiras,Aroeiras,06,,-4.566667,-37.983333
br,aroeiras,Aroeiras,17,7019,-7.516667,-35.683333
br,aroeiras,Aroeiras,20,,-3.816944,-42.03
br,aroeira velha,Aroeira Velha,06,,-3.016667,-40.016667
br,aroeirinha,Aroeirinha,20,,-7.366667,-41.666667
br,arouca,Arouca,27,,-20.566667,-50.616667
br,arraia,Arraia,26,,-26.9,-48.933333
br,arraial,Arraial,05,,-14.016667,-39.25
br,arraial,Arraial,06,,-3.516667,-40.25
br,arraial,Arraial,13,,-3.433333,-44.316667
br,arraial,Arraial,20,,-3.819722,-42.446111
br,arraial,Arraial,23,,-32.016667,-52.266667
br,arraial,Arraial,26,,-26.9,-48.933333
br,arraial,Arraial,27,,-22.833333,-46.65
br,arraial do cabo,Arraial do Cabo,21,26164,-22.966667,-42.016667
br,arraial sao bento,Arraial São Bento,27,,-22.916667,-47.716667
br,arraias,Arraias,31,6881,-12.977222,-46.891667
br,arranca-dente,Arranca-Dente,15,,-16.166667,-40.983333
br,arrastao,Arrastão,21,,-22.783333,-42.183333
br,arrayas,Arrayas,31,,-12.977222,-46.891667
br,arrebol,Arrebol,21,,-21.983333,-41.883333
br,arrecife,Arrecife,05,,-11.033333,-41.883333
br,arrecife,Arrecife,20,,-5.216667,-41.45
br,arrecife,Arrecife,30,,-8.05,-34.9
br,arrecife grande,Arrecife Grande,05,,-11.033333,-41.7
br,arrecifes,Arrecifes,05,,-12.283333,-41.05
br,arreias,Arreias,29,,-16.05,-50.05
br,arreios,Arreios,29,,-16.05,-50.05
br,arrelia,Arrelia,21,,-22.936667,-43.253611
br,arrependido,Arrependido,16,,-4.483333,-49.55
br,arrepol,Arrepol,21,,-21.983333,-41.883333
br,arrieiro,Arrieiro,17,,-8.05,-36.816667
br,arrinha,Arrinha,05,,-12.333333,-40.683333
br,arroial de lavrinhas,Arroial de Lavrinhas,14,,-15.3,-59.233333
br,arroial velho,Arroial Velho,14,,-14.683333,-59.183333
br,arroio baixo laje,Arroio Baixo Laje,26,,-26.937666,-49.626324
br,arroio bonito,Arroio Bonito,23,,-29.366667,-53.05
br,arroio corrente,Arroio Corrente,26,,-28.7,-49.083333
br,arroio da cruz,Arroio da Cruz,18,,-25.896929,-50.228786
br,arroio da seca,Arroio da Sêca,23,,-29.366667,-51.783333
br,arroio do meio,Arroio do Meio,23,16331,-29.4,-51.95
br,arroio do pessegueiro,Arroio do Pessegueiro,18,,-25.515737,-50.626623
br,arroio do silva,Arroio do Silva,26,,-28.983333,-49.433333
br,arroio do so,Arroio do Só,23,,-29.783333,-53.566667
br,arroio dos ratos,Arroio dos Ratos,23,13405,-30.083333,-51.716667
br,arroio do tigre,Arroio do Tigre,23,,-29.333333,-53.1
br,arroio grande,Arroio Grande,18,,-25.2897,-50.6679
br,arroio grande,Arroio Grande,23,16117,-32.233333,-53.083333
br,arroio guacu,Arroio Guaçu,18,,-24.383333,-54.25
br,arroio miranda,Arroio Miranda,23,,-28.2,-52.366667
br,arroio moreira,Arroio Moreira,23,,-32.0371,-52.7105
br,arroio peixoto,Arroio Peixoto,05,,-12.283333,-41.416667
br,arroio teixeira,Arroio Teixeira,23,,-29.633333,-49.966667
br,arroio trinta,Arroio Trinta,04,,-26.866667,-51.316667
br,arrojado,Arrojado,05,,-12.383333,-38.45
br,arrojado,Arrojado,06,,-6.666667,-39.033333
br,arroyal de lavrinhas,Arroyal de Lavrinhas,14,,-15.3,-59.233333
br,arroyal velho,Arroyal Velho,14,,-14.683333,-59.183333
br,arrozal,Arrozal,11,,-18.633333,-56.216667
br,arrozal,Arrozal,14,,-14.816667,-59.933333
br,arrozal,Arrozal,15,,-20.5,-42.216667
br,arrozal,Arrozal,16,,-1.266667,-48.816667
br,arrozal,Arrozal,21,,-22.616667,-44.05
br,arrozal,Arrozal,27,,-23.098611,-46.668333
br,arrozal de sao sebastiao,Arrozal de São Sebastiao,21,,-22.816667,-43.766667
br,arroz,Arroz,05,,-11,-45.283333
br,arroz,Arroz,06,,-4.316667,-38.6
br,arroz,Arroz,17,,-7.45,-37.566667
br,arroz,Arroz,20,,-8.333333,-41.416667
br,arroz,Arroz,30,,-7.766667,-38.75
br,arroz bravo,Arroz Bravo,06,,-3.95,-38.383333
br,arroz-doce,Arroz-Doce,18,,-23.592648,-49.864692
br,arrozeira,Arrozeira,26,,-26.733333,-49.266667
br,arroz sem sal,Arroz Sem Sal,14,,-14.366667,-56.716667
br,arruda,Arruda,14,,-15.033333,-56.116667
br,arruda,Arruda,17,,-7.133333,-36.05
br,arruda camara,Arruda Câmara,17,,-6.816667,-37.916667
br,arrudas,Arrudas,27,,-23.5077,-47.8342
br,arrudeiro,Arrudeiro,30,,-7.75,-37.483333
br,arruido,Arruido,17,,-7.033333,-38.583333
br,artemis,Artemis,27,,-22.666667,-47.75
br,arthur nogueira,Arthur Nogueira,27,,-22.583333,-47.15
br,articura,Articura,16,,-2.333333,-49.516667
br,artur,Artur,05,,-12.416667,-40.633333
br,artur grande,Artur Grande,30,,-8.633333,-36.7
br,artur nogueira,Artur Nogueira,27,40404,-22.583333,-47.15
br,arua,Aruá,06,,-4.333333,-38.583333
br,aruaja,Aruajá,04,,-5.033333,-66.816667
br,aruana,Aruanã,04,,-7.616667,-60.316667
br,aruana,Aruanã,29,,-14.9,-51.083333
br,aru,Aru,04,,.65,-67.233333
br,aru,Aru,16,,-2.216667,-49.783333
br,aruaru,Aruaru,06,,-4.583333,-38.35
br,aruata,Aruatã,18,,-25.925441,-49.178695
br,aruau,Aruaú,04,,-.383333,-66.35
br,arueira,Arueira,05,,-11.566667,-41.783333
br,arueira,Arueira,13,,-6.366667,-46.483333
br,aruja,Arujá,27,72078,-23.4,-46.333333
br,aruma,Arumã,04,,-4.735556,-62.150556
br,arumanduba,Arumanduba,04,,-2.6,-66.366667
br,arumanduba,Arumanduba,16,,-1.483333,-52.483333
br,arumandupa,Arumandupa,04,,-2.6,-66.366667
br,arumim,Arumim,25,,3.433333,-60.916667
br,arunta,Arunta,13,,-2.566667,-44.15
br,aruti,Aruti,04,,-.316667,-66.083333
br,arvaja,Arvajá,04,,-5.033333,-66.816667
br,arvoredo,Arvoredo,06,,-5.066667,-39.166667
br,arvoredo,Arvoredo,11,,-21.35,-56.416667
br,arvoredo,Arvoredo,17,,-7.1,-37.3
br,arvoredo,Arvoredo,26,,-28.4,-50.116667
br,arvore grande,Árvore Grande,11,,-19.216667,-51.816667
br,arvores,Árvores,23,,-29.266667,-53.55
br,arvoresinha,Arvoresinha,23,,-28.883333,-52.166667
br,arvore verde,Árvore Verde,05,,-13.566667,-40.883333
br,arvorezinha,Àrvorezinha,23,,-28.883333,-52.166667
br,ascencao,Ascenção,15,,-19.8,-44.583333
br,ascuria,Ascuria,26,,-26.966667,-49.366667
br,ascurra,Ascurra,26,,-26.966667,-49.366667
br,asdiubal,Asdiubal,15,,-16.833333,-41.7
br,asoenangka,Asoenangka,16,,1.766667,-56.366667
br,assacaio,Assacaio,04,,-3.816667,-69.4
br,assahytuba,Assahytuba,04,,-7.016667,-64.583333
br,assai,Assaí,18,12545,-23.366667,-50.816667
br,assai,Assaí,27,,-21.383333,-48.983333
br,assaituba,Assaituba,04,,-7.016667,-64.583333
br,assaizal,Assaizal,31,,-6.433333,-48.383333
br,assa-peixe,Assa-Peixe,15,,-15.85,-43.95
br,assarai,Assaraí,15,,-19.583333,-41.483333
br,assare,Assaré,06,11369,-6.866667,-39.866667
br,assembleia,Assembléia,02,,-9.4,-36.233333
br,assentadinho,Assentadinho,27,,-24.8307,-48.2865
br,assentado,Assentado,27,,-24.8144,-48.2717
br,assis,Assis,06,,-4.916667,-40.866667
br,assis,Assis,27,87473,-22.666667,-50.416667
br,assis brasil,Assis Brasil,01,,-10.916667,-69.533333
br,assis brasil,Assis Brasil,23,,-28.266667,-53.566667
br,assituas,Assituas,13,,-2.733333,-46.65
br,assiz,Assiz,27,,-22.666667,-50.416667
br,assu,Assu,22,,-5.577222,-36.9075
br,assu de torre,Assú de Torre,05,,-12.55,-38
br,assumpcao,Assumpção,04,,-5.016667,-62.783333
br,assumpcao,Assumpção,06,,-3.566667,-39.633333
br,assumpcao,Assumpção,24,,-9.016667,-61.616667
br,assuncao,Assunção,04,,-5.016667,-62.783333
br,assuncao,Assuncão,05,,-12.816667,-42.766667
br,assuncao,Assunção,06,,-3.566667,-39.633333
br,assuncao,Assuncão,17,,-7.066667,-36.716667
br,assuncao,Assunção,20,,-5.866667,-41.066667
br,assuncao,Assunção,22,,-5.516667,-35.8
br,assuncao,Assunção,24,,-8.133333,-63.016667
br,assungui,Assungui,18,,-25.530951,-50.553859
br,assunguy,Assunguy,18,,-24.983333,-49.5
br,assunguy de cima,Assunguy de Cima,18,,-24.983333,-49.5
br,assurua,Assuruá,05,,-11.3,-42.666667
br,astolfo dutra,Astolfo Dutra,15,10999,-21.316667,-42.866667
br,astorga,Astorga,18,20129,-23.216667,-51.666667
br,astrogildo,Astrogildo,21,,-22.977002,-43.585487
br,atafona,Atafona,11,,-23.533333,-55.283333
br,atafona,Atafona,21,,-21.616667,-41.016667
br,atafona,Atafona,26,,-27.116667,-49.5
br,ataiba pinto,Ataíba Pinto,15,,-20.2,-46.916667
br,atalaia,Atalaia,02,18908,-9.516667,-36.033333
br,atalaia,Atalaia,04,,-7.416667,-71.233333
br,atalaia,Atalaia,08,,-18.633333,-40.016667
br,atalaia,Atalaia,15,,-21.05,-45.983333
br,atalaia,Atalaia,16,,-.983333,-49.316667
br,atalaia,Atalaia,18,,-23.151633,-52.054438
br,atalaia,Atalaia,20,,-2.878611,-41.643889
br,atalaia,Atalaia,28,,-11.416667,-37.316667
br,atalaia do norte,Atalaia do Norte,04,,-4.365278,-70.193056
br,atalaia nova,Atalaia Nova,28,,-10.933333,-37.033333
br,atalaia velha,Atalaia Velha,28,,-10.966667,-37.066667
br,ataleia,Ataléia,15,,-18.05,-41.1
br,atalho,Atalho,05,,-10.116667,-40.733333
br,atalho,Atalho,21,,-22.55,-42.15
br,atalho,Atalho,30,,-8.983333,-38.333333
br,atamasio,Atamásio,11,,-21.516667,-54.15
br,atanasio,Atanasio,11,,-21.516667,-54.15
br,atanasio,Atanásio,13,,-3.588333,-43.175556
br,ataque,Ataque,05,,-12.85,-40.2
br,ataque,Ataque,15,,-22.033333,-45.566667
br,a. tarraca,A. Tarraca,11,,-22.316667,-55.033333
br,atauba,Ataúba,25,,-1.033333,-61.85
br,atenas,Atenas,01,,-8.866667,-71.483333
br,aterradinho,Aterradinho,11,,-21.133333,-56.65
br,aterradinho,Aterradinho,14,,-16.95,-57.35
br,aterradinho,Aterradinho,15,,-20.366667,-47.116667
br,aterradinho,Aterradinho,27,,-23.45,-48.566667
br,aterrado alto,Aterrado Alto,18,,-25.840009,-50.223137
br,aterrado,Aterrado,13,,-4.25,-45.633333
br,aterrado,Aterrado,14,,-17.016667,-56.6
br,athenas,Athenas,01,,-8.866667,-71.483333
br,ati-acu,Ati-Açu,23,,-28.05,-53.066667
br,ati acu,Ati Açu,23,,-28,-53.083333
br,ati assu,Ati Assu,23,,-28,-53.083333
br,atibaia,Atibaia,27,110970,-23.124167,-46.562222
br,ati-mirim,Ati-Mirim,23,,-28.05,-52.683333
br,atininga,Atininga,04,,-5.879444,-61.241667
br,atirado,Atirado,15,,-22.133333,-45.583333
br,atlantica,Atlântica,27,,-21.583333,-51.216667
br,atlantida,Atlântida,27,,-21.583333,-51.216667
br,atoleiro,Atoleiro,05,,-11.95,-44.716667
br,atoleiro,Atoleiro,13,,-3.412778,-42.667778
br,atoleiro,Atoleiro,20,,-3.6725,-42.599167
br,atoleiro,Atoleiro,22,,-6.333333,-37.883333
br,atoleiro de dentro,Atoleiro de Dentro,13,,-3.926944,-43.184722
br,atomia,Atomia,18,,-23.266667,-50.583333
br,atras dos morros,Atrás dos Morros,20,,-6,-41.466667
br,atravessado,Atravessado,04,,-4.085,-62.305
br,atuba,Atuba,18,,-25.433333,-49.233333
br,aturiai,Aturiaí,16,,-1.066667,-46.5
br,auari,Auari,04,,-8.333333,-67.333333
br,augosto severo,Augosto Severo,22,,-5.863333,-37.310556
br,augusta vitoria,Augusta Vitória,18,,-24.25,-50.85
br,augustinho,Augustinho,05,,-9.883333,-38.016667
br,augustinopolis,Augustinópolis,31,,-5.41,-47.706389
br,augusto correa,Augusto Correa,16,16280,-1.033333,-46.666667
br,augusto de lima,Augusto de Lima,15,,-18.1,-44.316667
br,augusto franco,Augusto Franco,15,,-21.716667,-43.633333
br,augusto montenegro,Augusto Montenegro,04,,-2.716667,-57.7
br,augusto nicolau,Augusto Nicolau,15,,-21.633333,-46.416667
br,augusto queiroga,Augusto Queiroga,15,,-17.483333,-41.666667
br,augusto seio,Augusto Seio,15,,-19.35,-41.083333
br,augusto severo,Augusto Severo,22,,-5.863333,-37.310556
br,augusto severo,Augusto Severo,23,,-28.816667,-51.8
br,augusto soares,Augusto Soares,15,,-21.283333,-45.7
br,auler,Auler,23,,-28.766667,-52.416667
br,aunas,Aunas,05,,-13.2,-39.3
br,aurea,Áurea,23,,-27.7,-52.066667
br,aureliopolis,Aureliópolis,29,,-17.15,-48.8
br,aurerliopolis,Aurerliopolis,29,,-17.15,-48.8
br,auriflama,Auriflama,27,11971,-20.683333,-50.566667
br,aurilandia,Aurilândia,29,,-16.733333,-50.466667
br,aurizona,Aurizona,13,,-1.283333,-45.766667
br,aurora,Aurora,01,,-9.683333,-72.083333
br,aurora,Aurora,05,,-12.4,-38.816667
br,aurora,Aurora,06,10757,-6.95,-38.966667
br,aurora,Aurora,11,,-19.2,-55.483333
br,aurora,Aurora,18,,-26.060833,-53.688056
br,ausentes,Ausentes,23,,-28.733333,-50.066667
br,austin,Austin,21,,-22.720978,-43.527517
br,autazes,Autazes,04,9614,-3.583333,-59.133333
br,auxiliadora,Auxiliadora,23,,-30.025,-51.191667
br,avahy,Avahy,27,,-22.133333,-49.366667
br,avai,Avaí,01,,-8.183333,-73.4
br,avai,Avaí,26,,-27.35,-51.583333
br,avai,Avaí,27,,-22.133333,-49.366667
br,avanhandava,Avanhandava,27,,-21.466667,-49.95
br,avantiguara,Avantiguara,15,,-18.766667,-49.083333
br,avare,Avaré,27,81287,-23.083333,-48.916667
br,avarzeado,Avarzeado,06,,-5.683333,-40.583333
br,avatinguara,Avatinguara,15,,-18.766667,-49.083333
br,aveiro,Aveiro,16,,-3.616667,-55.316667
br,avelar,Avelar,15,,-21.666667,-45.3
br,avelar,Avelar,21,,-22.321944,-43.406389
br,avelinopolis,Avelinópolis,29,,-16.5,-49.716667
br,avelino silveira,Avelino Silveira,15,,-15.1,-42.816667
br,avenca,Avenca,18,,-24.983333,-50.633333
br,avencal,Avencal,18,,-25.5538,-50.42894
br,avencal,Avencal,26,,-26.216567,-49.604935
br,avencal de baixo,Avencal de Baixo,26,,-26.216567,-49.604935
br,avencas,Avencas,27,,-22.283333,-50.116667
br,avenida,Avenida,05,,-13.006667,-38.525
br,avenquinha de santo antonio,Avenquinha de Santo Antônio,26,,-26.161593,-49.326335
br,aventureio,Aventureio,15,,-21.75,-42.816667
br,aviacao,Aviação,23,,-29.733333,-53.85
br,aviario,Aviário,05,,-12.3,-38.933333
br,avobral,Avobral,11,,-21.2,-56.833333
br,axinal dos rodrigues,Axinal dos Rodrigues,18,,-25.721388,-50.221168
br,axinim,Axinim,04,,-4.035278,-59.379722
br,axioma,Axioma,04,,-6.75,-64.516667
br,axixa,Axixá,13,,-2.85,-44.066667
br,axixa de goias,Axixá de Goiás,31,,-5.551111,-47.595556
br,axixa do tocantins,Axixá do Tocantins,31,9007,-5.551111,-47.595556
br,axui,Axuí,13,,-2.516667,-43.6
br,ayapua,Ayapua,04,,-4.463333,-62.055278
br,aymores,Aymores,05,,-17.833333,-40.166667
br,aymores,Aymorés,15,,-19.5,-41.066667
br,ayrao,Ayrão,04,,-2.626944,-60.95
br,ayri,Ayri,04,,-6.9,-58.283333
br,ayuruoca,Ayuruoca,15,,-21.966667,-44.6
br,azambuja,Azambuja,26,,-28.5,-49.216667
br,azauri,Azauri,16,,.616667,-54.15
br,azeredo,Azeredo,08,,-20.283333,-40.45
br,azevedo,Azevedo,06,,-5.216667,-40.066667
br,azevedo,Azevedo,08,,-20.283333,-40.45
br,azevedo,Azevedo,23,,-29.7,-51.333333
br,azevedo sodre,Azevedo Sodré,23,,-30.066667,-54.6
br,azevedro sodre,Azevedro Sodre,23,,-30.066667,-54.6
br,azevem,Azevém,17,,-6.966667,-38.616667
br,azevem,Azevém,30,,-8.233333,-36.666667
br,azeveria,Azeveria,30,,-8.233333,-36.666667
br,azurita,Azurita,15,,-20.016667,-44.466667
br,babacu,Babaçu,13,,-4.65,-43.6
br,babaculandia,Babaçulândia,31,,-7.209167,-47.621667
br,babia,Babia,06,,-3.55,-40.233333
br,babi,Babi,21,,-22.7,-43.383333
br,babilonia,Babilônia,08,,-20.933333,-41.416667
br,babilonia,Babilônia,13,,-8.283333,-45.95
br,babilonia,Babilônia,15,,-20.5,-46.65
br,babilonia,Babilônia,21,,-22.55,-44.466667
br,baby,Baby,21,,-22.7,-43.383333
br,babylonia,Babylonia,21,,-22.55,-44.466667
br,bacaba,Bacaba,04,,-3.416667,-66.05
br,bacaba,Bacaba,13,,-2.983333,-43.85
br,bacaba,Bacaba,31,,-10.915278,-48.529444
br,bacaba i,Bacaba I,13,,-3.605556,-43.495556
br,bacaba ii,Bacaba II,13,,-3.395,-43.232778
br,bacabal,Bacabal,04,,-5.283333,-60.566667
br,bacabal,Bacabal,13,72374,-4.233333,-44.783333
br,bacabal,Bacabal,16,,-5.533333,-56.916667
br,bacabal,Bacabal,25,,1.45,-60.7
br,bacabal,Bacabal,31,,-11.933056,-49.190556
br,bacabal do carrinho,Bacabal do Carrinho,13,,-3.721667,-43.355278
br,bacabal dos crentes,Bacabal dos Crentes,13,,-3.7275,-43.336667
br,bacabal do tiberio,Bacabal do Tibério,13,,-3.4825,-43.449444
br,bacabal ii,Bacabal II,13,,-3.37,-43.420278
br,bacabal iii,Bacabal III,13,,-3.506389,-43.338333
br,bacabalzinho,Bacabalzinho,16,,-5.466667,-56.883333
br,bacada,Bacada,04,,-6.316667,-68.166667
br,bacaeri,Bacaeri,14,,-14.2,-55.083333
br,bacaetava,Bacaetava,27,,-23.433333,-47.6
br,bacaina,Bacaína,13,,-6.75,-44.066667
br,bacaiuval,Bacaiuval,14,,-14.65,-57.216667
br,bacalhau,Bacalhau,05,,-12.316667,-38.433333
br,bacao,Bação,15,,-20.333333,-43.833333
br,bacara,Bacará,25,,.710833,-61.648611
br,bacatuba,Bacatuba,13,,-5.666667,-43.7
br,bacatu,Bacatu,13,,-3.816667,-44.866667
br,bacauba,Bacaúba,20,,-8.944167,-45.431111
br,bacaubas,Bacaúbas,20,,-8.944167,-45.431111
br,bacaxa,Bacaxá,21,,-22.9,-42.466667
br,bacayuval,Bacayuval,14,,-14.65,-57.216667
br,bacelar,Bacelar,21,,-21.916667,-42.616667
br,bacia de pedra,Bacia de Pedra,21,,-22.4175,-43.756944
br,bacia de pedras,Bacia de Pedras,21,,-22.4175,-43.756944
br,bacre,Bacre,16,,-1.9,-50.2
br,bacue,Bacué,13,,-3.373611,-42.440278
br,bacumixa,Bacumixá,06,,-3.316667,-39.466667
br,bacupari,Bacupari,06,,-7.3,-38.8
br,bacurau,Bacurau,06,,-3.25,-39.433333
br,bacuri,Bacuri,04,,-4.476389,-62.193333
br,bacuri,Bacuri,13,,-1.733333,-45.133333
br,bacuri,Bacuri,20,,-3.7325,-42.643056
br,bacuri,Bacuri,27,,-21.05,-50.983333
br,bacuri,Bacuri,31,,-5.766667,-47.8
br,bacuri grande,Bacuri Grande,04,,-4.491944,-62.205
br,bacuri grande,Bacuri Grande,16,,-5.433333,-48.6
br,bacuri i,Bacuri I,13,,-3.435556,-43.4325
br,bacuri ii,Bacuri II,13,,-3.111389,-42.354167
br,bacuriteua,Bacuriteua,16,,-.983333,-46.733333
br,bacuriti,Bacuriti,27,,-21.616667,-49.433333
br,bacurituba,Bacurituba,13,,-2.716667,-44.716667
br,bacurizeiro,Bacurizeiro,13,,-3.143056,-42.219722
br,bacurizinho,Bacurizinho,16,,-5.416667,-48.633333
br,bacururi,Bacururi,04,,-3.75,-66.183333
br,bacururu,Bacururu,04,,-3.75,-66.183333
br,bacury,Bacury,04,,-4.85,-62.533333
br,bacury grande,Bacury Grande,16,,-5.433333,-48.6
br,bacury sinho,Bacury Sinho,16,,-5.416667,-48.633333
br,badajos,Badajós,04,,-3.416667,-62.666667
br,badajos,Badajós,16,,-2.516667,-47.783333
br,badajos,Badajós,28,,-10.566667,-36.816667
br,badajoz,Badajóz,16,,-2.516667,-47.783333
br,badalo,Badalo,17,,-7.416667,-36.433333
br,badaro,Badaró,21,,-21.316667,-41.666667
br,badia,Badia,28,,-9.666667,-37.75
br,bady bassitt,Bady Bassitt,27,14216,-20.933333,-49.466667
br,bady brassitt,Bady Brassitt,27,,-20.933333,-49.466667
br,baependi,Baependi,15,12853,-21.95,-44.883333
br,baependy,Baependy,15,,-21.95,-44.883333
br,baeta,Baeta,05,,-11.2,-43.083333
br,baetas,Baetas,04,,-6.984722,-62.812778
br,baete,Baetê,05,,-13.716667,-40.066667
br,bagaco,Bagaço,13,,-3.458333,-43.4525
br,bagagem,Bagagem,15,,-18.983333,-47.466667
br,bage,Bagé,23,98943,-31.333333,-54.1
br,bago,Bago,16,,-4.699167,-52.765
br,bagre,Bagre,14,,-15.95,-55.716667
br,bagre,Bagre,15,,-19.3,-42.5
br,bagre,Bagre,16,,-1.9,-50.2
br,bagre,Bagre,18,,-25.102805,-48.317008
br,baguacu,Baguaçu,11,,-21.383333,-57
br,baguacu,Baguaçu,27,,-20.166667,-47.583333
br,baguari,Baguari,15,,-18.366667,-42.8
br,baguari,Baguari,27,,-22.866667,-47.983333
br,baguassu,Baguassú,27,,-20.716667,-49.066667
br,bahia,Bahia,05,,-12.983333,-38.516667
br,bahia,Bahia,26,,-26.816667,-52.033333
br,bahia de pedra,Bahia de Pedra,14,,-16.466667,-58.083333
br,bahia do genipapo,Bahia do Genipapo,11,,-19.666667,-56.15
br,bahianos,Bahianos,04,,-6.3,-62.216667
br,bahus,Bahus,11,,-18.316667,-53.166667
br,bahusinho,Bahúsinho,11,,-18.316667,-53.166667
br,baia,Baía,05,,-12.983333,-38.516667
br,baia,Baía,11,,-19.933333,-56.283333
br,baia,Baía,14,,-16.733333,-56.916667
br,baia,Baía,16,,-.783333,-51.133333
br,baia,Baía,26,,-26.816667,-52.033333
br,baia bela,Baía Bela,14,,-16.166667,-58.75
br,baia bonita,Baía Bonita,05,,-13.75,-40.216667
br,baia branca,Baía Branca,27,,-23.328547,-46.648192
br,baiacus,Baiacus,22,,-5.75,-37.85
br,baia das garcas,Baía das Garças,11,,-21.066667,-56.833333
br,baia das gracas,Baía das Graças,11,,-21.066667,-56.833333
br,baia das pedras,Baía das Pedras,11,,-19.283333,-55.716667
br,baia das pedras,Baía das Pedras,14,,-16.466667,-58.083333
br,baia da traicao,Baía da Traição,17,,-6.7,-34.933333
br,baia de cima,Baía de Cima,17,,-7.433333,-34.833333
br,baia de las pedras,Baía de las Pedras,14,,-16.466667,-58.083333
br,baia de pedras,Baia de Pedras,14,,-16.466667,-58.083333
br,baia de sao felix,Baía de São Felix,14,,-16.466667,-55.933333
br,baia de sao luis,Baía de São Luís,14,,-16.7,-57.216667
br,baia do cervo,Baía do Cervo,11,,-19.5,-55.833333
br,baia do genipapo,Baía do Genipapo,11,,-19.666667,-56.15
br,baia do itajai,Baía do Itajaí,26,,-26.651238,-49.853402
br,baia dos cavalos,Baía dos Cavalos,14,,-16.333333,-56.2
br,baia dos nunes,Baía dos Nunes,14,,-15.716667,-55.9
br,baia dos passaros,Baía dos Pássaros,11,,-17.833333,-55.483333
br,baia dos passaros,Baía dos Pássaros,14,,-16.6,-55.866667
br,baia formosa,Baía Formosa,21,,-22.833333,-41.966667
br,baia formosa,Baía Formosa,22,,-6.366667,-35
br,baia funda,Baía Funda,20,,-8.883333,-45.966667
br,baia mineira,Baía Mineira,11,,-18.466667,-56.45
br,baiana,Baiana,15,,-17.85,-40.783333
br,baianopolis,Baianópolis,11,,-19.766667,-54.783333
br,baianos,Baianos,04,,-6.3,-62.216667
br,baianos,Baianos,18,,-24.416667,-52.983333
br,baiao,Baião,06,,-7.733333,-38.916667
br,baiao,Baião,13,,-3.166667,-43.65
br,baiao,Baião,16,12316,-2.683333,-49.683333
br,baiao,Baião,22,,-6,-38.433333
br,baiao,Baião,30,,-7.833333,-38.083333
br,baiao,Baião,31,,-11.516667,-47.7
br,baiao grande,Baião Grande,30,,-8.8,-37.35
br,baiaozinho,Baiãozinho,30,,-8.783333,-37.333333
br,baia piraputanga,Baía Piraputanga,14,,-16.3,-56.133333
br,baia santa clara,Baía Santa Clara,11,,-19.433333,-55.383333
br,baia verde,Baía Verde,11,,-17.716667,-55.55
br,baiazinha,Baìazinha,11,,-21.716667,-57.283333
br,baiepau,Baiepau,25,,2.116667,-59.75
br,baile,Baile,11,,-22.233333,-53.4
br,bailique,Bailique,03,,.966667,-50.066667
br,bailique,Bailique,16,,-2.766667,-49.783333
br,bainho,Bainho,14,,-16.683333,-55.433333
br,baioes,Baiões,15,,-20.616667,-45.333333
br,baireiro,Baireiro,23,,-27.916667,-53.1
br,bairrinho,Bairrinho,27,,-22.6,-47.1
br,bairro 29 de marco,Bairro 29 de Março,21,,-22.890486,-43.617473
br,bairro aboboral,Bairro Aboboral,27,,-24.501115,-48.06458
br,bairro adriana,Bairro Adriana,21,,-22.885084,-43.546989
br,bairro afonso vizeu,Bairro Afonso Vizeu,21,,-22.923753,-43.57351
br,bairro aguacai,Bairro Aguaçai,27,,-23.657582,-47.077553
br,bairro agua do barreiro,Bairro Água do Barreiro,18,,-23.904024,-50.597442
br,bairro agua do oleo,Bairro Água do Óleo,18,,-23.002824,-49.992588
br,bairro agua esprajada,Bairro Agua Esprajada,27,,-23.660448,-47.047817
br,bairro agua feia,Bairro Água Feia,18,,-23.161906,-49.941401
br,bairro agua preta,Bairro Água Preta,27,,-23.12204,-46.696542
br,bairro agua quente,Bairro Água Quente,27,,-24.8814,-48.5078
br,bairro agulhas negras,Bairro Agulhas Negras,21,,-22.933696,-43.562129
br,bairro alegre,Bairro Alegre,27,,-23.284309,-46.70061
br,bairro alessandra,Bairro Alessandra,21,,-22.886949,-43.574175
br,bairro alto,Bairro Alto,18,,-24.811987,-48.930066
br,bairro alto,Bairro Alto,27,,-23.483333,-45.35
br,bairro anapolis,Bairro Anapolis,21,,-22.914538,-43.612669
br,bairro andre lopes,Bairro André Lopes,27,,-24.6015,-48.4059
br,bairro andreotti,Bairro Andreotti,18,,-23.173442,-52.003231
br,bairro araujo,Bairro Araujo,21,,-22.824553,-43.321463
br,bairro areado,Bairro Areado,27,,-24.565427,-48.788241
br,bairro areia branca,Bairro Areia Branca,18,,-23.936,-50.4617
br,bairro areia branca,Bairro Areia Branca,27,,-24.9524,-48.5636
br,bairro arixiguana,Bairro Arixiguana,18,,-23.756404,-50.617754
br,bairro aroeira,Bairro Aroeira,27,,-24.8657,-48.5494
br,bairro aurora,Bairro Aurora,21,,-22.911084,-43.582225
br,bairro badenfurt,Bairro Badenfurt,26,,-26.8824,-49.1405
br,bairro bairro nova mairinque,Bairro Bairro Nova Mairinque,27,,-23.537143,-47.19141
br,bairro bananal pequeno,Bairro Bananal Pequeno,27,,-24.501354,-48.077049
br,bairro barata,Bairro Barata,21,,-22.891761,-43.44159
br,bairro barra das provas,Bairro Barra das Provas,18,,-24.674084,-48.94434
br,bairro barra das provas,Bairro Barra das Provas,27,,-24.671723,-48.938669
br,bairro barra do betari,Bairro Barra do Betari,27,,-24.612374,-48.613839
br,bairro barra do taquaruvira,Bairro Barra do Taquaruvira,27,,-24.611662,-48.622733
br,bairro barra grande,Bairro Barra Grande,18,,-23.98695,-50.598238
br,bairro barra grande,Bairro Barra Grande,27,,-24.508149,-48.923928
br,bairro barra mansa,Bairro Barra Mansa,27,,-23.9589,-47.1318
br,bairro barra ribeirao do ferro,Bairro Barra Ribeirão do Ferro,26,,-27.0659,-49.6501
br,bairro barreiro,Bairro Barreiro,18,,-25.328333,-50.333611
br,bairro batistini,Bairro Batistini,27,,-23.754,-46.5799
br,bairro beija-flor,Bairro Beija-flor,27,,-23.4341,-46.153
br,bairro bela vista,Bairro Bela Vista,18,,-23.054823,-49.977433
br,bairro bela vista,Bairro Bela Vista,26,,-26.8982,-49.0091
br,bairro bela vista,Bairro Bela Vista,27,,-24.7656,-48.487
br,bairro belchior,Bairro Belchior,27,,-23.989623,-47.120335
br,bairro benfica,Bairro Benfica,18,,-25.52638,-50.46454
br,bairro biquinha,Bairro Biquinha,21,,-22.331866,-42.94597
br,bairro boava,Bairro Boava,27,,-23.7719,-47.1384
br,bairro boa vista,Bairro Boa Vista,27,,-23.003611,-46.511111
br,bairro bombas,Bairro Bombas,27,,-24.606013,-48.653359
br,bairro borore,Bairro Bororé,27,,-23.7712,-46.6428
br,bairro briquituba,Bairro Briquituba,27,,-23.519922,-47.238803
br,bairro buriti,Bairro Buriti,21,,-22.716239,-43.431153
br,bairro cachoeira,Bairro Cachoeira,18,,-23.227782,-49.962968
br,bairro cachoeira,Bairro Cachoeira,27,,-23.3707,-46.221
br,bairro caetetuba,Bairro Caetetuba,27,,-23.136667,-46.643611
br,bairro cafundo,Bairro Cafundo,27,,-23.3564,-46.235
br,bairro caiacanga,Bairro Caiacanga,27,,-24.560803,-48.019199
br,bairro caiacoara,Bairro Caiaçoara,27,,-23.183056,-46.680833
br,bairro caicara,Bairro Caiçara,18,,-23.112365,-52.090032
br,bairro camargo,Bairro Camargo,27,,-24.509418,-48.581276
br,bairro camarista meier,Bairro Camarista Méier,21,,-22.913748,-43.299144
br,bairro cambui,Bairro Cambuí,18,,-23.864235,-50.417751
br,bairro caminho do sitio,Bairro Caminho do Sítio,27,,-23.8288,-46.7449
br,bairro campininha,Bairro Campininha,27,,-23.240833,-46.654167
br,bairro campista,Bairro Campista,27,,-22.673911,-45.594034
br,bairro campo dos aleixos,Bairro Campo dos Aleixos,27,,-23.070674,-46.685954
br,bairro cangume,Bairro Cangume,27,,-24.60504,-48.799002
br,bairro capelinha,Bairro Capelinha,27,,-23.733407,-47.024174
br,bairro capinzal,Bairro Capinzal,18,,-23.910858,-50.552356
br,bairro capoeirinha,Bairro Capoeirinha,27,,-24.501628,-48.84988
br,bairro capuava,Bairro Capuava,27,,-23.305983,-46.622562
br,bairro capuavinha,Bairro Capuavinha,27,,-23.325211,-46.56057
br,bairro caracas,Bairro Caraças,27,,-24.665456,-48.893277
br,bairro caracol,Bairro Caracol,27,,-24.569933,-48.555267
br,bairro caratuva,Bairro Caratuva,18,,-23.650488,-50.738772
br,bairro carmo messias,Bairro Carmo Messias,27,,-23.748419,-47.047244
br,bairro caroba,Bairro Caroba,21,,-22.896039,-43.544601
br,bairro carolina,Bairro Carolina,21,,-22.875711,-43.538073
br,bairro castelhanos,Bairro Castelhanos,27,,-24.554,-48.4302
br,bairro cateto,Bairro Cateto,18,,-23.204755,-49.797512
br,bairro cebandilha,Bairro Cebandilha,27,,-23.598324,-47.225261
br,bairro chapero,Bairro Chaperó,21,,-22.810306,-43.758947
br,bairro congonhas,Bairro Congonhas,18,,-23.574597,-50.617735
br,bairro convento,Bairro Convento,27,,-23.454208,-46.070375
br,bairro corda,Bairro Corda,27,,-24.591759,-48.389891
br,bairro coreiropolis,Bairro Coreirópolis,27,,-24.523967,-48.838267
br,bairro corrego da lavra,Bairro Córrego da Lavra,27,,-24.630792,-48.768138
br,bairro corrego da onca,Bairro Córrego da Onça,27,,-24.792761,-48.527787
br,bairro corrego das mocas,Bairro Córrego das Moças,18,,-24.725963,-48.820886
br,bairro corrego do chiqueiro,Bairro Córrego do Chiqueiro,27,,-24.502988,-48.976585
br,bairro cortesias,Bairro Cortesias,27,,-24.745674,-48.14466
br,bairro cristovao,Bairro Cristóvão,27,,-24.560246,-48.06816
br,bairro cruz alta,Bairro Cruz Alta,27,,-24.6499,-48.3138
br,bairro cruzeiro,Bairro Cruzeiro,23,,-29.1708,-51.1404
br,bairro curucutu,Bairro Curucutu,27,,-23.8668,-46.5945
br,bairro da caceia,Bairro da Caceia,27,,-23.325825,-46.639017
br,bairro da cachoeira,Bairro da Cachoeira,27,,-23.73059,-47.043646
br,bairro da cachoeirinha,Bairro da Cachoeirinha,27,,-23.911665,-47.067539
br,bairro da capelinha,Bairro da Capelinha,27,,-23.4887,-46.2311
br,bairro da capivara,Bairro da Capivara,27,,-24.530848,-48.958069
br,bairro da cascata,Bairro da Cascata,27,,-23.261507,-46.71176
br,bairro da enseada,Bairro da Enseada,27,,-23.716667,-45.433333
br,bairro da estrela,Bairro da Estrela,18,,-25.952069,-50.014187
br,bairro da fazenda,Bairro da Fazenda,27,,-24.651899,-48.81359
br,bairro da forquilha,Bairro da Forquilha,27,,-24.660452,-48.73796
br,bairro da imbuia,Bairro da Imbuia,18,,-24.866667,-51
br,bairro da lagoa,Bairro da Lagoa,18,,-25.4931,-50.6615
br,bairro da lagoa,Bairro da Lagoa,27,,-23.583853,-47.035675
br,bairro da luz,Bairro da Luz,21,,-22.900972,-43.311835
br,bairro da onca,Bairro da Onça,27,,-24.698708,-48.352026
br,bairro da palmerinha,Bairro da Palmerinha,27,,-23.872981,-47.008876
br,bairro da pedreira,Bairro da Pedreira,27,,-23.064444,-46.628611
br,bairro da ponte,Bairro da Ponte,27,,-23.190731,-47.533909
br,bairro da prata,Bairro da Prata,21,,-22.383605,-42.953589
br,bairro das andorinhas,Bairro das Andorinhas,18,,-24.677381,-48.580755
br,bairro das andorinhas,Bairro das Andorinhas,27,,-24.670499,-48.584397
br,bairro das chagas,Bairro das Chagas,27,,-24.504068,-48.959916
br,bairro da serra,Bairro da Serra,27,,-24.551673,-48.68187
br,bairro da serra da caneca fina,Bairro da Serra da Caneca Fina,21,,-22.485902,-42.959023
br,bairro da serrinha,Bairro da Serrinha,27,,-23.51418,-47.060286
br,bairro das garcas,Bairro das Garças,27,,-23.616079,-47.02439
br,bairro das ilhas,Bairro das Ilhas,27,,-24.7789,-48.5143
br,bairro das lagoas,Bairro das Lagoas,27,,-23.947929,-47.056116
br,bairro das laranjeiras,Bairro das Laranjeiras,27,,-23.380171,-46.708493
br,bairro das palmeiras,Bairro das Palmeiras,27,,-23.381396,-46.625779
br,bairro das pederneiras,Bairro das Pederneiras,27,,-21.733333,-51.833333
br,bairro das pedras,Bairro das Pedras,27,,-23.909982,-47.029584
br,bairro das ritas,Bairro das Ritas,27,,-23.90769,-47.097686
br,bairro das rosas,Bairro das Rosas,27,,-23.971,-47.1078
br,bairro das senhorinhas,Bairro das Senhorinhas,27,,-23.9697,-47.0471
br,bairro da usina,Bairro da Usina,27,,-23.087222,-46.643889
br,bairro da velha central,Bairro da Velha Central,26,,-26.9312,-49.1275
br,bairro de furnas,Bairro de Furnas,27,,-24.535039,-48.726149
br,bairro de itapuca,Bairro de Itapuca,21,,-22.474,-44.4783
br,bairro de lavras,Bairro de Lavras,27,,-24.7746,-48.2151
br,bairro de sao lourenco,Bairro de São Lourenco,27,,-23.816667,-46.05
br,bairro descalvado,Bairro Descalvado,27,,-24.64509,-48.646805
br,bairro diana,Bairro Diana,21,,-22.91526,-43.579973
br,bairro do albuquerque,Bairro do Albuquerque,21,,-22.379099,-42.920661
br,bairro do areado,Bairro do Areado,27,,-24.697398,-48.373357
br,bairro do azeite,Bairro do Azeite,27,,-24.814134,-48.177178
br,bairro do barreiro,Bairro do Barreiro,27,,-23.466667,-49.283333
br,bairro do barro,Bairro do Barro,27,,-23.716667,-45.4
br,bairro do bau,Bairro do Baú,27,,-24.564639,-48.567185
br,bairro do betari,Bairro do Betari,27,,-24.579576,-48.630717
br,bairro do bonito,Bairro do Bonito,27,,-22.833333,-45.033333
br,bairro do breu,Bairro do Breu,27,,-23.075833,-46.742222
br,bairro do capim azedo,Bairro do Capim Azedo,27,,-23.675824,-47.204927
br,bairro do capim grosso,Bairro do Capim Grosso,20,,-7.916667,-41.883333
br,bairro do capuava,Bairro do Capuava,18,,-24.695217,-48.81938
br,bairro do carmo,Bairro do Carmo,27,,-23.630976,-47.099544
br,bairro do corrego dos boavas,Bairro do Córrego dos Boavas,27,,-24.608912,-48.815561
br,bairro do cupim,Bairro do Cupim,27,,-23.716568,-47.22927
br,bairro do curral,Bairro do Curral,27,,-23.653796,-47.176678
br,bairro do descampado,Bairro do Descampado,18,,-24.716462,-48.943762
br,bairro do engano,Bairro do Engano,27,,-23.997723,-47.152318
br,bairro do feital,Bairro do Feital,27,,-23.71865,-47.19626
br,bairro do feixe,Bairro do Feixe,18,,-24.677873,-48.591815
br,bairro do felisberto,Bairro do Felisberto,18,,-24.033333,-50.65
br,bairro do fria,Bairro do Fria,27,,-24.726817,-48.473872
br,bairro do frigorifico,Bairro do Frigorífico,27,,-24.68962,-48.111615
br,bairro do gamba,Bairro do Gambá,18,,-23.6242,-50.6321
br,bairro do goiana,Bairro do Goianã,27,,-23.556161,-47.151466
br,bairro do gritem,Bairro do Gritem,18,,-25.910306,-50.160861
br,bairro do imbui,Bairro do Imbuí,21,,-22.391481,-42.997087
br,bairro do jacaranda,Bairro do Jacarandá,21,,-22.4306,-42.914187
br,bairro do jacu,Bairro do Jacu,27,,-23.316667,-48.533333
br,bairro do juquia,Bairro do Juquiá,27,,-23.922885,-47.117136
br,bairro do lajeado,Bairro do Lajeado,27,,-24.597722,-48.871156
br,bairro do laranjal,Bairro do Laranjal,18,,-24.717075,-48.97021
br,bairro do machadinho,Bairro do Machadinho,27,,-23.062222,-46.694722
br,bairro do olinto,Bairro do Olinto,27,,-23.738523,-47.099322
br,bairro do paiol,Bairro do Paiol,27,,-23.4178,-46.0019
br,bairro do paiol pequeno,Bairro do Paiol Pequeno,27,,-23.632525,-47.193981
br,bairro do paiolzinho,Bairro do Paiolzinho,27,,-23.73028,-47.202607
br,bairro do palmital,Bairro do Palmital,27,,-24.536206,-48.831648
br,bairro do pavao,Bairro do Pavão,27,,-23.629523,-47.15224
br,bairro do pedroso,Bairro do Pedroso,27,,-22.8,-45.066667
br,bairro do piai,Bairro do Piaí,27,,-23.7538,-47.2077
br,bairro do quebra-frascos,Bairro do Quebra-Frascos,21,,-22.415559,-42.996086
br,bairro do ribeirao,Bairro do Ribeirão,27,,-23.509081,-47.152617
br,bairro do rosario,Bairro do Rosário,27,,-23.258282,-46.541276
br,bairro dos alexandres,Bairro dos Alexandres,27,,-23.972938,-47.161631
br,bairro dos alves,Bairro dos Alves,18,,-23.884958,-50.577372
br,bairro dos alves,Bairro dos Alves,27,,-23.810972,-47.201294
br,bairro do sao jose,Bairro do São José,20,,-3.5175,-42.181667
br,bairro dos baianos,Bairro dos Baianos,18,,-23.5983,-50.5083
br,bairro dos barnabes,Bairro dos Barnabes,27,,-23.981137,-47.155438
br,bairro dos camargo,Bairro dos Camargo,27,,-23.92,-47.1044
br,bairro dos canudos,Bairro dos Canudos,27,,-24.8965,-48.5395
br,bairro dos carmos,Bairro dos Carmos,27,,-23.87496,-47.080122
br,bairro dos carreiros,Bairro dos Carreiros,18,,-23.861141,-50.569381
br,bairro dos coelhos,Bairro dos Coelhos,27,,-24.533159,-48.937854
br,bairro dos domingos,Bairro dos Domingos,27,,-23.730769,-47.120324
br,bairro do setubal,Bairro do Setubal,27,,-23.574557,-47.225422
br,bairro dos farias,Bairro dos Farias,27,,-23.877441,-47.125403
br,bairro dos ferreiras,Bairro dos Ferreiras,27,,-23.942653,-47.171522
br,bairro dos filipes,Bairro dos Filipes,27,,-23.78161,-47.140576
br,bairro dos garcias,Bairro dos Garcias,27,,-23.859163,-47.084951
br,bairro dos godoy,Bairro dos Godoy,18,,-23.580978,-50.522177
br,bairro dos grilos,Bairro dos Grilos,27,,-23.7737,-47.0319
br,bairro dos henrique,Bairro dos Henrique,27,,-24.630252,-48.806854
br,bairro dos justinos,Bairro dos Justinos,27,,-23.922898,-47.077277
br,bairro dos justos,Bairro dos Justos,27,,-23.946602,-47.024722
br,bairro dos mendes,Bairro dos Mendes,27,,-23.762692,-47.025153
br,bairro dos meninos,Bairro dos Meninos,27,,-24.556565,-48.142218
br,bairro dos mineiros,Bairro dos Mineiros,18,,-23.592538,-50.521858
br,bairro dos nogueiras,Bairro dos Nogueiras,27,,-23.4316,-46.039
br,bairro do soroca mirim,Bairro do Soroca Mirim,27,,-23.674431,-47.111738
br,bairro dos padeiros,Bairro dos Padeiros,27,,-23.88893,-47.046364
br,bairro dos paes,Bairro dos Paes,27,,-23.689519,-47.242808
br,bairro dos patos,Bairro dos Patos,27,,-22.133333,-49.2
br,bairro dos pederneiras,Bairro dos Pederneiras,27,,-21.733333,-51.833333
br,bairro dos pedrosos,Bairro dos Pedrosos,27,,-23.732722,-47.078196
br,bairro dos pereiras,Bairro dos Pereiras,27,,-23.117778,-46.67
br,bairro dos pessegueiros,Bairro dos Pessegueiros,21,,-22.316032,-42.942636
br,bairro dos pintos,Bairro dos Pintos,27,,-23.216389,-46.542778
br,bairro dos pires,Bairro dos Pires,27,,-23.665542,-47.006251
br,bairro dos policenos,Bairro dos Policenos,18,,-25.499167,-50.384722
br,bairro dos pratas,Bairro dos Pratas,27,,-23.953653,-47.047182
br,bairro dos remdios,Bairro dos Remdios,27,,-23.3217,-46.0904
br,bairro dos remedios,Bairro dos Remédios,27,,-23.267562,-46.535873
br,bairro dos ribeiro,Bairro dos Ribeiro,27,,-23.7746,-47.062207
br,bairro dos rodrigues,Bairro dos Rodrigues,27,,-23.725725,-47.091546
br,bairro dos rosas,Bairro dos Rosas,27,,-23.857348,-47.004594
br,bairro dos soares,Bairro dos Soares,27,,-23.8425,-47.0075
br,bairro dos tatetos,Bairro dos Tatetos,27,,-23.8288,-46.5727
br,bairro dos telles,Bairro dos Telles,18,,-23.833333,-50.45
br,bairro dos valos,Bairro dos Valos,27,,-23.300813,-46.666147
br,bairro dos veigas,Bairro dos Veigas,27,,-23.401336,-46.508078
br,bairro dos vitalino,Bairro dos Vitalino,27,,-23.9512,-47.1619
br,bairro do tanque,Bairro do Tanque,27,,-23.030556,-46.537222
br,bairro do taquari,Bairro do Taquari,27,,-25.0562,-48.1016
br,bairro do teles,Bairro do Teles,18,,-23.833333,-50.45
br,bairro do tigre,Bairro do Tigre,18,,-23.600948,-50.649561
br,bairro do tude,Bairro do Tude,27,,-24.543418,-48.556429
br,bairro do turvo,Bairro do Turvo,27,,-24.65657,-48.133115
br,bairro do vieirinha,Bairro do Vieirinha,27,,-23.747117,-47.232302
br,bairro do vital,Bairro do Vital,27,,-22.916667,-47.366667
br,bairro do xisto,Bairro do Xisto,18,,-23.848671,-50.54375
br,bairro duvida,Bairro Dúvida,27,,-24.9468,-48.5397
br,bairro elaine,Bairro Elaine,21,,-22.923769,-43.52259
br,bairro elisa maria,Bairro Elisa Maria,21,,-22.872494,-43.573322
br,bairro ema da flora,Bairro Ema da Flora,18,,-23.073585,-49.981238
br,bairro engenheiro neiva,Bairro Engenheiro Neiva,27,,-22.784039,-45.163282
br,bairro engenho,Bairro Engenho,27,,-24.52859,-48.049326
br,bairro engenho velho,Bairro Engenho Velho,27,,-24.510945,-48.86885
br,bairro engo goulart,Bairro Engo Goulart,27,,-23.49587,-46.509549
br,bairro esplanada,Bairro Esplanada,21,,-22.872965,-43.550881
br,bairro esplanada,Bairro Esplanada,23,,-29.2006,-51.2062
br,bairro estancia lago azul,Bairro Estância Lago Azul,27,,-23.298599,-46.713833
br,bairro estreitinho,Bairro Estreitinho,18,,-24.899,-48.5799
br,bairro estreitinho,Bairro Estreitinho,27,,-24.899765,-48.568937
br,bairro faxina,Bairro Faxina,18,,-25.447778,-50.312222
br,bairro feital,Bairro Feital,27,,-24.635577,-48.542046
br,bairro figueira,Bairro Figueira,27,,-23.2909,-46.1271
br,bairro florianos,Bairro Florianos,18,,-25.464167,-50.360833
br,bairro fortaleza,Bairro Fortaleza,26,,-26.8536,-49.0558
br,bairro fregueisa da escada,Bairro Fregueisa da Escada,27,,-23.3844,-46.0581
br,bairro geremuniz,Bairro Geremuniz,27,,-23.3554,-46.2082
br,bairro godinho,Bairro Godinho,27,,-23.9499,-47.1022
br,bairro goiabal,Bairro Goiabal,27,,-23.3505,-46.0815
br,bairro grotao,Bairro Grotão,21,,-22.386016,-42.922211
br,bairro guarau,Bairro Guaraú,27,,-24.8067,-48.09
br,bairro guarauna de docas,Bairro Guaraúna de Docas,18,,-25.4275,-50.273056
br,bairro guarauninha,Bairro Guarauninha,18,,-25.449167,-50.295
br,bairro guarda-mao,Bairro Guarda-Mão,27,,-24.597842,-48.851696
br,bairro guaxinduva,Bairro Guaxinduva,27,,-23.109722,-46.511944
br,bairro gurutuba,Bairro Gurutuba,27,,-24.63017,-48.826301
br,bairro gurutuba dos boavas,Bairro Gurutuba dos Boavas,27,,-24.614329,-48.824211
br,bairro gurutuba dos martins,Bairro Gurutuba dos Martins,27,,-24.612166,-48.833488
br,bairro hilario,Bairro Hilário,27,,-24.61987,-48.286907
br,bairro iguatemi,Bairro Iguatemi,27,,-24.527224,-48.909816
br,bairro ilha do cedro,Bairro Ilha do Cedro,27,,-24.736309,-48.520751
br,bairro indaiatuba,Bairro Indaiatuba,27,,-24.8752,-48.5434
br,bairro iolanda danon,Bairro Iolanda Danon,21,,-22.77303,-43.511296
br,bairro ipatinga,Bairro Ipatinga,21,,-22.879665,-43.541867
br,bairro iracema,Bairro Iracema,21,,-22.880965,-43.592762
br,bairro irmaos prata,Bairro Irmãos Prata,21,,-22.772226,-43.417413
br,bairro itapeti,Bairro Itapeti,27,,-23.4077,-46.182
br,bairro itapetinga,Bairro Itapetinga,27,,-23.158889,-46.5475
br,bairro itapoa,Bairro Itapoã,21,,-22.769086,-43.505454
br,bairro itoupava do norte,Bairro Itoupava do Norte,26,,-26.8895,-49.0669
br,bairro ivaporunduva,Bairro Ivaporunduva,27,,-24.5629,-48.3928
br,bairro jabour,Bairro Jabour,21,,-22.879052,-43.494169
br,bairro jardim aladim,Bairro Jardim Aladim,27,,-23.808063,-46.736069
br,bairro jardim alamo,Bairro Jardim Alamo,27,,-23.8105,-46.742
br,bairro jardim almeida prado,Bairro Jardim Almeida Prado,27,,-23.776796,-46.691306
br,bairro jardim alvorada,Bairro Jardim Alvorada,27,,-23.7651,-46.6854
br,bairro jardim betania,Bairro Jardim Betânia,27,,-23.598496,-47.020454
br,bairro jardim cambara,Bairro Jardim Cambará,27,,-23.419852,-46.555211
br,bairro jardim casa grande,Bairro Jardim Casa Grande,27,,-23.303392,-46.747034
br,bairro jardim city,Bairro Jardim City,27,,-23.425544,-46.540098
br,bairro jardim cruzeiro,Bairro Jardim Cruzeiro,27,,-23.544938,-47.191916
br,bairro jardim das montanhas,Bairro Jardim das Montanhas,27,,-23.401504,-46.620072
br,bairro jardim das orquideas,Bairro Jardim das Orquideas,27,,-23.7512,-46.5999
br,bairro jardim dos reis,Bairro Jardim dos Reis,27,,-23.305583,-46.722847
br,bairro jardim erpim,Bairro Jardim Erpim,27,,-23.791839,-46.712823
br,bairro jardim heliana,Bairro Jardim Heliana,27,,-23.294685,-46.748615
br,bairro jardim itaim,Bairro Jardim Itaim,27,,-23.810309,-46.713685
br,bairro jardim leonor,Bairro Jardim Leonor,18,,-23.835387,-50.415155
br,bairro jardim lucelia,Bairro Jardim Lucélia,27,,-23.758653,-46.678582
br,bairro jardim margarida,Bairro Jardim Margarida,27,,-23.615382,-47.040649
br,bairro jardim marilda,Bairro Jardim Marilda,27,,-23.787872,-46.681785
br,bairro jardim monte alegre,Bairro Jardim Monte Alegre,27,,-23.773822,-46.688939
br,bairro jardim nossa senhora aparecida,Bairro Jardim Nossa Senhora Aparecida,27,,-23.259514,-46.737097
br,bairro jardim novo parelheiros,Bairro Jardim Novo Parelheiros,27,,-23.832072,-46.723512
br,bairro jardim parate,Bairro Jardim Parate,27,,-23.318,-46.1057
br,bairro jardim paulo afonso,Bairro Jardim Paulo Afonso,27,,-23.7853,-46.718346
br,bairro jardim potao vermelho,Bairro Jardim Potão Vermelho,27,,-23.603025,-47.00548
br,bairro jardim primavera,Bairro Jardim Primavera,18,,-23.829295,-50.413947
br,bairro jardim sabia,Bairro Jardim Sabiá,27,,-23.782749,-46.692143
br,bairro jardim santa barbara,Bairro Jardim Santa Bárbara,18,,-23.8545,-50.4079
br,bairro jardim santa teresinha,Bairro Jardim Santa Teresinha,27,,-23.8513,-46.6958
br,bairro jardim sao goncalo,Bairro Jardim São Gonçalo,27,,-23.33071,-46.606224
br,bairro jardim silveira,Bairro Jardim Silveira,27,,-23.849888,-46.713126
br,bairro jardim suico,Bairro Jardim Suiço,27,,-23.330041,-46.59592
br,bairro jardim varginha,Bairro Jardim Varginha,27,,-23.783915,-46.68132
br,bairro jardim virginia,Bairro Jardim Virginia,27,,-23.37094,-46.710954
br,bairro jesus,Bairro Jesus,27,,-24.671723,-48.938669
br,bairro juqueri-mirim,Bairro Juqueri-Mirim,27,,-23.363235,-46.618251
br,bairro juquia,Bairro Juquiá,27,,-23.974652,-47.177667
br,bairro lagoinha,Bairro Lagoinha,21,,-22.796513,-43.599385
br,bairro lagoinhas,Bairro Lagoinhas,27,,-23.2894,-46.0055
br,bairro lajeadinho,Bairro Lajeadinho,27,,-23.700414,-47.168061
br,bairro lajeado liso,Bairro Lajeado Liso,18,,-23.945099,-50.564365
br,bairro lambari,Bairro Lambari,27,,-23.3671,-46.1801
br,bairro laranjal,Bairro Laranjal,27,,-23.038333,-46.606944
br,bairro lencol,Bairro Lençol,27,,-24.590045,-48.034708
br,bairro limeira,Bairro Limeira,18,,-25.319722,-50.405278
br,bairro limoeiro,Bairro Limoeiro,27,,-24.503043,-48.880641
br,bairro macedo,Bairro Macedo,21,,-22.878141,-43.576786
br,bairro machado,Bairro Machado,27,,-23.345815,-46.657192
br,bairro mambuca,Bairro Mambuca,18,,-23.931727,-50.65377
br,bairro manuel gomes,Bairro Manuel Gomes,27,,-24.746369,-48.170965
br,bairro maraba,Bairro Marabá,18,,-23.601,-50.6135
br,bairro maracana,Bairro Maracanã,27,,-23.158056,-46.718889
br,bairro maracatu,Bairro Maracatu,27,,-23.3574,-46.1202
br,bairro marciana,Bairro Marciana,27,,-22.8278,-45.2183
br,bairro maria jose,Bairro Maria José,21,,-22.922514,-43.553091
br,bairro maria luiza,Bairro Maria Luiza,21,,-22.897782,-43.590049
br,bairro mario lombardi,Bairro Mário Lombardi,21,,-22.883722,-43.602665
br,bairro marli,Bairro Marli,18,,-23.859609,-50.395315
br,bairro mato-dentro,Bairro Mato-Dentro,27,,-23.287524,-46.644398
br,bairro mineiros,Bairro Mineiros,27,,-24.546469,-48.90095
br,bairro monte belo,Bairro Monte Belo,27,,-21.316667,-47.7
br,bairro morada do campo,Bairro Morada do Campo,21,,-22.919911,-43.547725
br,bairro moricaba,Bairro Moriçaba,21,,-22.89842,-43.530601
br,bairro morro grande,Bairro Morro Grande,27,,-23.3092,-46.1768
br,bairro murundu,Bairro Murundu,27,,-23.8034,-47.2457
br,bairro nhunguara,Bairro Nhunguara,27,,-24.585952,-48.425262
br,bairro nossa senhora aparecida,Bairro Nossa Senhora Aparecida,21,,-22.910922,-43.621759
br,bairro nossa senhora de fatima,Bairro Nossa Senhora de Fátima,27,,-23.008603,-47.503935
br,bairro nova cidade,Bairro Nova Cidade,21,,-22.902599,-43.590674
br,bairro nova guara,Bairro Nova Guará,27,,-22.8086,-45.1878
br,bairro nova jersei,Bairro Nova Jersei,21,,-22.92592,-43.631227
br,bairro ocorrencia,Bairro Ocorrência,18,,-24.671129,-48.609922
br,bairro ocorrencia,Bairro Ocorrência,27,,-24.663243,-48.598206
br,bairro oito e meio,Bairro Oito e Meio,27,,-23.9572,-47.2365
br,bairro ouro grande,Bairro Ouro Grande,18,,-23.187611,-49.877633
br,bairro padre andre,Bairro Padre André,27,,-24.617166,-48.017789
br,bairro paiol grande,Bairro Paiol Grande,27,,-23.519504,-47.021335
br,bairro palmital,Bairro Palmital,27,,-24.660801,-48.84264
br,bairro paraiso,Bairro Paraíso,21,,-22.4532,-44.4315
br,bairro parque pauh,Bairro Parque Pauh,27,,-23.304991,-46.734816
br,bairro parque petropolis,Bairro Parque Petropolis,27,,-23.383376,-46.630789
br,bairro parque santa ines,Bairro Parque Santa Inês,27,,-23.405055,-46.671138
br,bairro parque sant'ana,Bairro Parque Sant'Ana,27,,-23.250586,-46.749568
br,bairro passa-vinte,Bairro Passa-Vinte,27,,-24.518231,-48.736822
br,bairro passo manso,Bairro Passo Manso,26,,-26.901,-49.1439
br,bairro pau arcado,Bairro Pau Arcado,27,,-23.2175,-46.721111
br,bairro paulo bueno,Bairro Paulo Bueno,27,,-23.9757,-47.0914
br,bairro pedra amarela,Bairro Pedra Amarela,18,,-23.620225,-50.523456
br,bairro pedra branca,Bairro Pedra Branca,27,,-23.9287,-47.0069
br,bairro pedregulho,Bairro Pedregulho,27,,-22.8001,-45.1996
br,bairro peixoto,Bairro Peixoto,21,,-22.964887,-43.190867
br,bairro piedade,Bairro Píedade,27,,-22.82122,-45.180502
br,bairro pimentas,Bairro Pimentas,18,,-24.84,-48.5671
br,bairro pimentas,Bairro Pimentas,27,,-24.8575,-48.5639
br,bairro pindauva do meio,Bairro Pindaúva do Meio,27,,-24.884,-48.0793
br,bairro pinhal,Bairro Pinhal,27,,-23.272,-46.1305
br,bairro pinheirinho,Bairro Pinheirinho,27,,-24.9872,-48.5555
br,bairro piraquara,Bairro Piraquara,21,,-22.895329,-43.436881
br,bairro pirucaia,Bairro Pirucaia,27,,-23.31898,-46.530479
br,bairro poco do peixe,Bairro Poço do Peixe,21,,-22.358179,-42.959313
br,bairro ponte alta,Bairro Ponte Alta,27,,-23.011042,-46.659852
br,bairro ponte lavrada,Bairro Ponte Lavrada,27,,-23.590751,-47.086537
br,bairro portao,Bairro Portão,27,,-23.224722,-46.628889
br,bairro portinho,Bairro Portinho,18,,-25.4234,-48.7248
br,bairro porto alegre,Bairro Porto Alegre,27,,-23.0061,-47.5156
br,bairro posse,Bairro Posse,21,,-22.378339,-42.992188
br,bairro praia grande,Bairro Praia Grande,27,,-24.667583,-48.653002
br,bairro preto,Bairro Preto,18,,-23.247792,-49.795019
br,bairro primeiro ribeirao,Bairro Primeiro Ribeirão,27,,-24.739912,-48.477459
br,bairro rancho alegre,Bairro Rancho Alegre,18,,-23.47002,-49.99377
br,bairro reginaldo,Bairro Reginaldo,27,,-24.8167,-48.4941
br,bairro reta grande,Bairro Reta Grande,18,,-23.928482,-50.568503
br,bairro ribeirao,Bairro Ribeirão,27,,-24.523373,-48.586352
br,bairro rio abaixo,Bairro Rio Abaixo,27,,-23.044167,-46.641111
br,bairro rio acima,Bairro Rio Acima,27,,-23.2175,-46.667778
br,bairro rio bonito,Bairro Rio Bonito,27,,-23.9455,-47.2159
br,bairro rio da prata,Bairro Rio da Prata,21,,-22.887021,-43.474311
br,bairro rio das pedras,Bairro Rio das Pedras,27,,-24.610084,-48.591589
br,bairro rio de una,Bairro Rio de Una,27,,-23.676908,-47.239699
br,bairro rio do meio,Bairro Rio do Meio,27,,-24.626622,-48.780832
br,bairro rio pardinho,Bairro Rio Pardinho,27,,-25.048181,-48.560783
br,bairro rio sao pedrinho,Bairro Rio São Pedrinho,27,,-25.02801,-48.552362
br,bairro rio vermelho,Bairro Rio Vermelho,27,,-24.9818,-48.5048
br,bairro rodeio bonito,Bairro Rodeio Bonito,18,,-23.895184,-50.6537
br,bairro rolas,Bairro Rolas,21,,-22.927834,-43.669136
br,bairro rosario,Bairro Rosário,27,,-23.564102,-47.072152
br,bairro salvador,Bairro Salvador,21,,-22.927161,-43.557533
br,bairro santa ana,Bairro Santa Ana,27,,-23.29,-46.0588
br,bairro santa clara do guandu,Bairro Santa Clara do Guandu,21,,-22.834552,-43.616959
br,bairro santa cruz,Bairro Santa Cruz,27,,-24.563788,-48.986959
br,bairro santa fe,Bairro Santa Fe,27,,-23.362257,-46.559105
br,bairro santa ines,Bairro Santa Inês,21,,-22.873793,-43.564115
br,bairro santa ines,Bairro Santa Inês,27,,-23.366465,-46.667085
br,bairro santa margarida,Bairro Santa Margarida,21,,-22.891235,-43.604982
br,bairro santa rosa,Bairro Santa Rosa,18,,-25.328889,-50.434722
br,bairro santa teresa,Bairro Santa Teresa,18,,-23.207475,-49.759507
br,bairro santiago,Bairro Santiago,27,,-24.949595,-48.501192
br,bairro santo angelo,Bairro Santo Angelo,27,,-23.2694,-46.1552
br,bairro santo antonio,Bairro Santo Antônio,27,,-23.307298,-46.563076
br,bairro sao caetano,Bairro São Caetano,21,,-22.4584,-44.4784
br,bairro sao joao,Bairro São João,27,,-22.647778,-47.469722
br,bairro sao joao velho,Bairro São João Velho,27,,-23.539117,-47.026037
br,bairro sao jose,Bairro São José,21,,-22.4468,-44.3066
br,bairro sao roque,Bairro São Roque,18,,-23.938805,-50.501158
br,bairro sao vicente,Bairro São Vicente,27,,-23.358673,-46.637886
br,bairro sapatu,Bairro Sapatu,27,,-24.600459,-48.362303
br,bairro sarassara,Bairro Sarassará,27,,-23.696503,-47.090789
br,bairro serrinha,Bairro Serrinha,27,,-24.575537,-48.885117
br,bairro silex,Bairro Silex,21,,-22.816178,-43.632293
br,bairro silvestre,Bairro Silvestre,21,,-22.86972,-43.551249
br,bairro soares,Bairro Soares,27,,-24.552286,-48.604202
br,bairro so bento,Bairro So Bento,27,,-23.4366,-46.2425
br,bairro sombra,Bairro Sombra,06,,-7.033333,-38.766667
br,bairro sorocabucu,Bairro Sorocabuçu,27,,-23.724435,-47.173041
br,bairro soroca mirim,Bairro Soroca Mirim,27,,-23.593556,-47.145372
br,bairro surubi,Bairro Surubi,21,,-22.4664,-44.4323
br,bairro tabuao,Bairro Tabuão,18,,-23.945,-50.4469
br,bairro tabuo,Bairro Tabuo,27,,-23.3986,-46.2396
br,bairro taipas de pedra,Bairro Taipas de Pedra,27,,-23.576764,-47.058255
br,bairro tamandare,Bairro Tamandaré,27,,-22.8236,-45.1894
br,bairro taquarivai,Bairro Taquarivaí,27,,-23.933333,-48.683333
br,bairro taquarucu,Bairro Taquaruçu,27,,-24.509623,-48.904362
br,bairro tatapui,Bairro Tatapuí,18,,-23.8781,-50.4185
br,bairro tatupeba,Bairro Tatupeba,18,,-24.703577,-48.755501
br,bairro tiburcio,Bairro Tibúrcio,27,,-23.7535,-47.1132
br,bairro toca do tatu,Bairro Toca do Tatu,27,,-23.7795,-46.6653
br,bairro tocas,Bairro Tocas,18,,-25.433889,-50.261389
br,bairro tres canais,Bairro Três Canais,18,,-24.8193,-48.5593
br,bairro tres corregos,Bairro Três Córregos,21,,-22.34358,-42.944115
br,bairro tronquini,Bairro Tronquini,18,,-23.388774,-52.691472
br,bairro turvo,Bairro Turvo,18,,-25.404444,-50.303611
br,bairro varadouro,Bairro Varadouro,27,,-23.277,-46.19
br,bairro varanguera,Bairro Varanguera,27,,-23.511385,-47.142949
br,bairro vargem do salto,Bairro Vargem do Salto,27,,-23.748065,-47.265368
br,bairro vargem grande,Bairro Vargem Grande,27,,-23.313729,-46.684388
br,bairro verava,Bairro Verava,27,,-23.7793,-47.102
br,bairro vicentino,Bairro Vicentino,21,,-22.4771,-44.4478
br,bairro vila davi,Bairro Vila Davi,27,,-23.29434,-46.553059
br,bairro vila ida,Bairro Vila Ida,27,,-23.308121,-46.731114
br,bairro vila marcelo,Bairro Vila Marcelo,27,,-23.789984,-46.724393
br,bairro vila nova silva,Bairro Vila Nova Silva,27,,-23.493246,-46.506187
br,bairro vila operaria,Bairro Vila Operária,27,,-23.311267,-46.566257
br,bairro vila renascenca,Bairro Vila Renascença,27,,-23.367294,-46.569123
br,bairro vila rosckel,Bairro Vila Rosckel,27,,-23.840793,-46.732542
br,bairro vila santista,Bairro Vila Santista,27,,-23.324088,-46.745462
br,bairro vinte e nove de marco,Bairro Vinte e Nove de Março,21,,-22.890486,-43.617473
br,bairro vista alegre,Bairro Vista Alegre,21,,-22.864745,-43.780628
br,bairro vitor dumas,Bairro Vitor Dumas,21,,-22.933531,-43.697766
br,bairro volta grande,Bairro Volta Grande,27,,-23.546234,-47.052449
br,bairro vorstaht,Bairro Vorstaht,26,,-26.9025,-49.039
br,bairro votorantim,Bairro Votorantim,27,,-23.336535,-46.569467
br,bairrro vila aurora,Bairrro Vila Aurora,27,,-23.431662,-46.747962
br,baitaca,Baitaca,18,,-26.0405,-49.8174
br,baitaca,Baitaca,23,,-27.583333,-53.066667
br,baitapora,Baitaporã,11,,-22.333333,-53.283333
br,baixa alegre,Baixa Alegre,05,,-13.133333,-39.466667
br,baixa,Baixa,05,,-12.45,-40.633333
br,baixa,Baixa,06,,-4.75,-37.566667
br,baixa,Baixa,13,,-4.183333,-43.75
br,baixa,Baixa,15,,-19.966667,-47.966667
br,baixa,Baixa,20,,-6.966667,-40.866667
br,baixa,Baixa,22,,-5.503056,-37.498056
br,baixa bonita,Baixa Bonita,15,,-15.783333,-40.9
br,baixa branca,Baixa Branca,06,,-5.216667,-37.816667
br,baixa calada,Baixa Calada,04,,-5.845833,-61.276944
br,baixa da alegria,Baixa da Alegria,22,,-5.302778,-37.278611
br,baixa da areia,Baixa da Areia,28,,-10.15,-37.05
br,baixa da aroeira,Baixa da Aroeira,22,,-5.335278,-37.343056
br,baixa da carnauba,Baixa da Carnaúba,22,,-6.283333,-37.95
br,baixa da conceicao,Baixa da Conceição,13,,-3.760556,-43.295
br,baixada do burgo,Baixada do Burgo,28,,-9.883333,-37.55
br,baixa d'agua,Baixa d'Agua,13,,-3.071111,-43.032778
br,baixa da imbira,Baixa da Imbira,05,,-11.966667,-44.633333
br,baixa da lagoa,Baixa da Lagoa,05,,-12.633333,-39.816667
br,baixa da lagoa,Baixa da Lagoa,20,,-6.483333,-41.35
br,baixa da manipeba,Baixa da Manipeba,22,,-5.483333,-35.666667
br,baixadao,Baixadão,11,,-19.183333,-54.316667
br,baixa da onca,Baixa da Onça,06,,-7.6,-38.916667
br,baixa da onca,Baixa da Onça,13,,-3.378611,-43.116667
br,baixa-d'areia,Baixa-D'Areia,28,,-10.15,-37.05
br,baixa da ribaca,Baixa da Ribacã,22,,-5.7,-35.783333
br,baixa das cotias,Baixa das Cotias,13,,-3.228611,-43.014722
br,baixa da serra,Baixa da Serra,13,,-6.583333,-43.866667
br,baixa da umburana,Baixa da Umburana,30,,-8.55,-37.766667
br,baixa da vaca,Baixa da Vaca,13,,-3.379167,-43.183333
br,baixa de sao francisco,Baixa de São Francisco,22,,-5.413056,-36.962222
br,baixa do angico,Baixa do Angico,20,,-7.9,-41.6
br,baixa do aroeira,Baixa do Aroeira,05,,-13.533333,-40.966667
br,baixa do bezerro,Baixa do Bezerro,22,,-5.567222,-36.143333
br,baixa do cafe,Baixa do Café,20,,-7.983333,-41.016667
br,baixa do cajueiro,Baixa do Cajueiro,20,,-5.383333,-41.4
br,baixa do caldeirao,Baixa do Caldeirão,20,,-6.3,-41.683333
br,baixa do capim,Baixa do Capim,13,,-3.879722,-43.128611
br,baixa do cedro,Baixa do Cedro,05,,-13.016667,-43.666667
br,baixa do cerral,Baixa do Cerral,20,,-6.233333,-42.133333
br,baixa do cocal i,Baixa do Cocal I,13,,-3.280833,-43.261389
br,baixa do cocal ii,Baixa do Cocal II,13,,-3.263889,-43.225833
br,baixa do correio,Baixa do Correio,22,,-5.722222,-37.478611
br,baixa do coxo,Baixa do Coxo,20,,-3.659722,-42.181667
br,baixa do curral,Baixa do Curral,20,,-6.233333,-41.933333
br,baixa do curralinho,Baixa do Curralinho,20,,-3.476667,-42.175556
br,baixa do feijao,Baixa do Feijão,22,,-5.346667,-36.055
br,baixa do jacare,Baixa do Jacaré,20,,-3.475556,-42.045833
br,baixa do jacu,Baixa do Jacu,05,,-12.45,-41.1
br,baixa do jatoba,Baixa do Jatobá,20,,-5.983333,-42.916667
br,baixa do jua,Baixa do Juá,06,,-4.65,-40.966667
br,baixa do jua,Baixa do Juá,22,,-5.151667,-36.850833
br,baixa do juazeiro,Baixa do Juazeiro,06,,-5.3,-40.783333
br,baixa do juazerio,Baixa do Juàzerio,22,,-5.573611,-37.396667
br,baixa do lago,Baixa do Lago,13,,-3.430556,-42.773611
br,baixa do lirio,Baixa do Lirio,20,,-6.916667,-40.55
br,baixa do maximo,Baixa do Máximo,05,,-10.45,-37.916667
br,baixa do meio,Baixa do Meio,06,,-7.166667,-40.383333
br,baixa do meio,Baixa do Meio,22,,-5.254167,-36.358333
br,baixa do mel,Baixa do Mel,20,,-6.816667,-41.483333
br,baixa do palmeira,Baixa do Palmeira,05,,-12.75,-39.216667
br,baixa do pau ferro,Baixa do Pau Ferro,30,,-8.766667,-36.616667
br,baixa do poco,Baixa do Poco,06,,-7.55,-38.766667
br,baixa do quinquim,Baixa do Quinquim,22,,-5.216667,-35.616667
br,baixa do quin-quin,Baixa do Quin-Quin,22,,-5.216667,-35.616667
br,baixa do recanto,Baixa do Recanto,30,,-7.9,-38.9
br,baixa do riachao,Baixa do Riachão,05,,-13.25,-39.116667
br,baixa do sapateiro,Baixa do Sapateiro,21,,-22.859849,-43.241578
br,baixa do serrote,Baixa do Serrote,02,,-9.033333,-37.516667
br,baixa do sitio,Baixa do Sítio,06,,-6.416667,-38.966667
br,baixa do tatu,Baixa do Tatu,22,,-5.649722,-37.289167
br,baixa do tingui,Baixa do Tingui,15,,-15.966667,-44.4
br,baixa escura,Baixa Escura,20,,-7.966667,-43.166667
br,baixa fechada,Baixa Fechada,06,,-6,-40.716667
br,baixa fechada,Baixa Fechada,22,,-5.684722,-37.367222
br,baixa feia,Baixa Feia,20,,-5.933333,-42.116667
br,baixa fria,Baixa Fria,06,,-3.35,-40.25
br,baixa fria,Baixa Fria,13,,-5.4,-43.333333
br,baixa fria,Baixa Fria,20,,-3.920833,-42.153889
br,baixa funda,Baixa Funda,02,,-9.333333,-36.266667
br,baixa funda,Baixa Funda,05,,-12.5,-41.25
br,baixa funda,Baixa Funda,13,,-3.088889,-42.318056
br,baixa funda,Baixa Funda,22,,-5.433333,-35.8
br,baixa grande,Baixa Grande,02,,-9.733333,-36.216667
br,baixa grande,Baixa Grande,05,7534,-11.95,-40.183333
br,baixa grande,Baixa Grande,06,,-2.869167,-40.6125
br,baixa grande,Baixa Grande,13,,-2.333333,-44.6
br,baixa grande,Baixa Grande,15,,-16.1,-42.116667
br,baixa grande,Baixa Grande,20,,-5.866667,-42.183333
br,baixa grande,Baixa Grande,22,,-5.71,-37.485833
br,baixa grande,Baixa Grande,30,,-7.583333,-39.683333
br,baixa nova,Baixa Nova,06,,-2.9,-40.4
br,baixao,Baixão,05,,-10.3,-43.55
br,baixao,Baixão,13,,-3.005556,-42.351111
br,baixao,Baixão,20,,-3.568611,-42.116111
br,baixao,Baixão,27,,-21.366667,-47.483333
br,baixao,Baixão,31,,-12.8,-46.633333
br,baixao da fortaleza,Baixão da Fortaleza,05,,-10.166667,-43.7
br,baixao da negra,Baixão da Negra,13,,-5.116667,-43.266667
br,baixao das cajazeiras,Baixão das Cajazeiras,20,,-3.4575,-42.078889
br,baixao de areia,Baixão de Areia,13,,-5.966667,-43.966667
br,baixao de forro,Baixão de Fôrro,05,,-11.15,-43.8
br,baixao do aniceto,Baixão do Aniceto,20,,-5.083333,-41.7
br,baixao do calista,Baixão do Calista,05,,-9.45,-43.183333
br,baixao do calisto,Baixão do Calisto,05,,-9.45,-43.183333
br,baixao do calixto,Baixão do Calixto,05,,-9.45,-43.183333
br,baixao do capim,Baixão do Capim,13,,-3.167222,-42.263889
br,baixao do cavalo velho,Baixão do Cavalo Velho,20,,-3.910833,-42.526944
br,baixao do cedro,Baixão do Cedro,13,,-3.296944,-42.258611
br,baixao do centro,Baixão do Centro,13,,-3.1125,-42.033889
br,baixao do chiqueiro,Baixão do Chiqueiro,20,,-3.755556,-42.269722
br,baixao do coco,Baixão do Coco,20,,-6.133333,-42.75
br,baixao do damasio,Baixão do Damásio,05,,-10.166667,-43.7
br,baixao do damazio,Baixão do Damázio,05,,-10.166667,-43.7
br,baixao do ferro,Baixão do Ferro,05,,-11.15,-43.8
br,baixao do lucas,Baixão do Lucas,05,,-12.433333,-44.9
br,baixao do melo,Baixão do Melo,20,,-6.066667,-41.033333
br,baixao do tubiba,Baixão do Tubiba,06,,-5.5,-41
br,baixao do umbuzeiro,Baixão do Umbuzeiro,20,,-7.233333,-41.883333
br,baixao grande,Baixão Grande,13,,-3.866944,-43.260278
br,baixao grande,Baixão Grande,20,,-3.547222,-42.116944
br,baixao i,Baixão I,13,,-3.088889,-43.4825
br,baixao i,Baixão I,20,,-3.400833,-42.047222
br,baixao ii,Baixão II,13,,-3.299444,-42.228889
br,baixao iii,Baixão III,13,,-3.101944,-43.114722
br,baixao iv,Baixão IV,13,,-3.135,-43.303056
br,baixao velho,Baixão Velho,05,,-10.1,-42.716667
br,baixa preta,Baixa Preta,06,,-4.283333,-38.516667
br,baixa quente,Baixa Quente,15,,-16.95,-42.066667
br,baixa redonda,Baixa Redonda,20,,-5.666667,-42.933333
br,baixa redonda,Baixa Redonda,30,,-7.916667,-38.783333
br,baixa sao miguel,Baixa São Miguel,22,,-5.516667,-35.7
br,baixas,Baixas,06,,-6.333333,-40.516667
br,baixas,Baixas,13,,-5.433333,-43.05
br,baixas,Baixas,17,,-7.383333,-38.016667
br,baixas,Baixas,20,,-8.266667,-43.133333
br,baixas,Baixas,22,,-6.066667,-38.433333
br,baixas,Baixas,30,,-7.833333,-38.9
br,baixa seca,Baixa Sêca,05,,-9.55,-43.066667
br,baixa seca,Baixa Sêca,15,,-16.733333,-40.766667
br,baixa velha,Baixa Velha,30,,-8.733333,-37.333333
br,baixa verde,Baixa Verde,01,,-9.883333,-67.616667
br,baixa verde,Baixa Verde,06,,-5.55,-37.95
br,baixa verde,Baixa Verde,17,,-6.383333,-38.433333
br,baixa verde,Baixa Verde,20,,-6.783333,-40.6
br,baixa verde,Baixa Verde,22,,-5.333333,-37.75
br,baixa verde,Baixa Verde,30,,-7.75,-34.833333
br,baixax,Baixax,20,,-6.95,-41.866667
br,baixinha,Baixinha,05,,-13.116667,-39.6
br,baixinha,Baixinha,06,,-2.909167,-40.561389
br,baixinha,Baixinha,13,,-3.811389,-43.063056
br,baixinha,Baixinha,20,,-3.685833,-42.007222
br,baixinha,Baixinha,22,,-5.25,-35.816667
br,baixinha da franca,Baixinha da Franca,22,,-5.25,-35.8
br,baixinha de todos os santos,Baixinha de Todos os Santos,15,,-17.866667,-41.683333
br,baixinha dos flores,Baixinha dos Flores,13,,-3.8025,-43.0475
br,baixinha i,Baixinha I,13,,-3.412778,-43.494722
br,baixinha ii,Baixinha II,13,,-3.286389,-43.188333
br,baixinho,Baixinho,06,,-7.25,-40.4
br,baixio,Baixio,05,,-12.133333,-37.7
br,baixio,Baixio,06,,-5.95,-39.483333
br,baixio,Baixio,14,,-14.65,-56.2
br,baixio,Baixio,17,,-6.516667,-38.266667
br,baixio,Baixio,20,,-7.966667,-40.683333
br,baixio,Baixio,22,,-5.966667,-37.883333
br,baixio,Baixio,30,,-7.683333,-39.783333
br,baixio da donona,Baixio da Donona,06,,-6.35,-39.683333
br,baixio da roca,Baixio da Roça,06,,-6.033333,-39.466667
br,baixio do boi,Baixio do Boi,06,,-7.516667,-39.016667
br,baixio do boi,Baixio do Boi,30,,-7.983333,-38.85
br,baixio do facundo,Baixio do Facundo,06,,-7.066667,-39.933333
br,baixio do fogo,Baixio do Fogo,22,,-6.333333,-38.3
br,baixio do fumo,Baixio do Fumo,30,,-7.75,-39.35
br,baixio do jua,Baixio do Juá,30,,-7.783333,-39.3
br,baixio do lima,Baixio do Lima,06,,-7.15,-40.166667
br,baixio do paulo,Baixio do Paulo,30,,-7.616667,-39.45
br,baixio dos campos,Baixio dos Campos,17,,-7.75,-38.216667
br,baixio dos curimatas,Baixío dos Curimatás,13,,-3.333333,-45.316667
br,baixio dos nicolaus,Baixio dos Nicolaus,30,,-7.633333,-38.716667
br,baixio dos ramos,Baixio dos Ramos,06,,-7.233333,-40.133333
br,baixios,Baixios,02,,-9.7,-37.2
br,baixio verde,Baixio Verde,06,,-6.716667,-39.2
br,baixo,Baixo,14,,-14.65,-56.2
br,baixo,Baixo,15,,-16.4,-41.033333
br,baixo,Baixo,17,,-6.733333,-36.366667
br,baixo,Baixo,20,,-7.616667,-41.15
br,baixo dos curimatas,Baixo dos Curimatás,13,,-3.333333,-45.316667
br,baixo do zacarias,Baixo do Zacarias,06,,-2.933333,-40.2
br,baixo feia,Baixo Feia,20,,-5.933333,-42.116667
br,baixo guandu,Baixo Guandu,08,19292,-19.516667,-41.016667
br,baixo longa,Baixo Longá,20,,-3.166667,-41.866667
br,baixo mearim,Baixo Mearim,13,,-3.466667,-44.883333
br,baixo palmital,Baixo Palmital,26,,-26.901785,-49.866444
br,baixo vere,Baixo Verê,18,,-25.866667,-52.95
br,baje,Baje,01,,-9.166667,-72.266667
br,baje,Bajé,23,,-31.333333,-54.1
br,balaco,Balacó,21,,-22.283333,-41.783333
br,balaiada,Balaiada,13,,-3.866667,-44.183333
br,balaieiro,Balaieiro,15,,-15.616667,-44.466667
br,balanca,Balanca,06,,-3.516667,-39.6
br,balanca,Balança,17,,-7.55,-38.016667
br,balanca,Balança,20,,-6.983333,-40.966667
br,balanca,Balanca,22,,-5.741667,-37.464444
br,balancas,Balanças,06,,-5.266667,-39.6
br,balanco,Balanco,17,,-6.966667,-36.833333
br,balanco,Balanço,20,,-6.333333,-42.816667
br,balanco,Balanço,31,,-11.55,-46.85
br,balao,Balão,06,,-5.966667,-39.516667
br,balao primeiro,Balão Primeiro,18,,-25.507952,-50.529375
br,balbina,Balbina,04,,-2.916667,-68.3
br,balbino,Balbino,15,,-16.233333,-40.483333
br,balbino dias,Balbino Dias,15,,-16.95,-40.716667
br,balbinos,Balbinos,27,,-21.916667,-49.35
br,balco,Balço,06,,-5.366667,-39.95
br,baldim,Baldim,15,,-9.283333,-43.95
br,balduino oliveira,Balduíno Oliveira,05,,-16.333333,-39.833333
br,baleia,Baleia,05,,-16.266667,-39.183333
br,balins,Balins,20,,-8.75,-44.433333
br,balisa,Balisa,03,,-.466667,-52.466667
br,balisa,Balisa,14,,-16.25,-52.433333
br,balisa,Balisa,23,,-27.583333,-52.15
br,balisa,Balisa,27,,-21.783333,-51.05
br,balisa,Balisa,29,,-16.25,-52.416667
br,baliza,Baliza,22,,-6.266667,-38
br,baliza,Baliza,23,,-27.583333,-52.15
br,baliza,Baliza,25,,.950278,-59.911111
br,baliza,Baliza,27,,-21.783333,-51.05
br,baliza,Baliza,29,,-16.25,-52.416667
br,balneario,Balneário,26,,-26.983333,-48.633333
br,balneario de camboriu,Balneário de Camboriú,26,,-26.983333,-48.633333
br,balneario de rincao,Balneário de Rincão,26,,-28.833333,-49.25
br,balneario do rincao,Balneário do Rincão,26,,-28.833333,-49.25
br,balneario itajuba,Balneário Itajubá,26,,-26.7047,-48.6843
br,balneario praia do leste,Balneário Praia do Leste,18,,-25.691667,-48.466667
br,balneario sao jose,Balneário São José,27,,-23.769578,-46.722904
br,balsa,Balsa,13,,-5.666667,-43.083333
br,balsa,Balsa,18,,-23.655676,-50.048953
br,balsamo,Bálsamo,06,,-7.133333,-38.733333
br,balsamo,Bálsamo,11,,-18.05,-54.05
br,balsamo,Balsamo,17,,-6.666667,-38.45
br,balsamo,Bálsamo,18,,-23.4,-50.8
br,balsamo,Bálsamo,21,,-20.916667,-41.733333
br,balsamo,Bálsamo,27,,-20.3,-47.3
br,balsa nova,Balsa Nova,18,,-25.6,-49.616667
br,balsas,Balsas,13,68058,-7.516667,-46.033333
br,balseiro,Balseiro,13,,-3.774167,-43.439722
br,baltasar,Baltasar,21,,-21.583333,-42.15
br,baltazar,Baltazar,11,,-20.266667,-55.1
br,baltazar,Baltazar,21,,-21.583333,-42.15
br,balthazar,Balthazar,21,,-21.583333,-42.15
br,baluarte,Baluarte,05,,-9.466667,-43.533333
br,baluarte,Baluarte,20,,-6.15,-42.05
br,bamba,Bamba,30,,-8.9,-36.2
br,bambu,Bambu,15,,-22.516667,-46.433333
br,bambuhy,Bambuhy,15,,-20.016667,-45.966667
br,bambui,Bambuí,15,18840,-20.016667,-45.966667
br,bambura,Bambura,30,,-8.433333,-35.4
br,banabuiu,Banabuiú,06,,-5.283333,-38.866667
br,banana,Banana,13,,-3.645278,-43.459444
br,banana,Banana,18,,-25.133333,-52.65
br,bananal,Bananal,04,,-3.033333,-68.166667
br,bananal,Bananal,05,,-11.95,-45.733333
br,bananal,Bananal,11,,-20.25,-56.05
br,bananal,Bananal,13,,-3.994167,-43.118333
br,bananal,Bananal,14,,-14.833333,-55.983333
br,bananal,Bananal,15,,-18.45,-42.25
br,bananal,Bananal,18,,-25.175826,-48.377379
br,bananal,Bananal,21,,-22.788788,-43.163603
br,bananal,Bananal,26,,-26.45,-49
br,bananal,Bananal,27,,-22.6079,-45.6939
br,bananal de cima,Bananal de Cima,15,,-19.383333,-41.833333
br,bananal do norte,Bananal do Norte,08,,-20.75,-41.3
br,bananal do rio,Bananal do Rio,15,,-19.366667,-41.85
br,bananal grande,Bananal Grande,27,,-24.583333,-48.166667
br,bananal nobre,Bananal Nobre,14,,-14.733333,-56.333333
br,bananalzinho,Bananalzinho,14,,-14.55,-54.883333
br,bananas,Bananas,06,,-6.116667,-40.15
br,bananas,Bananas,15,,-20.533333,-45.3
br,bananas,Bananas,18,,-25.383333,-51.283333
br,bananeira,Bananeira,04,,-7.110833,-70.763611
br,bananeira,Bananeira,05,,-10.616667,-40.316667
br,bananeira,Bananeira,06,,-4.116667,-41.15
br,bananeira,Bananeira,13,,-3.838611,-43.352778
br,bananeira,Bananeira,17,,-7.5,-36.966667
br,bananeira,Bananeira,18,,-23.40316,-49.830385
br,bananeira,Bananeira,20,,-4.716667,-41.85
br,bananeira,Bananeira,24,,-10.65,-65.383333
br,bananeira,Bananeira,30,,-8.183333,-36.733333
br,bananeiras,Bananeiras,02,,-9.816667,-36.616667
br,bananeiras,Bananeiras,04,,-7.916667,-66.866667
br,bananeiras,Bananeiras,05,,-10.8,-38.816667
br,bananeiras,Bananeiras,06,,-4.15,-38.333333
br,bananeiras,Bananeiras,17,7371,-6.75,-35.616667
br,bananeiras,Bananeiras,21,,-21.1,-41.95
br,bananeiras,Bananeiras,24,,-10.65,-65.383333
br,bananeiras,Bananeiras,29,,-18.016667,-49.366667
br,bananeiro,Bananeiro,06,,-5.05,-40.766667
br,banca,Banca,05,,-12.916667,-41.283333
br,bancarios,Bancários,21,,-22.791457,-43.179975
br,banco,Banco,05,,-13.166667,-39.333333
br,banco central,Banco Central,05,,-14.45,-39.416667
br,banco da areia,Banco da Areia,20,,-5.866667,-41.15
br,banco da vitoria,Banco da Vitória,05,,-14.8,-39.1
br,banco de pedra,Banco de Pedra,05,,-14.633333,-39.266667
br,banco do pedro,Banco do Pedro,05,,-14.633333,-39.266667
br,bancos,Bancos,22,,-5.75,-35.75
br,banda,Bandá,13,,-3.931667,-42.815
br,bandara,Bandara,30,,-8.25,-38.15
br,bandarra,Bandarra,05,,-11.033333,-43.333333
br,bandarra,Bandarra,06,,-5.733333,-40.733333
br,bandarra,Bandarra,17,,-6.55,-38.333333
br,bandeira,Bandeira,05,,-14.683333,-39.5
br,bandeira,Bandeira,06,,-4.583333,-39.466667
br,bandeira,Bandeira,13,,-3.503333,-42.995
br,bandeira,Bandeira,15,,-15.9,-40.566667
br,bandeira,Bandeira,18,,-25.066667,-53.116667
br,bandeira,Bandeira,22,,-5.783333,-35.966667
br,bandeira,Bandeira,27,,-21.883333,-47.666667
br,bandeira,Bandeira,30,,-7.383333,-37.383333
br,bandeira de mello,Bandeira de Mello,05,,-13.05,-40.833333
br,bandeira de melo,Bandeira de Melo,05,,-13.05,-40.833333
br,bandeira do almada,Bandeira do Almada,05,,-14.683333,-39.5
br,bandeira do colonia,Bandeira do Colônia,05,,-15.116667,-40.1
br,bandeira do sul,Bandeira do Sul,15,,-21.783333,-46.383333
br,bandeirante,Bandeirante,22,,-5.058056,-36.879167
br,bandeirante,Bandeirante,26,,-26.8,-53.633333
br,bandeirante,Bandeirante,29,,-13.683333,-50.8
br,bandeirantes,Bandeirantes,11,,-19.883333,-54.383333
br,bandeirantes,Bandeirantes,15,,-20.333333,-43.366667
br,bandeirantes,Bandeirantes,18,29495,-23.1,-50.35
br,bandeirantes,Bandeirantes,21,,-21.866667,-41.783333
br,bandeirantes,Bandeirantes,26,,-26.8,-53.633333
br,bandeirantes,Bandeirantes,27,,-20.6,-50.8
br,bandeirantes,Bandeirantes,29,,-13.683333,-50.8
br,bandeirinha,Bandeirinha,05,,-12.516667,-40.9
br,bandeirinha,Bandeirinha,15,,-21.05,-45.4
br,bandiacu,Bandiaçu,05,,-11.616667,-39.133333
br,bandidos da fumaca,Bandidos da Fumaça,14,,-15.966667,-58.3
br,bandolim,Bandolim,13,,-3.782778,-42.901667
br,bangu,Bangu,21,,-22.881957,-43.466771
br,bangue,Banguê,05,,-9.25,-39.816667
br,bangue,Bangüé,13,,-3.826944,-43.3425
br,bangue,Banguê,20,,-3.951389,-42.296944
br,bangue,Bangüê,22,,-5.485278,-36.943333
br,banguelo,Banguelo,20,,-3.657778,-42.489167
br,banhadinho,Banhadinho,18,,-23.9207,-50.1631
br,banho,Banho,18,,-25.507882,-50.234618
br,banja,Banja,20,,-8.416667,-45.716667
br,banque,Banquê,06,,-2.8,-40.333333
br,banquete,Banquete,21,,-22.166667,-42.466667
br,banunal,Banunal,04,,-3.033333,-68.166667
br,baptista botelho,Baptista Botelho,27,,-23.016667,-49.416667
br,baquirivu,Baquirivu,27,,-23.5,-46.433333
br,baracaja,Baracajá,11,,-23.066667,-54.983333
br,baracari,Baracari,04,,-3.9225,-62.880556
br,barada,Barada,16,,-2.433333,-51.266667
br,baraganca,Baragança,27,,-22.95,-46.566667
br,barandao,Barandão,17,,-6.466667,-36.016667
br,barao ataliba nogueira,Barão Ataliba Nogueira,27,,-22.4,-46.75
br,barao,Barão,21,,-22.902631,-43.343862
br,barao,Barão,23,,-29.383333,-51.533333
br,barao,Barão,27,,-21.7,-46.866667
br,barao da angra,Barão da Angra,21,,-22.133333,-43.25
br,barao de angra,Barão de Angra,21,,-22.133333,-43.25
br,barao de antonina,Barão de Antonina,27,,-23.616667,-49.566667
br,barao de aquino,Barão de Aquino,21,,-22.116667,-42.65
br,barao de aquiras,Barão de Aquirás,06,,-6.833333,-40.366667
br,barao de aquiraz,Barão de Aquiraz,06,,-6.833333,-40.366667
br,barao de bom jardim,Barão de Bom Jardim,05,,-12.283333,-38.6
br,barao de capanema,Barão de Capanema,14,,-13.316667,-57.866667
br,barao de cocais,Barão de Cocais,15,22387,-19.933333,-43.466667
br,barao de cotegipe,Barão de Cotegipe,23,,-27.616667,-52.383333
br,barao de geraldo,Barão de Geraldo,27,,-22.816667,-47.1
br,barao de grajahu,Barão de Grajahú,13,,-6.75,-43.016667
br,barao de grajau,Barão de Grajaú,13,,-6.75,-43.016667
br,barao de juparana,Barão de Juparanã,21,,-22.343889,-43.682778
br,barao de lucena,Barão de Lucena,18,,-23.166667,-52.416667
br,barao de melgaco,Barão de Melgaço,14,4353,-16.216667,-55.966667
br,barao de melgaco,Barão de Melgaço,24,,-11.85,-60.716667
br,barao de rio branco,Barão de Rio Branco,01,,-7.516667,-73.016667
br,barao de sao jose,Barão de São José,21,,-21.85,-41.2
br,barao de suacuna,Barão de Suaçuna,30,,-8.4,-35.266667
br,barao de suassuna,Barão de Suassuna,30,,-8.4,-35.266667
br,barao de tromai,Barão de Tromaí,13,,-1.483333,-45.6
br,barao de vassouras,Barão de Vassouras,21,,-22.370278,-43.690556
br,barao do amparo,Barão do Amparo,21,,-22.473889,-43.652222
br,barao do grajau,Barão do Grajaú,13,,-6.75,-43.016667
br,barao do guandu,Barão do Guandu,21,,-22.675,-43.42
br,barao do iriri,Barão do Iriri,21,,-22.681389,-43.094444
br,barao do orlando,Barão do Orlando,14,,-13.55,-57.45
br,barao do triunfo,Barão do Triunfo,23,,-30.383333,-51.733333
br,barao hirsch,Barão Hirsch,23,,-27.75,-52.466667
br,baratinha,Baratinha,05,,-13.333333,-40.983333
br,barauna,Baraúna,05,,-9.316667,-40.016667
br,barauna,Baraúna,15,,-19.25,-42.416667
br,barauna,Baraúna,17,,-6.633333,-36.25
br,barauna,Baraúna,22,14113,-5.083333,-37.616667
br,barauna ferrada,Baraúna Ferrada,06,,-6.616667,-40.566667
br,baraunas,Baraúnas,05,,-12.65,-41.8
br,baraunas,Baraúnas,06,,-7.116667,-40.1
br,baraunas,Baraunas,15,,-19.066667,-42.716667
br,baraunas,Baraúnas,30,,-7.766667,-38.7
br,barbacena,Barbacena,15,122213,-21.233333,-43.766667
br,barbacena,Barbacena,16,,-2.766667,-52.066667
br,barbadinha,Barbadinha,22,,-5.366667,-37.3
br,barbadinho,Barbadinho,22,,-5.366667,-37.3
br,barbado,Barbado,05,,-13.283333,-41.933333
br,barbado,Barbado,25,,.943889,-61.706389
br,barbalha,Barbalha,06,33944,-7.316667,-39.283333
br,barbara do oeste,Bárbara do Oeste,27,,-22.749167,-47.413611
br,barbatao,Barbatão,06,,-4.15,-38.633333
br,barboleta,Barboleta,27,,-20.933333,-49.466667
br,barborema,Barborema,17,,-6.8,-35.6
br,barbosa,Barbosa,05,,-12.15,-37.966667
br,barbosa,Barbosa,06,,-5,-38.866667
br,barbosa,Barbosa,15,,-20.55,-41.883333
br,barbosa,Barbosa,17,,-6.466667,-37.8
br,barbosa,Barbosa,18,,-23.7491,-49.8296
br,barbosa,Barbosa,22,,-5.716944,-36.631389
br,barbosa,Barbosa,25,,-2.75,-60.666667
br,barbosa,Barbosa,27,,-21.3,-49.95
br,barbosa ferraz,Barbosa Ferraz,18,9048,-24.066667,-52.05
br,barbosas,Barbosas,18,,-23.7491,-49.8296
br,barbozas,Barbozas,18,,-23.7491,-49.8296
br,barca,Barca,15,,-17.5,-41.283333
br,barcada,Barcada,14,,-15.316667,-56.466667
br,barcarena,Barcarena,16,29872,-1.5,-48.666667
br,barcarena nova,Barcarena Nova,16,,-1.5,-48.616667
br,barcelar,Barcelar,21,,-21.916667,-42.616667
br,barcellos,Barcellos,04,,-1,-62.966667
br,barcelona,Barcelona,22,,-5.933333,-35.933333
br,barcelos,Barcelos,04,7356,-1,-62.966667
br,barcelos,Barcelos,05,,-14.033333,-39
br,barcelos,Barcelos,21,,-21.716667,-41.183333
br,barcelos do sul,Barcelos do Sul,05,,-14.033333,-39
br,bar-da-barra,Bar-da-Barra,24,,-9.016667,-61.85
br,bardo,Bardo,22,,-6.266667,-36.233333
br,bargarim,Bargarim,08,,-20.5,-41.416667
br,barigui,Barigui,11,,-23.233333,-55.3
br,barigui,Barigui,18,,-25.533333,-49.383333
br,bariqui,Bariqui,11,,-23.233333,-55.3
br,bariri,Bariri,27,28802,-22.066667,-48.733333
br,bariry,Bariry,27,,-22.066667,-48.733333
br,baronesa,Baronêsa,05,,-18.1,-39.683333
br,baronesa,Baronesa,27,,-23.094059,-47.757579
br,baroneza,Baroneza,05,,-18.1,-39.683333
br,barra aberta,Barra Aberta,11,,-21.75,-55.05
br,barra alegre,Barra Alegre,08,,-21.15,-41.6
br,barra alegre,Barra Alegre,15,,-19.45,-42.616667
br,barra alegre,Barra Alegre,21,,-22.25,-42.3
br,barra alta,Barra Alta,20,,-9.633333,-45.616667
br,barra azul,Barra Azul,20,,-10.533333,-45
br,barra bairro do areado,Barra Bairro do Areado,27,,-24.6846,-48.3306
br,barra bali,Barra Bali,21,,-23.00897,-43.436166
br,barra,Barra,02,,-9.316667,-38.233333
br,barra,Barra,05,20895,-11.083333,-43.166667
br,barra,Barra,06,,-3.75,-41.966667
br,barra,Barra,11,,-19.766667,-56.8
br,barra,Barra,13,,-3.458056,-42.790278
br,barra,Barra,15,,-19.133333,-48.766667
br,barra,Barra,17,,-6.766667,-34.916667
br,barra,Barra,20,,-10.05,-45.05
br,barra,Barra,21,,-21.116667,-41.733333
br,barra,Barra,22,,-4.951111,-37.15
br,barra,Barra,26,,-28.5,-48.75
br,barra,Barra,27,,-21.133333,-47.716667
br,barra,Barra,28,,-11.15,-37.166667
br,barra,Barra,29,,-15.8,-50.283333
br,barra,Barra,30,,-7.733333,-37.633333
br,barra bonita,Barra Bonita,18,,-23.8469,-50.1886
br,barra bonita,Barra Bonita,26,,-27.266667,-51.916667
br,barra bonita,Barra Bonita,27,37247,-22.483333,-48.533333
br,barraca,Barraca,04,,-4.9,-60.15
br,barraca,Barraca,08,,-18.4,-39.866667
br,barraca,Barraca,15,,-20.416667,-43.233333
br,barraca,Barraca,16,,-6.133333,-57.55
br,barraca,Barraca,30,,-7.85,-38.8
br,barraca da barra,Barraca da Barra,24,,-9.016667,-61.85
br,barraca da boca,Barraca da Bôca,03,,-.6,-52.583333
br,barraca da forquilha,Barraca da Forquilha,13,,-3.383333,-42.7
br,barraca da vista,Barraca da Vista,04,,-7.852222,-58.3175
br,barraca de alfredo lopes,Barraca de Alfredo Lopes,16,,-6.95,-58.216667
br,barraca de maneco rondon,Barraca de Maneco Rondon,14,,-13.65,-58.3
br,barraca de seringueiro,Barraca de Seringueiro,04,,-7.033333,-58.816667
br,barraca do alianca,Barraca do Aliança,23,,-29.416667,-53.45
br,barraca do allianca,Barraca do Alliança,23,,-29.416667,-53.45
br,barraca do barra,Barraca do Barra,24,,-9.016667,-61.85
br,barraca do cabral,Barraca do Cabral,14,,-16.083333,-57.7
br,barraca do gustavo,Barraca do Gustavo,14,,-9.716667,-60.566667
br,barraca do lucas,Barraca do Lucas,14,,-9.683333,-60.55
br,barraca do maneco rondon,Barraca do Maneco Rondon,14,,-13.65,-58.3
br,barraca do peruano,Barraca do Peruano,04,,-8.133333,-58.25
br,barraca do surubim,Barraca do Surubim,25,,2.683333,-60.983333
br,barraca do tomas,Barraca do Tomás,25,,2.533333,-60.933333
br,barracao,Barracão,05,,-10.7,-38.533333
br,barracao,Barracão,06,,-3.733333,-40.983333
br,barracao,Barracão,13,,-4.083333,-43.016667
br,barracao,Barracão,14,,-15.916667,-57.15
br,barracao,Barracão,15,,-16.416667,-43.25
br,barracao,Barracão,18,,-26.25,-53.636389
br,barracao,Barracão,20,,-7.116667,-41.4
br,barracao,Barracão,23,,-27.666667,-51.416667
br,barracao,Barracão,24,,-11.95,-64.183333
br,barracao,Barracão,26,,-27.033333,-48.9
br,barracao,Barracão,30,,-8.933333,-37.366667
br,barracao barreto,Barracão Barreto,14,,-8.8,-58.4
br,barracao bello horisonte,Barracão Bello Horisonte,24,,-11.883333,-64.166667
br,barracao belo horizonte,Barracão Belo Horizonte,24,,-11.883333,-64.166667
br,barracao do barreto,Barracão do Barreto,14,,-8.8,-58.4
br,barracao do camaleao,Barracão do Camaleão,04,,-2.683333,-65.816667
br,barracao do curua,Barração do Curuá,16,,-5.4,-54.466667
br,barracao do liberato,Barracão do Liberato,24,,-12.633333,-60.966667
br,barracao do maia,Barracão do Maia,14,,-8.05,-58.233333
br,barracao floresta,Barracão Floresta,16,,-8.95,-57.266667
br,barracao joffre,Barracão Joffre,24,,-13.5,-60.55
br,barracao jofre,Barracão Jofre,24,,-13.5,-60.55
br,barracao queimado,Barracão Queimado,14,,-13.0875,-59.895833
br,barracao rio mar,Barracão Rio Mar,16,,-7.25,-53.7
br,barracao sao jose,Barracão São José,14,,-9.2,-57.066667
br,barracao triumpho,Barracão Triumpho,24,,-11.95,-64.216667
br,barracao triunfo,Barracão Triunfo,24,,-11.95,-64.216667
br,barraca pereirinha,Barraca Pereirinha,16,,-8.15,-57.583333
br,barraca rapirran,Barraca Rapirran,01,,-10.333333,-67.183333
br,barraca republica,Barraca Republica,14,,-13.5,-60.5
br,barracas,Barracas,06,,-6.966667,-38.883333
br,barracas,Barracas,28,,-10.416667,-37.1
br,barraca terra firme,Barraca Terra Firme,24,,-11.983333,-64.25
br,barra clara,Barra Clara,26,,-27.533333,-49.116667
br,barraco alto,Barraco Alto,24,,-13.033333,-61.433333
br,barraco,Barraco,04,,-7.1,-60.45
br,barra comprida,Barra Comprida,13,,-9.35,-46
br,barracon,Barracon,18,,-26.25,-53.636389
br,barra da agua branca,Barra da Água Branca,05,,-14.266667,-39.25
br,barra da anta,Barra da Anta,26,,-26.912634,-49.662623
br,barra da arara,Barra da Arara,30,,-7.716667,-38.733333
br,barra da areia,Barra da Areia,18,,-24.983333,-51.083333
br,barra da boa vista,Barra da Boa Vista,08,,-21.183333,-40.933333
br,barra da caida,Barra da Caída,20,,-8.566667,-42.133333
br,barra da campineira,Barra da Campineira,13,,-3.431389,-43.054722
br,barra da casa dos negros,Barra da Casa dos Negros,05,,-13.316667,-41.133333
br,barra da choca,Barra da Choça,05,,-14.85,-40.583333
br,barra da craibeira,Barra da Craibeira,22,,-6.816667,-36.583333
br,barra da cruz,Barra da Cruz,05,,-9.65,-41.533333
br,barra da cruz,Barra da Cruz,18,,-25.083333,-48.8
br,barra da cruz,Barra da Cruz,22,,-5.688056,-36.377222
br,barra da cruz,Barra da Cruz,27,,-25.016609,-48.514762
br,barra da estiva,Barra da Estiva,05,12618,-13.633333,-41.316667
br,barra da estiva,Barra da Estiva,13,,-3.116111,-42.365833
br,barra da figueira,Barra da Figueira,15,,-19.6,-41.566667
br,barra da forquilha,Barra da Forquilha,18,,-24.702787,-48.97872
br,barra da forquilha,Barra da Forquilha,30,,-7.716667,-39.483333
br,barra da imbuia,Barra da Imbuia,18,,-24.866667,-51
br,barra da jangada,Barra da Jangada,18,,-26.033333,-51.583333
br,barra da onca,Barra da Onça,13,,-3.4,-42.783333
br,barra da onca,Barra da Onça,22,,-5.8325,-36.647778
br,barra da pendencia,Barra da Pendencia,06,,-6.6,-38.916667
br,barra da prata,Barra da Prata,13,,-3.086944,-43.371667
br,barra da pratinha,Barra da Pratinha,26,,-26.681183,-49.834724
br,barra d'areia,Barra d'Areia,18,,-24.983333,-51.083333
br,barra da roca,Barra da Roça,13,,-8.238611,-45.655278
br,barra da salina,Barra da Salina,15,,-16.6,-42.316667
br,barra da salinas,Barra da Salinas,15,,-16.6,-42.316667
br,barra das antas,Barra das Antas,18,,-24.066667,-50.633333
br,barra da sao joao,Barra da São João,21,,-22.6,-42
br,barradas,Barradas,13,,-3.483333,-45.183333
br,barradas,Barradas,27,,-22.7362,-45.6582
br,barra das corvinas,Barra das Corvinas,13,,-3.628333,-42.636389
br,barra da silva,Barra da Silva,30,,-8.433333,-38.85
br,barra das pombas,Barra das Pombas,26,,-26.568414,-49.952401
br,barra da tijuca,Barra da Tijuca,21,,-23.008054,-43.340378
br,barra da varginha,Barra da Varginha,27,,-23.466667,-45.566667
br,barra da varzea,Barra da Várzea,20,,-8.533333,-41.933333
br,barra de alegre,Barra de Alegre,15,,-20.016667,-41.85
br,barra de arica,Barra de Aricá,14,,-15.983333,-55.9
br,barra de bacururu,Barra de Bacururu,04,,-3.75,-66.183333
br,barra de caravelas,Barra de Caravelas,05,,-17.733333,-39.183333
br,barra de cima,Barra de Cima,22,,-6.45,-35.616667
br,barra de espinharos,Barra de Espinharos,22,,-6.433333,-37.366667
br,barra de guaratiba,Barra de Guaratiba,21,,-23.0622,-43.564718
br,barra de itabapoana,Barra de Itabapoana,08,,-21.3,-40.966667
br,barra de jangada,Barra de Jangada,30,,-8.816667,-35.883333
br,barra de jequirico,Barra de Jequirico,05,,-13.2,-38.933333
br,barra del chuy,Barra del Chuy,23,,-33.733333,-53.383333
br,barra de miguel dias,Barra de Miguel Dias,05,,-10.05,-42.6
br,barra de misericordia,Barra de Misericórdia,30,,-7.883333,-37.583333
br,barra de piaba,Barra de Piaba,17,,-6.383333,-38.516667
br,barra de santana,Barra de Santana,18,,-25.916667,-52.866667
br,barra de santana,Barra de Santana,22,,-6.15,-37.116667
br,barra de santa rosa,Barra de Santa Rosa,17,,-6.716667,-36.066667
br,barra de santo antonio,Barra de Santo Antônio,02,,-9.4,-35.5
br,barra de santo antonio,Barra de Santo Antonio,17,,-7.683333,-36.15
br,barra de santo antonio grande,Barra de Santo Antônio Grande,02,,-9.4,-35.5
br,barra de sao bento,Barra de São Bento,17,,-6.733333,-38.383333
br,barra de sao francisco,Barra de São Francisco,08,20743,-18.75,-40.866667
br,barra de sao francisco,Barra de São Francisco,21,,-21.966667,-42.7
br,barra de sao joao,Barra de São João,21,,-22.6,-42
br,barra de sao joao,Barra de São João,30,,-8.416667,-35.666667
br,barra de sao manuel,Barra de São Manuel,16,,-7.328056,-58.085556
br,barra de sao mateus,Barra de São Mateus,08,,-18.583333,-39.75
br,barra de sao miguel,Barra de São Miguel,02,,-9.833333,-35.9
br,barra de sao miguel,Barra de São Miguel,17,,-7.733333,-36.316667
br,barra de sao pedro,Barra de São Pedro,30,,-7.833333,-40.316667
br,barra do acu,Barra do Açu,21,,-21.916667,-40.983333
br,barra do araquari,Barra do Araquari,26,,-26.4592,-48.6031
br,barra do arara,Barra do Arará,05,,-9.483333,-40.783333
br,barra do ararapira,Barra do Ararapira,18,,-25.29288,-48.099974
br,barra do arati,Barra do Arati,04,,-3.566667,-66.083333
br,barra do areado,Barra do Areado,27,,-24.605875,-48.990115
br,barra do arica,Barra do Aricá,14,,-15.983333,-55.9
br,barra do ariranha,Barra do Ariranha,15,,-18.666667,-41.1
br,barra do barao,Barra do Barão,05,,-10.466667,-38.15
br,barra do batatal,Barra do Batatal,08,,-20.616667,-40.766667
br,barra do batatal,Barra do Batatal,27,,-24.586279,-48.270775
br,barra do bode,Barra do Bode,22,,-5.300833,-36.576667
br,barra do bonito,Barra do Bonito,20,,-8.733333,-41.766667
br,barra do bonito,Barra do Bonito,30,,-7.916667,-38.316667
br,barra do braco,Barra do Braço,27,,-24.646833,-48.297547
br,barra do brejo,Barra do Brejo,05,,-9.95,-42.866667
br,barra do brejo,Barra do Brejo,20,,-10.033333,-45.366667
br,barra do breu de cima,Barra do Breu de Cima,04,,-3.833333,-66.316667
br,barra do bugres,Barra do Bugres,14,31313,-15.083333,-57.183333
br,barra do buriti,Barra do Buriti,29,,-14.316667,-46.033333
br,barra do cabure,Barra do Caburé,13,,-3.558333,-43.279444
br,barra do cafundo,Barra do Cafundó,26,,-28.3,-49.383333
br,barra do camaragibe,Barra do Camaragibe,02,,-9.316667,-35.433333
br,barra do canhoto,Barra do Canhoto,02,,-9.1,-36.066667
br,barra do carvalho,Barra do Carvalho,05,,-13.666667,-38.966667
br,barra do cedro,Barra do Cedro,13,,-3.576667,-43.327778
br,barra do cedro,Barra do Cedro,18,,-25.159167,-48.22
br,barra do cedro,Barra do Cedro,30,,-7.9,-39.55
br,barra do chapeu,Barra do Chapéu,27,,-24.466667,-49.033333
br,barra do chata,Barra do Chata,30,,-8.5,-35.933333
br,barra do cipo,Barra do Cipó,06,,-5.7,-39.15
br,barra do coelho,Barra do Coelho,18,,-24.822747,-48.912138
br,barra do comandante,Barra do Comandante,05,,-9.8,-43.433333
br,barra do corda,Barra do Corda,13,48902,-5.5,-45.25
br,barra do cordeiro,Barra do Cordeiro,18,,-25.168104,-48.528878
br,barra do corrego,Barra do Córrego,30,,-8.716667,-38.35
br,barra do cuiete,Barra do Cuieté,15,,-19.083333,-41.55
br,barra do cuite,Barra do Cuité,15,,-19.083333,-41.55
br,barra do dollman,Barra do Dollman,26,,-26.894773,-49.673667
br,barra do exu,Barra do Exu,30,,-8.066667,-38.45
br,barra do feijao,Barra do Feijão,06,,-5.416667,-38.1
br,barra do felix,Barra do Félix,14,,-16.466667,-55.933333
br,barra do figueiredo,Barra do Figueiredo,06,,-5.383333,-38.283333
br,barra do fogo,Barra do Fogo,05,,-14.666667,-40.05
br,barra do fogo,Barra do Fogo,15,,-15.233333,-42.066667
br,barra do funchal,Barra do Funchal,15,,-19.383333,-45.883333
br,barra do furado,Barra do Furado,05,,-15.25,-41.333333
br,barra do garapa,Barra do Garapa,13,,-5.45,-42.966667
br,barra do garcas,Barra do Garças,14,52402,-15.883333,-52.25
br,barra do garcez,Barra do Garcez,05,,-13.15,-38.833333
br,barra do garrote,Barra do Garrote,06,,-3.5,-39.9
br,barra do gentil,Barra do Gentil,05,,-13.9,-40.533333
br,barra do gil,Barra do Gil,05,,-13,-38.616667
br,barra do goncalo,Barra do Goncalo,22,,-5.616667,-35.883333
br,barra do imbui,Barra do Imbuí,21,,-22.400976,-42.976083
br,barra do inga,Barra do Ingá,13,,-5.516667,-43
br,barra do ipanema,Barra do Ipanema,02,,-9.866667,-37.25
br,barra do ipueira,Barra do Ipueira,06,,-5.116667,-39.533333
br,barra dois irmaos,Barra Dois Irmãos,05,,-10.15,-43.133333
br,barra-do-itabapoana,Barra-do-Itabapoana,08,,-21.3,-40.966667
br,barra do itapemirim,Barra do Itapemirim,08,,-21.016667,-40.8
br,barra do itapocu,Barra do Itapocu,26,,-26.5713,-48.6763
br,barra do itariri,Barra do Itariri,05,,-11.966667,-37.616667
br,barra do jacare,Barra do Jacaré,18,,-23.115321,-50.182551
br,barra do jacu,Barra do Jacu,13,,-3.559722,-43.150833
br,barra do jacupiranga,Barra do Jacupiranga,27,,-24.633333,-47.733333
br,barra do jacutinga,Barra do Jacutinga,26,,-27.090065,-49.741474
br,barra do jangada,Barra do Jangada,18,,-26.05,-51.5
br,barra do japo,Barra do Japó,04,,-3.533333,-66.083333
br,barra do jardim,Barra do Jardim,06,,-7.583333,-39.266667
br,barra do jardim,Barra do Jardim,30,,-8.35,-35.983333
br,barra do jenipapo,Barra do Jenipapo,30,,-9.283333,-37.033333
br,barra do jequirica,Barra do Jequiriçá,05,,-13.2,-38.933333
br,barra do jiquirica,Barra do Jiquiriça,05,,-13.2,-38.933333
br,barra do joaquim tavora,Barra do Joaquim Távora,08,,-19.316667,-40.583333
br,barra do jua,Barra do Juá,17,,-6.533333,-38.566667
br,barra do jua,Barra do Juá,30,,-8.45,-38.083333
br,barra do jundia,Barra do Jundiá,26,,-28.916667,-49.55
br,barra do limoeiro,Barra do Limoeiro,18,,-24.780486,-48.898393
br,barra do longa,Barra do Longá,20,,-3.15,-41.933333
br,barra do luis pereira,Barra do Luís Pereira,15,,-18.95,-44.116667
br,barra do macaco,Barra do Macaco,13,,-3.538056,-43.098333
br,barra do maraba,Barra do Marabá,08,,-21.2,-40.95
br,barra do marmelo,Barra do Marmelo,20,,-6.383333,-42.85
br,barra do maroba,Barra do Marobá,08,,-21.2,-40.95
br,barra do maxaranguape,Barra do Maxaranguape,22,,-5.516667,-35.266667
br,barra do mendes,Barra do Mendes,05,,-11.716667,-42.066667
br,barra do mendes,Barra do Mendes,18,,-24.761272,-48.884247
br,barra do mororo,Barra do Mororó,20,,-7.483333,-41.883333
br,barra do morro,Barra do Morro,14,,-15.583333,-55.85
br,barra do mosquito,Barra do Mosquito,20,,-9.483333,-45.783333
br,barra do mundo novo,Barra do Mundo Novo,05,,-11.866667,-40.516667
br,barra do nilo,Barra do Nilo,05,,-9.733333,-38.05
br,barra do novo brasil,Barra do Novo Brasil,08,,-19.116667,-40.416667
br,barra do oitis,Barra do Oitis,17,,-7.383333,-38.3
br,barra do olho d'agua,Barra do Olho d'Agua,20,,-6.983333,-40.866667
br,barra do ouro,Barra do Ouro,23,,-29.566667,-50.266667
br,barra do pajeu,Barra do Pajeú,30,,-8.9,-38.7
br,barra do palmeira,Barra do Palmeira,20,,-10.583333,-44.933333
br,barra do paraguacu,Barra do Paraguaçu,05,,-12.85,-38.8
br,barra do parai,Barra do Parai,21,,-22.466111,-43.827778
br,barra do paraopeba,Barra do Paraopeba,15,,-18.833333,-45.183333
br,barra do pindauva,Barra do Pindaúva,27,,-24.7579,-48.0694
br,barra do pinheiro,Barra do Pinheiro,26,,-27.333333,-51.75
br,barra do pirahy,Barra do Pirahy,21,,-22.466111,-43.827778
br,barra do pirai,Barra do Piraí,21,87669,-22.466111,-43.827778
br,barra do piraim,Barra do Piraim,14,,-16.483333,-56.333333
br,barra do pires,Barra do Pires,05,,-13.116667,-42.3
br,barra do poruquara,Barra do Poruquara,18,,-25.304528,-48.274031
br,barra do pote,Barra do Pote,05,,-13.033333,-38.633333
br,barra do prata,Barra do Prata,20,,-10.116667,-45.366667
br,barra do quarai,Barra do Quaraí,23,,-30.216667,-57.55
br,barra do riachao,Barra do Riachão,06,,-5.516667,-39.916667
br,barra do riachao,Barra do Riachão,13,,-3.554167,-43.389167
br,barra do riachinho,Barra do Riachinho,05,,-10.233333,-43.2
br,barra do riacho,Barra do Riacho,05,,-11.933333,-44.9
br,barra do riacho,Barra do Riacho,08,,-19.833333,-40.05
br,barra do riancho,Barra do Riancho,05,,-11.933333,-44.9
br,barra do ribeirao feio,Barra do Ribeirão Feio,27,,-24.797873,-48.434105
br,barra do ribeirao grande,Barra do Ribeirão Grande,27,,-24.9021,-48.4753
br,barra do ribeiro,Barra do Ribeiro,23,,-30.3,-51.3
br,barra do rico,Barra do Rico,15,,-16.616667,-41.116667
br,barra do rio abaixo,Barra do Rio Abaixo,27,,-23.383333,-47.116667
br,barra do rio azul,Barra do Rio Azul,18,,-25.723062,-50.686237
br,barra do rio azul,Barra do Rio Azul,23,,-27.383333,-52.433333
br,barra do rio,Barra do Rio,05,,-11.2,-46.133333
br,barra do rio,Barra do Rio,13,,-3.434167,-42.708611
br,barra do rio batatal,Barra do Rio Batatal,27,,-24.7148,-48.3367
br,barra do rio da prata,Barra do Rio da Prata,26,,-26.7033,-49.8293
br,barra do rio de contas,Barra do Rio de Contas,05,,-14.3,-39
br,barra do rio doce,Barra do Rio Doce,05,,-15.4,-39
br,barra do rio do cerro,Barra do Rio do Cerro,26,,-26.516667,-49.133333
br,barra do rio dos bugres,Barra do Rio dos Bugres,14,,-15.083333,-57.183333
br,barra do rio grande,Barra Do Rio Grande,05,,-11.083333,-43.166667
br,barra do rio jacupiranga,Barra do Rio Jacupiranga,27,,-24.633333,-47.733333
br,barra do rio negro,Barra do Rio Negro,04,,-3.113333,-60.025278
br,barra do rio pardo,Barra do Rio Pardo,27,,-24.670239,-48.681197
br,barra do rocha,Barra do Rocha,05,,-14.233333,-39.65
br,barra do roncador,Barra do Roncador,26,,-26.881276,-49.71475
br,barra do roque,Barra do Roque,20,,-6.6,-41.783333
br,barra do sabia,Barra do Sabiá,08,,-19.133333,-40.616667
br,barra do saco,Barra do Saco,02,,-9.7,-37.633333
br,barra do sai-guacu,Barra do Saí-Guaçu,18,,-25.9626,-48.598
br,barra dos andrades,Barra dos Andrades,18,,-25.663286,-50.606737
br,barra do santana,Barra do Santana,18,,-25.916667,-52.866667
br,barra do sao manuel,Barra do São Manuel,16,,-7.328056,-58.085556
br,barra do sao pedro,Barra do São Pedro,27,,-24.543839,-48.429994
br,barra dos bugres,Barra Dos Bugres,14,,-15.083333,-57.183333
br,barra dos cachimbos,Barra dos Cachimbos,30,,-8.883333,-36.4
br,barra dos coqueiros,Barra dos Coqueiros,28,28590,-10.9,-37.05
br,barra dos currais,Barra dos Currais,13,,-3.522222,-43.130278
br,barra dos dois rios,Barra dos Dois Rios,22,,-5.903056,-36.200556
br,barra do serrote,Barra do Serrote,30,,-8.433333,-39.3
br,barra do siemens,Barra do Siemens,18,,-25.6,-53.783333
br,barra do siemes,Barra do Siemes,18,,-25.6,-53.783333
br,barra do silva,Barra do Silva,30,,-8.433333,-38.85
br,barra do sirinhaem,Barra do Sirinhaém,30,,-8.6,-35.066667
br,barra do sitia,Barra do Sitiá,06,,-5.166667,-38.65
br,barra do sitio,Barra do Sítio,13,,-3.136111,-43.101944
br,barra dos melos,Barra dos Melos,06,,-3.9,-40.25
br,barra dos melos,Barra dos Melos,18,,-25.9582,-49.9061
br,barra do soldado,Barra do Soldado,27,,-24.734173,-48.050082
br,barra dos remedios,Barra dos Remédios,06,,-2.902222,-41.082778
br,barra do sul,Barra do Sul,26,,-26.4592,-48.6031
br,barra do superagui,Barra do Superagui,18,,-25.454499,-48.241236
br,barra do tapera,Barra do Tapera,13,,-5.433333,-42.933333
br,barra do taquara,Barra do Taquara,30,,-8.283333,-36.066667
br,barra do tarrachil,Barra do Tarrachil,05,,-8.783333,-38.966667
br,barra do teixeira,Barra do Teixeira,18,,-24.666667,-49.5
br,barra do triunfo,Barra do Triunfo,08,,-19.7,-40.5
br,barra do trombudo,Barra do Trombudo,26,,-27.25,-49.7
br,barra do trucu,Barra do Truçu,06,,-6.283333,-39.266667
br,barra do turvo,Barra do Turvo,27,,-24.757,-48.5059
br,barra dourada,Barra Dourada,27,,-20.783333,-49.566667
br,barra do varzea,Barra do Várzea,20,,-8.533333,-41.933333
br,barra do veado,Barra do Veado,26,,-27.383333,-51.933333
br,barra do xando,Barra do Xandó,17,,-7.583333,-36.416667
br,barra falsa,Barra Falsa,23,,-31.833333,-52.266667
br,barra feliz,Barra Feliz,15,,-19.966667,-43.45
br,barra funda,Barra Funda,02,,-9.7,-36.4
br,barra funda,Barra Funda,05,,-13.45,-40.383333
br,barra funda,Barra Funda,13,,-3.066667,-42.3
br,barragem,Barragem,05,,-10.733333,-43.5
br,barragem,Barragem,27,,-23.865658,-46.625292
br,barra grande,Barra Grande,02,,-9,-35.2
br,barra grande,Barra Grande,05,,-11.766667,-44.433333
br,barra grande,Barra Grande,13,,-3.3475,-43.476667
br,barra grande,Barra Grande,15,,-22.2,-45.333333
br,barra grande,Barra Grande,18,,-23.516498,-50.042443
br,barra grande,Barra Grande,20,,-2.911667,-41.410556
br,barra grande,Barra Grande,21,,-22.15,-42.316667
br,barra grande,Barra Grande,23,,-28.666667,-49.1
br,barra grande,Barra Grande,27,,-20.416667,-48.833333
br,barra grande,Barra Grande,30,,-8.116667,-36.516667
br,barra i,Barra I,13,,-3.393611,-43.430556
br,barra ii,Barra II,13,,-3.321111,-43.456111
br,barra logo,Barra Logo,13,,-8.216667,-45.75
br,barra longa,Barra Longa,15,,-20.283333,-43.05
br,barra luis pereira,Barra Luís Pereira,15,,-18.95,-44.116667
br,barra mansa,Barra Mansa,15,,-21.633333,-45.05
br,barra mansa,Barra Mansa,18,,-23.85231,-50.583984
br,barra mansa,Barra Mansa,21,164054,-22.533333,-44.183333
br,barra mansa,Barra Mansa,27,,-23.973624,-47.119444
br,barranca,Barranca,11,,-22.166667,-57.433333
br,barranca vermelha,Barranca Vermelha,11,,-19.933333,-56.766667
br,barranceira,Barranceira,26,,-28.416667,-48.8
br,barranco alto,Barranco Alto,11,,-18.216667,-55.483333
br,barranco alto,Barranco Alto,14,,-14.9,-56.45
br,barranco alto,Barranco Alto,15,,-21.183333,-45.966667
br,barranco alto,Barranco Alto,24,,-13.033333,-61.433333
br,barranco alto,Barranco Alto,27,,-25.214526,-48.06866
br,barranco arica,Barranco Aricá,14,,-15.983333,-55.9
br,barranco,Barranco,11,,-22.166667,-57.433333
br,barranco,Barranco,14,,-15.933333,-57.683333
br,barranco,Barranco,26,,-26.1,-48.783333
br,barranco branco,Barranco Branco,11,,-19.966667,-56.733333
br,barranco vermelho,Barranco Vermelho,11,,-19.933333,-56.766667
br,barrania,Barrânia,27,,-21.55,-46.533333
br,barra nova,Barra Nova,02,,-9.566667,-37.083333
br,barra nova,Barra Nova,05,,-16.666667,-39.616667
br,barra nova,Barra Nova,06,,-4.1,-38.15
br,barra nova,Barra Nova,08,,-18.9,-39.766667
br,barra nova,Barra Nova,13,,-3.876389,-43.326111
br,barranquinho,Barranquinho,11,,-18.216667,-55.483333
br,barrao de capanema,Barrão de Capanema,14,,-13.316667,-57.866667
br,barrao de melgaco,Barrão de Melgaco,24,,-11.85,-60.716667
br,barrao do grajahu,Barrao Do Grajahu,13,,-6.75,-43.016667
br,barrao orlando,Barrão Orlando,14,,-13.55,-57.45
br,barraos,Barraos,04,,-7.9,-60.683333
br,barra preta,Barra Preta,08,,-20.683333,-41.6
br,barraquinha,Barraquinha,18,,-24.283333,-51.566667
br,barra ribeirao da onca,Barra Ribeirão da Onça,26,,-27.0665,-49.7254
br,barra ribeirao do salto,Barra Ribeirão do Salto,27,,-24.8639,-48.1038
br,barra rio abaixo,Barra Rio Abaixo,27,,-23.383333,-47.116667
br,barra rio dona ema,Barra Rio Dona Ema,26,,-26.986507,-49.687686
br,barra rio manso,Barra Rio Manso,27,,-23.366667,-45.4
br,barras,Barras,18,,-24.066667,-52.45
br,barras,Barras,20,21597,-4.25,-42.3
br,barras do maratahoan,Barras do Maratahoan,20,,-4.25,-42.3
br,barras do maratoam,Barras do Maratoam,20,,-4.25,-42.3
br,barra seca,Barra Sêca,08,,-18.916667,-40.583333
br,barra seca,Barra Sêca,21,,-21.483333,-41.116667
br,barra sul,Barra Sul,21,,-23.007988,-43.427082
br,barratina,Barratina,11,,-20.016667,-55.116667
br,barra velha,Barra Velha,05,,-12.733333,-40.816667
br,barra velha,Barra Velha,06,,-5.9,-40.816667
br,barra velha,Barra Velha,13,,-3.534722,-43.314444
br,barra velha,Barra Velha,26,17665,-26.6406,-48.6851
br,barra velha,Barra Velha,30,,-8.1,-37.283333
br,barra verde,Barra Verde,05,,-12.766667,-40.816667
br,barra verde,Barra Verde,06,,-6.416667,-40.116667
br,barra verde,Barra Verde,22,,-6.333333,-37
br,barra verde,Barra Verde,30,,-7.866667,-39.25
br,barreado,Barreado,15,,-22.060833,-43.645
br,barreio de cima,Barreio de Cima,15,,-20.2488,-43.9922
br,barreios,Barreios,06,,-6.966667,-39.733333
br,barreira alta,Barreira Alta,03,,.55,-52.2
br,barreira alta,Barreira Alta,30,,-7.766667,-39.8
br,barreira,Barreira,04,,-4.1,-63.083333
br,barreira,Barreira,06,,-3.05,-40.116667
br,barreira,Barreira,11,,-18.033333,-54.166667
br,barreira,Barreira,13,,-3.470556,-42.534722
br,barreira,Barreira,15,,-16.283333,-41.183333
br,barreira,Barreira,16,,-4.066667,-55.883333
br,barreira,Barreira,20,,-6.483333,-41.916667
br,barreira,Barreira,21,,-21.083333,-41.866667
br,barreira,Barreira,27,,-23.116667,-49.033333
br,barreira,Barreira,30,,-8.15,-37.716667
br,barreira branca,Barreira Branca,04,,-4.315556,-67.345
br,barreira branca,Barreira Branca,20,,-3.896944,-42.215
br,barreira branca,Barreira Branca,31,,-6.7,-48.733333
br,barreira da aroeira,Barreira da Aroeira,20,,-7.766667,-41.566667
br,barreira da ema,Barreira da Ema,05,,-10.25,-42.366667
br,barreira do campo,Barreira do Campo,16,,-9.3,-50.1
br,barreira do jacuruna,Barreira do Jacuruna,05,,-13.066667,-38.85
br,barreira do mato,Barreira do Mato,13,,-5.933333,-43.45
br,barreira do matupiri,Barreira do Matupiri,04,,-5.570556,-61.106944
br,barreira dos vianas,Barreira dos Vianas,06,,-4.7,-37.766667
br,barreira do vasco,Barreira do Vasco,21,,-22.888855,-43.229272
br,barreira funda,Barreira Funda,13,,-3.879722,-43.411944
br,barreira funda,Barreira Funda,20,,-5.95,-42.866667
br,barreirao,Barreirão,05,,-11.816667,-41.95
br,barreirao,Barreirão,14,,-14.716667,-57.566667
br,barreirao,Barreirão,18,,-23.0802,-50.2295
br,barreiras,Barreiras,02,,-10.166667,-36.166667
br,barreiras,Barreiras,05,158296,-12.133333,-45
br,barreiras,Barreiras,06,,-3.416667,-39.133333
br,barreiras,Barreiras,13,,-2.868056,-41.9125
br,barreiras,Barreiras,15,,-17.533333,-43.016667
br,barreiras,Barreiras,17,,-6.866667,-34.9
br,barreiras,Barreiras,20,,-6.35,-41.933333
br,barreiras,Barreiras,21,,-21.083333,-41.866667
br,barreiras,Barreiras,22,,-5.083333,-36.5
br,barreiras,Barreiras,31,,-5.9,-47.45
br,barreiras de jacuruna,Barreiras de Jacuruna,05,,-13.066667,-38.85
br,barreiras de santo antonio,Barreiras de Santo Antônio,05,,-13.066667,-38.95
br,barreira vermelha,Barreira Vermelha,22,,-5.166667,-36.016667
br,barreirinha,Barreirinha,04,11257,-2.793611,-57.068889
br,barreirinha,Barreirinha,13,,-4.233333,-44.233333
br,barreirinha,Barreirinha,14,,-16.55,-56.116667
br,barreirinha,Barreirinha,15,,-21.333333,-45.516667
br,barreirinha,Barreirinha,16,,-9.466667,-50.133333
br,barreirinha,Barreirinha,20,,-7.166667,-40.933333
br,barreirinha,Barreirinha,27,,-22.866667,-47.7
br,barreirinhas,Barreirinhas,13,17437,-2.75,-42.833333
br,barreirinho,Barreirinho,15,,-21,-45.833333
br,barreirinho,Barreirinho,18,,-23.1297,-50.0098
br,barreirinho,Barreirinho,27,,-22.866667,-47.7
br,barreirinho d'oeste,Barreirinho d'Oeste,18,,-24.133333,-52.833333
br,barreirinho dos beltrao,Barreirinho dos Beltrão,18,,-25.730175,-50.652944
br,barreiro baixo,Barreiro Baixo,29,,-13.766667,-46.45
br,barreiro,Barreiro,05,,-10.75,-44.483333
br,barreiro,Barreiro,06,,-6.083333,-40.8
br,barreiro,Barreiro,07,,-15.983333,-47.483333
br,barreiro,Barreiro,11,,-18.033333,-54.166667
br,barreiro,Barreiro,13,,-3.210833,-43.335833
br,barreiro,Barreiro,14,,-14.483333,-55.8
br,barreiro,Barreiro,15,,-14.4,-43.866667
br,barreiro,Barreiro,18,,-24.15,-51
br,barreiro,Barreiro,20,,-10.75,-44.783333
br,barreiro,Barreiro,23,,-28.45,-53.95
br,barreiro,Barreiro,26,,-26.3,-50.533333
br,barreiro,Barreiro,27,,-22.216667,-47.116667
br,barreiro,Barreiro,30,,-7.733333,-37.833333
br,barreiro,Barreiro,31,,-5.7,-48.116667
br,barreiro branco,Barreiro Branco,04,,-7.183333,-58.116667
br,barreiro branco,Barreiro Branco,05,,-14.05,-43.683333
br,barreiro da ema,Barreiro da Ema,05,,-10.25,-42.366667
br,barreiro da ema,Barreiro da Ema,22,,-6.133333,-36.3
br,barreiro da raiz,Barreiro da Raiz,15,,-16.033333,-43.266667
br,barreiro de baixo,Barreiro de Baixo,27,,-22.616667,-44.4
br,barreiro de baixo,Barreiro de Baixo,29,,-13.766667,-46.45
br,barreiro de santo antonio,Barreiro de Santo Antônio,05,,-13.066667,-38.95
br,barreiro do jaiba,Barreiro do Jaíba,15,,-15.616667,-43.6
br,barreiro do nascimento,Barreiro do Nascimento,31,,-11.883333,-50.633333
br,barreiro dos cocos,Barreiro dos Cocós,20,,-3.638056,-42.163889
br,barreiro grande,Barreiro Grande,05,,-13.766667,-43.6
br,barreiro grande,Barreiro Grande,18,,-25.8999,-49.8913
br,barreiro iii,Barreiro III,20,,-3.520833,-42.033333
br,barreiro iv,Barreiro IV,20,,-3.5475,-42.127222
br,barreiro manecao,Barreiro Manecão,27,,-24.9374,-48.2948
br,barreiro novo,Barreiro Novo,05,,-13.833333,-41.133333
br,barreiro rico,Barreiro Rico,27,,-23.215193,-47.785318
br,barreiros,Barreiros,02,,-9.383333,-38.05
br,barreiros,Barreiros,05,,-15.6,-39.2
br,barreiros,Barreiros,06,,-4.416667,-38.65
br,barreiros,Barreiros,15,,-17.316667,-44.466667
br,barreiros,Barreiros,16,,-4.066667,-55.883333
br,barreiros,Barreiros,17,,-7.633333,-38.683333
br,barreiros,Barreiros,20,,-5.7,-43.066667
br,barreiros,Barreiros,22,,-5.083333,-36.5
br,barreiros,Barreiros,26,,-26.3,-50.533333
br,barreiros,Barreiros,27,,-24.7921,-48.4774
br,barreiros,Barreiros,30,35565,-8.816667,-35.2
br,barreiros de santo antonio,Barreiros de Santo Antônio,05,,-13.066667,-38.95
br,barreiros dos porcos,Barreiros dos Porcos,20,,-7.633333,-41.666667
br,barreiro vermelho,Barreiro Vermelho,15,,-15.366667,-43.283333
br,barrejirnha,Barrejirnha,20,,-5.766667,-42.6
br,barrelina,Barrelina,11,,-20.016667,-55.116667
br,barrenta,Barrenta,06,,-3.266667,-39.633333
br,barrento,Barrento,06,,-3.266667,-39.533333
br,barrento,Barrento,22,,-6,-36.05
br,barrento dos cesarios,Barrento dos Cesarios,17,,-6.9,-37.783333
br,barrera,Barrera,13,,-7.9,-47
br,barrero,Barrero,11,,-18.366667,-55.983333
br,barretina,Barretina,11,,-17.933333,-54.5
br,barreto,Barreto,08,,-20.633333,-41.233333
br,barreto,Barreto,14,,-8.8,-58.4
br,barreto,Barreto,15,,-20.05,-43.2
br,barreto,Barreto,21,,-22.333333,-41.75
br,barreto,Barreto,22,,-5.683333,-35.833333
br,barreto,Barreto,23,,-28.3,-51.466667
br,barreto,Barreto,30,,-7.55,-39.35
br,barretos,Barretos,15,,-20.283333,-43.166667
br,barretos,Barretos,27,101222,-20.55,-48.55
br,barretro ii,Barretro II,20,,-3.403889,-42.034444
br,barriero,Barriero,27,,-21.583333,-47.183333
br,barrieros,Barrieros,17,,-6.633333,-37.966667
br,barriga,Barriga,20,,-6.666667,-42.183333
br,barrigada,Barrigada,15,,-15.75,-46.35
br,barriguda,Barriguda,02,,-9.416667,-37.266667
br,barriguda,Barriguda,05,,-10.516667,-41.05
br,barriguda,Barriguda,06,,-5.6,-40.783333
br,barriguda,Barriguda,13,,-3.083333,-44.116667
br,barriguda,Barriguda,17,,-7.733333,-38.55
br,barriguda,Barriguda,28,,-10.833333,-38.133333
br,barriguda,Barriguda,30,,-7.666667,-38.783333
br,barriguda de cima,Barriguda de Cima,05,,-11.283333,-40.933333
br,barrigudinha,Barrigudinha,30,,-7.55,-39.55
br,barrigudo,Barrigudo,02,,-9.6,-36.9
br,barrigudo,Barrigudo,05,,-12.033333,-41.65
br,barrinha,Barrinha,05,,-10.233333,-43.5
br,barrinha,Barrinha,06,,-2.8,-40.35
br,barrinha,Barrinha,13,,-4.216667,-43.233333
br,barrinha,Barrinha,14,,-16.7,-56.833333
br,barrinha,Barrinha,18,,-24.714962,-48.995249
br,barrinha,Barrinha,20,,-2.915556,-41.385
br,barrinha,Barrinha,21,,-22.205833,-43.015278
br,barrinha,Barrinha,22,,-5.1675,-37.419722
br,barrinha,Barrinha,23,,-28.55,-52.666667
br,barrinha,Barrinha,27,26981,-21.2,-48.15
br,barrinha roteio,Barrinha Roteio,02,,-9.833333,-35.966667
br,barrinhas,Barrinhas,20,,-5.133333,-42.516667
br,barrinho,Barrinho,14,,-16.7,-56.833333
br,barrinho,Barrinho,27,,-23.116667,-45.366667
br,barrinia,Barrinia,27,,-21.55,-46.533333
br,barrio barra grande,Barrio Barra Grande,18,,-24.681411,-48.965007
br,barrio do costao,Barrio do Costão,18,,-25.289301,-48.328532
br,barrio do pavao,Barrio do Pavão,27,,-24.643945,-48.790037
br,barrio do rolado,Barrio do Rolado,18,,-24.716632,-48.930163
br,barrio ponta aguda,Barrio Ponta Aguda,26,,-26.9007,-49.0476
br,barrios,Barrios,11,,-21.783333,-53.55
br,barrio vocoroca,Barrio Voçoroca,18,,-25.8202,-49.0623
br,barris,Barris,05,,-12.985,-38.51
br,barroada,Barroada,15,,-19.016667,-42.65
br,barro alto,Barro Alto,04,,-3.883333,-63.766667
br,barro alto,Barro Alto,05,,-11.766667,-41.9
br,barro alto,Barro Alto,20,,-8.85,-45.383333
br,barro alto,Barro Alto,29,,-15.066667,-48.966667
br,barro,Barro,05,,-12.583333,-38.266667
br,barro,Barro,06,11519,-6.716667,-38.866667
br,barro,Barro,08,,-20.8,-41.716667
br,barro,Barro,13,,-3.083333,-45.416667
br,barro,Barro,15,,-16.333333,-41.483333
br,barro,Barro,17,,-6.983333,-38.05
br,barro,Barro,20,,-6.916667,-41.466667
br,barro,Barro,22,,-6.366667,-38.4
br,barro,Barro,23,,-27.566667,-52.05
br,barro,Barro,25,,4.283333,-60.833333
br,barro,Barro,27,,-23.716667,-45.4
br,barro,Barro,30,,-7.5,-39.8
br,barro branco,Barro Branco,06,,-7.75,-38.983333
br,barro branco,Barro Branco,08,,-20.55,-40.483333
br,barro branco,Barro Branco,13,,-3.805833,-43.3275
br,barro branco,Barro Branco,15,,-20.716667,-41.933333
br,barro branco,Barro Branco,16,,-1.333333,-47.8
br,barro branco,Barro Branco,18,,-25.225452,-48.872992
br,barro branco,Barro Branco,20,,-6.966667,-41.933333
br,barro branco,Barro Branco,21,,-21.5,-41.783333
br,barro branco,Barro Branco,25,,-3.366667,-60.25
br,barro branco,Barro Branco,26,,-28.416667,-49.416667
br,barro branco,Barro Branco,27,,-24.689223,-48.087762
br,barro branco,Barro Branco,30,,-8.483333,-36.866667
br,barro branco de baixo,Barro Branco de Baixo,18,,-25.699307,-50.48678
br,barro branco de cima,Barro Branco de Cima,18,,-25.68946,-50.48516
br,barroca,Barroca,05,,-10.9,-38.35
br,barroca,Barroca,13,,-3.712778,-43.188611
br,barroca,Barroca,17,,-7.166667,-36.433333
br,barroca,Barroca,20,,-3.337222,-42.019444
br,barroca,Barroca,22,,-5.986944,-36.768889
br,barroca,Barroca,27,,-21.416667,-47.283333
br,barroca,Barroca,29,,-15.35,-48.5
br,barroca,Barroca,30,,-8.25,-38.533333
br,barroca da onca,Barroca da Onça,20,,-3.576944,-42.171389
br,barroca da vaca,Barroca da Vaca,13,,-3.720278,-43.480556
br,barroca funda,Barroca Funda,20,,-7.916667,-43.116667
br,barroca funda,Barroca Funda,27,,-23.236,-47.9259
br,barrocao,Barrocão,05,,-9.833333,-42.116667
br,barrocao,Barrocão,13,,-3.123056,-43.095556
br,barrocao,Barrocão,15,,-16.416667,-43.25
br,barrocao,Barrocão,17,,-7.483333,-38.416667
br,barrocao,Barrocão,20,,-3.678056,-42.5125
br,barrocao,Barrocão,22,,-5.210278,-36.145556
br,barrocao,Barrocão,27,,-22.716667,-47.366667
br,barrocao de baixo,Barrocão de Baixo,13,,-3.682222,-43.35
br,barrocao de cima,Barrocão de Cima,13,,-3.675278,-43.361389
br,barrocao i,Barrocão I,13,,-3.409444,-43.138889
br,barrocao ii,Barrocão II,13,,-3.395,-43.133611
br,barrocas,Barrocas,05,,-11.516667,-39.066667
br,barrocas,Barrocas,20,,-7.883333,-43.1
br,barro da cabra,Barro da Cabra,17,,-6.966667,-38.133333
br,barro do prata,Barro do Prata,20,,-8.05,-44.466667
br,barro do saltinho,Barro do Saltinho,27,,-24.686267,-48.568586
br,barro duro,Barro Duro,13,,-2.866667,-42.283333
br,barro duro,Barro Duro,20,,-5.816667,-42.516667
br,barrolandia,Barrolândia,31,,-9.780833,-48.621944
br,barro preto,Barro Prêto,05,,-14.766667,-39.45
br,barro preto,Barro Prêto,15,,-20.383333,-43.016667
br,barro preto,Barro Preto,18,,-23.6396,-49.9692
br,barro preto,Barro Preto,20,,-5.283333,-42.65
br,barro preto,Barro Prêto,23,,-28.1,-53.7
br,barro preto,Barro Prêto,27,,-20.65,-47.333333
br,barro preto,Barro Prêto,30,,-8.566667,-37.116667
br,barroquinha,Barroquinha,06,12410,-2.983333,-41.083333
br,barroquinha,Barroquinha,13,,-3.362222,-42.719722
br,barroquinha dos fieis,Barroquinha dos Fiéis,06,,-2.979722,-41.134167
br,barro salto do meio,Barro Salto do Meio,18,,-25.806415,-48.990584
br,barros,Barros,17,,-7.3,-37.566667
br,barros,Barros,27,,-23.7378,-47.6138
br,barros cassal,Barros Cassal,23,,-29.1,-52.583333
br,barros filho,Barros Filho,21,,-22.830855,-43.369472
br,barroso,Barroso,02,,-9.366667,-37.233333
br,barroso,Barroso,14,,-15.9,-56.816667
br,barroso,Barroso,15,16975,-21.183333,-43.966667
br,barroso,Barroso,20,,-7.45,-41.566667
br,barroso,Barroso,27,,-21.416667,-47.283333
br,barro verde,Barro Verde,05,,-12.766667,-40.816667
br,barro verde,Barro Verde,17,,-7.2,-37.233333
br,barro vermelho,Barro Vermelho,05,,-10.966667,-44.166667
br,barro vermelho,Barro Vermelho,06,,-3.966667,-40.233333
br,barro vermelho,Barro Vermelho,13,,-3.701111,-42.743889
br,barro vermelho,Barro Vermelho,17,,-6.633333,-37.883333
br,barro vermelho,Barro Vermelho,20,,-3.367222,-42.085556
br,barro vermelho,Barro Vermelho,21,,-22.066667,-41.666667
br,barro vermelho,Barro Vermelho,22,,-5.476111,-36.140556
br,barro vermelho,Barro Vermelho,23,,-29.9277,-50.8876
br,barro vermelho,Barro Vermelho,26,,-28.9,-49.466667
br,barro vermelho,Barro Vermelho,30,,-7.466667,-37.35
br,barruada,Barruada,15,,-19.016667,-42.65
br,bar terra-firme,Bar Terra-Firme,24,,-12.033333,-64.283333
br,bartolomeu,Bartolomeu,06,,-3.6,-40.166667
br,bartolomeu,Bartolomeu,17,,-7.3,-38.466667
br,barueri,Barueri,27,251999,-23.516667,-46.883333
br,baruri,Baruri,04,,-.883333,-63.016667
br,base aerea do amapa,Base Aérea do Amapá,03,,2.066667,-50.866667
br,base das canoas,Base das Canoas,16,,-2.25,-55.95
br,basilio alves morango,Basílio Alves Morango,08,,-18.016667,-40.766667
br,basilio,Basílio,20,,-7.5,-40.833333
br,basilio,Basílio,23,,-31.883333,-53.016667
br,basilio gomes,Basílio Gomes,15,,-17.933333,-40.816667
br,bastiao,Bastião,05,,-12.816667,-41.7
br,bastioes,Bastiões,06,,-4.616667,-38.716667
br,bastioes,Bastiões,17,,-7.05,-35.55
br,bastister,Bastister,04,,-5.629444,-63.518333
br,bastos,Bastos,13,,-3.561389,-42.996111
br,bastos,Bastos,27,17681,-21.933333,-50.716667
br,basuca,Basuca,15,,-18.766667,-41.883333
br,bataguacu,Bataguaçu,11,,-21.7,-52.366667
br,bataipora,Bataiporã,11,7346,-22.333333,-53.283333
br,batal,Batal,20,,-6.1,-42.2
br,batalha,Batalha,02,11820,-9.683333,-37.133333
br,batalha,Batalha,05,,-10.866667,-45.3
br,batalha,Batalha,06,,-4.25,-38.616667
br,batalha,Batalha,08,,-21.1,-41.016667
br,batalha,Batalha,13,,-5.866667,-43.916667
br,batalha,Batalha,20,8744,-4.016667,-42.083333
br,batalha,Batalha,21,,-22.716667,-43.15
br,batalha,Batalha,27,,-21.916667,-49.25
br,batalha,Batalha,30,,-7.833333,-38.383333
br,batalha,Batalha,31,,-12.316667,-46.4
br,batalhao,Batalhão,17,,-7.2,-36.816667
br,batalha velha,Batalha Velha,13,,-6.383333,-43.216667
br,batan,Batan,21,,-22.862636,-43.424926
br,batataes,Batataes,27,,-20.883333,-47.616667
br,batatais,Batatais,27,51977,-20.883333,-47.616667
br,batatal,Batatal,02,,-9.4,-37.25
br,batatal,Batatal,14,,-14.466667,-57.35
br,batatal,Batatal,27,,-24.669195,-48.328014
br,batatas,Batatas,06,,-6.45,-40.2
br,batateira,Batateira,05,,-9.95,-41.366667
br,batateira,Batateira,30,,-8.55,-35.85
br,batateiro,Batateiro,30,,-8.65,-37.1
br,batatuba,Batatuba,27,,-23.066667,-46.416667
br,bate,Bate,20,,-8.866667,-43.15
br,batedor,Batedor,06,,-5.166667,-39.6
br,batedor,Batedor,30,,-7.566667,-39.816667
br,bateeiro,Bateeiro,05,,-12.383333,-40.916667
br,bateia,Bateia,15,,-22.366667,-45.833333
br,bateia,Batéia,18,,-24.800149,-48.868408
br,bateia,Bateia,26,,-26.966667,-48.916667
br,bateia do barracao,Batéia do Barracão,26,,-26.966667,-48.916667
br,bateias,Bateias,18,,-25.366667,-49.516667
br,bateias,Bateias,27,,-23.7035,-47.7711
br,bateias de baixo,Bateias de Baixo,26,,-26.0894,-49.2582
br,bateiro,Bateiro,05,,-12.383333,-40.916667
br,batelao,Batelão,21,,-21.316667,-41.033333
br,batel,Batel,18,,-25.4359,-48.738
br,batente,Batente,30,,-8.566667,-35.9
br,bateria,Bateria,04,,.966667,-66.833333
br,bate-vento,Bate-Vento,13,,-1.3,-44.9
br,batinga,Batinga,05,,-16.916667,-40.5
br,batinga,Batinga,15,,-21.683333,-45.05
br,batinga,Batinga,17,,-7.333333,-37.466667
br,batinga,Batinga,20,,-7.383333,-40.6
br,batinga,Batinga,30,,-7.633333,-37.8
br,batista,Batista,05,,-12.933333,-39.55
br,batista,Batista,27,,-24.9408,-48.0878
br,batista botelho,Batista Botelho,27,,-23.016667,-49.416667
br,batistini,Batistini,27,,-23.7564,-46.5654
br,batoque,Batoque,05,,-10.566667,-40.6
br,batoque,Batoque,06,,-4.4,-40.366667
br,batovi,Batovi,14,,-15.883333,-53.4
br,batuque,Batuque,05,,-15.1,-41.083333
br,baturite,Baturité,04,,-5.720833,-63.510278
br,baturite,Baturité,06,22417,-4.333333,-38.883333
br,baturite,Baturité,13,,-1.983333,-44.783333
br,batuva,Batuva,18,,-25.088056,-48.230278
br,baua,Baua,04,,1.033333,-66.816667
br,bau,Baú,06,,-6.4,-39.4
br,bau,Baú,11,,-18.316667,-53.166667
br,bau,Bau,13,,-5.25,-43.433333
br,bau,Baú,14,,-15.233333,-56.3
br,bau,Baú,15,,-17.916667,-43.083333
br,bau de cima,Baú de Cima,27,,-22.6952,-45.6205
br,bau do centro,Baú do Centro,27,,-22.7051,-45.6635
br,baunilha,Baunilha,08,,-19.566667,-40.5
br,baunilha,Baunilha,14,,-16.133333,-55.416667
br,bauru,Bauru,27,335031,-22.316667,-49.066667
br,baus,Baús,11,,-18.316667,-53.166667
br,bauta,Bautá,04,,.316667,-67.283333
br,bau velho,Baú Velho,27,,-22.7233,-45.6926
br,bauxi,Bauxi,14,,-15.166667,-56.65
br,bauzinho,Bauzinho,11,,-18.316667,-53.166667
br,baviera,Baviera,22,,-5.543889,-36.908889
br,baxio,Baxio,30,,-8.4,-40.183333
br,baxios,Baxios,02,,-9.7,-37.2
br,baxiu,Baxiú,22,,-5.166667,-35.8
br,bayeux,Bayeux,17,91058,-7.133333,-34.933333
br,b. da boiada,B. da Boiada,27,,-21.283333,-47.1
br,b. das rosas,B. das Rosas,27,,-22.766667,-46.783333
br,bebedor,Bebedor,02,,-9.116667,-37.666667
br,bebedor,Bebedor,11,,-21.316667,-55.866667
br,bebedor,Bebedor,20,,-5.05,-41.15
br,bebedouro,Bebedouro,02,,-9.65,-35.75
br,bebedouro,Bebedouro,05,,-10.283333,-37.933333
br,bebedouro,Bebedouro,06,,-6.633333,-40.116667
br,bebedouro,Bebedouro,13,,-2.466667,-44.766667
br,bebedouro,Bebedouro,15,,-19.233333,-48.383333
br,bebedouro,Bebedouro,17,,-6.883333,-38.416667
br,bebedouro,Bebedouro,27,71863,-20.933333,-48.466667
br,bebedouro,Bebedouro,30,,-8.45,-35.95
br,bebedouro de cima,Bebedouro de Cima,20,,-4.166667,-41.533333
br,bebedouro de sao pedro,Bebedouro de São Pedro,13,,-3.25,-42.116667
br,bebedouro i,Bebedouro I,13,,-3.473889,-43.381389
br,bebedouro ii,Bebedouro II,13,,-3.326667,-43.070833
br,bebedouro iii,Bebedouro III,13,,-3.555,-43.090833
br,bebedouuro de sao pedro,Bebedouuro de São Pedro,13,,-3.25,-42.116667
br,bebedovro,Bebedovro,13,,-6.166667,-43.1
br,beberibe,Beberibe,06,37028,-4.183333,-38.133333
br,bebida nova,Bebida Nova,13,,-3.932778,-42.976944
br,bebida velha,Bebida Velha,22,,-5.333333,-35.533333
br,beco,Beco,05,,-12.45,-41.683333
br,beco,Beco,06,,-5.466667,-40.85
br,becreio,Becreio,20,,-7.933333,-43.033333
br,beija-flor,Beija-Flor,05,,-12.683333,-38.95
br,beija-flor,Beija-Flor,11,,-21.383333,-56.233333
br,beija-flor,Beija-Flor,14,,-13.783333,-55.233333
br,beija-flor,Beija-Flor,15,,-21.133333,-43.083333
br,beija-flor,Beija-Flor,20,,-3.756111,-42.256389
br,beiju,Beiju,30,,-8.483333,-37.683333
br,beira alta,Beira Alta,08,,-20.7,-41.3
br,beira do rio,Beira do Rio,05,,-13.583333,-41.216667
br,beira do rio,Beira do Rio,06,,-6.416667,-38.883333
br,beira do tai,Beira do Taí,21,,-21.783333,-41.166667
br,beira mar,Beira Mar,23,,-32.166667,-52.116667
br,beirao,Beirão,15,,-16.833333,-41.8
br,beira serra,Beira Serra,15,,-20.2315,-43.9929
br,beja,Beja,16,,-1.6,-48.783333
br,bejamin novais,Bejamin Novais,23,,-28.666667,-53.6
br,beju,Beju,17,,-6.533333,-35.3
br,bela alianca,Bela Aliança,06,,-5.366667,-39.183333
br,bela alianca,Bela Aliança,26,,-27.1855,-49.5815
br,bela aurora,Bela Aurora,04,,.066667,-63.983333
br,bela aurora,Bela Aurora,06,,-4.866667,-40.266667
br,bela aurora,Bela Aurora,08,,-20.7,-41.416667
br,bela aurora,Bela Aurora,16,,-1.766667,-46.333333
br,bela aurora,Bela Aurora,28,,-9.816667,-37.5
br,bela brisa,Bela Brisa,04,,-6.883611,-62.637778
br,bela cruz,Bela Cruz,06,12715,-3.05,-40.183333
br,bela cruz,Bela Cruz,15,,-22.366667,-45.633333
br,bela estrela,Bela Estrêla,13,,-5.483333,-46.183333
br,bela fama,Bela Fama,15,,-20.0066,-43.8379
br,bela flor,Bela Flor,05,,-12.416667,-38.466667
br,bela floresta,Bela Floresta,27,,-20.6,-51.266667
br,belagua,Belágua,13,,-3.005,-42.448333
br,bela joana,Bela Joana,21,,-22.016667,-42.666667
br,bela lorena,Bela Lorena,15,,-15.216667,-46.016667
br,bela manha,Bela Manhã,18,,-23.466667,-50.35
br,belamento,Belamento,30,,-7.983333,-37.233333
br,belamino dias,Belamino Dias,15,,-17.016667,-46.75
br,bela monte,Bela Monte,16,,-3.083333,-51.766667
br,bela nova,Bela Nova,05,,-15.05,-39.683333
br,bela paisagem,Bela Paisagem,05,,-13.566667,-40.883333
br,bela pinta,Bela Pinta,05,,-14.716667,-40.633333
br,belarmino,Belarmino,18,,-25.133333,-52.816667
br,belarmino,Belarmino,29,,-17.516667,-52.7
br,belarmino ferreira,Belarmino Ferreira,15,,-16.883333,-43.2
br,belas aguas,Belas Águas,06,,-5.633333,-38.166667
br,belas artes,Belas Artes,11,,-21.683333,-54.383333
br,bela veneza,Bela Veneza,20,,-6.016667,-42.083333
br,bela vista,Bela Vista,02,,-9.283333,-36.233333
br,bela vista,Bela Vista,03,,2.266667,-50.75
br,bela vista,Bela Vista,04,,.133333,-67.9
br,bela vista,Bela Vista,05,,-11.833333,-41.016667
br,bela vista,Bela Vista,06,,-3.216667,-39.616667
br,bela vista,Bela Vista,08,,-19.533333,-40.416667
br,bela vista,Bela Vista,11,18127,-22.1,-56.516667
br,bela vista,Bela Vista,13,,-3.401389,-43.222778
br,bela vista,Bela Vista,14,,-16.05,-56.883333
br,bela vista,Bela Vista,15,,-15.733333,-44.55
br,bela vista,Bela Vista,16,,-3.366667,-51.833333
br,bela vista,Bela Vista,18,,-23.215593,-52.231562
br,bela vista,Bela Vista,20,,-3.916389,-42.227778
br,bela vista,Bela Vista,21,,-20.983333,-41.916667
br,bela vista,Bela Vista,22,,-5.161389,-36.496944
br,bela vista,Bela Vista,23,,-28.2,-52.633333
br,bela vista,Bela Vista,24,,-11.516667,-65.25
br,bela vista,Bela Vista,25,,1.933333,-60.983333
br,bela vista,Bela Vista,26,,-26.1784,-49.977
br,bela vista,Bela Vista,27,,-20.033333,-47.85
br,bela vista,Bela Vista,29,,-16.966667,-48.95
br,bela vista,Bela Vista,30,,-7.466667,-39.733333
br,bela vista,Bela Vista,31,,-8.211111,-49.222222
br,bela vista de goias,Bela Vista de Goiás,29,14289,-16.966667,-48.95
br,bela vista do meio,Bela Vista do Meio,05,,-14.933333,-40.233333
br,bela vista do paraiso,Bela Vista do Paraíso,18,14332,-23,-51.2
br,bela vista do sul,Bela Vista do Sul,26,,-26.1784,-49.977
br,bela vista do toldo,Bela Vista do Tôldo,26,,-26.266667,-50.5
br,belchior alto,Belchior Alto,26,,-26.8106,-49.0122
br,belchior baixo,Belchior Baixo,26,,-26.8544,-49.0348
br,belchior,Belchior,15,,-20.733333,-44.016667
br,belchior,Belchior,26,,-26.8544,-49.0348
br,belchior,Belchior,30,,-7.95,-39.9
br,beldroega,Beldroega,30,,-8.85,-36.75
br,beldroegas,Beldroegas,30,,-8.75,-38.166667
br,bele,Belé,06,,-5.283333,-39.15
br,belem,Belém,02,,-9.583333,-36.416667
br,belem,Belém,04,,-3.916667,-69.616667
br,belem,Belém,05,,-12.616667,-38.933333
br,belem,Belém,06,,-4.5,-39.616667
br,belem,Belém,08,,-18.466667,-39.733333
br,belem,Belém,13,,-1.85,-44.8
br,belem,Belem,15,,-18.9,-41.616667
br,belem,Belém,16,1407737,-1.45,-48.483333
br,belem,Belém,17,15550,-6.716667,-35.5
br,belem,Belém,18,,-23.433333,-51.733333
br,belem,Belém,20,,-4.216667,-42.983333
br,belem,Belém,21,,-22.966667,-44.283333
br,belem,Belém,22,,-5.35,-35.966667
br,belem,Belém,24,,-8.533333,-63.666667
br,belem,Belém,28,,-9.8,-37.333333
br,belem,Belém,30,,-7.916667,-38.466667
br,belem da cachoeira,Belém da Cachoeira,05,,-12.616667,-38.933333
br,belem de cabroba,Belém de Cabrobá,30,,-8.766667,-38.966667
br,belem de caicara,Belém de Caiçara,17,,-6.716667,-35.5
br,belem de maria,Belém de Maria,30,,-8.616667,-35.85
br,belem de sao francisco,Belém de São Francisco,30,11124,-8.766667,-38.966667
br,belem do bajados,Belém do Bajadós,04,,-3.494722,-62.547222
br,belem do brejo do cruz,Belém do Brejo do Cruz,17,,-6.183333,-37.533333
br,belem do candeia,Belém do Candeia,04,,-3.516667,-62.466667
br,belem do condeia,Belêm do Condeia,04,,-3.516667,-62.466667
br,belem do para,Belem do Pará,16,,-1.45,-48.483333
br,belem do sao francisco,Belém do São Francisco,30,,-8.766667,-38.966667
br,belem nova,Belem Nova,23,,-30.116667,-51.166667
br,belem novo,Belém Novo,23,,-30.2,-51.166667
br,belem santos,Belém Santos,15,,-18.9,-41.616667
br,belem velho,Belém Velho,23,,-30.116667,-51.166667
br,belexas,Belexas,04,,-2.55,-67.383333
br,beleza,Beleza,02,,-9.316667,-36.233333
br,beleza,Beleza,06,,-7.283333,-38.666667
br,beleza,Beleza,15,,-16.865833,-44.584722
br,beleza,Beleza,20,,-6.116667,-41.583333
br,beleza,Beleza,22,,-6.066667,-37.583333
br,beleza,Beleza,30,,-7.833333,-40.516667
br,belezas,Belezas,04,,-2.55,-67.383333
br,belford roxo,Belford Roxo,21,466101,-22.761995,-43.404654
br,belfort roxo,Belfort Roxo,21,,-22.761995,-43.404654
br,belisario,Belisário,15,,-20.916667,-42.466667
br,belisario,Belisário,23,,-28.466667,-53.433333
br,belisario benitez,Belisário Benítez,23,,-29.8,-56.85
br,belisario fulgencio,Belisário Fulgêncio,15,,-16.8,-41.666667
br,bella brisa,Bella Brisa,04,,-6.883611,-62.637778
br,bella monte,Bella Monte,16,,-3.083333,-51.766667
br,bella vista,Bella Vista,04,,.133333,-67.9
br,bella vista,Bella Vista,05,,-11.833333,-41.016667
br,bella vista,Bella Vista,11,,-22.1,-56.516667
br,bella vista,Bella Vista,15,,-16.258056,-44.159167
br,bella vista,Bella Vista,16,,-7.55,-53.3
br,bella vista,Bella Vista,18,,-25.433333,-54.583333
br,bella vista,Bella Vista,25,,1.933333,-60.983333
br,bella vista,Bella Vista,26,,-26.1784,-49.977
br,bella vista,Bella Vista,29,,-16.966667,-48.95
br,bello horizonte,Bello Horizonte,04,,-2.683333,-67.533333
br,bello horizonte,Bello Horizonte,15,,-19.916667,-43.933333
br,bello horizonte,Bello Horizonte,16,,-5.3,-52.866667
br,bello horizonte,Bello Horizonte,24,,-11.883333,-64.166667
br,bello jardim,Bello Jardim,30,,-8.333333,-36.433333
br,bello monte,Bello Monte,02,,-9.833333,-37.266667
br,bello monte,Bello Monte,04,,-8.116667,-70.333333
br,bello monte,Bello Monte,16,,-3.083333,-51.766667
br,bello monte,Bello Monte,27,,-23.35,-49.366667
br,bello valle,Bello Valle,15,,-20.416667,-44.016667
br,belmiro braga,Belmiro Braga,15,,-21.949722,-43.415833
br,belmont,Belmont,06,,-4.866667,-39.683333
br,belmont,Belmont,15,,-21.827222,-43.277778
br,belmont,Belmont,24,,-8.65,-63.833333
br,belmonte,Belmonte,01,,-9.333333,-72.2
br,belmonte,Belmonte,05,9806,-15.85,-38.9
br,belmonte,Belmonte,06,,-5.1,-40.683333
br,belmonte,Belmonte,14,,-7.65,-58.116667
br,belmonte,Belmonte,15,,-20,-41.45
br,belmonte,Belmonte,20,,-7.716667,-40.8
br,belmonte,Belmonte,21,,-22.35,-41.966667
br,belmonte,Belmonte,24,,-8.65,-63.833333
br,belmonte,Belmonte,27,,-21.466667,-47.516667
br,belmonte,Belmonte,30,,-7.866667,-38.766667
br,belo banho,Belo Banho,20,,-9.333333,-45.65
br,belo campo,Belo Campo,05,,-11.55,-41.616667
br,belo horizonte,Belo Horizonte,02,,-9.45,-37.266667
br,belo horizonte,Belo Horizonte,04,,-2.683333,-67.533333
br,belo horizonte,Belo Horizonte,05,,-10.15,-42.233333
br,belo horizonte,Belo Horizonte,06,,-7.083333,-40.083333
br,belo horizonte,Belo Horizonte,08,,-20.733333,-40.616667
br,belo horizonte,Belo Horizonte,11,,-19.8,-54.033333
br,belo horizonte,Belo Horizonte,15,2373255,-19.916667,-43.933333
br,belo horizonte,Belo Horizonte,16,,-5.3,-52.866667
br,belo horizonte,Belo Horizonte,17,,-6.866667,-38.35
br,belo horizonte,Belo Horizonte,20,,-6.883333,-40.6
br,belo horizonte,Belo Horizonte,22,,-5.456944,-36.410556
br,belo horizonte,Belo Horizonte,24,,-11.883333,-64.166667
br,belo horizonte,Belo Horizonte,27,,-21.416667,-47.933333
br,belo horizonte,Belo Horizonte,28,,-9.783333,-37.866667
br,belo horizonte,Belo Horizonte,31,,-10.483333,-49.516667
br,belo hurizonte,Belo Hurizonte,20,,-3.374167,-42.035556
br,belo jardim,Belo Jardim,02,,-9.416667,-37.316667
br,belo jardim,Belo Jardim,05,,-12.35,-40.083333
br,belo jardim,Belo Jardim,30,49923,-8.333333,-36.433333
br,belo monte,Belo Monte,01,,-10.033333,-66.8
br,belo monte,Belo Monte,02,,-9.833333,-37.266667
br,belo monte,Belo Monte,04,,-6.216667,-64.183333
br,belo monte,Belo Monte,05,,-13.666667,-40.316667
br,belo monte,Belo Monte,16,,-3.083333,-51.766667
br,belo monte,Belo Monte,20,,-6.5,-42.683333
br,belo monte,Belo Monte,27,,-23.35,-49.366667
br,belomonte,Belomonte,30,,-8.816667,-36.55
br,belo norte,Belo Norte,06,,-5.383333,-39.383333
br,belo oriente,Belo Oriente,15,18471,-19.233333,-42.466667
br,belo vale,Belo Vale,15,,-20.416667,-44.016667
br,belterra,Belterra,16,,-2.633333,-54.95
br,beluno,Beluno,23,,-29.45,-54.966667
br,belvedere,Belvedere,26,,-28.516667,-49.383333
br,bem-bom,Bem-Bom,05,,-9.716667,-41.8
br,bem-feita,Bem-Feita,02,,-9.283333,-37.566667
br,bemfica,Bemfica,15,,-21.683333,-43.433333
br,bemfica,Bemfica,16,,-1.3,-48.3
br,bem posta,Bem Posta,15,,-17.416667,-42.516667
br,bemposta,Bemposta,21,,-22.139722,-43.098056
br,bem-quer,Bem-Quer,13,,-6.683333,-42.983333
br,bem sera,Bem Será,31,,-8.923056,-48.106667
br,bem-te-vi,Bem-te-vi,04,,-5.417222,-63.041389
br,bem-te-vi,Bem-Te-Vi,18,,-24.2,-51.833333
br,bem-te-vi,Bem-Te-Vi,20,,-3.788889,-42.017778
br,bemtevi,Bemtevi,30,,-8.55,-35.583333
br,bene dias machado,Bené Dias Machado,15,,-20.4,-46.716667
br,benedicto leite,Benedicto Leite,13,,-7.216667,-44.566667
br,benedicto novo,Benedicto Novo,26,,-26.8,-49.416667
br,beneditinos,Beneditinos,20,5005,-5.45,-42.366667
br,benedito alves,Benedito Alves,26,,-26.665054,-49.518707
br,benedito,Benedito,04,,-6.35,-60.316667
br,benedito,Benedito,05,,-9.016667,-39.5
br,benedito,Benedito,15,,-14.583333,-44.216667
br,benedito dos santos,Benedito dos Santos,21,,-21.066667,-41.733333
br,benedito leite,Benedito Leite,13,,-7.216667,-44.566667
br,benedito medeiros,Benedito Medeiros,15,,-20.35,-46.816667
br,benedito novo,Benedito Novo,26,,-26.8,-49.416667
br,beneficente,Beneficente,04,,-7.133333,-60.483333
br,beneficiente,Beneficiente,04,,-7.133333,-60.483333
br,benevente,Benevente,08,,-20.8,-40.65
br,benevenuto,Benevenuto,25,,1.883333,-61.016667
br,benevides,Benevides,16,49813,-1.366667,-48.25
br,benevolencia,Benevolência,06,,-5.966667,-39.1
br,benfica,Benfica,01,,-8.316667,-73.283333
br,benfica,Benfica,04,,-6.765,-70.936389
br,benfica,Benfica,05,,-12.383333,-39.3
br,benfica,Benfica,15,,-16.783333,-41.083333
br,benfica,Benfica,16,,-1.3,-48.3
br,benfica,Benfica,21,,-22.891683,-43.24092
br,benfica,Benfica,22,,-4.972222,-37.068056
br,benfica,Benfica,23,,-29.9,-51.383333
br,benfica,Benfica,27,,-22.483333,-46.933333
br,bengala,Bengala,30,,-8.016667,-35.483333
br,bengalas,Bengalas,30,,-8.016667,-35.483333
br,benigno,Benigno,04,,-8,-60.85
br,benjamim,Benjamim,16,,-1.333333,-48.433333
br,benjamim,Benjamim,18,,-25.333333,-53.883333
br,benjamim,Benjamim,25,,-3.3,-61.016667
br,benjamim constant,Benjamim Constant,04,,-4.374444,-70.029722
br,benjamim de barros,Benjamim de Barros,29,,-17.566667,-51.916667
br,benjamim not,Benjamim Not,23,,-28.666667,-53.6
br,benjamim santana,Benjamim Santana,15,,-16.433333,-40.45
br,benjamin,Benjamin,16,,-1.333333,-48.433333
br,benjamin,Benjamin,18,,-25.333333,-53.883333
br,benjamin constant,Benjamin Constant,04,13998,-4.374444,-70.029722
br,benjamin constant,Benjamin Constant,15,,-21.95,-42.883333
br,benjamin constant,Benjamin Constant,16,,-1.066667,-46.6
br,benjamin constant,Benjamin Constant,23,,-27.733333,-52.983333
br,benjamin dos santos,Benjamin dos Santos,29,,-16.283333,-50.416667
br,benjamin novais,Benjamin Novais,23,,-28.666667,-53.6
br,benqueirao,Benqueirão,17,,-6.983333,-36.116667
br,benta,Benta,11,,-17.9,-54.583333
br,bentevi,Bentevi,30,,-8.55,-35.583333
br,bentinho,Bentinho,15,,-17.466667,-41.883333
br,bento alto,Bento Alto,26,,-28.666667,-49.566667
br,bento,Bento,05,,-13.3,-39.666667
br,bento,Bento,15,,-17.333333,-41.1
br,bento brasil,Bento Brasil,25,,2.816667,-60.616667
br,bento de abreu,Bento de Abreu,27,,-21.283333,-50.8
br,bento fernandes,Bento Fernandes,22,,-5.683333,-35.816667
br,bento gomes,Bento Gomes,11,,-18.066667,-54.533333
br,bento goncalves,Bento Gonçalves,23,90854,-29.166667,-51.516667
br,bento munhoz,Bento Munhoz,18,,-24.9,-53.133333
br,bento pereira,Bento Pereira,06,,-5.116667,-38.35
br,bentopolis,Bentópolis,18,,-22.933333,-51.716667
br,bento ribeiro,Bento Ribeiro,21,,-22.868014,-43.36207
br,bento rodrigues,Bento Rodrigues,15,,-20.233333,-43.416667
br,bento rogrigues,Bento Rogrigues,06,,-5.616667,-39.766667
br,bentos,Bentos,15,,-22.6324,-45.5363
br,bento simoes,Bento Simões,05,,-12.15,-38.733333
br,benvenuto,Benvenuto,16,,-2.583333,-51.016667
br,bequimao,Bequimão,13,5695,-2.433333,-44.783333
br,bergamasco,Bergamasco,27,,-22.416667,-47.3
br,berigui,Berigui,18,,-25.533333,-49.383333
br,berilo,Berilo,15,,-16.95,-42.483333
br,berimbau,Berimbau,04,,-5.590278,-60.806667
br,berimbau,Berimbau,06,,-5.416667,-40.466667
br,beriolino bitu,Beriolino Bitu,15,,-17.316667,-40.933333
br,beriquara,Beriquara,27,,-20.316667,-47.6
br,beritingas,Beritingas,05,,-11.6,-38.8
br,berlenga,Berlenga,20,,-7.266667,-40.583333
br,berlengas,Berlengas,20,,-6.4,-41.75
br,berlim,Berlim,04,,-3.438889,-63.416944
br,berlinque,Berlinque,05,,-13.1,-38.75
br,bernarda,Bernarda,06,,-7.2,-38.683333
br,bernarda,Bernarda,30,,-7.8,-38.166667
br,bernardes,Bernardes,29,,-16.5,-52.05
br,bernardino borges,Bernardino Borges,15,,-20.433333,-46.266667
br,bernardino de campos,Bernardino de Campos,27,9342,-23.033333,-49.483333
br,bernardo,Bernardo,02,,-9.083333,-37.466667
br,bernardo,Bernardo,05,,-13.133333,-39.016667
br,bernardo,Bernardo,13,,-4.616667,-44.916667
br,bernardo,Bernardo,16,,-5.283333,-55.866667
br,bernardo dias,Bernardo Dias,14,,-15.666667,-57.5
br,bernardo sayao,Bernardo Sayão,31,,-7.856944,-48.786389
br,bernardo vieira,Bernardo Vieira,30,,-7.933333,-38.55
br,berra bode,Berra Bode,06,,-3.9,-38.383333
br,berro,Berro,20,,-3.593333,-42.583056
br,berro de dentro,Berro de Dentro,20,,-3.583889,-42.570556
br,berta,Berta,11,,-17.9,-54.583333
br,bertanholi,Bertanholi,18,,-24.5,-49.516667
br,bertinho,Bertinho,16,,-2.783333,-50.4
br,bertioga,Bertioga,06,,-6.55,-38.85
br,bertioga,Bertioga,17,,-7.5,-36.283333
br,bertioga,Bertioga,27,,-23.85,-46.15
br,berto cirio,Berto Círio,23,,-29.8572,-51.2742
br,bertolinia,Bertolínia,20,,-7.633333,-43.95
br,bertolino pinheiro,Bertolino Pinheiro,15,,-17.3,-41.316667
br,bertopolis,Bertópolis,15,,-17.016667,-40.566667
br,beruri,Beruri,04,,-3.9,-61.366667
br,berury,Berury,04,,-3.9,-61.366667
br,besouro,Besouro,01,,-8.9825,-72.726389
br,besouro,Besouro,06,,-7.533333,-39.083333
br,besouro,Besouro,18,,-25.216667,-53.2
br,besta morta,Besta Morta,13,,-3.111389,-42.379722
br,betania,Betânia,05,,-13.083333,-42.866667
br,betania,Betânia,06,,-3.283333,-39.65
br,betania,Betânia,20,,-5.566667,-42.65
br,betania,Betânia,30,,-8.266667,-38.033333
br,betim,Betim,15,384038,-19.966667,-44.216667
br,betuli,Betuli,05,,-9.733333,-42.216667
br,bevenuto,Bevenuto,16,,-2.583333,-51.016667
br,beverine,Beverine,26,,-26.95,-53.216667
br,beverini,Beverini,26,,-26.95,-53.216667
br,beverni,Beverni,26,,-26.95,-53.216667
br,bevilacqua,Bevilacqua,23,,-29.1354,-51.0476
br,bexiga,Bexiga,13,,-3.7875,-42.7375
br,bexiga,Bexiga,23,,-29.966667,-52.683333
br,beya-flor,Beya-Flor,15,,-21.133333,-43.083333
br,bezerra,Bezerra,20,,-7.5,-41.516667
br,bezerras,Bezerras,17,,-6.816667,-37.85
br,bezerrinha,Bezerrinha,06,,-5.566667,-39.033333
br,bezerro manso,Bezerro Manso,20,,-5.233333,-42.516667
br,bezerro morto,Bezerro Morto,06,,-6.683333,-38.7
br,bezerro morto,Bezerro Morto,20,,-6.666667,-41.35
br,bezerros,Bezerros,20,,-3.753889,-42.515556
br,bezerros,Bezerros,30,51437,-8.233333,-35.75
br,bezouro,Bezouro,17,,-7.083333,-38.116667
br,biancardia,Biancárdia,08,,-19.416667,-40.333333
br,bias fortes,Bias Fortes,15,,-21.6,-43.766667
br,biaxao do coco,Biaxão do Côco,13,,-5.483333,-43.466667
br,biboca,Biboca,21,,-21.45,-41.633333
br,bica,Bica,06,,-5.316667,-38.033333
br,bica,Bica,13,,-3.955,-43.154444
br,bica de pedra,Bica de Pedra,27,,-22.233333,-48.683333
br,bicame,Bicame,27,,-23.090978,-47.865368
br,bicanca,Bicanca,08,,-20.216667,-40.216667
br,bicas,Bicas,15,12684,-21.716667,-43.066667
br,bicas do meio,Bicas do Meio,15,,-22.516667,-45.35
br,bicho de baixo,Bicho de Baixo,05,,-13.516667,-41.633333
br,bicho do meio,Bicho do Meio,05,,-13.5,-41.65
br,bicuda,Bicuda,05,,-13.95,-41.266667
br,bicudo,Bicudo,05,,-13.95,-41.266667
br,bicudo,Bicudo,27,,-21.216667,-51.05
br,bicudos,Bicudos,27,,-22.316667,-47.7
br,bicuiba,Bicuíba,13,,-3.4325,-42.598333
br,bicuiba,Bicuíba,15,,-20.083333,-42.366667
br,bicuida,Bicuída,13,,-3.287778,-42.333333
br,bifurcacao,Bifurcação,26,,-28.45,-48.783333
br,biguacu,Biguaçu,26,51993,-27.5,-48.666667
br,biguassu,Biguassú,26,,-27.5,-48.666667
br,biguazinho,Biguàzinho,27,,-24.283333,-47.533333
br,bilac,Bilac,27,,-21.4,-50.466667
br,bilheira,Bilheira,06,,-4.016667,-40.05
br,binga,Binga,04,,-7.7,-65.05
br,bioto guimaraes,Bioto Guimarães,15,,-17.716667,-41.583333
br,biquinha,Biquinha,21,,-22.223889,-43.686667
br,biquinhas,Biquinhas,15,,-18.783333,-45.5
br,biraba,Biraba,05,,-10.8,-42.833333
br,biriba,Biriba,05,,-12,-38.2
br,biribeira,Biribeira,05,,-12.633333,-38.2
br,biribiri,Biribiri,15,,-18.133333,-43.616667
br,birigui,Birigui,27,102279,-21.3,-50.316667
br,biriguy,Biriguy,27,,-21.3,-50.316667
br,biririca,Biririca,08,,-20.016667,-40.233333
br,biriricas,Biriricas,08,,-18.6,-40.1
br,biriricas de baixo,Biriricas de Baixo,08,,-20.35,-40.583333
br,biritiba-mirim,Biritiba-Mirim,27,26459,-23.583333,-46.033333
br,biritinga,Biritinga,05,,-11.6,-38.8
br,birra,Birra,31,,-11.666667,-47.066667
br,biscaia,Biscaia,18,,-25.066667,-49.9
br,bismarck,Bismarck,14,,-16.75,-57.05
br,bismarque,Bismarque,14,,-16.75,-57.05
br,bitaculo,Bitáculo,29,,-17.05,-49.783333
br,bitenambi,Bitenambi,05,,-13.583333,-39.5
br,bitencourt,Bitencourt,14,,-16.316667,-57.516667
br,bitencurt,Bitencurt,14,,-16.316667,-57.516667
br,bitumirim,Bitumirim,18,,-25.033333,-50.783333
br,bitupita,Bitupitá,06,,-2.895,-41.275833
br,bituri,Bituri,15,,-20.533333,-44.083333
br,bituruna,Bituruna,18,,-26.166667,-51.566667
br,bituva,Bituva,23,,-29.7818,-50.8024
br,bituva das campinas,Bituva das Campinas,18,,-25.5636,-50.4904
br,bituva do kuller,Bituva do Küller,18,,-25.539523,-50.483626
br,bituva dos lopes,Bituva dos Lopes,18,,-25.558158,-50.53029
br,bituva dos lucios,Bituva dos Lúcios,18,,-25.59849,-50.49416
br,bituva dos machados,Bituva dos Machados,18,,-25.60089,-50.44119
br,bituva dos saruva,Bituva dos Saruva,18,,-25.61541,-50.44665
br,bixopa,Bixopá,06,,-5,-38.2
br,bizarra,Bizarra,30,,-7.75,-35.466667
br,bizum,Bizum,20,,-7.783333,-41.633333
br,blau nunes,Blau Nunes,23,,-28.366667,-53.25
br,blauth,Blauth,23,,-29.233333,-51.45
br,blinha,Blinha,26,,-27.3,-49.366667
br,blumenau,Blumenau,26,293955,-26.9222,-49.0615
br,boa agua,Boa Água,06,,-4.833333,-38.616667
br,boa agua,Boa Água,17,,-6.4,-37.566667
br,boa agua,Boa Água,22,,-5.883333,-35.666667
br,boa agua dos leandros,Boa Água dos Leandros,22,,-6.183333,-37.883333
br,boa barreirinha,Boa Barreirinha,27,,-23.3,-47.166667
br,boa barrinha,Boa Barrinha,27,,-23.3,-47.166667
br,boa centro,Boa Centro,23,,-27.75,-54.5
br,boa chapeleira,Boa Chapeleira,27,,-23.233333,-47.083333
br,boacica,Boacica,22,,-5.283333,-35.566667
br,boacica,Boacica,27,,-24.9849,-48.0116
br,boacu,Boaçu,05,,-13.983333,-40.2
br,boa dadiva,Boa Dadiva,06,,-5.483333,-40.316667
br,boa eoperanca,Boa Eoperança,08,,-21.016667,-41.616667
br,boa espaernca,Bôa Espaernca,06,,-7.05,-38.783333
br,boa espera,Boa Espera,05,,-11.916667,-38.866667
br,boa esperanca,Boa Esperança,01,,-9.95,-66.683333
br,boa esperanca,Boa Esperança,02,,-9.316667,-37.95
br,boa esperanca,Boa Esperança,03,,2.833333,-51.05
br,boa esperanca,Boa Esperança,04,,-2.65,-67.483333
br,boa esperanca,Boa Esperança,05,,-10.616667,-43.5
br,boa esperanca,Boa Esperanca,06,,-4.066667,-39.266667
br,boa esperanca,Boa Esperança,08,9254,-18.55,-40.283333
br,boa esperanca,Boa Esperança,11,,-19.383333,-56.45
br,boa esperanca,Boa Esperança,13,,-1.683333,-44.966667
br,boa esperanca,Boa Esperança,15,33840,-21.083333,-45.566667
br,boa esperanca,Boa Esperança,16,,-1.25,-47.166667
br,boa esperanca,Boa Esperanca,17,,-6.233333,-37.483333
br,boa esperanca,Boa Esperança,18,,-24.383333,-49.566667
br,boa esperanca,Boa Esperança,20,,-10,-45.483333
br,boa esperanca,Boa Esperança,21,,-21.233333,-41.533333
br,boa esperanca,Boa Esperança,22,,-5.381111,-36.038611
br,boa esperanca,Boa Esperança,23,,-28.3,-53.65
br,boa esperanca,Boa Esperança,25,,3.35,-61.383333
br,boa esperanca,Boa Esperança,27,,-20.216667,-50.366667
br,boa esperanca,Boa Esperança,29,,-14.533333,-46.2
br,boa esperanca,Boa Esperança,30,,-8.4,-36.533333
br,boa esperanca,Boa Esperança,31,,-11.816667,-47.45
br,boa esperanca do mearim,Boa Esperança do Mearim,13,,-4.883333,-44.883333
br,boa esperanca do sul,Boa Esperança do Sul,27,10787,-21.983333,-48.383333
br,boa esperaranca,Boa Esperarança,20,,-9.25,-44.083333
br,boa estrela,Boa Estrêla,31,,-7.766667,-48.566667
br,boa familia,Bôa Familia,08,,-19.8,-40.85
br,boa familia,Boa Família,15,,-21.216667,-42.516667
br,boa fe,Boa Fé,04,,-5.646944,-64.205556
br,boa fe,Boa Fé,05,,-12.333333,-39.4
br,boa fe,Boa Fé,06,,-5.55,-40.516667
br,boa fe,Boa Fé,16,,-4.6,-56.2
br,boa fe,Boa Fé,17,,-6.883333,-38.7
br,boa fe,Boa Fé,20,,-6.066667,-41.916667
br,boa fe,Boa Fé,21,,-22.366667,-41.883333
br,boa fortuna,Boa Fortuna,21,,-21.05,-41.733333
br,boa guaxinduba,Boa Guaxinduba,27,,-23.283333,-47.016667
br,boa hora,Boa Hora,04,,-7.466667,-70.166667
br,boa hora,Boa Hora,05,,-10.966667,-38.533333
br,boa hora,Boa Hora,06,,-5.066667,-39.816667
br,boa hora,Boa Hora,13,,-3.2525,-42.938056
br,boa hora,Boa Hora,24,,-11.683333,-65.083333
br,boa ideia,Boa Idéia,30,,-8.15,-37.566667
br,boa lembranca,Boa Lembrança,04,,-4.475556,-59.866389
br,boa lembranca,Boa Lembrança,05,,-9.616667,-38.083333
br,boa memoria,Boa Memória,11,,-21.583333,-55.533333
br,boa morada,Boa Morada,13,,-7.766667,-45.5
br,boa morte,Boa Morte,15,,-20.433333,-43.983333
br,boa morte,Boa Morte,16,,-1.4,-48.666667
br,boa nova,Boa Nova,04,,-5.604444,-61.140833
br,boa nova,Boa Nova,05,,-12.25,-40.55
br,boa nova,Boa Nova,14,,-13.416667,-57.916667
br,boa nova,Boa Nova,20,,-6.066667,-42.716667
br,boapaba,Boapaba,08,,-19.65,-40.616667
br,boa paz,Boa Paz,05,,-12.15,-38.583333
br,boa paz,Boa Paz,22,,-5.291111,-36.502222
br,boa razao,Boa Razão,13,,-3.610556,-43.307778
br,boa-saude,Boa-Saúde,06,,-7.116667,-39.766667
br,boa-saude,Boa-Saúde,22,,-6.15,-35.583333
br,boa sentenca,Boa Sentença,05,,-13.583333,-41.716667
br,boa sombra,Boa Sombra,02,,-9.15,-37.733333
br,boa sorte,Boa Sorte,02,,-9.666667,-37.466667
br,boa sorte,Boa Sorte,04,,-2.75,-65.85
br,boa sorte,Boa Sorte,05,,-12.05,-40.183333
br,boa sorte,Boa Sorte,06,,-5.116667,-39.316667
br,boa sorte,Boa Sorte,08,,-20.2,-41.066667
br,boa sorte,Boa Sorte,11,,-19.35,-57.083333
br,boa sorte,Boa Sorte,13,,-8.55,-46.5
br,boa sorte,Boa Sorte,14,,-15.077778,-59.874722
br,boa sorte,Boa Sorte,15,,-15.833333,-40.983333
br,boa sorte,Boa Sorte,17,,-6.45,-36.35
br,boa sorte,Boa Sorte,21,,-21.85,-42.25
br,boa sorte,Boa Sorte,22,,-5.216667,-37.716667
br,boa sorte,Boa Sorte,30,,-8.566667,-36.9
br,boa sorte,Boa Sorte,31,,-9.630833,-46.533889
br,boa terra,Boa Terra,05,,-12.016667,-41
br,boa uniao,Boa União,04,,-4.393333,-59.991111
br,boa-uniao,Boa-União,04,,-7.55,-66.266667
br,boa uniao,Boa União,04,,-7.8,-68.516667
br,boa uniao,Boa União,05,,-12.183333,-38.5
br,boa uniao,Boa União,06,,-4.5,-38.75
br,boa uniao,Boa União,16,,-2.066667,-49.15
br,boa uniao,Boa União,30,,-8.466667,-40.433333
br,boa vargem grande,Boa Vargem Grande,27,,-23.35,-47.066667
br,boa ventura,Boa Ventura,06,,-4.9,-39.666667
br,boa ventura,Boa Ventura,15,,-21.616667,-43.35
br,boa ventura,Boa Ventura,17,,-7.416667,-38.216667
br,boa ventura,Boa Ventura,18,,-24.95,-51.616667
br,boa ventura,Boa Ventura,20,,-5.516667,-41.666667
br,boaventura,Boaventura,21,,-21.316667,-41.633333
br,boa ventura,Boa Ventura,29,,-16.45,-51.783333
br,boa ventura,Boa Ventura,30,,-7.783333,-37.533333
br,boa vereda,Boa Vereda,15,,-22.45,-46.233333
br,boa viagem,Boa Viagem,05,,-12.928333,-38.511667
br,boa viagem,Boa Viagem,06,24671,-5.116667,-39.733333
br,boa viagem,Boa Viagem,30,,-8.116667,-34.883333
br,boa vida,Boa Vida,15,,-19.683333,-41.6
br,boa vida,Boa Vida,21,,-22.3,-42.783333
br,boa vinha,Boa Vinha,27,,-22.6,-47.75
br,boa vista,Boa Vista,01,,-10.3,-67.25
br,boa vista,Boa Vista,02,,-9.366667,-36.066667
br,boa vista,Boa Vista,03,,-.35,-52.316667
br,boa vista,Boa Vista,04,,.25,-64.016667
br,boa vista,Boa Vista,05,,-10.066667,-39.7
br,boa-vista,Boa-Vista,05,,-12.666667,-40.616667
br,boa vista,Boa Vista,05,,-12.733333,-41.833333
br,boa vista,Boa Vista,06,,-3.733333,-40.233333
br,boa vista,Boa Vista,07,,-15.833333,-47.55
br,boa vista,Boa Vista,08,,-18.65,-39.75
br,boa vista,Boa Vista,11,,-17.85,-54.216667
br,boa vista,Boa Vista,13,,-3.216667,-42.566667
br,boa vista,Boa Vista,14,,-15.116667,-56.4
br,boa vista,Boa Vista,15,,-15.766667,-44.716667
br,boa vista,Boa Vista,16,,-1.066667,-50.333333
br,boa vista,Boa Vista,17,,-6.133333,-37.483333
br,boa vista,Boa Vista,18,,-23.983756,-50.519436
br,boa vista,Boa Vista,20,,-10.483333,-45.1
br,boa vista,Boa Vista,21,,-21.366667,-41.483333
br,boa vista,Boa Vista,22,,-5.064167,-37.470278
br,boa vista,Boa Vista,23,,-28.95,-53.15
br,boa vista,Boa Vista,24,,-10.733333,-62.133333
br,boa vista,Boa Vista,25,235159,2.816667,-60.666667
br,boa vista,Boa Vista,26,,-26.283333,-48.833333
br,boa vista,Boa Vista,27,,-20.166667,-47.7
br,boa vista,Boa Vista,28,,-10.433333,-37.133333
br,boa vista,Boa Vista,30,,-7.5,-37.533333
br,boa vista,Boa Vista,31,,-11.45,-47.883333
br,boa vista da malhada,Boa Vista da Malhada,30,,-8.066667,-36.083333
br,boa vista de baixo,Boa Vista de Baixo,27,,-23.686812,-47.46012
br,boa vista de colonia,Boa Vista de Colônia,30,,-7.666667,-37.7
br,boa vista de palmas,Boa Vista de Palmas,15,,-16.466667,-45.766667
br,boa vista de santo antonio,Boa Vista de Santo Antônio,05,,-10.516667,-42.55
br,boa vista de sao antonio,Boa Vista de São Antonio,05,,-10.516667,-42.55
br,boa vista de trairas e aracati,Boa Vista de Traíras e Aracati,29,,-16.183333,-49.083333
br,boa vista do bacuri,Boa Vista do Bacuri,04,,-4.833333,-62.566667
br,boa vista do burica,Boa Vista do Burica,23,,-27.633333,-54.166667
br,boa vista do capanema,Bóa Vista do Capanema,18,,-26.134444,-53.575833
br,boa vista do erechim,Bôa Vista do Erechim,23,,-27.633333,-52.283333
br,boa vista do helvecio,Boa Vista do Helvécio,05,,-13.716667,-40.616667
br,boa vista do jauato,Boa Vista do Jauató,04,,-2.766667,-65.283333
br,boa vista do lagamar,Boa Vista do Lagamar,05,,-11.833333,-43.316667
br,boa vista do marzagao,Bôa Vista do Marzagão,29,,-17.983333,-48.65
br,boa vista do matao,Boa Vista do Matão,29,,-16.216667,-49.2
br,boa vista do pichaui,Boa Vista do Pichauí,05,,-12.016667,-43.35
br,boa vista do pindare,Boa Vista do Pindaré,13,,-3.4,-44.983333
br,boa vista do pixaui,Boa Vista do Pixauí,05,,-12.016667,-43.35
br,boa vista do rio branco,Boa Vista do Rio Branco,25,,2.816667,-60.666667
br,boa vista dos cariocas,Boa Vista dos Cariocas,20,,-3.65,-42.15
br,boa vista dos inacios,Boa Vista dos Inácios,30,,-8.716667,-36.633333
br,boa vista dos nunes,Boa Vista dos Nunes,17,,-7.666667,-37.133333
br,boa vista dos oleos,Boa Vista dos Óleos,15,,-21.566667,-46.033333
br,boa vista do tocantins,Boa Vista Do Tocantins,31,,-6.324444,-47.277778
br,boa vista do tremendal,Boa Vista do Tremendal,15,,-15.15,-42.883333
br,boa vista esteires,Bôa Vista Esteires,05,,-10.516667,-42.55
br,boa vista lagamar,Bôa Vista Lagamar,05,,-11.833333,-43.316667
br,boa vista-lugarejo,Boa Vista-Lugarejo,27,,-24.583333,-47.633333
br,boa vitoria,Boa Vitória,15,,-22.5144,-45.6156
br,bobo,Bobo,15,,-20.783333,-45.133333
br,boca aripuana,Boca Aripuanã,04,,-5.120278,-60.378889
br,boca da barra ii,Boca da Barra II,13,,-3.444722,-42.394722
br,boca da caatinga,Boca da Caatinga,20,,-5.716667,-41.9
br,boca da catinga,Bôca da Catinga,20,,-10.016667,-44.433333
br,boca da estrada,Bôca da Estrada,25,,-2.116667,-61
br,boca da lagoa sao joao,Boca da Lagoa São Joaõ,04,,-1.917222,-61.405556
br,boca da mata,Bôca da Mata,02,17834,-9.6,-36.25
br,boca da mata,Bôca da Mata,05,,-12.766667,-39.466667
br,boca da mata,Boca da Mata,13,,-3.720833,-42.731111
br,boca-da-mata,Boca-da-Mata,17,,-7.516667,-34.9
br,boca da mata,Boca da Mata,20,,-3.777778,-42.492778
br,boca da mata,Bôca da Mata,25,,4.316667,-61.15
br,boca da mata de jose carneiro,Bôca da Mata de José Carneiro,02,,-9.566667,-36.366667
br,boca da peca,Bôca da Peça,30,,-7.983333,-37.7
br,boca da picada,Bôca da Picada,05,,-10.783333,-43.566667
br,boca da picada,Boca da Picada,13,,-3.41,-42.6
br,boca da serra,Boca da Serra,23,,-29.0879,-51.0308
br,boca da vargem,Boca da Várgem,22,,-5.320833,-36.725
br,boca da varzea,Bôca da Várzea,05,,-12.033333,-38.733333
br,boca de pauini,Boca de Pauiní,04,,-7.783333,-67.083333
br,boca de tauiry,Boca de Tauiry,16,,-5.133333,-49.3
br,boca de teuini,Boca de Teuiní,04,,-7.95,-67.233333
br,boca do acara,Bôca do Acará,04,,-6.229444,-62.254444
br,boca do acre,Bôca do Acre,04,14427,-8.75,-67.383333
br,boca do arara,Boca do Arará,01,,-8.945,-72.761667
br,boca do caju,Boca do Caju,04,,-3.369722,-62.591389
br,boca do campana,Bôca do Campana,04,,-5.866111,-61.693611
br,boca do campo,Bôca do Campo,05,,-12.25,-41.366667
br,boca do capana,Bôca do Capanã,04,,-5.866111,-61.693611
br,boca do carapanatuba,Boca do Carapanatuba,04,,-6.754167,-62.591667
br,boca do carrasco,Bôca do Carrasco,05,,-13.5,-40.833333
br,boca do centro,Bôca do Centro,20,,-3.75,-42.4
br,boca do coco,Boca do Coco,20,,-5.283333,-42.216667
br,boca do corrego,Bôca do Córrego,05,,-15.866667,-39.116667
br,boca do corrego,Boca do Côrrego,06,,-3.116667,-39.666667
br,boca do corvo,Boca do Corvo,06,,-4.666667,-37.816667
br,boca do curara,Boca do Curara,04,,-5.756111,-60.94
br,boca do curuquele,Bôca do Curuquelê,04,,-8.316667,-65.683333
br,boca do curuquete,Bôca do Curuquetê,04,,-8.316667,-65.683333
br,boca do fumaco,Boca do Fumaco,04,,-3.75,-59.05
br,boca do jaminaua,Boca do Jaminaua,01,,-9.133333,-70.833333
br,boca do jari,Bôca do Jari,16,,-1.116667,-51.966667
br,boca do mato,Bôca do Mato,05,,-12.766667,-39.466667
br,boca do mato,Boca do Mato,21,,-22.908466,-43.292974
br,boca do moaca,Boca do Moaca,04,,-7.683333,-68.283333
br,boca do moaco,Bôca do Moaco,04,,-7.683333,-68.283333
br,boca do monte,Bôca do Monte,23,,-29.633333,-53.916667
br,boca do munguba,Boca do Munguba,04,,-3.525278,-62.895556
br,boca do mutum,Bôca do Mutum,04,,-4.433333,-68.05
br,boca do pajeu,Bôca do Pajeú,30,,-8.916667,-38.7
br,boca do punus,Boca do Punus,04,,-3.683333,-61.45
br,boca do purus,Boca do Purus,04,,-3.683333,-61.45
br,boca do rapirra,Boca do Rapirra,01,,-10.333333,-67.183333
br,boca do rio,Bôca do Rio,05,,-13.033333,-38.65
br,boca do saco,Bôca do Saco,05,,-10.616667,-43.5
br,boca do saco,Boca do Saco,20,,-7.166667,-41.65
br,boca do taquari,Boca do Taquari,01,,-7.933333,-71.466667
br,boca do tauari,Boca do Tauari,01,,-7.933333,-71.466667
br,boca do tejo,Boca do Tejo,01,,-8.981389,-72.717778
br,boca do tucuma,Boca do Tucumã,04,,-5.092222,-59.365
br,bocaina,Bocaina,11,,-20.816667,-57.366667
br,bocaina,Bocaina,13,,-6.75,-44.066667
br,bocaina,Bocaina,14,,-15.266667,-56.75
br,bocaina,Bocaina,15,,-17.266667,-46.15
br,bocaina,Bocaina,18,,-25,-50.266667
br,bocaina,Bocaina,20,,-6.916667,-41.316667
br,bocaina,Bocâina,26,,-27.75,-49.95
br,bocaina,Bocaina,27,,-20.466667,-47.733333
br,bocaina de minas,Bocaina de Minas,15,,-22.166667,-44.4
br,bocaina do sul,Bocaina do Sul,26,,-27.75,-49.95
br,bocaine,Bocaine,20,,-6.716667,-42.666667
br,bocaiuva,Bocaiúva,11,,-21.983333,-54.533333
br,bocaiuva,Bocaiuva,14,,-14.65,-57.216667
br,bocaiuva,Bocaiúva,15,32115,-17.116667,-43.816667
br,bocaiuva,Bocaiúva,18,,-25.183333,-49.133333
br,bocaiuva,Bocaiúva,23,,-28.766667,-51.933333
br,bocaiuva,Bocaiuva,27,,-22.516667,-48.683333
br,bocaiuva do sul,Bocaiúva do Sul,18,,-25.183333,-49.133333
br,bocaiuval,Bocaiuval,14,,-14.65,-57.216667
br,bocaja,Bocajá,11,,-22.75,-55.216667
br,boca torta,Boca Torta,06,,-7.033333,-38.7
br,bocayuva,Bocayuva,15,,-17.116667,-43.816667
br,bocayuva,Bocayuva,18,,-25.183333,-49.133333
br,bocayuva,Bocayuva,27,,-22.516667,-48.683333
br,bocayuval,Bocayuval,14,,-14.65,-57.216667
br,bocca da maffa,Bocca da Maffa,02,,-9.683333,-36.183333
br,bocca de matta,Bocca de Matta,17,,-7.516667,-34.9
br,bocca do acre,Bocca do Acre,04,,-8.75,-67.383333
br,bocca do curua,Bocca do Curuá,16,,-5.4,-54.466667
br,bocca do fumaco,Bocca do Fumaco,04,,-3.75,-59.05
br,bocca do jaminaua,Bocca do Jaminaua,01,,-9.133333,-70.833333
br,bocca do moaco,Bocca do Moaco,04,,-7.683333,-68.283333
br,bocca do monte,Bocca do Monte,23,,-29.633333,-53.916667
br,bocca do mutum,Bocca do Mutum,04,,-4.433333,-68.05
br,bocca do pauhiny,Bocca do Pauhiny,04,,-7.783333,-67.083333
br,bocca do rapirra,Bocca do Rapirra,01,,-10.333333,-67.183333
br,bocca do tauary,Bocca do Tauary,01,,-7.933333,-71.466667
br,bocca do tauiry,Bocca do Tauiry,16,,-5.133333,-49.3
br,bocianowski,Bocianowski,26,,-28.633333,-49.316667
br,bocianwski,Bocianwski,26,,-28.633333,-49.316667
br,bocoroca,Boçoroca,05,,-9.466667,-41.1
br,bocoroca,Boçoroca,23,,-28.733333,-54.916667
br,bocuituba,Bocuituba,05,,-12.666667,-42.816667
br,bode,Bode,11,,-17.633333,-55.033333
br,bodega,Bodega,11,,-20.05,-55.783333
br,bodega,Bodega,15,,-20.316667,-43.1
br,bodo,Bodó,22,,-5.9875,-36.411944
br,bodoco,Bodocó,30,11329,-7.783333,-39.916667
br,bodocongo,Bodocongó,17,,-7.516667,-35.983333
br,bodote,Bodote,18,,-25.183333,-53.083333
br,bofete,Bofete,27,,-23.116667,-48.25
br,boia,Bóia,21,,-21.6,-41.933333
br,boiacanga,Boiacanga,04,,-.8625,-64.823333
br,boiacu,Boiaçu,25,,-.439722,-61.782222
br,boiada,Boiada,06,,-6.266667,-40.216667
br,boiada,Boiada,27,,-21.283333,-47.1
br,boiadeiro,Boiadeiro,27,,-22.603889,-47.495
br,boianga,Boiangá,21,,-21.633333,-41.433333
br,boiao,Boião,13,,-3.268611,-43.494167
br,boiaruca ponta,Boiaruca Ponta,04,,.066667,-67.783333
br,boi,Boi,06,,-4.033333,-40.083333
br,boi,Boi,13,,-3.028056,-43.034722
br,boi,Boi,20,,-3.546389,-42.346944
br,boi brave,Boi Brave,17,,-7.7,-36.25
br,boi de carro,Boi de Carro,14,,-16.233333,-56.583333
br,boi jagua,Boi Jagua,11,,-23.2,-54.85
br,boim,Boim,16,,-3.083333,-55.3
br,boi morto,Boi Morto,14,,-15.583333,-57.45
br,boi morto,Boi Morto,17,,-6.883333,-38.6
br,boi morto,Boi Morto,20,,-3.716111,-42.398611
br,boi pombo,Boi Pombo,17,,-7.85,-36.483333
br,boi raposo,Boi Rapôso,17,,-7.066667,-37.4
br,bois,Bois,06,,-3.55,-39.683333
br,bois,Bois,15,,-18.65,-49.283333
br,bois,Bois,20,,-9.433333,-44.766667
br,bois buritis,Bois Buritis,05,,-11.3,-42.816667
br,boiteuxburgo,Boiteuxburgo,26,,-27.416667,-49.216667
br,boituva,Boituva,27,48756,-23.283333,-47.683333
br,boiuna,Boiúna,21,,-22.905389,-43.412055
br,boi velho,Boi Velho,17,,-7.616667,-37.166667
br,boi velho,Boi Velho,22,,-5.133889,-36.465
br,bojuru,Bojuru,23,,-31.633333,-51.433333
br,bola,Bola,02,,-9.433333,-36.8
br,bola,Bola,06,,-4.5,-38.466667
br,bola,Bola,13,,-5.083333,-43.233333
br,bolacha,Bolacha,23,,-32.166667,-52.2
br,bolandeira,Bolandeira,05,,-12.8,-38.383333
br,bolandeira,Bolandeira,06,,-7.15,-40.283333
br,bolandeira,Bolandeira,17,,-6.35,-38.55
br,bolao,Bolão,17,,-7.616667,-36.35
br,bolaxa,Bolaxa,23,,-32.166667,-52.2
br,boliche,Boliche,11,,-20.266667,-54.5
br,boliche seco,Boliche Sêco,11,,-21.3,-55.95
br,bolicho,Bolicho,11,,-22.933333,-55.466667
br,bolicho seco,Bolicho Seco,11,,-21.3,-55.95
br,bolivia,Bolívia,04,,-7.366667,-58.033333
br,bolivia,Bolivia,06,,-4.666667,-40.033333
br,bolivia,Bolívia,20,,-3.982778,-42.039444
br,bom-assunto,Bom-Assunto,20,,-3.98,-42.2
br,bomba,Bomba,29,,-14.2,-46.3
br,bombas,Bombas,26,,-27.142222,-48.509444
br,bombinhas,Bombinhas,26,,-27.151111,-48.507778
br,bombonagem,Bombonagem,06,,-5.366667,-38.566667
br,bom caminho,Bom Caminho,05,,-12.433333,-40.35
br,bom centro,Bom Centro,23,,-27.75,-54.5
br,bom comercio,Bom Comércio,24,,-9.75,-65.9
br,bom conselho,Bom Conselho,02,,-9.7,-37.433333
br,bom conselho,Bom Conselho,05,,-10.6,-38.383333
br,bom conselho,Bom Conselho,30,27801,-9.166667,-36.683333
br,bom descanso,Bom Descanso,22,,-5.305833,-37.143333
br,bom desejo,Bom Desejo,05,,-12.616667,-41.666667
br,bom despacho,Bom Despacho,05,,-12.116667,-39.1
br,bom despacho,Bom Despacho,15,40304,-19.716667,-45.25
br,bom destino,Bom Destino,01,,-9.697778,-67.524167
br,bom destino,Bom Destino,03,,-.433333,-52.45
br,bom destino,Bom Destino,08,,-20.933333,-41.416667
br,bom destino,Bom Destino,11,,-22.966667,-55.283333
br,bom destino,Bom Destino,16,,-6.1,-54.116667
br,bom destino,Bom Destino,22,,-5.065278,-37.425833
br,bom destino,Bom Destino,30,,-9.1,-36.683333
br,bom dia,Bom Dia,11,,-23.383333,-55.133333
br,bom distracto,Bom Distracto,01,,-10.116667,-67.366667
br,bom distrato,Bom Distrato,01,,-10.116667,-67.366667
br,bomfim,Bomfim,05,,-10.45,-40.183333
br,bom fim,Bom Fim,05,,-12.233333,-39.216667
br,bomfim,Bomfim,05,,-9.166667,-39.066667
br,bom fim,Bom Fim,11,,-20.133333,-54.483333
br,bomfim,Bomfim,13,,-3.305278,-43.135278
br,bomfim,Bomfim,15,,-20.333333,-44.25
br,bom fim,Bom Fim,20,,-9.15,-42.85
br,bom fim,Bom Fim,21,,-22.516667,-43.5
br,bom fim,Bom Fim,27,,-21.266667,-47.816667
br,bomfim,Bomfim,29,,-16.666667,-48.6
br,bom fim,Bom Fim,31,,-11.853611,-47.534444
br,bomfim da feira,Bomfim da Feira,05,,-12.233333,-39.216667
br,bomfim paulista,Bomfim Paulista,27,,-21.266667,-47.816667
br,bom future,Bom Future,04,,-6.25,-62.216667
br,bom futuro,Bom Futuro,01,,-7.8,-72.066667
br,bom futuro,Bom Futuro,04,,-1.8,-65.65
br,bom futuro,Bom Futuro,05,,-16.416667,-39.283333
br,bom futuro,Bom Futuro,14,,-15.133333,-59.916667
br,bom futuro,Bom Futuro,16,,-6.416667,-54.783333
br,bom futuro,Bom Futuro,20,,-5.183333,-41.95
br,bom futuro,Bom Futuro,22,,-5.944722,-37.432778
br,bom futuro,Bom Futuro,24,,-9.583333,-64.983333
br,bom futuro,Bom Futuro,25,,3.533333,-61.1
br,bom garis,Bom Garis,05,,-11.266667,-38.95
br,bom gosto,Bom Gôsto,05,,-12.166667,-41.133333
br,bom gosto,Bom Gôsto,13,,-2.85,-43.95
br,bom gosto,Bom Gosto,20,,-5.016667,-42.583333
br,bom intento,Bom Intento,03,,.15,-52.05
br,bom intento,Bom Intento,04,,-5.638056,-63.776389
br,bom jardim,Bom Jardim,04,,-3.195833,-62.811111
br,bom jardim,Bom Jardim,05,,-10.266667,-43.5
br,bom jardim,Bom Jardim,06,,-4.566667,-38.633333
br,bom jardim,Bom Jardim,08,,-21.066667,-41.6
br,bom jardim,Bom Jardim,11,,-19.9,-54.2
br,bom jardim,Bom Jardim,13,12343,-7.016667,-46.483333
br,bom jardim,Bom Jardim,14,,-15.783333,-55.466667
br,bom jardim,Bom Jardim,15,,-15.916667,-40.55
br,bom jardim,Bom Jardim,16,,-1.116667,-50.95
br,bom jardim,Bom Jardim,17,,-6.933333,-38.716667
br,bom jardim,Bom Jardim,18,,-25.033333,-50.783333
br,bom jardim,Bom Jardim,20,,-3.528056,-42.428056
br,bom jardim,Bom Jardim,21,11716,-22.15,-42.416667
br,bom jardim,Bom Jardim,22,,-6.283333,-35.233333
br,bom jardim,Bom Jardim,23,,-29.6,-51.166667
br,bom jardim,Bom Jardim,24,,-10.333333,-62.333333
br,bom jardim,Bom Jardim,25,,3.433333,-61.25
br,bom jardim,Bom Jardim,26,,-28.333333,-49.633333
br,bom jardim,Bom Jardim,27,,-24.183333,-47.616667
br,bom jardim,Bom Jardim,29,,-16.283333,-52.116667
br,bom jardim,Bom Jardim,30,13523,-7.783333,-35.583333
br,bom jardim,Bom Jardim,31,,-12.441389,-47.7375
br,bom jardim da serra,Bom Jardim da Serra,26,,-28.333333,-49.633333
br,bom jardim de cima,Bom Jardim de Cima,15,,-20.583333,-42.883333
br,bom jardim de fora,Bom Jardim de Fora,05,,-12.266667,-43.3
br,bom jardim de goias,Bom Jardim de Goiás,29,,-16.283333,-52.116667
br,bom jardim de minas,Bom Jardim de Minas,15,,-21.95,-44.183333
br,bom jardin,Bom Jardin,15,,-21.95,-44.183333
br,bom jardin,Bom Jardin,18,,-25.033333,-50.783333
br,bom jesus,Bom Jesus,01,,-7.766667,-73.35
br,bom jesus,Bom Jesus,02,,-9.216667,-37.466667
br,bom jesus,Bom Jesus,04,,-2.883333,-68.483333
br,bom jesus,Bom Jesus,05,,-11.516667,-38.166667
br,bom jesus,Bom Jesus,06,,-3.45,-40.016667
br,bom jesus,Bom Jesus,08,,-19.833333,-41.116667
br,bom jesus,Bom Jesus,13,,-3.283611,-43.136111
br,bom jesus,Bom Jesus,15,,-18.683333,-42.633333
br,bom jesus,Bom Jesus,16,,-1.066667,-50.45
br,bom jesus,Bom Jesus,17,,-6.183333,-37.533333
br,bom jesus,Bom Jesus,18,,-26.0947,-49.7693
br,bom jesus,Bom Jesus,20,12666,-9.066667,-44.366667
br,bom jesus,Bom Jesus,22,,-5.235556,-36.191389
br,bom jesus,Bom Jesus,23,,-28.7,-50.4
br,bom jesus,Bom Jesus,24,,-10.330556,-62.241667
br,bom jesus,Bom Jesus,26,,-26.75,-52.35
br,bom jesus,Bom Jesus,29,,-18.2,-49.733333
br,bom jesus,Bom Jesus,30,,-7.6,-37.316667
br,bom jesus,Bom Jesus,31,,-11.85,-47.183333
br,bom jesus da cachoeira alegre,Bom Jesus da Cachoeira Alegre,15,,-21.266667,-42.4
br,bom jesus da cachoeira,Bom Jesus da Cachoeira,15,,-21.266667,-42.4
br,bom jesus da floresta,Bom Jesus da Floresta,15,,-18.833333,-41.25
br,bom jesus da lapa,Bom Jesus da Lapa,05,40693,-13.25,-43.416667
br,bom jesus da madeira,Bom Jesus da Madeira,15,,-20.716667,-42.416667
br,bom jesus da penha,Bom Jesus da Penha,15,,-21.016667,-46.533333
br,bom jesus da ribeira,Bom Jesus da Ribeira,27,,-24.716667,-47.55
br,bom jesus da serra,Bom Jesus da Serra,05,,-14.383333,-40.516667
br,bom jesus das pedras,Bom Jesus das Pedras,15,,-17.6,-44.983333
br,bom jesus da terra preta,Bom Jesus da Terra Preta,27,,-23.25,-46.6
br,bom jesus da vista alegre,Bom Jesus da Vista Alegre,15,,-19.066667,-41.75
br,bom jesus de itabapoana,Bom Jesus de Itabapoana,21,,-21.133333,-41.683333
br,bom jesus de itaueira,Bom Jesus de Itaueira,20,,-7.083333,-43.016667
br,bom jesus de lufa,Bom Jesus de Lufa,15,,-17.25,-41.916667
br,bom jesus de mantenas,Bom Jesus de Mantenas,15,,-18.666667,-41.4
br,bom jesus de quixelo,Bom Jesus de Quixelô,06,,-6.266667,-39.2
br,bom jesus de triunfo,Bom Jesus de Triunfo,23,,-29.933333,-51.716667
br,bom jesus do amparo,Bom Jesus do Amparo,15,,-19.7,-43.466667
br,bom jesus do bagre,Bom Jesus do Bagre,15,,-19.3,-42.5
br,bom jesus do barracao,Bom Jesus do Barracão,18,,-26.193333,-53.598611
br,bom jesus do carangola,Bom Jesus do Carangola,15,,-20.6,-42.283333
br,bom jesus do corrego,Bom Jesus do Córrego,15,,-22.633333,-46.033333
br,bom jesus do galho,Bom Jesus do Galho,15,12476,-19.833333,-42.316667
br,bom jesus do gurgueia,Bom Jesus do Gurgueia,20,,-9.066667,-44.366667
br,bom jesus do iguape,Bom Jesus do Iguapé,18,,-23.722138,-50.54571
br,bom jesus do itabapoana,Bom Jesus do Itabapoana,21,30822,-21.133333,-41.683333
br,bom jesus do itaveira,Bom Jesus do Itaveira,20,,-7.083333,-43.016667
br,bom jesus do lufa,Bom Jesús do Lufa,15,,-17.25,-41.916667
br,bom jesus do madeira,Bom Jesus do Madeira,15,,-20.716667,-42.416667
br,bom jesus do manhuacu,Bom Jesus do Manhuaçu,15,,-20.283333,-42.166667
br,bom jesus do munao novo,Bom Jesus do Munao Novo,15,,-19.75,-41.333333
br,bom jesus do mundo novo,Bom Jesus do Mundo Novo,15,,-19.75,-41.333333
br,bom jesus do norte,Bom Jesus do Norte,08,,-21.116667,-41.666667
br,bom jesus do pontal,Bom Jesus do Pontal,15,,-16.766667,-42.033333
br,bom jesus do quixelo,Bom Jesus do Quixelo,06,,-6.266667,-39.2
br,bom jesus do rio negro,Bom Jesus do Rio Negro,15,,-17.25,-40.933333
br,bom jesus dos meiras,Bom Jesús dos Meiras,05,,-14.216667,-41.666667
br,bom jesus dos perdoes,Bom Jesus dos Perdões,27,12422,-23.133333,-46.466667
br,bom jesus dos pobres,Bom Jesus dos Pobres,05,,-12.8,-38.783333
br,bom jesus do tabuleiro,Bom Jesus do Tabuleiro,15,,-18.25,-42.6
br,bom jesus do tocantins,Bom Jesus do Tocantins,31,,-8.913333,-48.011667
br,bom jesus do triunfo,Bom Jesus do Triunfo,23,,-29.933333,-51.716667
br,bom jesus i,Bom Jesus I,13,,-3.9525,-42.970278
br,bom jesus ii,Bom Jesus II,13,,-3.963611,-42.971667
br,bom jesus velho,Bom Jesus Velho,13,,-3.845556,-43.241111
br,bom lugar,Bom Lugar,04,,-2.7,-67.533333
br,bom lugar,Bom Lugar,13,,-4.333333,-44.966667
br,bom lugar,Bom Lugar,16,,-1.566667,-52.866667
br,bom lugar,Bom Lugar,20,,-3.646111,-42.383333
br,bom lugar,Bom Lugar,21,,-21.333333,-41.083333
br,bom lugar,Bom Lugar,22,,-5.133333,-37.083333
br,bom lugar,Bom Lugar,24,,-10.616667,-62.433333
br,bom negocio,Bom Negócio,22,,-5.656111,-36.754722
br,bom nome,Bom Nome,02,,-9.35,-37.966667
br,bom nome,Bom Nome,06,,-6.15,-39.4
br,bom nome,Bom Nome,17,,-7.333333,-36.983333
br,bom nome,Bom Nome,20,,-7.533333,-41.133333
br,bom nome,Bom Nome,30,,-7.983333,-38.616667
br,bom passar,Bom Passar,20,,-5.116667,-42.4
br,bom pastor,Bom Pastor,15,,-19.25,-41.05
br,bom pastor,Bom Pastor,30,,-8.616667,-36.783333
br,bompim da mata,Bompim da Mata,05,,-12.55,-38.3
br,bom principio,Bom Principio,06,,-3.216667,-40.066667
br,bom principio,Bom Princípio,13,,-3.250556,-43.118611
br,bom principio,Bom Princípio,20,,-3.908611,-42.536944
br,bom principio,Bom Princípio,22,,-6,-37.883333
br,bom principio,Bom Princípio,23,,-27.8,-54.766667
br,bom principio,Bom Principio,24,,-9.666667,-62.35
br,bom principio,Bom Princípio,31,,-7.75,-48.45
br,bom principip,Bom Principip,06,,-6.016667,-40.766667
br,bom recreio,Bom Recreio,23,,-28.25,-52.483333
br,bom repouso,Bom Repouso,15,,-22.466667,-46.15
br,bom retiro,Bom Retiro,05,,-12.95,-38.766667
br,bom retiro,Bom Retiro,08,,-20.616667,-40.85
br,bom retiro,Bom Retiro,15,,-18,-43.216667
br,bom retiro,Bom Retiro,18,,-25.204585,-48.989476
br,bom retiro,Bom Retiro,20,,-7.883333,-42.8
br,bom retiro,Bom Retiro,21,,-22.948002,-43.292054
br,bom retiro,Bom Retiro,23,,-27.333333,-52.15
br,bom retiro,Bom Retiro,24,,-10.491667,-62.425
br,bom retiro,Bom Retiro,26,,-27.116667,-51.466667
br,bom retiro,Bom Retiro,27,,-21.083333,-47.883333
br,bom retiro do guaiba,Bom Retiro do Guaíba,23,,-30.116667,-51.5
br,bom retiro do sul,Bom Retiro do Sul,23,,-29.616667,-51.933333
br,bom socego,Bom Socego,05,,-12.2,-42.666667
br,bom socego,Bom Socego,11,,-20.9,-55.516667
br,bom socorro,Bom Socorro,04,,-4.394167,-59.976389
br,bom sossego,Bom Sossêgo,05,,-12.2,-42.666667
br,bom sossego,Bom Sossêgo,06,,-5.133333,-40.866667
br,bom sossego,Bom Sossêgo,11,,-20.9,-55.516667
br,bom sossego,Bom Sossego,13,,-3.401111,-43.211944
br,bom sossego,Bom Sossêgo,17,,-6.683333,-37.55
br,bom sossego,Bom Sossêgo,30,,-7.866667,-37.783333
br,bom successo,Bom Successo,04,,-1.133333,-62.65
br,bom successo,Bom Successo,15,,-21.033333,-44.766667
br,bom successo,Bom Successo,21,,-22.860844,-43.25219
br,bom successo,Bom Successo,27,,-23.383333,-48.716667
br,bom sucesso,Bom Sucesso,04,,-1.133333,-62.65
br,bom sucesso,Bom Sucesso,05,,-12.083333,-37.966667
br,bom sucesso,Bom Sucesso,06,,-5.083333,-39.133333
br,bom sucesso,Bom Sucesso,07,,-15.516667,-47.633333
br,bom sucesso,Bom Sucesso,08,,-20.983333,-41.633333
br,bom sucesso,Bom Sucesso,11,,-19.316667,-55.2
br,bom sucesso,Bom Sucesso,13,,-3.6,-43.366667
br,bom sucesso,Bom Sucesso,14,,-15.716667,-56.116667
br,bom sucesso,Bom Sucesso,15,13786,-21.033333,-44.766667
br,bom sucesso,Bom Sucesso,16,,-6.833333,-53.833333
br,bom sucesso,Bom Sucesso,17,,-6.45,-37.933333
br,bom sucesso,Bom Sucesso,18,,-23.1403,-50.2403
br,bom sucesso,Bom Sucesso,20,,-3.867778,-42.590833
br,bom sucesso,Bom Sucesso,21,,-22.256618,-42.774422
br,bom sucesso,Bom Sucesso,26,,-26.700614,-49.688309
br,bom sucesso,Bom Sucesso,27,,-21.316667,-47.416667
br,bom sucesso,Bom Sucesso,29,,-15.583333,-49.433333
br,bom sucesso,Bom Sucesso,30,,-8.5,-36.716667
br,bom sucesso,Bom Sucesso,31,,-7.966667,-48.633333
br,bom sucesso dos milagres,Bom Sucesso dos Milagres,22,,-5.3,-37.683333
br,bom sueso,Bom Sueso,11,,-19.316667,-55.2
br,bom tempo,Bom Tempo,06,,-5.366667,-40.55
br,bom tempo,Bom Tempo,13,,-2.933333,-44.15
br,bom unico,Bom Único,04,,-2.85,-68.85
br,bom viver,Bom Viver,04,,-3.083333,-57.233333
br,bom viver,Bom Viver,05,,-12.716667,-38.433333
br,bom viver,Bom Viver,20,,-5.1,-41.983333
br,bom viver,Bom Viver,31,,-5.416667,-48.55
br,bonanca,Bonança,15,,-15.733333,-44.183333
br,bonassi,Bonassi,23,,-29.1507,-51.0277
br,bondade,Bondade,13,,-7.433333,-46.4
br,bonecu,Boneçu,05,,-12.633333,-38.483333
br,bonetes,Bonetes,26,,-26.216667,-50.633333
br,bonfim,Bonfim,02,,-9.266667,-37.333333
br,bonfim,Bonfim,04,,-.316667,-66.683333
br,bonfim,Bonfim,05,,-10.45,-40.183333
br,bonfim,Bonfim,06,,-3.583333,-40.483333
br,bonfim,Bonfim,11,,-18.266667,-57.466667
br,bonfim,Bonfim,13,,-2.983333,-45.2
br,bonfim,Bonfim,14,,-17.5,-54.75
br,bonfim,Bonfim,15,,-17.883333,-42.316667
br,bonfim,Bonfim,16,,-4.766667,-56.516667
br,bonfim,Bonfim,20,,-3.808056,-42.231111
br,bonfim,Bonfim,21,,-22.516667,-43.5
br,bonfim,Bonfim,22,,-5.184167,-36.506944
br,bonfim,Bonfim,24,,-10.316667,-62.331944
br,bonfim,Bonfim,25,5769,3.083333,-59.95
br,bonfim,Bonfim,27,,-22.966667,-45.25
br,bonfim,Bonfim,28,,-11.066667,-37.85
br,bonfim,Bonfim,29,,-16.666667,-48.6
br,bonfim,Bonfim,30,,-7.683333,-37.2
br,bonfim,Bonfim,31,,-11.853611,-47.534444
br,bonfim da feira,Bonfim da Feira,05,,-12.233333,-39.216667
br,bonfim da mata,Bonfim da Mata,05,,-12.55,-38.3
br,bonfim de arari,Bonfim de Arari,13,,-3.433333,-44.783333
br,bonfim do arari,Bonfim do Arari,13,,-3.433333,-44.783333
br,bonfim i,Bonfim I,13,,-3.686111,-43.395556
br,bonfim ii,Bonfim II,13,,-3.677222,-43.381111
br,bonfim iii,Bonfim III,13,,-3.914167,-43.305
br,bonfim paulista,Bonfim Paulista,27,,-21.266667,-47.816667
br,bonfinopolis,Bonfinópolis,29,,-16.633333,-48.966667
br,bonhu,Bonhu,06,,-4.833333,-38.166667
br,bonifacio,Bonifácio,02,,-9.516667,-36.566667
br,bonilha,Bonilha,13,,-5.2,-43.216667
br,bonim,Bonim,18,,-23.811631,-50.054001
br,boninal,Boninal,05,,-12.7,-41.833333
br,bonita,Bonita,05,,-12.45,-40.1
br,bonita,Bonita,06,,-6.6,-38.866667
br,bonitao,Bonitão,13,,-5.483333,-43.416667
br,bonitinho,Bonitinho,17,,-7.683333,-36
br,bonito,Bonito,02,,-10.383333,-36.333333
br,bonito,Bonito,05,,-11.683333,-37.633333
br,bonito,Bonito,06,,-4.383333,-39.466667
br,bonito,Bonito,11,14504,-21.133333,-56.466667
br,bonito,Bonito,13,,-5.383333,-43.233333
br,bonito,Bonito,15,,-15.333333,-44.766667
br,bonito,Bonito,16,,-1.416667,-47.316667
br,bonito,Bonito,17,,-7.283333,-36.95
br,bonito,Bonito,18,,-25.838713,-50.026299
br,bonito,Bonito,20,,-5.65,-41.8
br,bonito,Bonito,22,,-5.382778,-36.352778
br,bonito,Bonito,23,,-28.583333,-53.616667
br,bonito,Bonito,26,,-28.433333,-49.4
br,bonito,Bonito,27,,-25.201944,-48.131667
br,bonito,Bonito,29,,-18.383333,-52.116667
br,bonito,Bonito,30,8867,-8.483333,-35.733333
br,bonito,Bonito,31,,-6.133333,-47.466667
br,bonito de cima,Bonito de Cima,05,,-12.216667,-41.25
br,bonito de santa fe,Bonito de Santa Fé,17,,-7.316667,-38.516667
br,bonito velha,Bonito Velha,17,,-7.466667,-38.55
br,bonival,Bonival,05,,-12.7,-41.833333
br,bonotto,Bonotto,18,,-23.5766,-49.9358
br,bonsecesso,Bonsecesso,20,,-5.35,-42.566667
br,bons olhos,Bons Olhos,15,,-19.2,-48.3
br,bons olnos,Bons Olnos,15,,-19.2,-48.3
br,bonsucesso,Bonsucesso,05,,-12.65,-42.216667
br,bonsucesso,Bonsucesso,06,,-3.466667,-39.783333
br,bonsucesso,Bonsucesso,08,,-20.983333,-41.566667
br,bonsucesso,Bonsucesso,14,,-15.716667,-56.116667
br,bonsucesso,Bonsucesso,17,,-6.716667,-36.183333
br,bonsucesso,Bonsucesso,20,,-7.966667,-41.516667
br,bonsucesso,Bonsucesso,21,,-22.860844,-43.25219
br,bonsucesso,Bonsucesso,22,,-5.283333,-37.65
br,bonsucesso,Bonsucesso,26,,-26.700614,-49.688309
br,bonsucesso,Bonsucesso,30,,-7.9,-36.116667
br,bontim,Bontim,06,,-5.25,-38.5
br,bonzao,Bonzão,05,,-12.333333,-41.316667
br,boqueirao,Boqueirão,02,,-9.25,-37.866667
br,boqueirao,Boqueirão,05,,-11.333333,-43.85
br,boqueirao,Boqueirão,06,,-3.733333,-38.866667
br,boqueirao,Boqueirão,11,,-21.483333,-54.683333
br,boqueirao,Boqueirão,13,,-3.695,-43.4775
br,boqueirao,Boqueirão,15,,-16.566667,-41.283333
br,boqueirao,Boqueirão,17,11566,-7.483333,-36.116667
br,boqueirao,Boqueirão,18,,-25.483333,-49.25
br,boqueirao,Boqueirão,20,,-10.433333,-45.233333
br,boqueirao,Boqueirão,21,,-22.838612,-43.472046
br,boqueirao,Boqueirão,22,,-5.933333,-35.883333
br,boqueirao,Boqueirão,23,,-29.3,-52.433333
br,boqueirao,Boqueirão,30,,-7.716667,-39.85
br,boqueirao,Boqueirão,31,,-11.633333,-47.466667
br,boqueirao das parreiras,Boqueirao das Parreiras,05,,-14.566667,-42.95
br,boqueirao de fora,Boqueirão de Fora,20,,-6.816667,-40.716667
br,boqueirao de parreiras,Boqueirão de Parreiras,05,,-14.566667,-42.95
br,boqueirao do cesario,Boqueirão do Cesário,06,,-4.583333,-38.2
br,boqueirao do fabricio,Boqueirão do Fabrício,13,,-3.582222,-43.301944
br,boqueirao do gado,Boqueirão do Gado,13,,-3.577778,-43.255278
br,boqueirao do leao,Boqueirão do Leão,23,,-29.3,-52.433333
br,boqueirao dos cochos,Boqueirão dos Cochos,17,,-7.166667,-38.166667
br,boqueirao dos couxos,Boqueirao dos Couxos,17,,-7.166667,-38.166667
br,boqueirao dos filipes,Boqueirão dos Filipes,20,,-9.738611,-45.674167
br,boqueiraozinho,Boqueirãozinho,05,,-14.333333,-43.166667
br,boqueiraozinho,Boqueirãozinho,13,,-3.685278,-43.495833
br,boqueriao,Boquerião,23,,-29.3,-52.433333
br,boquim,Boquim,28,14848,-11.15,-37.616667
br,boquinha,Boquinha,11,,-18.4,-56.116667
br,boquira,Boquira,05,6306,-12.816667,-42.766667
br,bora,Borá,13,,-9.833333,-46.1
br,bora,Borá,27,,-22.283333,-50.55
br,boraceia,Boracéia,27,,-22.166667,-48.75
br,borba,Borba,04,11918,-4.388889,-59.593611
br,borba,Borba,23,,-30.966667,-52.383333
br,borba gato,Borba Gato,15,,-19.133333,-43
br,borboleta,Borboleta,18,,-24.7,-51.783333
br,borboleta,Borboleta,26,,-26.689823,-49.530043
br,borboleta,Borboleta,27,,-20.933333,-49.466667
br,borborema,Borborema,17,,-6.8,-35.6
br,borborema,Borborema,27,11759,-21.616667,-49.066667
br,borborema,Borborema,30,,-7.666667,-37.7
br,borda da mata,Borda da Mata,06,,-6.783333,-38.866667
br,borda da mata,Borda da Mata,15,12814,-22.266667,-46.166667
br,borda da mata,Borda da Mata,27,,-20.333333,-47.283333
br,borda da mata,Borda da Mata,28,,-10.566667,-37.266667
br,borda da matta,Borda da Matta,15,,-22.266667,-46.166667
br,borebi,Borebi,27,,-22.566667,-48.983333
br,boreby,Boreby,27,,-22.566667,-48.983333
br,borel,Borel,21,,-22.93768,-43.254174
br,borel,Borel,26,,-28.083333,-50.433333
br,borgado,Borgado,06,,-5.116667,-40.116667
br,borges,Borges,06,,-4.883333,-37.866667
br,borges,Borges,13,,-5.25,-43.116667
br,borges,Borges,14,,-15.6,-55.083333
br,borges,Borges,17,,-7.1,-36.566667
br,borges,Borges,25,,2.666667,-61.016667
br,borges,Borges,30,,-9.083333,-36.666667
br,borgheto,Borgheto,23,,-29.2,-51.5
br,borgueto,Borgueto,23,,-29.2,-51.5
br,borracha,Borracha,05,,-9.4,-39.633333
br,borracha,Borracha,13,,-3.083889,-42.296111
br,borrachudo,Borrachudo,06,,-3.55,-38.883333
br,borrachudo,Borrachudo,13,,-3.294444,-42.347778
br,borrachudo,Borrachudo,18,,-25.262411,-48.490596
br,borralho,Borralho,04,,-2.607222,-57.268056
br,borrazopolis,Borrazópolis,18,,-23.933333,-51.6
br,bosque,Bosque,20,,-6.633333,-41.75
br,bosque,Bosque,23,,-32.066667,-52.183333
br,bosque,Bosque,27,,-21.283333,-47.383333
br,bosque da inspiracao,Bosque da Inspiração,27,,-23.377521,-46.628864
br,bosque dos esquilos,Bosque dos Esquilos,21,,-22.962153,-43.331885
br,bossoroca,Bossoroca,05,,-9.466667,-41.1
br,bossoroca,Bossoroca,23,,-28.733333,-54.916667
br,botafogo,Botafogo,01,,-8.25,-73.166667
br,botafogo,Botafogo,04,,-3.45,-68.333333
br,botafogo,Botafogo,15,,-21.383333,-43.283333
br,botafogo,Botafogo,18,,-23.384729,-52.60926
br,botafogo,Botafogo,21,,-22.951497,-43.187988
br,botafogo,Botafogo,27,,-20.983333,-48.55
br,botelho,Botelho,25,,.648889,-61.675833
br,botelho,Botelho,27,,-21.35,-48.766667
br,botelhos,Botelhos,15,11073,-21.65,-46.4
br,botorobi,Botorobi,15,,-20.066667,-44.433333
br,botos,Botos,16,,-2.916667,-49.65
br,botucarai,Botucaraí,23,,-29.7,-52.9
br,botucatu,Botucatu,27,113865,-22.866667,-48.433333
br,botucudo,Botucudo,18,,-24.416667,-51.116667
br,botujuru,Botujuru,27,,-23.4599,-46.1089
br,botumirim,Botumirim,15,,-16.866667,-43.016667
br,botupora,Botuporã,05,,-13.35,-42.483333
br,botuquara,Botuquara,05,,-13.666667,-42.866667
br,botuquara,Botuquara,27,,-23.4902,-46.0532
br,boturana,Boturana,27,,-20.283333,-49.5
br,boturobi,Boturobi,15,,-20.066667,-44.433333
br,boturuma,Boturuma,27,,-20.283333,-49.5
br,boturuna,Boturuna,27,,-20.283333,-49.5
br,botuvera,Botuverá,26,,-27.216667,-49.083333
br,bouquinha,Bouquinha,20,,-5.25,-42.666667
br,braba,Braba,05,,-12.35,-39.05
br,brabo,Brabo,30,,-8.15,-37.433333
br,bracatinga,Bracatinga,18,,-25.371409,-48.984222
br,bracinho,Bracinho,11,,-19.6,-54.3
br,bracinho,Bracinho,13,,-3.31,-43.089722
br,bracinho,Bracinho,14,,-16.383333,-57.916667
br,braco,Braço,27,,-24.6379,-48.2924
br,braco do laurentino,Braço do Laurentino,26,,-27.2023,-49.7037
br,braco do norte,Braço do Norte,05,,-13.816667,-39.416667
br,braco do norte,Braço do Norte,26,22375,-28.283333,-49.183333
br,braco do pindauva,Braço do Pindaúva,27,,-24.804449,-48.061746
br,braco do pito,Braço do Pito,27,,-24.697295,-48.200288
br,braco do queimado,Braço do Queimado,27,,-24.7999,-48.2165
br,braco do trombudo,Braço do Trombudo,26,,-27.35,-49.9
br,braco feio,Braço Feio,27,,-24.878,-48.224
br,braco itoupava,Braço Itoupava,26,,-27.1405,-49.6458
br,braco paula ramos,Braço Paula Ramos,26,,-26.7532,-49.0045
br,braco torrete,Braço Torrete,26,,-26.998566,-49.956212
br,braga,Braga,06,,-4.633333,-39.766667
br,braga,Braga,17,,-7.183333,-38.616667
br,braga,Braga,23,,-27.616667,-53.75
br,braganca,Bragança,15,,-20.583333,-46.766667
br,braganca,Bragança,16,57164,-1.05,-46.766667
br,braganca,Bragança,23,,-30.7,-55.183333
br,braganca,Bragança,27,,-22.95,-46.566667
br,braganca paulista,Bragança Paulista,27,125099,-22.95,-46.566667
br,brajo faichada,Brajo Faichada,31,,-11.266667,-46.666667
br,branco,Branco,05,,-13.566667,-39.9
br,branco,Branco,14,,-15.983333,-58.616667
br,branco,Branco,21,,-21.5,-41.783333
br,brancos,Brancos,18,,-25.8483,-49.4494
br,brandao,Brandão,05,,-12.283333,-40.583333
br,brandao,Brandão,06,,-3.466667,-39.45
br,brandao,Brandão,30,,-8.666667,-39.183333
br,brandoes,Brandoes,22,,-6.516667,-37.2
br,brandura,Brandura,13,,-3.033333,-43.45
br,branquinha,Branquinha,02,,-9.25,-36.033333
br,brasabrantes,Brasabrantes,29,,-16.433333,-49.383333
br,brasa,Brasa,20,,-7.15,-40.9
br,bras,Brás,04,,-2.083333,-58.166667
br,bras,Brás,15,,-15.416667,-46.9
br,bras,Brás,27,,-23.55,-46.616667
br,bras cubas,Brás Cubas,27,,-23.533333,-46.216667
br,bras de pina,Brás de Pina,21,,-22.832978,-43.297667
br,brasilandia,Brasilândia,07,,-15.683333,-48.2
br,brasilandia do tocantins,Brasilândia do Tocantins,31,,-8.354722,-48.364444
br,brasilania,Brasilânia,29,,-16.016667,-49.533333
br,brasil,Brasil,04,,-4.516667,-71.616667
br,brasil,Brasil,11,,-22.366667,-54.566667
br,brasil,Brasil,27,,-21.583333,-46.9
br,brasileia,Brasiléia,01,11200,-11,-68.733333
br,brasileiras,Brasileiras,30,,-9.05,-36.566667
br,brasil gaudioso,Brasil Gaudioso,11,,-23.816667,-54.2
br,brasilia,Brasília,01,,-11,-68.733333
br,brasilia,Brasília,07,2207812,-15.783333,-47.916667
br,brasilia,Brasília,13,,-3.443889,-42.485556
br,brasilia,Brasília,15,,-16.211944,-44.430833
br,brasilia,Brasília,18,,-22.716667,-51.4
br,brasilia,Brasília,20,,-3.894722,-42.694167
br,brasilia,Brasília,22,,-5.370556,-36.329444
br,brasilia de minas,Brasília de Minas,15,14730,-16.211944,-44.430833
br,brasilia legal,Brasília Legal,16,,-3.816667,-55.6
br,brasilino,Brasilino,05,,-17.35,-40.433333
br,brasil leite,Brasil Leite,23,,-30.016667,-56.45
br,brasino,Brasino,23,,-30.633333,-51.733333
br,brasitania,Brasitânia,27,,-20.133333,-50.316667
br,braslandia,Braslândia,07,,-15.683333,-48.2
br,brasopolis,Brasópolis,15,,-22.466667,-45.616667
br,bras pires,Brás Pires,15,,-20.85,-43.25
br,brauna,Braúna,05,,-10.433333,-40.15
br,brauna,Braúna,06,,-6.866667,-39.45
br,brauna,Braúna,21,,-21.116667,-41.783333
br,brauna,Braúna,27,,-21.5,-50.3
br,brauna,Braúna,30,,-8.5,-36.383333
br,braunal,Braunal,11,,-22.1,-57.766667
br,braunas,Braúnas,15,,-19.066667,-42.716667
br,braunas,Braúnas,20,,-7.366667,-40.933333
br,braunas-de-guanhaes,Braúnas-de-Guanhães,15,,-19.066667,-42.716667
br,braunat,Braunat,11,,-22.1,-57.766667
br,brava,Brava,05,,-12.35,-39.05
br,bravo,Bravo,05,,-12.15,-39.466667
br,bravo,Bravo,06,,-6.483333,-39.3
br,bravo,Bravo,20,,-5.766667,-42.85
br,brazabrantes,Brazabrantes,29,,-16.433333,-49.383333
br,braz,Braz,27,,-23.55,-46.616667
br,brazilia,Brazilia,15,,-16.211944,-44.430833
br,brazlandia,Brazlândia,07,,-15.683333,-48.2
br,brazopolis,Brazópolis,15,,-22.466667,-45.616667
br,braz pires,Braz Pires,15,,-20.85,-43.25
br,brebe,Brebe,04,,-5.701111,-60.930833
br,brecha,Brecha,02,,-9.5,-36.833333
br,breiinho,Breiinho,30,,-9.1,-38.283333
br,breio de sao felix,Breio de São Félix,13,,-5.483333,-43.5
br,breio grande,Breio Grande,20,,-5.85,-41.35
br,breja,Breja,06,,-4.25,-38.933333
br,brejal,Brejal,18,,-25.116667,-49.483333
br,brejao,Brejão,05,,-10.938611,-45.714722
br,brejao,Brejão,11,,-20.266667,-55.533333
br,brejao,Brejão,13,,-3.512222,-43.195833
br,brejao,Brejão,14,,-15.316667,-57.316667
br,brejao,Brejão,15,,-18.666667,-47.333333
br,brejao,Brejão,18,,-23.0743,-50.0269
br,brejao,Brejão,20,,-5.766667,-42.55
br,brejao,Brejão,27,,-21.633333,-46.866667
br,brejao,Brejão,29,,-12.983333,-46.466667
br,brejao,Brejão,30,,-9.05,-36.483333
br,brejao,Brejão,31,,-7.033333,-48.1
br,brejao da caatinga,Brejão da Caatinga,05,,-10.433333,-40.866667
br,brejao da catinga,Brejão da Catinga,05,,-10.433333,-40.866667
br,brejao das grotas,Brejão das Grotas,05,,-10.65,-40.466667
br,brejao de santa cruz,Brejão de Santa Cruz,30,,-9.05,-36.483333
br,brejatuba,Brejatuba,18,,-25.916667,-48.583333
br,brejauba,Brejaúba,08,,-20.15,-41.283333
br,brejauba,Brejaúba,15,,-19.2,-43.15
br,brejaubinha,Brejaùbinha,15,,-18.75,-42.216667
br,brejauva,Brejaúva,27,,-23.833333,-47.95
br,brejetuba,Brejetuba,08,,-20.15,-41.283333
br,brejetubinha,Brejetubinha,08,,-20.166667,-41.283333
br,brejinhe,Brejinhe,06,,-7.7,-38.9
br,brejinho,Brejinho,05,,-11.366667,-43.3
br,brejinho,Brejinho,06,,-6.25,-39.033333
br,brejinho,Brejinho,13,,-3.511111,-43.178611
br,brejinho,Brejinho,17,,-6.333333,-37.8
br,brejinho,Brejinho,20,,-3.420556,-42.145278
br,brejinho,Brejinho,22,7625,-6.183333,-35.35
br,brejinho,Brejinho,30,,-7.383333,-37.316667
br,brejinho,Brejinho,31,,-11.014167,-48.505
br,brejinho das amethystas,Brejinho das Amethystas,05,,-14.283333,-42.516667
br,brejinho das ametistas,Brejinho das Ametistas,05,,-14.283333,-42.516667
br,brejinho da serra negra,Brejinho da Serra Negra,05,,-12.033333,-43
br,brejinho de nazare,Brejinho de Nazaré,31,,-11.014167,-48.505
br,brejinho do ismael,Brejinho do Ismael,13,,-5.883333,-43.283333
br,brejo alegre,Brejo Alegre,15,,-20.033333,-44.65
br,brejo alegre,Brejo Alegre,27,,-21.133333,-50.166667
br,brejo bonito,Brejo Bonito,15,,-19.016667,-46.6
br,brejo,Brejo,05,,-11.766667,-42.4
br,brejo,Brejo,06,,-3.766667,-41.25
br,brejo,Brejo,13,11636,-3.683333,-42.783333
br,brejo,Brejo,15,,-15.8,-45.866667
br,brejo,Brejo,17,,-6.916667,-37.966667
br,brejo,Brejo,20,,-3.971667,-42.090556
br,brejo,Brejo,22,,-5.166667,-35.75
br,brejo,Brejo,30,,-8.55,-35.333333
br,brejo comprido,Brejo Comprido,31,,-9.6625,-47.963611
br,brejo da canabrava,Brejo da Canabrava,05,,-12.15,-40.883333
br,brejo da cruz,Brejo da Cruz,17,,-6.35,-37.5
br,brejo da fama,Brejo da Fama,05,,-13.216667,-41.616667
br,brejo da fortaleza,Brejo da Fortaleza,20,,-6.75,-41.816667
br,brejo da madre de deus,Brejo da Madre de Deus,30,27370,-8.15,-36.366667
br,brejo da onca,Brejo da Onça,20,,-5.816667,-41.35
br,brejo da porta,Brejo da Porta,13,,-8.499722,-45.738056
br,brejo da roca,Brejo da Roça,13,,-8.238611,-45.655278
br,brejo das almas,Brejo das Almas,15,,-16.383333,-41.516667
br,brejo da serra,Brejo da Serra,05,,-10.1,-43.266667
br,brejo das freiras,Brejo das Freiras,17,,-6.7,-38.516667
br,brejo das missoes,Brejo das Missões,05,,-12.016667,-44.483333
br,brejo das pedras,Brejo das Pedras,20,,-7.4,-41.9
br,brejo da taboa,Brejo da Taboa,05,,-10.466667,-42.583333
br,brejo da tabua,Brejo da Tabua,05,,-10.466667,-42.583333
br,brejo de cima,Brejo de Cima,05,,-13.25,-41.583333
br,brejo de dentro,Brejo de Dentro,30,,-7.9,-37.666667
br,brejo de santo antonio,Brejo de Santo Antônio,30,,-7.483333,-40.116667
br,brejo de santo inacio,Brejo de Santo Inácio,20,,-7.416667,-41.916667
br,brejo de sao caetano,Brejo de São Caetano,15,,-14.65,-44.033333
br,brejo de sao felix,Brejo de São Félix,13,,-5.4,-43.4
br,brejo de sao joao,Brejo de São João,20,,-7.983333,-42.733333
br,brejo do amparo,Brejo do Amparo,15,,-15.433333,-44.4
br,brejo do borbo,Brejo do Borbo,05,,-9.35,-38.466667
br,brejo do burgo,Brejo do Burgo,05,,-9.35,-38.466667
br,brejo do buriti,Brejo do Buriti,05,,-10.016667,-43.033333
br,brejo do buriti,Brejo do Buriti,29,,-14.316667,-46.033333
br,brejo do coqueiro,Brejo do Coqueiro,20,,-6.483333,-41.366667
br,brejo do cruz,Brejo do Cruz,17,,-6.35,-37.5
br,brejo do espirito santo,Brejo do Espírito Santo,05,,-13.333333,-44.3
br,brejo do fogo,Brejo do Fogo,15,,-15.233333,-42.066667
br,brejo do gomes,Brejo do Gomes,05,,-9.433333,-42.166667
br,brejo do mata-fome,Brejo do Mata-Fome,15,,-14.883333,-44.216667
br,brejo do mutambal,Brejo do Mutambal,15,,-15.55,-44.016667
br,brejo do salto,Brejo do Salto,05,,-11.083333,-45.733333
br,brejo dos altos,Brejo dos Altos,20,,-8.933333,-44.283333
br,brejo dos cagados,Brejo dos Cágados,20,,-6.916667,-43.933333
br,brejo dos marques,Brejo dos Marques,05,,-12.766667,-41.8
br,brejo dos martires,Brejo dos Mártires,15,,-15.05,-43.116667
br,brejo dos santos,Brejo dos Santos,06,,-7.483333,-39
br,brejo dos santos,Brejo dos Santos,17,,-6.366667,-37.816667
br,brejo do tabuleiro,Brejo do Tabuleiro,20,,-7.1,-41.75
br,brejo do tucano,Brejo do Tucano,20,,-7.016667,-41.733333
br,brejoes,Brejões,05,,-11.033333,-41.416667
br,brejo escuro,Brejo Escuro,13,,-9,-46.016667
br,brejo espirito santo,Brejo Espírito Santo,05,,-13.333333,-44.3
br,brejo fechado,Brejo Fechado,31,,-11.266667,-46.666667
br,brejo feichado,Brejo Feichado,31,,-11.266667,-46.666667
br,brejo grande,Brejo Grande,05,,-10.033333,-38.533333
br,brejo grande,Brejo Grande,06,,-7.25,-39.766667
br,brejo grande,Brejo Grande,15,,-15.816667,-44.033333
br,brejo grande,Brejo Grande,20,,-5.85,-41.35
br,brejo grande,Brejo Grande,28,,-10.433333,-36.466667
br,brejo joao alves,Brejo João Alves,05,,-12.416667,-41.683333
br,brejo largo,Brejo Largo,31,,-11.033333,-46.533333
br,brejo logo,Brejo Logo,13,,-8.216667,-45.75
br,brejo luisa de brito,Brejo Luisa de Brito,05,,-12.85,-42.016667
br,brejo luiza de brito,Brejo Luiza de Brito,05,,-12.85,-42.016667
br,brejo novo,Brejo Novo,05,,-12.833333,-40.8
br,brejo novo,Brejo Nôvo,30,,-7.45,-37.516667
br,brejo piqui,Brejo Piqui,05,,-10.233333,-43.116667
br,brejo redondo,Brejo Redondo,13,,-6.45,-46.95
br,brejo santo,Brejo Santo,06,27384,-7.483333,-39
br,brejos das freiras,Brejos das Freiras,17,,-6.666667,-38.483333
br,brejos dos pachecos,Brejos dos Pachecos,06,,-3.5,-41.333333
br,brejo secco,Brejo Secco,06,,-7.2,-40.133333
br,brejo seco,Brejo Sêco,06,,-7.2,-40.133333
br,brejo seco,Brejo Seco,20,,-7.683333,-43.066667
br,brejo seco,Brejo Sêco,31,,-10.166667,-48.3
br,brejo velho,Brejo Velho,05,,-12.483333,-43.966667
br,brejo velho,Brejo Velho,20,,-6.483333,-41.366667
br,brejo velho,Brejo Velho,30,,-8.933333,-36.7
br,brejo verde,Brejo Verde,31,,-11.966944,-49.250556
br,brejui,Brejuí,22,,-6.316667,-36.55
br,brenha,Brenha,06,,-4.2,-38.816667
br,breozinho,Breozinho,04,,-3.483333,-66.383333
br,breta,Breta,05,,-12.5,-38.9
br,brete,Brete,11,,-18.65,-56.783333
br,breuzinho,Breuzinho,04,,-3.483333,-66.383333
br,breves,Breves,16,46474,-1.666667,-50.483333
br,brigada,Brigada,06,,-6.716667,-39.566667
br,brigadeiro tobias,Brigadeiro Tobias,27,,-23.507804,-47.366566
br,brigido,Brígido,15,,-21.416667,-46.216667
br,brigue,Brigue,03,,.85,-50.1
br,brilhante,Brilhante,06,,-5.416667,-40.25
br,brilhante,Brilhante,11,,-20.5,-54.2
br,brilhante,Brilhante,13,,-6.316667,-43.1
br,brilhante,Brilhante,14,,-15.966667,-55.066667
br,brilhante,Brilhante,15,,-18.5,-48.883333
br,brilhante,Brilhante,17,,-7.6,-38.066667
br,brilhantina,Brilhantina,16,,-1.2,-49.15
br,brinco,Brinco,21,,-21.916667,-41.75
br,brioso,Brioso,11,,-19.483333,-54.5
br,brioso,Brioso,27,,-20.8,-50.166667
br,britania,Britânia,29,,-15.233333,-51.15
br,brithante,Brithante,14,,-15.966667,-55.066667
br,brito,Brito,06,,-5.4,-39.233333
br,brito,Brito,17,,-7.066667,-36.933333
br,brito,Brito,28,,-10.6,-36.783333
br,brito,Brito,30,,-8.866667,-36.683333
br,broca,Broca,05,,-9.833333,-42.466667
br,broca,Broca,30,,-8.866667,-37.4
br,brocato,Brocató,30,,-7.816667,-38.166667
br,brocheirs,Brocheirs,23,,-29.516667,-51.633333
br,brochier,Brochier,23,,-29.516667,-51.633333
br,brococo,Brococo,30,,-7.883333,-38.1
br,brocos,Brocós,13,,-5.083333,-43.816667
br,brocoto,Brocotó,30,,-7.816667,-38.166667
br,brodosqui,Brodósqui,27,,-20.983333,-47.666667
br,brodovsky,Brodovsky,27,,-20.983333,-47.666667
br,brodowski,Brodowski,27,18366,-20.983333,-47.666667
br,brondo,Brondó,05,,-12.983333,-39.6
br,brotas,Brotas,05,,-12,-42.633333
br,brotas,Brotas,06,,-3.566667,-39.75
br,brotas,Brotas,14,,-15.2,-56.366667
br,brotas,Brotas,17,,-7.25,-37.95
br,brotas,Brotas,20,,-5.366667,-41.466667
br,brotas,Brotas,27,18690,-22.283333,-48.116667
br,brotas de macahubas,Brotas de Macahubas,05,,-12,-42.633333
br,brotas de macaubas,Brotas de Macaúbas,05,,-12,-42.633333
br,brudertahl,Brudertahl,26,,-26.797,-49.1716
br,brumadinho,Brumadinho,05,,-13.55,-41.9
br,brumadinho,Brumadinho,15,27564,-20.133333,-44.216667
br,brumado,Brumado,05,41990,-14.216667,-41.666667
br,brumado,Brumado,14,,-14.716667,-56.633333
br,brumado,Brumado,15,,-18.75,-49.416667
br,brumado do assurua,Brumado do Assuruá,05,,-11.55,-42.75
br,brumal,Brumal,15,,-19.983333,-43.45
br,brundue,Brundué,05,,-11.933333,-42.933333
br,bruno,Bruno,18,,-23.409548,-52.503786
br,brusque,Brusque,26,88286,-27.1,-48.933333
br,bruto,Bruto,06,,-4.8,-40.316667
br,buare,Buare,18,,-25.85,-52.45
br,buarque,Buarque,15,,-20.75,-43.8
br,buarque de macedo,Buarque de Macedo,15,,-20.75,-43.8
br,bu,Bu,05,,-12.05,-37.7
br,bubu,Bubu,08,,-20.283333,-40.4
br,bucuituba,Bucuituba,05,,-12.666667,-42.816667
br,buena hora,Buena Hora,14,,-15.6,-60.366667
br,buena hora,Buena Hora,24,,-11.683333,-65.083333
br,bueno andrade,Bueno Andrade,27,,-21.666667,-48.25
br,bueno brandao,Bueno Brandão,15,5777,-22.45,-46.35
br,bueno,Bueno,14,,-15.25,-56.2
br,bueno,Bueno,15,,-19.45,-41.5
br,bueno de andrada,Bueno de Andrada,27,,-21.666667,-48.25
br,bueno de andrade,Bueno de Andrade,21,,-22.366667,-43.416667
br,bueno de andrade,Bueno de Andrade,27,,-21.666667,-48.25
br,buenolandia,Buenolândia,29,,-15.8,-50.283333
br,buenopolis,Buenópolis,15,,-17.9,-44.183333
br,buenos aires,Buenos Aires,01,,-8.492778,-72.845556
br,buenos aires,Buenos Aires,05,,-9.6,-42.816667
br,buenos aires,Buenos Aires,06,,-6.366667,-38.866667
br,buenos-aires,Buenos-Aires,06,,-7.116667,-40.033333
br,buenos aires,Buenos Aires,08,,-20.583333,-40.533333
br,buenos aires,Buenos Aires,13,,-2.85,-43.533333
br,buenos aires,Buenos Aires,27,,-22.3,-50.216667
br,buenos aires,Buenos Aires,30,,-7.6,-37.233333
br,buenos,Buenos,27,,-23.728114,-47.518779
br,buerarama,Buerarama,05,,-14.95,-39.316667
br,buerarema,Buerarema,05,16002,-14.95,-39.316667
br,bufadeira,Bufadeira,18,,-23.983333,-51.2
br,bugi,Bugi,05,,-12.183333,-39.35
br,bugio,Bugio,18,,-25.667827,-50.67296
br,bugio,Bugio,27,,-24.8703,-48.4783
br,bugre,Bugre,15,,-19.416667,-42.25
br,bugre,Bugre,18,,-25.85,-52.45
br,bugre,Bugre,23,,-29.466667,-53.3
br,bugre,Bugre,26,,-26.066667,-50.233333
br,bugre,Bugre,27,,-22.6121,-45.6809
br,bugres,Bugres,26,,-26.066667,-50.233333
br,buicu,Buiçu,04,,-4.268611,-62.282222
br,buique,Buíque,30,20324,-8.616667,-37.15
br,buiu,Buiú,17,,-7.316667,-37.75
br,buiuio,Buiuio,29,,-14.733333,-49.083333
br,bujari,Bujari,01,,-9.838056,-67.937778
br,bujaru,Bujaru,16,6189,-1.516667,-48.016667
br,bulha,Bulha,27,,-24.544461,-48.049913
br,bulhoes,Bulhões,21,,-22.4606,-44.3453
br,bulhoes velho,Bulhões Velho,21,,-22.4606,-44.3453
br,bultrim,Bultrim,17,,-7.083333,-35.866667
br,bupeva,Bupeva,26,,-26.383333,-48.616667
br,buquim,Buquim,28,,-11.15,-37.616667
br,buquira,Buquira,27,,-22.966667,-45.833333
br,buracao,Buracão,05,,-12.183333,-44.95
br,buracao,Buracão,14,,-14.35,-55.766667
br,buracao,Buracão,15,,-16.25,-41.866667
br,buracao,Buracao,22,,-5.3,-37.733333
br,buracao,Buracão,27,,-21.016667,-47.633333
br,buracica,Buracica,05,,-12.266667,-38.516667
br,buraco d'agua,Buraco d'Agua,05,,-10.466667,-40.533333
br,buraco d' agua,Buraco d' Agua,05,,-12.083333,-39.283333
br,buraco d'agua,Buraco d'Agua,05,,-9.233333,-38.916667
br,buraco d'agua,Buraco d'Agua,20,,-6.066667,-41.75
br,buraco do bicho,Buraco do Bicho,15,,-20.666667,-43.916667
br,buraco seco,Buraco Sêco,22,,-5.45,-35.866667
br,buranhem,Buranhém,05,,-12.516667,-38.65
br,burarama,Burarama,08,,-20.7,-41.333333
br,burgo agricola,Burgo Agrícola,16,,-5.366667,-49.2
br,buri,Buri,05,,-12.2,-38
br,buri,Buri,27,15959,-23.8,-48.583333
br,buriche,Buriche,21,,-22.933333,-42.866667
br,burieta,Burietá,05,,-13.55,-39.466667
br,buris,Buris,05,,-13.55,-39.466667
br,buris dos lopes,Buris dos Lopes,05,,-13.516667,-39.466667
br,buritama,Buritama,27,12712,-21.05,-50.133333
br,buriti alegre,Buriti Alegre,29,9427,-18.15,-49.05
br,buriti bravo,Buriti Bravo,13,17693,-5.833333,-43.833333
br,buriti,Buriti,05,,-10.016667,-43.033333
br,buriti,Buriti,06,,-3.166667,-39.45
br,buriti,Buriti,11,,-18.25,-54.5
br,buriti,Buriti,13,7025,-3.916667,-42.95
br,buriti,Buriti,14,,-13.2,-58.633333
br,buriti,Buriti,15,,-17.283333,-46.466667
br,buriti,Buriti,18,,-25.366667,-52.666667
br,buriti,Buriti,20,,-3.830556,-42.495
br,buriti,Buriti,27,,-20.616667,-47.7
br,buriti,Buriti,29,,-14.383333,-46.2
br,buriti cercado,Buriti Cercado,13,,-6.533333,-43.083333
br,buriti compredo,Buriti Compredo,15,,-18.75,-45.15
br,buriti comprido,Buriti Comprido,20,,-6.666667,-41.616667
br,buriti congonhas,Buriti Congonhas,21,,-22.860244,-43.332003
br,buriti cortado,Buriti Cortado,13,,-5.183333,-43.1
br,buriti da aurora,Buriti da Aurora,13,,-3.991389,-43.435278
br,buriti da cachoeira,Buriti da Cachoeira,15,,-19.05,-44.533333
br,buriti das eguas,Buriti das Eguas,20,,-6.766667,-41.4
br,buriti de laje,Buriti de Laje,20,,-5.633333,-42.183333
br,buriti do castelo,Buriti do Castelo,20,,-5.95,-42.183333
br,buriti do estevam,Buriti do Estevam,13,,-3.783333,-43.259722
br,buriti dos correias,Buriti dos Correias,13,,-3.908056,-43.358889
br,buriti dos lopes,Buriti dos Lopes,20,9475,-3.166667,-41.866667
br,buriti dos montes,Buriti dos Montes,20,,-5.3,-41.1
br,buriti do tocantins,Buriti do Tocantins,31,,-5.296111,-48.094444
br,buriti fechado,Buriti Fechado,14,,-15.233333,-56.933333
br,buriti fechado,Buriti Fechado,20,,-5.25,-41.666667
br,buriti frio,Buriti Frio,13,,-5.333333,-43.45
br,buriti grande,Buriti Grande,13,,-6.166667,-47.166667
br,buriti grande,Buriti Grande,15,,-19.25,-44.583333
br,buriti grande,Buriti Grande,20,,-5.95,-42.9
br,buritirama,Buritirama,05,,-10.716667,-43.65
br,buritirana,Buritirana,13,,-3.368611,-43.021111
br,buritirana,Buritirana,20,,-6.183333,-42.85
br,buritirana,Buritirana,31,,-7.25,-48.216667
br,buriti redondo,Buriti Redondo,13,,-3.082778,-42.258333
br,buritis,Buritis,15,16243,-15.616667,-46.433333
br,buritis,Buritis,27,,-20.183333,-47.733333
br,buriti seco,Buriti Seco,13,,-3.266389,-42.788889
br,buriti-so,Buriti-Só,31,,-10.483333,-46.033333
br,buriti so,Buriti Só,31,,-6.983333,-48.066667
br,buriti torto,Buriti Torto,13,,-5.283333,-46.016667
br,buritizal,Buritizal,03,,.833333,-50.116667
br,buritizal,Buritizal,13,,-3.407222,-43.413333
br,buritizal,Buritizal,14,,-15.733333,-54.45
br,buritizal,Buritizal,16,,-5.183333,-56.6
br,buritizal,Buritizal,20,,-5.216667,-42.083333
br,buritizal,Buritizal,27,,-20.183333,-47.733333
br,buritizeiro,Buritizeiro,13,,-3.810278,-43.363333
br,buritizeiro,Buritizeiro,15,25104,-17.35,-44.966667
br,buritizinho,Buritizinho,05,,-12.216667,-44.433333
br,buritizinho,Buritizinho,06,,-7.333333,-38.783333
br,buritizinho,Buritizinho,13,,-2.95,-42.183333
br,buritizinho,Buritizinho,20,,-5.033333,-42.216667
br,buritizinho,Buritizinho,29,,-14.6,-47.616667
br,buritizinho i,Buritizinho I,13,,-3.570556,-43.088611
br,buritizinho ii,Buritizinho II,13,,-3.315833,-43.134722
br,buritizo,Buritizo,31,,-6.983333,-48.066667
br,burituranas,Burituranas,15,,-17.366667,-44.2
br,burity alegre,Burity Alegre,29,,-18.15,-49.05
br,burityba-mirim,Burityba-Mirim,27,,-23.583333,-46.033333
br,burity bravo,Burity Bravo,13,,-5.833333,-43.833333
br,burity,Burity,06,,-7.216667,-39.383333
br,burity,Burity,11,,-21.366667,-55.8
br,burity,Burity,13,,-3.916667,-42.95
br,burity,Burity,14,,-15.383333,-55.833333
br,burity,Burity,15,,-15.616667,-46.433333
br,burity dos lopes,Burity dos Lopes,20,,-3.166667,-41.866667
br,buritys,Buritys,27,,-20.183333,-47.733333
br,burityzal,Burityzal,16,,-5.183333,-56.6
br,buritzinho,Buritzinho,20,,-5.683333,-41.883333
br,burizeiro,Burizeiro,05,,-12.733333,-38.3
br,burrego,Burrego,30,,-7.933333,-36.483333
br,burriguda dos frades,Burriguda dos Frades,17,,-7.883333,-36.466667
br,burunhaem,Burunhaém,05,,-16.533333,-40.066667
br,bury,Bury,27,,-23.8,-48.583333
br,busca-vida,Busca-Vida,05,,-12.8,-38.2
br,busco vida,Busco Vida,05,,-12.883333,-38.266667
br,butanta,Butantã,05,,-12.866667,-39.333333
br,butia,Butiá,23,19494,-30.116667,-51.966667
br,butia,Butiá,26,,-27.116667,-50.833333
br,butia da lapa,Butiá da Lapa,18,,-26.0016,-49.9621
br,butia de cima,Butiá de Cima,18,,-25.990515,-50.014968
br,butia de cima,Butiá de Cima,26,,-26.2432,-49.9286
br,butia do lajeado,Butiá do Lajeado,26,,-26.2087,-49.9309
br,butia dos carvalho,Butiá dos Carvalho,26,,-26.2432,-49.9286
br,butia dos colaco,Butiá dos Colaço,18,,-25.982038,-50.016911
br,butia dos colacos,Butia dos Colaços,18,,-25.959069,-50.027663
br,butio,Butió,23,,-30.116667,-51.966667
br,buzebio oliveira,Buzebio Oliveira,18,,-23.8107,-50.3623
br,buzios,Búzios,21,,-22.75,-41.883333
br,caa-guacu,Caa-Guaçu,23,,-27.383333,-54.216667
br,caaguacu,Caaguaçu,27,,-23.277517,-47.854631
br,caaguacu de cima,Caaguaçu de Cima,27,,-23.308732,-47.851658
br,caamirim,Caamirim,17,,-7.1,-35.766667
br,caapiranga,Caapiranga,04,,-3.3,-61.216667
br,caapoa,Caapoã,17,,-6.766667,-36.8
br,caapora,Caaporã,17,13770,-7.516667,-34.9
br,caarapa,Caarapã,11,,-22.45,-55.016667
br,caarapo,Caarapó,11,13863,-22.633333,-54.8
br,caatiba,Caatiba,05,,-15,-40.4
br,caatinga,Caatinga,02,,-9.4,-37.45
br,caatinga,Caatinga,05,,-12.066667,-38.933333
br,caatinga,Caatinga,15,,-17.166667,-45.883333
br,caatinga,Caatinga,22,,-5.629167,-37.043611
br,caatinga de alecrim,Caatinga de Alecrim,17,,-6.966667,-38.216667
br,caatinga do atanasio,Caatinga do Atanásio,06,,-5.683333,-38.2
br,caatinga do gois,Caatinga do Góis,22,,-5.433333,-37.783333
br,caatinga do moura,Caatinga do Moura,05,,-10.966667,-40.75
br,caatinga do porco,Caatinga do Porco,20,,-7.8,-42.633333
br,caatingas,Caatingas,05,,-13.6,-39.983333
br,cabaca,Cabaça,05,,-10.133333,-43.466667
br,cabaca,Cabaca,22,,-5.453611,-36.355556
br,cabacais,Cabaçais,27,,-23.678882,-47.847069
br,cabacal,Cabaçal,14,,-16.016667,-58.533333
br,cabacas,Cabaças,05,,-9.216667,-38.383333
br,cabacas,Cabaças,06,,-5.066667,-40.866667
br,cabacas,Cabacas,17,,-7.55,-38.633333
br,cabacas,Cabaças,30,,-7.95,-38.7
br,cabaceira,Cabaceira,05,,-10.183333,-43.3
br,cabaceira,Cabaceira,06,,-7.033333,-40.416667
br,cabaceira,Cabaceira,20,,-6.883333,-40.516667
br,cabaceira,Cabaceira,28,,-9.933333,-37.116667
br,cabaceira,Cabaceira,30,,-8.45,-38.033333
br,cabaceiras,Cabaceiras,05,,-11.5,-42.333333
br,cabaceiras,Cabaceiras,17,,-7.016667,-37.45
br,cabaceiras,Cabaceiras,22,,-5.533333,-35.433333
br,cabaceiras,Cabaceiras,27,,-21.683333,-47.95
br,cabaceiras do paraguacu,Cabaceiras do Paraguaçu,05,,-12.55,-39.183333
br,cabaceiro,Cabaceiro,20,,-3.828333,-42.409444
br,cabaceiro,Cabaceiro,28,,-9.933333,-37.116667
br,cabana,Cabana,22,,-5.299444,-36.543889
br,cabana,Cabana,30,,-7.733333,-38.35
br,cabanas,Cabanas,30,,-8.416667,-36.35
br,cabana valente,Cabana Valente,18,,-25.5222,-49.8491
br,cabange,Cabange,02,,-9.266667,-36.466667
br,cabanha florestal,Cabanha Florestal,18,,-25.4129,-50.6895
br,cabaraquara,Cabaraquara,18,,-25.8304,-48.571
br,cabatam,Cabatam,06,,-3.133333,-39.733333
br,cabeca,Cabeça,02,,-9.966667,-36.066667
br,cabeca,Cabeça,13,,-5,-43.4
br,cabeca,Cabeça,27,,-22.35,-47.683333
br,cabeca,Cabeça,28,,-10.5,-36.416667
br,cabeca d'anta,Cabeca d'Anta,18,,-25.166667,-49.083333
br,cabeca danta,Cabeça Danta,20,,-3.3425,-42.089167
br,cabeca d'anta,Cabeca d'Anta,30,,-7.883333,-38
br,cabeca da onca,Cabeca da Onca,06,,-5.45,-40.916667
br,cabeca da onca,Cabeça da Onça,17,,-6.533333,-37.933333
br,cabeca de boi,Cabeça de Boi,05,,-8.933333,-38.533333
br,cabeca de boi,Cabeça de Boi,06,,-5.533333,-39.116667
br,cabeca de boi,Cabeça de Boi,17,,-7.266667,-37.783333
br,cabeca de boi,Cabeça de Boi,20,,-10.816667,-45.166667
br,cabeca de boi,Cabeca de Boi,22,,-5.783333,-35.55
br,cabeca de cavalo,Cabeça de Cavalo,17,,-7.8,-36.5
br,cabeca de joao ferino,Cabeca de João Ferino,20,,-6.033333,-36.55
br,cabeca de touro,Cabeça de Touro,14,,-16.116667,-59.95
br,cabeca de vaca,Cabeça de Vaca,06,,-5.25,-39.966667
br,cabeca de vaca,Cabeça de Vaca,22,,-5.841667,-37.154444
br,cabeca do cavalo,Cabeça do Cavalo,13,,-3.878889,-42.989444
br,cabeca-no-tempo,Cabeça-no-Tempo,20,,-9.7,-43.816667
br,cabeca quebrada,Cabeça Quebrada,13,,-3.695278,-42.785
br,cabecas,Cabeças,05,,-12.6,-39.033333
br,cabeceira alta do formoso,Cabeceira Alta do Formoso,29,,-18.1,-53.116667
br,cabeceira apa,Cabeceira Apa,11,,-22.016667,-55.766667
br,cabeceira bento gomes,Cabeceira Bento Gomes,14,,-15.8,-56.583333
br,cabeceira,Cabeceira,05,,-10.183333,-43.3
br,cabeceira,Cabeceira,11,,-18.75,-54.766667
br,cabeceira,Cabeceira,13,,-3.098056,-42.940833
br,cabeceira,Cabeceira,20,,-3.800833,-42.383611
br,cabeceira,Cabeceira,30,,-8.45,-38.033333
br,cabeceira da bacaba,Cabeceira da Bacaba,13,,-5.1,-43.15
br,cabeceira da boa hora,Cabeceira da Boa Hora,13,,-3.284722,-42.931944
br,cabeceira da laje,Cabeceira da Laje,13,,-7.216667,-47.25
br,cabeceira de pedras,Cabeceira de Pedras,05,,-12.166667,-46.216667
br,cabeceira do apa,Cabeceira do Apa,11,,-22.016667,-55.766667
br,cabeceira do corda,Cabeceira do Corda,13,,-6.55,-43.216667
br,cabeceira do frei pedro,Cabeceira do Frei Pedro,20,,-5.216667,-42.15
br,cabeceira do ipuita,Cabeceira do Ipuitã,11,,-23.433333,-55.266667
br,cabeceira do ouro,Cabeceira do Ouro,05,,-15.083333,-40.2
br,cabeceira do pindauva,Cabeceira do Pindaúva,27,,-24.7875,-48.054
br,cabeceira do riachao,Cabeceira do Riachão,20,,-9.071389,-45.72
br,cabeceira do ribeirao da cruz,Cabeceira do Ribeirão da Cruz,18,,-23.2777,-49.8034
br,cabeceira do utinga,Cabeceira do Utinga,05,,-12.016667,-41.05
br,cabeceira estrela,Cabeceira Estrela,11,,-22.3,-55.833333
br,cabeceira funda,Cabeceira Funda,11,,-20.933333,-55.033333
br,cabeceira grande,Cabeceira Grande,05,,-13.216667,-44.666667
br,cabeceira limpa,Cabeceira Limpa,11,,-21.583333,-53.85
br,cabeceira rio manso,Cabeceira Rio Manso,14,,-15.65,-55.316667
br,cabeceira sao domingos,Cabeceira São Domingos,11,,-22.083333,-55.016667
br,cabeceiras,Cabeceiras,20,,-4.483333,-42.316667
br,cabeceiras,Cabeceiras,29,,-15.8,-46.983333
br,cabeceiras de pedras,Cabeceiras de Pedras,05,,-12.166667,-46.216667
br,cabeceiras do paraguacu,Cabeceiras do Paraguaçu,05,,-12.55,-39.183333
br,cabeceira velha,Cabeceira Velha,05,,-11.316667,-46.333333
br,cabeceirinha,Cabeceirinha,13,,-6.983333,-47.05
br,cabeceirinha,Cabeceirinha,31,,-11.921667,-46.470278
br,cabe chico,Cabe Chico,04,,-5.766389,-59.35
br,cabecinha,Cabecinha,27,,-20.633333,-47.15
br,cabeco,Cabeço,20,,-6.95,-41.666667
br,cabeco,Cabeço,28,,-10.5,-36.416667
br,cabeco de joao ferino,Cabeço de João Ferino,22,,-5.974444,-36.616111
br,cabecote,Cabeçote,20,,-3.273611,-42.022222
br,cabeco vermelho,Cabeco Vermelho,22,,-5.466667,-35.983333
br,cabecudas,Cabeçudas,26,,-26.95,-48.633333
br,cabedello,Cabedello,17,,-6.966667,-34.833333
br,cabedelo,Cabedelo,17,54841,-6.966667,-34.833333
br,cabedelos,Cabedelos,17,,-6.966667,-34.833333
br,cabeleira,Cabeleira,22,,-5.3375,-36.965833
br,cabeleira,Cabeleira,30,,-8.45,-36.116667
br,cabelo,Cabelo,05,,-12.45,-38.266667
br,cabelo,Cabelo,30,,-7.766667,-37.733333
br,cabelo da cuia,Cabelo da Cuia,05,,-10.3,-39.066667
br,cabelo de negro,Cabelo de Negro,22,,-5.233333,-37.533333
br,cabiuna,Cabiúna,18,,-23.383333,-50.75
br,cabiunas,Cabiúnas,21,,-22.3,-41.716667
br,caboba,Caboba,13,,-3.009444,-42.577778
br,cabo,Cabo,30,,-8.283333,-35.033333
br,cabo chico,Cabo Chico,04,,-5.766389,-59.35
br,cabocio,Cabocio,20,,-7.533333,-41.283333
br,caboclinho,Caboclinho,06,,-2.95,-40.066667
br,caboclo,Caboclo,02,,-9.533333,-37.533333
br,caboclo,Caboclo,05,,-12.566667,-39
br,caboclo,Caboclo,06,,-6.5,-39.216667
br,caboclo,Caboclo,20,,-4.616667,-41.75
br,caboclo,Caboclo,30,,-8.516667,-41
br,caboclo de fora,Caboclo de Fora,05,,-13.2,-38.983333
br,caboclos,Caboclos,05,,-15.85,-39.766667
br,caboclos,Caboclos,20,,-7.283333,-40.583333
br,caboco,Cabocó,05,,-12.566667,-39
br,cabo do campo,Cabo do Campo,30,,-8.35,-36.883333
br,cabo do pasto,Cabo do Pasto,02,,-10.083333,-36.516667
br,cabo frio,Cabo Frio,21,108241,-22.883333,-42.016667
br,cabo joao,Cabo João,29,,-16.266667,-51.666667
br,cabore,Caboré,13,,-3.795833,-42.756944
br,cabore,Caboré,20,,-9.2,-42.516667
br,cabori,Cabori,04,,.366667,-67.283333
br,caboto,Caboto,05,,-12.75,-38.483333
br,cabo verde,Cabo Verde,15,,-21.466667,-46.4
br,cabo verde,Cabo Verde,20,,-3.819444,-42.326111
br,cabra,Cabra,20,,-5.416667,-42.916667
br,cabrais,Cabrais,17,,-7.2,-38.45
br,cabral,Cabral,14,,-15.5,-55.8
br,cabralia,Cabrália,05,,-12.816667,-41.8
br,cabralia,Cabrália,27,,-22.466667,-49.333333
br,cabralia paulista,Cabrália Paulista,27,,-22.466667,-49.333333
br,cabras,Cabras,04,,-5.168333,-58.588333
br,cabreiro,Cabreiro,05,,-13.4,-41.05
br,cabreiro,Cabreiro,06,,-4.616667,-37.833333
br,cabrestos,Cabrestos,15,,-20.383333,-46.266667
br,cabreuva,Cabreúva,27,38743,-23.3,-47.133333
br,cabritos,Cabritos,15,,-21.566667,-44.716667
br,cabrituba,Cabrituba,28,,-9.65,-37.933333
br,cabriuva,Cabriúva,27,,-23.3,-47.133333
br,cabrobo,Cabrobó,30,16096,-8.516667,-39.316667
br,cabucu,Cabuçu,05,,-12.016667,-38.1
br,cabucu,Cabuçu,21,,-22.783448,-43.547674
br,cabucu,Cabuçu,27,,-23.406329,-46.538228
br,cabuis,Cabuis,21,,-22.806128,-43.4062
br,cabura,Caburã,16,,-6.766667,-57.533333
br,cabure,Caburé,13,,-3.573889,-43.275833
br,cabure,Caburé,17,,-7.8,-38.233333
br,caburu,Caburu,15,,-21.1,-44.35
br,cabussu,Cabussú,21,,-22.833333,-42.916667
br,cacabu,Caçabu,05,,-10.666667,-38.916667
br,cacada,Caçada,18,,-25.142971,-48.363855
br,cacada real,Caçada Real,25,,3.133333,-60.716667
br,cacador,Caçador,18,,-24.940349,-48.885726
br,cacador,Caçador,21,,-22.764167,-43.791667
br,cacador,Caçador,26,63727,-26.783333,-51
br,cacador,Caçador,27,,-22.566667,-49.65
br,cacaia,Cacaia,16,,-1.4,-48.116667
br,cacal,Cacal,05,,-12.433333,-44.65
br,cacamba,Caçamba,02,,-9.383333,-36.266667
br,cacambinha,Caçambinha,02,,-9.216667,-36.25
br,cacapava,Caçapava,23,,-30.5,-53.5
br,cacapava,Caçapava,27,72341,-23.1,-45.716667
br,cacapava do sul,Caçapava do Sul,23,17522,-30.5,-53.5
br,cacapava velha,Caçapava Velha,27,,-23.116667,-45.65
br,cacaratiba,Caçaratiba,15,,-17.25,-43.033333
br,cacare,Cacaré,06,,-7.466667,-38.966667
br,cacare,Cacaré,17,,-6.783333,-38.566667
br,cacare varjota,Cacaré Varjota,17,,-7.1,-38.6
br,cacaria,Cacaria,30,,-7.866667,-39.466667
br,cacaroca,Caçaroca,08,,-20.4,-40.383333
br,cacarongonga,Caçarongonga,05,,-12.6,-38.616667
br,cacaual,Cacaual,13,,-1.983333,-46.216667
br,cacau,Cacáu,17,,-7.183333,-38.55
br,cacau,Cacaú,30,,-8.65,-35.266667
br,cacaueira,Cacaueira,06,,-5.133333,-40
br,cacaulandia,Cacaulândia,24,,-10.341667,-62.9
br,cacauzinho,Cacauzinho,04,,-4.425278,-59.830833
br,cacequi,Cacequi,23,12868,-29.883333,-54.816667
br,cacequy,Cacequy,23,,-29.883333,-54.816667
br,caceres,Cáceres,14,73431,-16.066667,-57.683333
br,cacete,Cacete,13,,-5.1,-45.333333
br,cachaco,Cachaço,06,,-6.616667,-38.816667
br,cachambi,Cachambi,21,,-22.889008,-43.279091
br,cachambu,Cachambú,26,,-27.166667,-52.866667
br,cachamorra,Cachamorra,21,,-22.951291,-43.56045
br,cacha pregos,Cacha Pregos,05,,-13.116667,-38.783333
br,cacha torta,Cacha Torta,15,,-20.333333,-42.483333
br,cacheado,Cacheado,06,,-5.266667,-40.833333
br,cache,Caché,20,,-8.45,-42.4
br,cacheiro,Cacheiro,08,,-20.85,-41.1
br,cachimba,Cachimba,18,,-25.616667,-49.35
br,cachimbo,Cachimbo,06,,-5.983333,-39.616667
br,cachimbo,Cachimbo,13,,-5.883333,-44.316667
br,cachimbo,Cachimbo,15,,-18.466667,-43.65
br,cachimbo,Cachimbo,16,,-8.95,-54.9
br,cachimbos,Cachimbos,15,,-18.466667,-43.65
br,cachimho,Cachimho,04,,-5.541944,-64.052222
br,cachinaoa,Cachinaoa,01,,-8.716667,-71.883333
br,cachinaua,Cachinaua,01,,-8.716667,-71.883333
br,cachirimbu,Cachirimbu,13,,-5.083333,-43.416667
br,cacho do moleiro,Cacho do Moleiro,05,,-12.416667,-41.633333
br,cacho dos moleiros,Cacho dos Moleiros,05,,-12.416667,-41.633333
br,cachoeira alegre,Cachoeira Alegre,08,,-20.716667,-41.833333
br,cachoeira alegre,Cachoeira Alegre,15,,-21.25,-42.3
br,cachoeira alegre,Cachoeira Alegre,21,,-21.25,-41.516667
br,cachoeira alta,Cachoeira Alta,29,,-18.8,-50.966667
br,cachoeira branca,Cachoeira Branca,11,,-20.9,-53.35
br,cachoeira,Cachoeira,01,,-8.6,-73.15
br,cachoeira,Cachoeira,02,,-9.6,-37.116667
br,cachoeira,Cachoeira,04,,-3.0425,-61.555278
br,cachoeira,Cachoeira,05,16145,-12.6,-38.966667
br,cachoeira,Cachoeira,06,,-3.166667,-40.216667
br,cachoeira,Cachoeira,08,,-20.35,-41.633333
br,cachoeira,Cachoeira,11,,-19.55,-54.583333
br,cachoeira,Cachoeira,13,,-3.057222,-42.755278
br,cachoeira,Cachoeira,14,,-14.416667,-55.65
br,cachoeira,Cachoeira,15,,-16.6,-41.483333
br,cachoeira,Cachoeira,16,,-1.016667,-48.966667
br,cachoeira,Cachoeira,17,,-6.316667,-37.566667
br,cachoeira,Cachoeira,18,,-25.2557,-48.7371
br,cachoeira,Cachoeira,20,,-3.744444,-42.526389
br,cachoeira,Cachoeira,21,,-21.2,-41.666667
br,cachoeira,Cachoeira,22,,-5.683056,-36.57
br,cachoeira,Cachoeira,23,,-30.033333,-52.9
br,cachoeira,Cachoeira,26,,-27.433333,-48.45
br,cachoeira,Cachoeira,27,,-20.2,-47.416667
br,cachoeira,Cachoeira,29,,-13.433333,-46.833333
br,cachoeira,Cachoeira,30,,-7.733333,-38.45
br,cachoeira,Cachoeira,31,,-7.216667,-48.383333
br,cachoeira da abadia,Cachoeira da Abadia,05,,-11.533333,-37.566667
br,cachoeira da abbadia,Cachoeira da Abbadia,05,,-11.533333,-37.566667
br,cachoeira da ema,Cachoeira da Ema,27,,-21.916667,-47.35
br,cachoeira da mata,Cachoeira da Mata,05,,-17.4,-40.05
br,cachoeira da moca,Cachoeira da Moça,06,,-3.766667,-40.15
br,cachoeira da moca,Cachoeira da Moça,17,,-6.583333,-38.383333
br,cachoeira de baixo,Cachoeira de Baíxo,06,,-4.3,-39.233333
br,cachoeira de cima,Cachoeira de Cima,18,,-25.22899,-48.750102
br,cachoeira de emas,Cachoeira de Emas,27,,-21.916667,-47.35
br,cachoeira de goias,Cachoeira de Goiás,29,,-16.733333,-50.633333
br,cachoeira de itabuna,Cachoeira de Itabuna,05,,-14.45,-39.416667
br,cachoeira de macacos,Cachoeira de Macacos,15,,-19.533333,-44.433333
br,cachoeira de manuel roque,Cachoeira de Manuel Roque,05,,-14.166667,-40.25
br,cachoeira de minas,Cachoeira de Minas,15,,-22.35,-45.783333
br,cachoeira de minas,Cachoeira de Minas,17,,-7.566667,-38.083333
br,cachoeira de sapo,Cachoeira de Sapo,22,,-5.75,-35.916667
br,cachoeira do arari,Cachoeira do Arari,16,,-1.016667,-48.966667
br,cachoeira do bom jesus,Cachoeira do Bom Jesus,26,,-27.433333,-48.45
br,cachoeira do brumado,Cachoeira do Brumado,15,,-20.383333,-43.283333
br,cachoeira do campo,Cachoeira do Campo,15,,-20.333333,-43.666667
br,cachoeira do funil,Cachoeira do Funil,21,,-22.116667,-43.55
br,cachoeira do ilanema,Cachoeira do Ilanema,18,,-25.7908,-49.4561
br,cachoeira do mato,Cachoeira do Mato,05,,-17.4,-40.05
br,cachoeira do pajehu,Cachoeira do Pajehu,15,,-15.95,-41.5
br,cachoeira do pajeu,Cachoeira do Pajeú,15,,-15.95,-41.5
br,cachoeira do repouso,Cachoeira do Repouso,04,,-4.359722,-70.933056
br,cachoeira do roberto,Cachoeira do Roberto,30,,-8.65,-41.133333
br,cachoeira do samuel,Cachoeira do Samuel,24,,-8.75,-63.466667
br,cachoeira do sapateiro,Cachoeira do Sapateiro,20,,-3.92,-42.097778
br,cachoeira do sapo,Cachoeira do Sapo,22,,-5.75,-35.916667
br,cachoeira dos domingos,Cachoeira dos Domingos,18,,-25.579476,-50.745684
br,cachoeira dos indios,Cachoeira dos Índios,17,,-6.933333,-38.683333
br,cachoeira do sul,Cachoeira do Sul,23,74696,-30.033333,-52.9
br,cachoeira dourada,Cachoeira Dourada,15,,-18.5,-49.5
br,cachoeira dourada,Cachoeira Dourada,29,,-18.5,-49.516667
br,cachoeira escura,Cachoeira Escura,15,,-19.3,-42.383333
br,cachoeira funda,Cachoeira Funda,11,,-20.933333,-55.033333
br,cachoeira grande,Cachoeira Grande,02,,-9.05,-37.516667
br,cachoeira grande,Cachoeira Grande,03,,2.15,-51.016667
br,cachoeira grande,Cachoeira Grande,05,,-13.583333,-41.266667
br,cachoeira grande,Cachoeira Grande,06,,-4.6,-41.2
br,cachoeira grande,Cachoeira Grande,30,,-8.483333,-36.166667
br,cachoeira lisa,Cachoeira Lisa,02,,-8.95,-36.05
br,cachoeirao,Cachoeirão,11,,-20.416667,-55.283333
br,cachoeira paulista,Cachoeira Paulista,27,,-22.666667,-45.016667
br,cachoeira pedra,Cachoeira Pedra,11,,-19.966667,-54.366667
br,cachoeira samuel,Cachoeira Samuel,24,,-8.75,-63.466667
br,cachoeiras,Cachoeiras,15,,-22.35,-45.783333
br,cachoeiras,Cachoeiras,17,,-6.983333,-37.266667
br,cachoeiras,Cachoeiras,21,,-22.316667,-41.883333
br,cachoeiras,Cachoeiras,30,,-7.683333,-39.366667
br,cachoeiras de macacu,Cachoeiras de Macacu,21,46178,-22.466667,-42.65
br,cachoeira seca,Cachoeira Seca,27,,-24.747248,-48.116356
br,cachoeira seca,Cachoeira Sêca,30,,-8.1,-36.033333
br,cachoeira torta,Cachoeira Torta,15,,-20.333333,-42.483333
br,cachoeirinha,Cachoeirinha,02,,-9.416667,-37.9
br,cachoeirinha,Cachoeirinha,04,,-3.124167,-60.009167
br,cachoeirinha,Cachoeirinha,05,,-12.65,-38.966667
br,cachoeirinha,Cachoeirinha,06,,-5.05,-40.4
br,cachoeirinha,Cachoeirinha,08,,-18.833333,-40.916667
br,cachoeirinha,Cachoeirinha,11,,-18.166667,-54.25
br,cachoeirinha,Cachoeirinha,13,,-1.616667,-45.1
br,cachoeirinha,Cachoeirinha,14,,-15.566667,-54.466667
br,cachoeirinha,Cachoeirinha,15,,-18.966667,-41.633333
br,cachoeirinha,Cachoeirinha,16,,-5.4,-54.3
br,cachoeirinha,Cachoeirinha,17,,-6.6,-35.533333
br,cachoeirinha,Cachoeirinha,18,,-24.166667,-49.666667
br,cachoeirinha,Cachoeirinha,21,,-21.533333,-41.916667
br,cachoeirinha,Cachoeirinha,23,121086,-29.95,-51.083333
br,cachoeirinha,Cachoeirinha,24,,-10.916667,-65.266667
br,cachoeirinha,Cachoeirinha,25,,2.333333,-60.866667
br,cachoeirinha,Cachoeirinha,27,,-21.666667,-47.533333
br,cachoeirinha,Cachoeirinha,30,12905,-8.483333,-36.233333
br,cachoeirinha,Cachoeirinha,31,,-6.0525,-47.749444
br,cachoeirinha de itauna,Cachoeirinha de Itaúna,08,,-18.833333,-40.916667
br,cachoeirinhas,Cachoeirinhas,15,,-21.95,-46.616667
br,cachoeiro,Cachoeiro,21,,-22.383333,-42.1
br,cachoeiro,Cachoeiro,30,,-8.216667,-36.033333
br,cachoeiro de itapemirim,Cachoeiro de Itapemirim,08,187023,-20.85,-41.1
br,cachoeiro de santa leopoldina,Cachoeiro de Santa Leopoldina,08,,-20.1,-40.533333
br,cachoeiro do itapemirim,Cachoeiro do Itapemirim,08,,-20.85,-41.1
br,cachoeiros,Cachoeiros,21,,-22.383333,-42.1
br,cachoera,Cachoera,06,,-5.6,-40.866667
br,cachoerinha,Cachoerinha,04,,-5.489444,-60.834444
br,cachoerinha,Cachoerinha,15,,-20.15,-41.733333
br,cachorrinho,Cachorrinho,03,,.716667,-51.916667
br,cachorro,Cachorro,14,,-15.25,-56.55
br,cachorro,Cachorro,17,,-6.683333,-37.7
br,cachos,Cachos,15,,-21.483333,-45.416667
br,cachucha,Cachucha,13,,-4.2,-44.516667
br,cacimba,Cacimba,05,,-10.2,-43.633333
br,cacimba,Cacimba,06,,-6.35,-38.733333
br,cacimba,Cacimba,14,,-15.8,-60.2
br,cacimba,Cacimba,17,,-7.05,-38.433333
br,cacimba,Cacimba,20,,-8.083333,-45.25
br,cacimba,Cacimba,30,,-7.983333,-36.016667
br,cacimba cercada,Cacimba Cercada,02,,-9.516667,-37.483333
br,cacimba da baixa,Cacimba da Baixa,22,,-5.078333,-36.492222
br,cacimba dantas,Cacimba Dantas,20,,-5.85,-41.216667
br,cacimba da onca,Cacimba da Onca,06,,-5.483333,-38.65
br,cacimba de areia,Cacimba de Areia,22,,-7.116667,-37.166667
br,cacimba de baixo,Cacimba de Baixo,05,,-9.583333,-39.083333
br,cacimba de baixo,Cacimba de Baixo,22,,-5.946944,-36.936111
br,cacimba de baixo,Cacimba de Baixo,30,,-7.783333,-38.35
br,cacimba de cima,Cacimba de Cima,17,,-7.533333,-36.333333
br,cacimba de cima,Cacimba de Cima,22,,-6.433333,-38.016667
br,cacimba de cima,Cacimba de Cima,30,,-8.9,-36.983333
br,cacimba de dentro,Cacimba de Dentro,17,7447,-6.65,-35.783333
br,cacimba de meio,Cacimba de Meio,17,,-7.55,-36.9
br,cacimba de pedra,Cacimba de Pedra,05,,-12.05,-39.1
br,cacimba de pedra riacho,Cacimba de Pedra Riacho,20,,-5.866667,-41.116667
br,cacimba do maia,Cacimba do Maia,05,,-9.116667,-38.983333
br,cacimba do meio,Cacimba do Meío,06,,-4.966667,-39.116667
br,cacimba do meio,Cacimba do Meio,20,,-6.633333,-41.716667
br,cacimba do meio,Cacimba do Meio,30,,-7.983333,-37.85
br,cacimba funda,Cacimba Funda,06,,-4.860833,-37.451667
br,cacimba grande,Cacimba Grande,20,,-5.85,-41.85
br,cacimba i,Cacimba I,13,,-3.941667,-43.041389
br,cacimba ii,Cacimba II,13,,-3.957222,-43.038333
br,cacimba nova,Cacimba Nova,06,,-5.1,-40.2
br,cacimba nova,Cacimba Nova,17,,-7.766667,-38.166667
br,cacimba nova,Cacimba Nova,30,,-8.116667,-38.8
br,cacimbao,Cacimbão,06,,-5.3,-40.95
br,cacimbao,Cacimbão,20,,-3.746944,-42.265
br,cacimbas,Cacimbas,02,,-9.516667,-37.616667
br,cacimbas,Cacimbas,05,,-12.016667,-37.683333
br,cacimbas,Cacimbas,06,,-2.85,-40.116667
br,cacimbas,Cacimbas,17,,-7.033333,-37.533333
br,cacimbas,Cacimbas,20,,-3.785,-42.008056
br,cacimbas,Cacimbas,21,,-21.65,-41.1
br,cacimbas,Cacimbas,30,,-8.066667,-35.266667
br,cacimbas dos cavalos,Cacimbas dos Cavalos,20,,-6.2,-41.333333
br,cacimba seca,Cacimba Sêca,30,,-9.033333,-38.25
br,cacimba velha,Cacimba Velha,20,,-6.9,-40.616667
br,cacimba velha,Cacimba Velha,22,,-5.1,-37.516667
br,cacimbinha,Cacimbinha,02,,-9.4,-37
br,cacimbinha,Cacimbinha,06,,-3.8,-40.2
br,cacimbinha,Cacimbinha,11,,-21.833333,-55.716667
br,cacimbinha,Cacimbinha,13,,-3.248056,-43.325
br,cacimbinha,Cacimbinha,17,,-6.65,-38.1
br,cacimbinha,Cacimbinha,20,,-7.183333,-41.3
br,cacimbinha,Cacimbinha,22,,-5.907778,-36.336667
br,cacimbinhas,Cacimbinhas,02,4618,-9.4,-37
br,cacimbinhas,Cacimbinhas,11,,-21.833333,-55.716667
br,cacimbinhas,Cacimbinhas,23,,-31.566667,-53.383333
br,cacimbo de dentro,Cacimbo de Dentro,17,,-6.65,-35.783333
br,cacimbu nova,Cacimbu Nova,17,,-6.7,-38.6
br,cacinum,Caçinum,05,,-12.683333,-38.866667
br,cacique doble,Cacique Doble,23,,-27.75,-51.616667
br,cacoal,Cacoal,04,,-4.148056,-60.548889
br,cacoal,Cacoal,13,,-1.983333,-46.216667
br,cacoal,Cacoal,24,55566,-11.5,-61.416667
br,cacoalinho,Cacoalinho,04,,-7.766667,-67.75
br,cacoci,Cacoci,06,,-6.416667,-40.5
br,cacoeirinha,Cacoeirinha,25,,3.033333,-60.433333
br,cacoeiro,Caçoeiro,18,,-25.429826,-48.427331
br,cacoes,Cações,05,,-13,-38.783333
br,cacomera,Cacomera,01,,-8.5,-71.15
br,caconda,Caconda,21,,-21.6,-41.583333
br,caconde,Caconde,27,12434,-21.55,-46.633333
br,cacozinho,Caçozinho,13,,-3.015278,-43.304444
br,cacual,Cacual,24,,-11.5,-61.416667
br,cacu,Caçu,29,10098,-18.616667,-51.066667
br,cacuia,Cacuia,21,,-22.809659,-43.19088
br,cacule,Caculé,05,12143,-14.5,-42.216667
br,cacununga,Caçununga,14,,-16.05,-53.633333
br,cacuria,Cacuriã,04,,-7.383333,-65.2
br,cadeado,Cadeado,23,,-28.566667,-53.816667
br,cadeia,Cadeia,23,,-29.7,-51.683333
br,cadete,Cadete,05,,-12.716667,-39.083333
br,cado bravo,Cado Bravo,05,,-10.733333,-40.566667
br,cadori,Cadori,26,,-27.25,-51.733333
br,cadoz,Cadoz,02,,-9.65,-35.766667
br,cadoz,Cadoz,06,,-3.616667,-41.366667
br,cadoz,Cadoz,13,,-3.444722,-42.723056
br,cadoz,Cadoz,20,,-6.033333,-41.516667
br,cadoz de baixo,Cadoz de Baixo,20,,-3.616667,-41.466667
br,cadozinho,Cadozinho,20,,-6.016667,-41.533333
br,cadu de baixo,Cadu de Baixo,05,,-13.45,-40.05
br,caem,Caém,05,,-11.1,-40.433333
br,caetano,Caetano,05,,-11.05,-39.683333
br,caetano,Caetano,06,,-3.066667,-39.55
br,caetano,Caetano,11,,-20.2,-55.266667
br,caetano,Caetano,13,,-9.566667,-45.85
br,caetano jose,Caetano José,15,,-20.266667,-44.216667
br,caetanopolis,Caetanópolis,15,,-19.3,-44.4
br,caete-acu,Caeté-Açu,05,,-12.716667,-41.483333
br,caete,Caeté,14,,-15.85,-58.283333
br,caete,Caeté,15,33232,-19.9,-43.666667
br,caete,Caeté,16,,-1.75,-48.666667
br,caete,Caetê,18,,-24.033333,-50.45
br,caete,Caeté,21,,-23.022693,-43.508827
br,caete,Caetê,27,,-23.598218,-47.067313
br,caetes,Caetés,15,,-21.813889,-43.263056
br,caetes,Caetés,30,5386,-8.766667,-36.633333
br,caetetuba,Caetetuba,27,,-23.136667,-46.643611
br,caetetu,Caetetú,20,,-5.483333,-42.983333
br,caetetu,Caetetu,27,,-23.5671,-47.8863
br,caetetu,Caetetu,31,,-11.966667,-47.266667
br,caetite,Caetité,05,27188,-14.066667,-42.483333
br,caetuba,Caetuba,27,,-23.136667,-46.643611
br,cafarnaum,Cafarnaum,05,12940,-11.7,-41.466667
br,cafeara,Cafeara,18,,-22.783333,-51.7
br,cafe,Café,08,,-20.883333,-41.566667
br,cafe,Café,15,,-19.066667,-41.866667
br,cafe,Café,18,,-23.890419,-50.185564
br,cafe,Café,27,,-20.45,-47.8
br,cafe,Café,29,,-14.516667,-49.066667
br,cafeeiros,Cafeeiros,18,,-23.75,-53.15
br,cafe jardim,Café Jardim,22,,-5.553611,-37.011111
br,cafelandia,Cafelandia,14,,-16.666667,-53.416667
br,cafelandia,Cafelândia,18,,-24.65,-53.333333
br,cafelandia,Cafelândia,21,,-21.5,-41.933333
br,cafelandia,Cafelândia,27,13777,-21.816667,-49.583333
br,cafelandia do leste matogrossense,Cafelândia do Leste Matogrossense,14,,-16.666667,-53.416667
br,cafemirim,Cafèmirim,15,,-19.316667,-41.983333
br,cafe ralo,Café Ralo,08,,-18.666667,-41
br,cafesal,Cafesal,18,,-23.883333,-53.5
br,cafesopolis,Cafesópolis,27,,-21.9,-49.75
br,cafezal,Cafèzal,13,,-3,-44.983333
br,cafezal,Cafèzal,15,,-21.316667,-46.5
br,cafezal,Cafèzal,16,,-1.55,-48.583333
br,cafezal,Cafèzal,18,,-23.883333,-53.5
br,cafezal,Cafezal,27,,-24.5923,-48.3234
br,cafezopolis,Cafezópolis,27,,-21.9,-49.75
br,cafofa,Cafofa,30,,-8.716667,-36.483333
br,cafongo,Cafongó,05,,-14.5,-39.6
br,cafuca,Cafuca,22,,-5.978333,-36.441111
br,cafufa,Cafufa,05,,-10.233333,-38.033333
br,cafuipe,Cafuipe,23,,-28.25,-54.016667
br,cafunda,Cafundá,21,,-22.9487,-43.488168
br,cafundo,Cafundó,02,,-9.433333,-36.383333
br,cafundo,Cafundó,05,,-11.233333,-42.6
br,cafundo,Cafundó,06,,-5.566667,-39.1
br,cafundo,Cafundó,13,,-3.605,-43.442778
br,cafundo,Cafundó,15,,-15.983333,-46.083333
br,cafundo,Cafundó,17,,-7.383333,-37.7
br,cafundo,Cafundo,20,,-5.85,-43.016667
br,cafundo,Cafundó,23,,-29.616667,-51.5
br,cafundo,Cafundó,27,,-21.616667,-47.716667
br,cafungo,Cafungó,05,,-14.5,-39.6
br,cafuta,Cafutá,05,,-10.233333,-38.033333
br,cagado,Cágado,02,,-8.966667,-37.783333
br,cagado,Cágado,05,,-13.116667,-39.516667
br,cagado,Cágado,13,,-5.883333,-43.966667
br,cagado,Cágado,20,,-3.474167,-42.005
br,cagado,Cágado,30,,-8.933333,-36.516667
br,cagados,Cágados,05,,-13.116667,-39.516667
br,cagados,Cágados,14,,-15.266667,-56.5
br,cagados,Cágados,20,,-5.55,-41.5
br,cahem,Cahem,05,,-11.1,-40.433333
br,cahen,Cahen,05,,-11.1,-40.433333
br,caiabu,Caiabu,27,,-22.016667,-51.233333
br,caiacanga,Caiacanga,26,,-27.716667,-48.583333
br,caiada,Caiada,22,,-6.016667,-35.633333
br,caiada de baixo,Caiada de Baixo,22,,-6.05,-35.683333
br,caiambe,Caiambé,04,,-3.566667,-64.383333
br,caiana,Caiana,13,,-3.835833,-42.829722
br,caiana,Caiana,15,,-20.7,-41.933333
br,caiana,Caiana,17,,-6.816667,-38.016667
br,caiana,Caiana,30,,-8.466667,-36.383333
br,caianana,Caianana,05,,-13.866667,-40.5
br,caiapo,Caiapó,15,,-21.683333,-42.416667
br,caiapo,Caiapó,16,,-8.338056,-50.464444
br,caiaponia,Caiapônia,29,10947,-16.95,-51.816667
br,caiary,Caiary,04,,-6.591667,-62.398889
br,caiaue,Caiaué,04,,-3.05,-65.966667
br,caibate,Caibaté,23,,-28.283333,-54.633333
br,caibe,Caibê,08,,-20.966667,-41.45
br,caibros,Caibros,17,,-6.9,-38.166667
br,cai,Caí,05,,-17,-39.183333
br,cai,Caí,23,,-29.583333,-51.383333
br,caicara,Caiçara,02,,-9.766667,-37.15
br,caicara,Caiçara,04,,-3.2,-64.833333
br,caicara,Caiçara,05,,-12.283333,-42.366667
br,caicara,Caiçara,06,,-2.866667,-40.4
br,caicara,Caiçara,15,,-17.25,-43.033333
br,caicara,Caiçara,16,,-1.15,-51.933333
br,caicara,Caiçara,17,,-6.483333,-36.416667
br,caicara,Caiçara,20,,-3.747222,-42.494444
br,caicara,Caiçara,22,,-5.066667,-36.05
br,caicara,Caiçara,23,,-27.266667,-53.416667
br,caicara,Caiçara,28,,-9.866667,-37.266667
br,caicara,Caiçara,29,,-15.566667,-50.2
br,caicara,Caicara,30,,-7.666667,-37.383333
br,caicara chico,Caicara Chico,17,,-7.4,-38.5
br,caicara de baixo,Caiçara de Baixo,05,,-10.433333,-41.616667
br,caicara de baixo,Caiçara de Baixo,17,,-6.716667,-37.65
br,caicara de baixo,Caicara de Baixo,22,,-5.883333,-35.983333
br,caicara de cima,Caiçara de Cima,17,,-6.766667,-37.616667
br,caicara do rio do vento,Caiçara do Rio do Vento,22,,-5.758889,-35.997778
br,caicara i,Caiçara I,20,,-3.270556,-42.086111
br,caicara ii,Caiçara II,20,,-3.273056,-42.046944
br,caicarinha,Caiçarinha,06,,-4.7,-39.266667
br,caicarinha,Caiçarinha,17,,-6.8,-37.816667
br,caicarinha,Caiçarinha,18,,-23.080059,-52.057597
br,caicarinha,Caicarinha,20,,-6.783333,-41.3
br,caicarinha da penha,Caiçarinha da Penha,30,,-7.833333,-38.55
br,caico,Caicó,17,,-6.733333,-37.5
br,caico,Caicó,22,54935,-6.45,-37.1
br,caida d'agua,Caida d'Agua,31,,-10.95,-47.483333
br,cai de baixo,Caí de Baixo,18,,-25.8816,-49.4394
br,cai de cima,Caí de Cima,18,,-25.856,-49.4545
br,caieira,Caieira,06,,-6.05,-38.916667
br,caieira,Caieira,13,,-4.9,-42.983333
br,caieira,Caieira,17,,-6.816667,-37.816667
br,caieira,Caieira,26,,-27.416667,-48.583333
br,caieira,Caieira,27,,-23.6439,-47.8452
br,caieira,Caieira,30,,-8.133333,-38.983333
br,caieiras,Caieiras,13,,-4.9,-42.983333
br,caieiras,Caieiras,18,,-25.8631,-48.5654
br,caieiras,Caieiras,27,87199,-23.36193,-46.740681
br,caieiras de sao pedro,Caieiras de São Pedro,22,,-5.451389,-36.587778
br,caietra,Caietra,15,,-21.216667,-43.916667
br,caimbombo,Caimbombo,05,,-12.7,-42.25
br,cainema,Cainema,05,,-13.1,-38.95
br,caioba,Caiobá,18,,-25.8395,-48.5406
br,caioca,Caioca,06,,-3.6,-40.25
br,caio prado,Caio Prado,06,,-4.666667,-38.966667
br,caipe,Caípe,05,,-12.7,-38.6
br,caipe,Caipê,08,,-20.966667,-41.45
br,caipira,Caipira,15,,-20.516667,-45.033333
br,caipora,Caipora,01,,-9.2,-72.683333
br,caipora,Caipora,30,,-8.316667,-40.566667
br,caipu,Caipu,06,,-6.633333,-39.316667
br,cairara,Cairara,06,,-5.15,-39.816667
br,cairari,Cairari,16,,-2.55,-49.116667
br,cairary,Cairary,16,,-2.55,-49.116667
br,caire,Cairé,23,,-28.116667,-53.083333
br,cairiri,Cairiri,31,,-11.888611,-49.073333
br,cairu,Cairu,04,,-7.233333,-65
br,cairu,Cairu,05,,-12.866667,-38.8
br,caisara,Caisara,04,,-4.274444,-59.409167
br,caissara,Caissara,04,,-3.2,-64.833333
br,caita,Caitá,18,,-25.783333,-50.583333
br,caitau,Caitaú,04,,-3.483333,-66.066667
br,caite,Caité,18,,-25.066667,-49.316667
br,caitete,Caiteté,05,,-14.066667,-42.483333
br,caitetu,Caitetu,02,,-9.716667,-37.266667
br,caitetu,Caitetu,05,,-9.866667,-42.583333
br,caitetu,Caitetú,20,,-5.483333,-42.983333
br,caiteuara,Caiteuara,13,,-1.683333,-45.5
br,caitinga,Caitinga,05,,-12.983333,-39.133333
br,caititu,Caititu,05,,-12.7,-41.766667
br,caititu,Caititu,06,,-6.116667,-39.616667
br,caititu,Caititu,17,,-7.15,-38.266667
br,caititu,Caititu,20,,-5.483333,-42.983333
br,caititu,Caititu,27,,-20.7,-47.366667
br,caititu,Caititu,30,,-7.966667,-38.7
br,caititu,Caititu,31,,-11.966667,-47.266667
br,caiua,Caiuá,27,,-21.883333,-51.966667
br,caiuas,Caiuás,11,,-21.8,-54.55
br,caiuba,Caiubá,18,,-25.8473,-48.5458
br,caiubi,Caiubi,05,,-15.916667,-39.883333
br,caiubi,Caiubi,27,,-22.741111,-47.471944
br,caiucara,Caiuçara,27,,-23.141667,-46.69
br,caixa da fartura,Caixa da Fartura,05,,-13.5,-39.966667
br,caixa d'agua,Caixa d'Agua,06,,-4.2,-40.466667
br,caixa d'agua,Caixa d'Agua,23,,-29.5,-54.633333
br,caixa furada,Caixa Furada,14,,-14.5,-56.183333
br,caixao,Caixão,02,,-9.3,-38.2
br,caixa prego,Caixa Prego,05,,-12.816667,-41.233333
br,caixa prego,Caixa Prego,18,,-25.466667,-52.333333
br,caixa-pregos,Caixa-Pregos,05,,-13.116667,-38.783333
br,caja,Cajá,02,,-9.666667,-36.216667
br,caja,Cajá,05,,-12.033333,-40.183333
br,caja,Cajá,06,,-5.933333,-38.6
br,caja,Cajá,17,,-7.183333,-35.383333
br,caja,Cajá,30,,-7.616667,-37.433333
br,caja de baixo,Caja de Baixo,30,,-7.516667,-37.6
br,cajaiba,Cajaíba,05,,-12.083333,-40.55
br,cajaibas,Cajaíbas,05,,-13.45,-39.1
br,cajamar,Cajamar,27,56684,-23.35,-46.883333
br,cajapio,Cajapió,22,,-2.966667,-44.8
br,cajari,Cajari,04,,-6.591667,-62.398889
br,cajari,Cajari,13,,-3.333333,-45.016667
br,cajati,Cajati,18,,-25.2,-53.166667
br,cajati,Cajati,27,27566,-24.728502,-48.110541
br,cajazeira,Cajàzeira,02,,-9.383333,-36.45
br,cajazeira,Cajàzeira,05,,-12.316667,-40.8
br,cajazeira,Cajazeira,06,,-3.3,-40.266667
br,cajazeira,Cajàzeira,13,,-5.05,-43.45
br,cajazeira,Cajázeira,17,,-7.2,-37.783333
br,cajazeira,Cajazeira,20,,-7.15,-41.6
br,cajazeira,Cajazeira,22,,-5.616667,-35.633333
br,cajazeira,Cajàzeira,30,,-8.116667,-36.4
br,cajazeiras,Cajàzeiras,05,,-10.766667,-38.433333
br,cajazeiras,Cajazeiras,06,,-3.4,-39.4
br,cajazeiras,Cajazeiras,13,,-3.117222,-42.376389
br,cajazeiras,Cajàzeiras,17,43914,-6.9,-38.566667
br,cajazeiras,Cajazeiras,20,,-3.666389,-42.586944
br,cajazeiras,Cajazeiras,22,,-6.483333,-38.1
br,cajazeiras dos lourencos,Cajàzeiras dos Lourenços,17,,-6.85,-37.916667
br,cajazeiro,Cajàzeiro,06,,-5.533333,-39.5
br,cajazeiro,Cajázeiro,17,,-7.283333,-37.7
br,cajazeiros,Cajazeiros,06,,-4.4,-40.366667
br,cajaziras,Cajaziras,06,,-7.15,-39.766667
br,cajiru,Cajiru,05,,-12.816667,-38.25
br,cajobi,Cajobi,27,,-20.883333,-48.816667
br,cajoby,Cajoby,27,,-20.883333,-48.816667
br,cajoeira,Cajoeira,16,,-5.616667,-54.45
br,cajual,Cajual,25,,-3.133333,-60.55
br,cajuapara,Cajuapara,16,,-4.283333,-47.416667
br,cajubeira,Cajubeira,20,,-3.64,-42.5525
br,cajubi,Cajubi,08,,-17.916667,-40.283333
br,cajubim,Cajubim,04,,-6.683333,-60.35
br,cajubim,Cajubim,16,,-.633333,-47.716667
br,cajubim,Cajubim,24,,-9.45,-62.633333
br,caju,Caju,04,,-3.395,-63.458889
br,caju,Caju,05,,-12.133333,-39.25
br,caju,Caju,13,,-6.066667,-43.183333
br,caju,Caju,14,,-14.366667,-56.433333
br,caju,Caju,15,,-16.35,-41.316667
br,caju,Caju,16,,-1.633333,-47.8
br,caju,Caju,21,,-22.877614,-43.21363
br,caju,Caju,25,,3.55,-59.883333
br,cajueira,Cajueira,16,,-7.8,-49.933333
br,cajueiras,Cajueiras,20,,-2.928889,-41.336111
br,cajueirinho,Cajueirinho,06,,-3.066667,-40.466667
br,cajueiro,Cajueiro,02,15063,-9.716667,-36.45
br,cajueiro,Cajueiro,05,,-10.833333,-39.433333
br,cajueiro,Cajueiro,06,,-3.866667,-40.383333
br,cajueiro,Cajueiro,13,,-2.833333,-46.566667
br,cajueiro,Cajueiro,16,,-3.233333,-51.833333
br,cajueiro,Cajueiro,17,,-7.7,-38.116667
br,cajueiro,Cajueiro,20,,-2.928889,-41.336111
br,cajueiro,Cajueiro,22,,-5.15,-35.533333
br,cajueiro,Cajueiro,24,,-10.85,-62.966667
br,cajueiro,Cajueiro,28,,-10.366667,-37.266667
br,cajueiro,Cajueiro,30,,-7.633333,-37.766667
br,cajueiro,Cajueiro,31,,-8.066667,-48.083333
br,cajueiro da estrema,Cajueiro da Estrema,05,,-17.833333,-39.266667
br,cajueiro do boi,Cajueiro do Boi,06,,-2.966667,-40.033333
br,cajueiro do sapucaia,Cajueiro do Sapucaia,02,,-9.75,-36.266667
br,cajueiros,Cajueiros,06,,-5.283333,-38.166667
br,cajui,Cajuí,05,,-10.05,-42.216667
br,cajui,Cajuí,13,,-3.715278,-43.458333
br,cajui,Cajui,17,,-6.6,-38.6
br,cajui,Cajuí,20,,-3.8725,-42.071944
br,cajuri,Cajuri,15,,-20.8,-42.8
br,cajuru,Cajuru,15,,-20.783333,-44.35
br,cajuru,Cajuru,23,,-29.25,-51.416667
br,cajuru,Cajuru,27,19540,-21.283333,-47.3
br,cajuru da cebolla,Cajuru da Cebolla,15,,-20.783333,-44.35
br,cajuru do sul,Cajuru do Sul,27,,-23.4,-47.383333
br,cajury,Cajury,15,,-20.8,-42.8
br,cajutino,Cajutino,04,,-.25,-66.766667
br,calabaca,Calabaça,06,,-6.816667,-39.233333
br,calabar,Calabar,13,,-3.354444,-43.421944
br,calabouco,Calabouço,13,,-1.866667,-44.7
br,calafibre,Calafibre,15,,-20.883333,-47.083333
br,calama,Calama,24,,-8.05,-62.883333
br,calamaque,Calamaque,04,,-.25,-64.066667
br,calambao,Calambão,15,,-20.766667,-43.2
br,calambau,Calambau,15,,-20.583333,-45.05
br,calanaque,Calanaque,04,,-.25,-64.066667
br,calcada,Calçada,05,,-12.083333,-38.033333
br,calcada,Calçada,06,,-6.066667,-40.716667
br,calcadinha,Calçadinha,18,,-24.8513,-48.5933
br,calcado,Calçado,30,,-8.7,-36.333333
br,calcados,Calçados,13,,-3.639167,-42.718333
br,cal,Cal,20,,-7.216667,-41.783333
br,calcamento,Calçamento,15,,-15.45,-44.466667
br,calcere,Calcere,05,,-14.633333,-42.816667
br,calc. muquy,Calç. Muquy,08,,-20.983333,-41.533333
br,calcoene,Calçoene,03,,2.5,-50.95
br,caldas,Caldas,06,,-7.4,-39.383333
br,caldas,Caldas,15,,-21.933333,-46.383333
br,caldas novas,Caldas Novas,29,63681,-17.75,-48.633333
br,caldeira,Caldeira,04,,-3.25,-60.25
br,caldeira,Caldeirã,20,,-8.366667,-42.6
br,caldeirao,Caldeirão,02,,-9.716667,-36.45
br,caldeirao,Caldeirão,04,,-3.25,-60.25
br,caldeirao,Caldeirão,05,,-10.2,-39.266667
br,caldeirao,Caldeirão,06,,-2.95,-40.316667
br,caldeirao,Caldeirão,13,,-3.675278,-43.448056
br,caldeirao,Caldeirão,17,,-6.966667,-38.533333
br,caldeirao,Caldeirão,20,,-4.316667,-41.716667
br,caldeirao,Caldeirão,22,,-5.666667,-35.766667
br,caldeirao,Caldeirão,24,,-9.316667,-64.583333
br,caldeirao,Caldeirão,30,,-7.733333,-37.883333
br,caldeirao da cruz,Caldeiraõ da Cruz,20,,-5.4,-41.266667
br,caldeirao da onca,Caldeirão da Onça,05,,-12.466667,-40.533333
br,caldeirao das queimadas,Caldeirão das Queimadas,05,,-13.6,-40.233333
br,caldeirao de baixo,Caldeirão de Baixo,13,,-3.961667,-43.345833
br,caldeirao de cima,Caldeirão de Cima,13,,-3.962222,-43.364722
br,caldeirao do bento,Caldeirão do Bento,05,,-12.633333,-40.266667
br,caldeirao do bravo gordo,Caldeirão do Bravo Gordo,20,,-6.266667,-41.233333
br,caldeirao do cachorro,Caldeirão do Cachorro,20,,-6.2,-40.916667
br,caldeirao do mato,Caldeirão do Mato,05,,-12.016667,-39.116667
br,caldeirao do onca,Caldeirão do Onça,05,,-12.466667,-40.533333
br,caldeirao do saco,Caldeirão do Saco,20,,-6.583333,-41.666667
br,caldeirao fejo,Caldeirão Fejo,20,,-6.333333,-40.8
br,caldeirao grande,Caldeirão Grande,05,,-11.016667,-40.283333
br,caldeirao grande,Caldeirão Grande,20,,-7.35,-40.633333
br,caldeiraosinho,Caldeirãosinho,20,,-9.166667,-42.983333
br,caldeirao verde,Caldeirão Verde,05,,-13.816667,-40.083333
br,caldeiraozinho,Caldeirãozinho,05,,-12.4,-40.833333
br,caldeiraozinho,Caldeirãozinho,20,,-7.316667,-40.666667
br,caldeiraozinho,Caldeirãozinho,30,,-7.766667,-39.65
br,caldeiras,Caldeiras,05,,-13.616667,-42.6
br,caldeiroes,Caldeirões,17,,-6.433333,-37.85
br,caldeiroes,Caldeirões,20,,-7.1,-41.5
br,caldeiroes,Caldeirões,30,,-9.233333,-36.583333
br,caldeiroes de cima,Caldeirões de Cima,02,,-9.333333,-36.65
br,calderao,Calderão,24,,-9.316667,-64.583333
br,calderoes,Calderões,30,,-9.233333,-36.583333
br,calembar,Calembar,05,,-12.666667,-38.85
br,calheiros,Calheiros,21,,-21.016667,-41.733333
br,california,Califórnia,05,,-13.883333,-39.616667
br,california,California,06,,-3.383333,-40.033333
br,california,Califórnia,08,,-20.216667,-40.6
br,california,Califórnia,13,,-3.216667,-46.766667
br,california,California,17,,-7.533333,-38.166667
br,california,Califórnia,18,,-23.633333,-51.366667
br,california,Califórnia,21,,-22.890465,-43.585594
br,california,Califórnia,22,,-5.783333,-35.4
br,california,Califórnia,27,,-21.65,-47.483333
br,calilea,Calilea,04,,-7.35,-62.933333
br,calisto,Calisto,04,,-4.680833,-59.438611
br,calisto,Calisto,31,,-11.466667,-46.75
br,calixto,Calixto,05,,-13.583333,-38.966667
br,calixto,Calixto,15,,-19.25,-41.15
br,calixto,Calixto,31,,-11.466667,-46.75
br,calmom,Calmom,26,,-26.6,-51.083333
br,calmon,Calmon,04,,-7.633333,-68.933333
br,calmon,Calmon,26,,-26.6,-51.083333
br,calogeras,Calógeras,18,,-23.983333,-49.816667
br,calogi,Calogi,08,,-20.066667,-40.433333
br,caloji,Caloji,08,,-20.066667,-40.433333
br,caloji,Caloji,15,,-20.933333,-45.066667
br,calpela do alto alegre,Calpéla do Alto Alégre,05,,-11.666667,-39.85
br,calsoene,Calsoene,03,,2.5,-50.95
br,caluc,Caluc,06,,-5.033333,-38.766667
br,calumbi,Calumbi,05,,-10.05,-39.15
br,calumbi,Calumbi,06,,-6.883333,-38.966667
br,calumbi,Calumbi,13,,-3.902222,-43.036389
br,calumbi,Calumbi,17,,-7.933333,-38.183333
br,calumbi,Calumbi,20,,-3.607778,-42.060278
br,calumbi,Calumbi,30,,-7.683333,-39.666667
br,calutino,Calutino,04,,-.25,-66.766667
br,calvario,Calvário,02,,-9.533333,-36.833333
br,camaca,Camacá,05,,-15.4,-39.5
br,camacagi,Camaçagi,05,,-10.1,-42.55
br,camacandi,Camaçandi,05,,-13.2,-39
br,camacaoca,Camacaoca,13,,-3.666667,-45.633333
br,camacari,Camaçari,02,,-10.116667,-36.283333
br,camacari,Camaçari,05,188763,-12.483333,-38.216667
br,camacari,Camaçari,13,,-5.266667,-47.366667
br,camacary,Camacary,05,,-12.683333,-38.333333
br,camacho,Camacho,15,,-20.633333,-45.166667
br,camacho,Camacho,26,,-28.616667,-48.866667
br,camacho,Camacho,27,,-22.333333,-47.216667
br,camacu,Camaçu,02,,-9.966667,-36.366667
br,cama galo,Cama Galo,06,,-6.4,-38.9
br,camaipi,Camaipi,03,,.016667,-51.933333
br,camalau,Camalaú,17,,-6.983333,-34.833333
br,camaleao,Camaleão,25,,.923056,-61.685833
br,camaleoes,Camaleões,03,,1.166667,-50.466667
br,camamu,Camamu,05,13924,-13.95,-39.116667
br,camanducaia,Camanducaia,15,17823,-22.766667,-46.15
br,camapoa,Camapoã,11,,-19.5,-54.083333
br,camapoan,Camapoan,11,,-19.5,-54.083333
br,camapua,Camapuã,11,11119,-19.5,-54.083333
br,camapua,Camapuã,15,,-20.533333,-43.983333
br,camapuan,Camapuan,11,,-19.5,-54.083333
br,camapuan,Camapuan,15,,-20.533333,-43.983333
br,camaqua,Camaquã,23,53170,-30.85,-51.816667
br,camaquam,Camaquam,11,,-19.5,-54.083333
br,camara,Camará,04,,-3.915833,-62.643056
br,camara,Camará,05,,-12.583333,-38.483333
br,camara,Camará,06,,-3.616667,-39.616667
br,camara,Camará,08,,-20.9,-41.266667
br,camara,Camará,16,,-3.033333,-55.3
br,camara,Câmara,21,,-21.4,-41.383333
br,camarada,Camarada,20,,-6.916667,-41.433333
br,camarada,Camarada,30,,-8.033333,-35.8
br,camaragibe,Camaragibe,30,148966,-8.016667,-34.966667
br,camarajibe,Camarajibe,30,,-8.016667,-34.966667
br,camarao,Camarão,02,,-9.216667,-37.766667
br,camarao,Camarão,04,,1.3,-68.716667
br,camarao,Camarão,22,,-5.942222,-36.515
br,camaratuba,Camaratuba,02,,-9.35,-36.05
br,camaratuba,Camaratuba,17,,-6.65,-35.133333
br,camaratuba,Camaratuba,30,,-8.416667,-35.85
br,camarazal,Camarazal,17,,-7.033333,-35.466667
br,camarazinho,Camarazinho,04,,-3.91,-62.691111
br,camargo,Camargo,18,,-23.35,-53.716667
br,camargo,Camargo,23,,-28.583333,-52.2
br,camargo,Camargo,27,,-20.833333,-48.75
br,camargo,Camargo,29,,-17.7,-52.3
br,camargo martins,Camargo Martins,29,,-15.8,-48.3
br,camargos,Camargos,15,,-20.266667,-43.4
br,camargos,Camargos,27,,-23.287796,-47.920502
br,camarinha,Camarinha,30,,-7.766667,-39.116667
br,camarinha d'agua,Camarinha d'Agua,30,,-7.933333,-36.533333
br,camarua,Camaruã,04,,-5.765,-64.394167
br,camaruji,Camaruji,05,,-13.516667,-39.1
br,camassandi,Camassandi,05,,-13.2,-39
br,camassari,Camassari,05,,-10.1,-42.55
br,camassary,Camassary,05,,-12.683333,-38.333333
br,camatei,Camateí,05,,-14.566667,-42.95
br,camaubau,Camaubau,22,,-5.25,-35.55
br,camauma,Camauma,04,,-5.449722,-62.853611
br,cambaiaba,Cambaiaba,21,,-21.783333,-41.25
br,cambajuva,Cambajuva,26,,-28.333333,-49.633333
br,cambaquara,Cambaquara,27,,-23.9,-45.45
br,cambara,Cambará,14,,-16.233333,-57.583333
br,cambara,Cambará,18,21380,-23.0411,-50.0741
br,cambara,Cambará,23,,-29.033333,-50.15
br,cambara,Cambará,26,,-26.910071,-49.805128
br,cambara,Cambará,27,,-21.716667,-49.016667
br,cambaras,Cambaras,14,,-16.55,-57.85
br,cambaratiba,Cambaratiba,27,,-21.716667,-49.016667
br,cambarazinho,Cambaràzinho,14,,-17.25,-57.2
br,cambaru,Cambarú,18,,-25.446563,-48.567797
br,cambauba,Cambaúba,31,,-10.833333,-47.516667
br,cambaubas,Cambaúbas,31,,-10.833333,-47.516667
br,cambe,Cambé,18,91081,-23.233333,-51.25
br,cambiasca,Cambiasca,21,,-21.716667,-41.933333
br,cambira,Cambira,18,,-23.6,-51.566667
br,cambirela,Cambirela,26,,-27.683333,-48.766667
br,cambito,Cambito,17,,-6.6,-38.516667
br,cambitos,Cambitos,30,,-7.45,-37.15
br,cambiu,Cambiú,18,,-23.864235,-50.417751
br,camboa,Camboa,06,,-3.4,-39.116667
br,camboapina,Camboapina,08,,-20.433333,-40.433333
br,camboata,Camboatá,05,,-12.4,-38.2
br,camboata,Camboatá,13,,-3.744444,-42.794167
br,camboata,Camboatá,28,,-10.683333,-37.216667
br,camboeiro,Camboeiro,20,,-6.466667,-41.783333
br,cambogue,Camboguê,05,,-12.383333,-37.966667
br,camboim,Camboim,02,,-9.366667,-36.033333
br,camboim de cima,Camboim de Cima,02,,-9.366667,-36.033333
br,camboriu,Camboriú,26,49101,-26.983333,-48.633333
br,cambota,Cambota,06,,-2.966667,-40.316667
br,cambota,Cambotá,13,,-3.448333,-42.7925
br,cambota,Cambota,21,,-22.214444,-43.683056
br,cambotas,Cambotas,13,,-3.133333,-42.75
br,cambotinha,Cambotinha,06,,-2.983333,-40.283333
br,cambuata,Cambuatá,28,,-10.683333,-37.216667
br,cambuca,Cambucá,30,,-7.833333,-35.883333
br,cambucas,Cambucás,05,,-13.933333,-41.15
br,cambuci,Cambuci,21,9395,-21.566667,-41.916667
br,cambucy,Cambucy,21,,-21.566667,-41.916667
br,cambuhy,Cambuhy,15,,-22.616667,-46.066667
br,cambui,Cambuí,05,,-10.166667,-43.283333
br,cambui,Cambuí,13,,-9.173889,-46.2
br,cambui,Cambuí,15,21247,-22.616667,-46.066667
br,cambui,Cambuí,18,,-23.864235,-50.417751
br,cambuii,Cambuíí,18,,-23.864235,-50.417751
br,cambuis,Cambuís,05,,-12.133333,-37.983333
br,cambuizal,Cambuizal,05,,-12.333333,-39.416667
br,cambuquira,Cambuquira,15,10116,-21.85,-45.3
br,cambuquira,Cambuquira,20,,-7.733333,-43.766667
br,camburi,Camburi,08,,-20.266667,-40.266667
br,camela,Camela,30,,-8.516667,-35.116667
br,cameleoes,Cameleões,03,,1.166667,-50.466667
br,camelia,Camélia,15,,-19.733333,-50.183333
br,camelleira,Camelleira,30,,-8.583333,-35.4
br,camelo,Camelo,22,,-5.682778,-36.980833
br,cameta,Cametá,04,,-6.166667,-64.233333
br,cameta,Cametá,13,,-8.983333,-46.4
br,cameta,Cametá,16,45202,-2.25,-49.5
br,cameta,Cametá,17,,-6.283333,-37.633333
br,camilo pereira,Camilo Pereira,15,,-16.85,-40.783333
br,caminas dos konkl,Caminas dos Konkl,26,,-26.1458,-49.9506
br,caminho alto,Caminho Alto,26,,-26.961235,-49.823244
br,caminho das areias,Caminho das Areias,26,,-26.9234,-49.218
br,caminho da serra,Caminho da Serra,21,,-22.839535,-43.518093
br,caminho do anum,Caminho do Anum,26,,-26.92689,-49.766712
br,caminho do job,Caminho do Job,21,,-22.819653,-43.380708
br,caminho do meio,Caminho do Meio,26,,-27.007,-49.5735
br,caminho do morro,Caminho do Morro,26,,-26.9609,-49.7951
br,caminho do pinhal,Caminho do Pinhal,26,,-26.985,-49.8624
br,caminho do posto,Caminho do Posto,26,,-26.965865,-49.689622
br,caminho dos cacadores,Caminho dos Caçadores,26,,-26.923717,-49.646533
br,caminho novo,Caminho Novo,13,,-3.8475,-42.766944
br,caminho novo,Caminho Nôvo,20,,-5.016667,-42.633333
br,caminho peroba,Caminho Peroba,26,,-27.1228,-49.7331
br,caminho tamandua,Caminho Tamanduá,26,,-27.0226,-49.6552
br,camiranga,Camiranga,16,,-1.8,-46.283333
br,camirim,Camirim,05,,-10.9,-41.6
br,camisa,Camisa,05,,-13.916667,-41.716667
br,camisao,Camisão,05,,-12.166667,-39.733333
br,camisao,Camisão,11,,-20.45,-55.716667
br,camobi,Camobi,23,,-29.7,-53.7
br,camoci,Camoci,20,,-2.916667,-41.55
br,camocim,Camocim,06,44482,-2.89,-40.846111
br,camocim,Camocim,30,,-8.35,-35.766667
br,camocim de sao felix,Camocim de São Félix,30,10270,-8.35,-35.766667
br,camocituba,Camocituba,30,,-8.35,-35.766667
br,camocochico,Camocochico,05,,-14.533333,-42.283333
br,camolengue,Camolengue,05,,-13.566667,-40.466667
br,camoroa,Camoroá,06,,-5.633333,-39.916667
br,campana,Campana,04,,-5.866111,-61.693611
br,campanario,Campanário,11,,-22.8,-55.05
br,campanario,Campanário,15,,-18.25,-41.733333
br,campanha,Campanha,11,,-21.1,-54.3
br,campanha,Campanha,13,,-3.483333,-44.45
br,campanha,Campanha,15,12507,-21.833333,-45.4
br,campanha,Campanha,21,,-22.305983,-42.80681
br,campeche,Campeche,26,,-27.666667,-48.483333
br,campeira,Campeira,13,,-9.492222,-45.931389
br,campeiro,Campeiro,11,,-21.183333,-54.75
br,campeiro,Campeiro,13,,-9.316667,-45.95
br,campelina,Campelina,05,,-13.65,-40.35
br,campelo,Campelo,13,,-4.433333,-44.7
br,campelo,Campelo,21,,-21.483333,-42.25
br,campeste,Campeste,06,,-3.35,-39.283333
br,campestre,Campestre,02,,-8.85,-35.583333
br,campestre,Campestre,05,,-12.35,-41.8
br,campestre,Campestre,06,,-4.283333,-37.966667
br,campestre,Campestre,11,,-22.216667,-56.1
br,campestre,Campestre,13,,-3.536667,-43.134722
br,campestre,Campestre,15,11802,-21.716667,-46.25
br,campestre,Campestre,17,,-7.416667,-37.716667
br,campestre,Campestre,18,,-25.05,-49.1
br,campestre,Campestre,20,,-3.826111,-42.29
br,campestre,Campestre,22,,-5.374722,-36.276111
br,campestre,Campestre,23,,-30.366667,-55.716667
br,campestre,Campestre,27,,-20.633333,-47.183333
br,campestre do biskai,Campestre do Biskai,18,,-25.7817,-49.3909
br,campestre dos borges,Campestre dos Borges,18,,-25.521053,-50.288722
br,campestre dos vieiras,Campestre dos Vieiras,18,,-25.513287,-50.295578
br,campestre grande,Campestre Grande,31,,-7.416667,-48.4
br,campestre i,Campestre I,13,,-3.8025,-42.780833
br,campestre ii,Campestre II,13,,-3.868611,-42.780278
br,campestrinho,Campestrinho,27,,-21.716667,-46.65
br,campimho,Campimho,30,,-7.783333,-37.633333
br,campina alta,Campina Alta,18,,-24.516667,-50.65
br,campina bonita,Campina Bonita,18,,-25.183333,-51.533333
br,campina,Campina,04,,-4.226111,-66.442778
br,campina,Campina,05,,-12.333333,-40.816667
br,campina,Campina,06,,-3.333333,-39.9
br,campina,Campina,13,,-7.65,-46.566667
br,campina,Campina,14,,-14.816667,-56.416667
br,campina,Campina,16,,-5.8,-48.333333
br,campina,Campina,17,,-6.766667,-38.416667
br,campina,Campina,18,,-24.3,-52.4
br,campina,Campina,23,,-27.983333,-54.85
br,campina,Campina,27,,-23.504146,-47.646744
br,campina,Campina,30,,-7.866667,-38.65
br,campina da lagoa,Campina da Lagoa,18,,-24.55,-52.716667
br,campina de pupos,Campina de Pupos,18,,-24.233333,-50.716667
br,campina do amoral,Campina do Amoral,18,,-24.3,-52.4
br,campina do monte alegre,Campina do Monte Alegre,27,,-23.583333,-48.466667
br,campina do norte,Campina do Norte,04,,-4.205556,-70.685
br,campina do paiol velho,Campina do Paiol Velho,18,,-25.4837,-50.5546
br,campina dos gomes,Campina dos Gomes,18,,-23.966667,-51.183333
br,campina dos indios,Campina dos Índios,18,,-25.966667,-52.333333
br,campina dos pupos,Campina dos Pupos,18,,-24.233333,-50.716667
br,campina do veado,Campina do Veado,27,,-24.116667,-48.9
br,campina grande,Campina Grande,03,,.183333,-51.116667
br,campina grande,Campina Grande,17,348943,-7.216667,-35.883333
br,campina grande,Campina Grande,18,,-25.3,-49.083333
br,campina grande do sul,Campina Grande do Sul,18,31112,-25.3,-49.083333
br,campinarama,Campinarama,05,,-15.25,-40.566667
br,campinarana,Campinarana,05,,-15.25,-40.566667
br,campinas belas,Campinas Belas,18,,-24.833333,-50.916667
br,campinas,Campinas,02,,-9.466667,-36.15
br,campinas,Campinas,04,,-3.283333,-61.1
br,campinas,Campinas,05,,-11.6,-41.033333
br,campinas,Campinas,06,,-5.183333,-39.083333
br,campinas,Campinas,11,,-19.016667,-56.35
br,campinas,Campinas,15,,-17.85,-43.366667
br,campinas,Campinas,16,,-5.8,-48.333333
br,campinas,Campinas,18,,-25.367941,-50.648109
br,campinas,Campinas,21,,-22.166667,-42.683333
br,campinas,Campinas,23,,-27.716667,-52.616667
br,campinas,Campinas,26,,-28.933333,-49.483333
br,campinas,Campinas,27,1031573,-22.9,-47.083333
br,campinas,Campinas,29,,-14.333333,-49.133333
br,campinas,Campinas,31,,-11.55,-47.316667
br,campinas do dias,Campinas do Dias,18,,-25.839744,-49.930653
br,campinas do piaui,Campinas do Piauí,20,,-7.65,-41.866667
br,campinas dos andrade,Campinas dos Andrade,18,,-26.0628,-49.8081
br,campinas do sul,Campinas do Sul,23,,-27.716667,-52.616667
br,campina verde,Campina Verde,15,13137,-19.516667,-49.466667
br,campina verde,Campina Verde,31,,-9.9325,-48.938333
br,campineira,Campineira,20,,-6.333333,-42.35
br,campineira i,Campineira I,13,,-3.43,-43.035278
br,camping das palmeiras,Camping das Palmeiras,26,,-26.7206,-48.6834
br,campinhas,Campinhas,05,,-11.6,-41.033333
br,campinho,Campinho,02,,-9.283333,-38.016667
br,campinho,Campinho,05,,-12.75,-41.1
br,campinho,Campinho,08,,-20.15,-40.283333
br,campinho,Campinho,13,,-1.716667,-46.216667
br,campinho,Campinho,16,,-1.533333,-52.3
br,campinho,Campinho,18,,-23.772678,-50.281099
br,campinho,Campinho,21,,-22.885594,-43.349477
br,campinho,Campinho,27,,-20.7,-47.716667
br,campinho,Campinho,30,,-7.816667,-39.1
br,campinho dos cavalos,Campinho dos Cavalos,20,,-3.951111,-42.576389
br,campinhos,Campinhos,05,,-12.416667,-38.783333
br,campinhos,Campinhos,30,,-8.933333,-38.516667
br,campininha,Campininha,27,,-23.23433,-47.878477
br,campinorte,Campinorte,29,,-14.333333,-49.133333
br,campins,Campins,20,,-6.183333,-41.8
br,campista,Campista,27,,-22.673911,-45.594034
br,campo alegra,Campo Alegra,31,,-10.7,-47.466667
br,campo alegre,Campo Alegre,02,16786,-9.8,-36.35
br,campo alegre,Campo Alegre,04,,-5.65,-61.033333
br,campo alegre,Campo Alegre,05,,-11.966667,-39.883333
br,campo alegre,Campo Alegre,06,,-5.65,-38.65
br,campo alegre,Campo Alegre,11,,-18.5,-56.5
br,campo alegre,Campo Alegre,13,,-5.283333,-46.366667
br,campo alegre,Campo Alegre,14,,-15.6,-56.6
br,campo alegre,Campo Alegre,15,,-15.583333,-44.1
br,campo alegre,Campo Alegre,18,,-23.368766,-49.822309
br,campo alegre,Campo Alegre,20,,-6.633333,-42.533333
br,campo alegre,Campo Alegre,21,,-22.2939,-44.4824
br,campo alegre,Campo Alegre,23,,-27.633333,-54.633333
br,campo alegre,Campo Alegre,26,,-26.1928,-49.2532
br,campo alegre,Campo Alegre,27,,-20.783333,-47.283333
br,campo alegre,Campo Alegre,29,,-18.566667,-51.95
br,campo alegre,Campo Alegre,30,,-7.816667,-38.933333
br,campo alegre,Campo Alegre,31,,-10.7,-47.466667
br,campo alegre de goias,Campo Alegre de Goiás,29,,-17.65,-47.75
br,campo alegre do mosquito,Campo Alegre do Mosquito,02,,-9.8,-36.35
br,campo alto,Campo Alto,26,,-26.75,-50.4
br,campo alto,Campo Alto,27,,-22.033333,-47.333333
br,campo arado,Campo Arado,14,,-15.766667,-55.4
br,campo azul,Campo Azul,15,,-16.504167,-44.808889
br,campo bello,Campo Bello,06,,-4.1,-39.05
br,campo bello,Campo Bello,15,,-20.883333,-45.266667
br,campo bello,Campo Bello,21,,-22.5,-44.566667
br,campo bello,Campo Bello,26,,-27.9,-50.75
br,campo belo,Campo Belo,03,,1.25,-50.8
br,campo belo,Campo Belo,15,,-16.504167,-44.808889
br,campo belo,Campo Belo,21,,-22.5,-44.566667
br,campo belo,Campo Belo,26,,-27.9,-50.75
br,campo belo do sul,Campo Belo do Sul,26,,-27.9,-50.75
br,campo bom,Campo Bom,23,54762,-29.683333,-51.05
br,campo bonito,Campo Bonito,18,,-25.016667,-52.983333
br,campo,Campo,11,,-20.483333,-56.133333
br,campo,Campo,13,,-5,-43.466667
br,campo,Campo,16,,-.866667,-46.866667
br,campo,Campo,25,,.803056,-61.660833
br,campo,Campo,27,,-21.383333,-47.05
br,campo comprido,Campo Comprido,13,,-3.966667,-42.884444
br,campo comprido,Campo Comprido,16,,-7.5,-57.5
br,campo comprido,Campo Comprido,17,,-6.516667,-36.133333
br,campo comprido,Campo Comprido,18,,-25.416667,-49.316667
br,campo comprido,Campo Comprido,20,,-3.746667,-42.566389
br,campo da bocaina,Campo da Bocaina,15,,-22.283333,-46.1
br,campo da lanca,Campo da Lança,26,,-26.1931,-49.8292
br,campo das flores,Campo das Flores,15,,-20.45,-46.3
br,campo de cima,Campo de Cima,05,,-10.683333,-44.416667
br,campo de diauarum,Campo de Diauarum,14,,-11.2,-53.233333
br,campo de fora,Campo de Fora,17,,-7.05,-37.866667
br,campo de pouso,Campo de Pouso,20,,-7.766667,-42.25
br,campo de pouso,Campo de Pouso,23,,-32.0995,-52.606
br,campo de sao cristovao,Campo de São Cristóvão,21,,-22.899292,-43.214988
br,campo de sao marcos,Campo de São Marcos,21,,-22.886555,-43.680647
br,campo de sementes,Campo de Sementes,22,,-5.066667,-37.4
br,campo do atanasio,Campo do Atanásio,27,,-22.933333,-45.383333
br,campo do baio,Campo do Baio,18,,-25.755321,-50.00932
br,campo do barreira,Campo do Barreira,16,,-9.3,-50.1
br,campo do brito,Campo do Brito,28,8011,-10.75,-37.5
br,campo do bugre,Campo do Bugre,18,,-25.45,-52.483333
br,campo do caju,Campo do Caju,15,,-20.633333,-45.116667
br,campo do careta,Campo do Careta,20,,-6.166667,-42.3
br,campo do cocho,Campo do Cocho,27,,-22.416667,-47.633333
br,campo do coelho,Campo do Coelho,21,,-22.25,-42.65
br,campo do coxo,Campo do Coxo,27,,-22.416667,-47.633333
br,campo do crioulo,Campo do Crioulo,28,,-10.966667,-37.766667
br,campo do cupinharol,Campo do Cupinharol,20,,-6.883333,-42.683333
br,campo do meio,Campo do Meio,05,,-10.466667,-40.166667
br,campo do meio,Campo do Meio,15,,-20.266667,-46.383333
br,campo do meio,Campo do Meio,23,,-28.316667,-52.05
br,campo do meio,Campo do Meio,27,,-23.5689,-47.7141
br,campo do monteiro,Campo do Monteiro,27,,-22.7081,-45.7256
br,campo do muro,Campo do Muro,17,,-6.883333,-36.25
br,campo do pires,Campo do Pires,15,,-20.0137,-43.8522
br,campo dora,Campo Dora,11,,-18.916667,-56.65
br,campo dos afonsos,Campo dos Afonsos,21,,-22.879221,-43.391562
br,campo do sampaio,Campo do Sampaio,15,,-18.066667,-43.85
br,campo dos bois,Campo dos Bois,14,,-16.583333,-57.05
br,campo dos cavalos,Campo dos Cavalos,05,,-9.566667,-40.65
br,campo dos pintos,Campo dos Pintos,26,,-26.4,-50.833333
br,campo do tenente,Campo do Tenente,18,,-25.979444,-49.681944
br,campo ere,Campo Erê,26,,-26.383333,-53.05
br,campo esperanca,Campo Esperança,01,,-10.416667,-67.633333
br,campo faxinal,Campo Faxinal,26,,-26.383333,-53.05
br,campo fechado,Campo Fechado,18,,-25.3,-51.75
br,campo florido,Campo Florido,15,,-19.783333,-48.583333
br,campo formosa,Campo Formosa,05,,-15.016667,-41.116667
br,campo formosa,Campo Formosa,29,,-17.05,-48.3
br,campo formoso,Campo Formoso,05,23921,-10.516667,-40.333333
br,campo formoso,Campo Formoso,11,,-19.433333,-55.25
br,campo formoso,Campo Formoso,15,,-19.783333,-48.583333
br,campo formoso,Campo Formoso,29,,-17.05,-48.3
br,campo frio,Campo Frio,05,,-14.483333,-43.383333
br,campo grande,Campo Grande,02,3054,-10.233333,-36.5
br,campo grande,Campo Grande,04,,-8.75,-59.266667
br,campo grande,Campo Grande,05,,-12.516667,-39.65
br,campo grande,Campo Grande,06,,-3.65,-40.05
br,campo grande,Campo Grande,08,,-20.35,-40.4
br,campo grande,Campo Grande,11,729164,-20.45,-54.616667
br,campo grande,Campo Grande,13,,-3.663056,-42.726111
br,campo grande,Campo Grande,14,,-16.166667,-56.266667
br,campo grande,Campo Grande,15,,-15.533333,-41.5
br,campo grande,Campo Grande,17,,-6.966667,-36.983333
br,campo grande,Campo Grande,18,,-25.057993,-48.958651
br,campo grande,Campo Grande,20,,-3.752222,-42.5875
br,campo grande,Campo Grande,21,,-22.906675,-43.552896
br,campo grande,Campo Grande,27,,-23.966667,-46.35
br,campo grande,Campo Grande,28,,-10.566667,-37.2
br,campo grande,Campo Grande,30,,-8.666667,-38.633333
br,campo grave,Campo Grave,06,,-5.283333,-38.75
br,campo largo,Campo Largo,05,,-10.4,-41.416667
br,campo largo,Campo Largo,13,,-6.383333,-44.983333
br,campo largo,Campo Largo,16,,-2.05,-49.616667
br,campo largo,Campo Largo,18,94669,-25.433333,-49.533333
br,campo largo,Campo Largo,20,,-3.833333,-42.65
br,campo largo,Campo Largo,27,,-23.190278,-46.702778
br,campo largo da roseira,Campo Largo da Roseira,18,,-25.7,-49.166667
br,campolide,Campolide,05,,-13.916667,-39.616667
br,campolide,Campolide,15,,-21.6,-43.883333
br,campo limpa,Campo Limpa,15,,-21.466667,-42.516667
br,campo limpo,Campo Limpo,05,,-10.133333,-42.116667
br,campo limpo,Campo Limpo,06,,-4.9,-40.283333
br,campo limpo,Campo Limpo,11,,-17.933333,-54.633333
br,campo limpo,Campo Limpo,14,,-15.366667,-55.25
br,campo limpo,Campo Limpo,21,,-22.310428,-42.912765
br,campo limpo,Campo Limpo,27,,-20.733333,-47.2
br,campo limpo,Campo Limpo,29,,-15.85,-48.283333
br,campo lindo,Campo Lindo,29,,-16.283333,-49.083333
br,campo magro,Campo Magro,18,,-25.35,-49.45
br,campo maior,Campo Maior,20,31740,-4.816667,-42.166667
br,campo maje,Campo Majé,30,,-8.516667,-36.75
br,campo mistico,Campo Místico,15,,-22.45,-46.35
br,campo mourao,Campo Mourão,18,,-24.05,-52.366667
br,campo mystico,Campo Mystico,15,,-22.45,-46.35
br,camponeza,Camponeza,20,,-6.483333,-41.3
br,campo novo,Campo Novo,06,,-3.816667,-40.233333
br,campo novo,Campo Novo,08,,-21.083333,-40.95
br,campo novo,Campo Novo,11,,-19.4,-57.616667
br,campo novo,Campo Novo,13,,-4.7,-45.9
br,campo novo,Campo Novo,14,,-15.9,-54.433333
br,campo novo,Campo Novo,15,,-17.9,-41.166667
br,campo novo,Campo Nôvo,17,,-6.816667,-36.25
br,campo novo,Campo Novo,18,,-25.116667,-49.116667
br,campo novo,Campo Novo,23,,-27.7,-53.8
br,campo novo,Campo Novo,26,,-26.0723,-49.8498
br,campo pequeno,Campo Pequeno,28,,-11.116667,-37.916667
br,campo real,Campo Real,18,,-25.45,-51.8
br,campo real,Campo Real,21,,-22.937244,-43.572851
br,campo redondo,Campo Redondo,13,,-3.703889,-43.378333
br,campo redondo,Campo Redondo,15,,-15.633333,-44
br,campo redondo,Campo Redondo,20,,-3.898056,-42.326111
br,campo redondo,Campo Redondo,22,,-6.233333,-36.183333
br,campo redondo,Campo Redondo,27,,-22.35,-47.983333
br,campos altos,Campos Altos,15,12648,-19.683333,-46.166667
br,campo santana,Campo Santana,01,,-8.3,-72.716667
br,campo santo,Campo Santo,05,,-12.995,-38.513333
br,campo santo,Campo Santo,30,,-8.966667,-36.533333
br,campos bellos,Campos Bellos,05,,-15.033333,-41.266667
br,campos bellos,Campos Bellos,29,,-13.05,-46.883333
br,campos belos,Campos Belos,06,,-4.1,-39.05
br,campos belos,Campos Belos,29,15583,-13.05,-46.883333
br,campos borges,Campos Borges,23,,-28.883333,-53
br,campos,Campos,05,,-12.283333,-39.033333
br,campos,Campos,06,,-4.566667,-39.35
br,campos,Campos,15,,-19.35,-45.933333
br,campos,Campos,20,,-3.183333,-41.5
br,campos,Campos,21,387422,-21.75,-41.3
br,campos,Campos,22,,-5.883333,-37.783333
br,campos,Campos,23,,-31.466667,-52.666667
br,campos,Campos,28,,-11.183333,-38.016667
br,campos,Campos,30,,-8.05,-36.45
br,campos da cantareira,Campos da Cantareira,27,,-23.378283,-46.643201
br,campos de cunha,Campos de Cunha,27,,-22.916667,-44.816667
br,campos de mairipora,Campos de Mairiporã,27,,-23.330821,-46.628445
br,campos de membeca,Campos de Membeca,21,,-22.4259,-44.4842
br,campos de sao benedito,Campos de São Benedito,27,,-23.309114,-46.653594
br,campos do jordao,Campos do Jordão,27,53320,-22.7264,-45.5792
br,campos do meio,Campos do Meio,15,,-21.116667,-45.833333
br,campos dos goitacazes,Campos dos Goitacazes,21,,-21.75,-41.3
br,campos eliseos,Campos Elíseos,11,,-20.95,-53.283333
br,campos elisios,Campos Elisios,11,,-20.95,-53.283333
br,campos elisios,Campos Elísios,21,,-22.4548,-44.4377
br,campos elyseos,Campos Elyseos,21,,-22.704444,-43.266111
br,campos geraes,Campos Geraes,15,,-21.233333,-45.766667
br,campos gerais,Campos Gerais,15,22260,-21.233333,-45.766667
br,campos lindos,Campos Lindos,31,,-7.996111,-46.706389
br,campos novas,Campos Novas,28,,-9.6,-38.033333
br,campos novos,Campos Novos,13,,-3.770278,-43.369722
br,campos novos,Campos Novos,18,,-25.45,-52.916667
br,campos novos,Campos Novos,21,,-22.7,-42.033333
br,campos novos,Campos Novos,22,,-5.431389,-36.559722
br,campos novos,Campos Novos,23,,-27.7,-53.8
br,campos novos,Campos Novos,26,22563,-27.4,-51.2
br,campos novos,Campos Novos,27,,-22.6,-50.016667
br,campos novos,Campos Novos,28,,-9.6,-38.033333
br,campos novos,Campos Novos,30,,-7.6,-37.466667
br,campos novos da cunha,Campos Novos da Cunha,27,,-22.916667,-44.816667
br,campos novos de cunha,Campos Novos de Cunha,27,,-22.916667,-44.816667
br,campos novos do paranapanema,Campos Novos do Paranapanema,27,,-22.6,-50.016667
br,campos novos paulista,Campos Novos Paulista,27,,-22.6,-50.016667
br,campos sales,Campos Sales,05,,-14.75,-40.533333
br,campos sales,Campos Sales,06,17648,-7.066667,-40.383333
br,campos sales,Campos Sales,20,,-4.016667,-42.083333
br,campos salles,Campos Salles,06,,-7.066667,-40.383333
br,campos segundo,Campos Segundo,20,,-6.316667,-41.916667
br,campo sujo,Campo Sujo,30,,-8.916667,-36.7
br,campos velhos,Campos Velhos,06,,-5.516667,-38
br,campo verde,Campo Verde,03,,.9,-51.633333
br,campo verde,Campo Verde,05,,-12.7,-39.316667
br,campo verde,Campo Verde,11,22842,-20.416667,-54.066667
br,campo verde,Campo Verde,17,,-7.55,-36.15
br,campo verde,Campo Verde,20,,-7.25,-40.75
br,campo vicente,Campo Vicente,23,,-29.633333,-50.9
br,camuca,Camuca,17,,-6.8,-35.6
br,camurcim,Camurcim,01,,-8.992222,-71.583333
br,camurim,Camurim,22,,-5.354444,-37.462778
br,camurugi,Camurugi,05,,-13.516667,-39.1
br,camurupim,Camurupim,20,,-3.083333,-41.45
br,camurupim,Camurupim,22,,-5.18,-36.323611
br,camurupim de baixo,Camurupim de Baixo,20,,-2.924167,-41.467778
br,camurupim de cima,Camurupim de Cima,20,,-3.083333,-41.45
br,camuscada,Camuscada,05,,-10.033333,-42.633333
br,camutanga,Camutanga,30,,-7.416667,-35.283333
br,camuti,Camuti,16,,-3.65,-56.55
br,camuxinga,Camuxinga,02,,-9.3,-37.216667
br,camuxinga de cima,Camuxinga de Cima,02,,-9.3,-37.216667
br,canaa,Canaã,04,,-4.134722,-60.964722
br,canaa,Canaã,06,,-3.216667,-39.366667
br,canaa,Canaã,15,,-20.683333,-42.616667
br,canaa,Canaã,17,,-6.516667,-38.416667
br,canaa,Canaã,22,,-5.18,-37.195278
br,canaa,Canaã,27,,-21.533333,-47.683333
br,canaa,Canaã,30,,-8.4,-36.783333
br,canaan,Canaán,06,,-5.833333,-39.6
br,canaan,Canaan,27,,-21.533333,-47.683333
br,canabarro,Canabarro,23,,-29.2,-52.033333
br,cana-brava,Cana-Brava,02,,-9.633333,-36.483333
br,canabrava,Canabrava,05,,-10.666667,-40.816667
br,cana brava,Cana Brava,05,,-12.05,-43.1
br,canabrava,Canabrava,05,,-12.116667,-43.9
br,cana brava,Cana Brava,05,,-13.3,-43.983333
br,canabrava,Canabrava,05,,-13.65,-41.583333
br,cana brava,Cana Brava,05,,-13.866667,-42.7
br,canabrava,Canabrava,05,,-9.75,-39.616667
br,cana brava,Cana Brava,05,,-9.783333,-38.316667
br,canabrava,Canabrava,06,,-6.433333,-40.716667
br,cana brava,Cana Brava,06,,-6.55,-40.616667
br,cana brava,Cana Brava,13,,-3.080556,-42.228333
br,cana-brava,Cana-Brava,13,,-6.283333,-42.983333
br,canabrava,Canabrava,15,,-16.316667,-43.416667
br,cana-brava,Cana-Brava,20,,-10.1,-45.183333
br,cana brava,Cana Brava,20,,-5.133333,-41.15
br,cana brava,Cana Brava,22,,-5.316667,-35.583333
br,cana brava,Cana Brava,28,,-10.416667,-37.216667
br,canabrava,Canabrava,28,,-9.583333,-37.983333
br,cana brava,Cana Brava,30,,-7.5,-39.833333
br,canabrava,Canabrava,30,,-8.666667,-39.183333
br,cana brava,Cana Brava,31,,-12.900833,-46.765833
br,canabrava da cruz,Canabrava da Cruz,05,,-12.183333,-38.716667
br,canabrava de santa teresa de jesus dos quiriris,Canabrava de Santa Teresa de Jesus dos Quiriris,05,,-10.833333,-38.533333
br,canabrava do boqueirao,Canabrava do Boqueirão,05,,-12.05,-43.1
br,canabrava do braga,Canabrava do Braga,05,,-12.216667,-43.1
br,canabrava do goncalo,Canabrava do Gonçalo,05,,-11.333333,-42.133333
br,canabrava do miranda,Canabrava do Miranda,05,,-11.683333,-41.766667
br,canabrava dos caldeiras,Canabrava dos Caldeiras,05,,-13.616667,-42.6
br,canabrava dos martins,Canabrava dos Martins,05,,-12.2,-41.683333
br,cana brava dos pais,Cana Brava dos Pais,02,,-9.633333,-36.483333
br,cana brava grande,Cana Brava Grande,06,,-7.516667,-38.783333
br,cana brava ii,Cana Brava II,13,,-3.0775,-42.280556
br,cana brava iii,Cana Brava III,13,,-3.205,-42.193333
br,canabravao,Canabravão,05,,-12.416667,-44.866667
br,canabravinha,Canabravinha,05,,-13.533333,-42.166667
br,cana bravinha,Cana Bravinha,06,,-7.616667,-38.733333
br,cana,Cana,06,,-6.266667,-40.65
br,cana,Cana,13,,-6.65,-42.916667
br,canaci,Canaci,05,,-13.5,-41.116667
br,canacuri,Canacuri,04,,-7.816667,-67.133333
br,canada,Canadá,05,,-12.283333,-40.433333
br,canada,Canada,06,,-4.2,-38.85
br,canada,Canadá,13,,-1.65,-44.9
br,cana do reino,Cana do Reino,15,,-21.783333,-45.833333
br,canafistinha,Canafistinha,06,,-2.933333,-40.283333
br,canafistula,Canafístula,02,,-9.4,-36.7
br,canafistula,Canafístula,05,,-12.433333,-43.283333
br,canafistula,Canafistula,06,,-3.966667,-39.233333
br,canafistula,Canafístula,13,,-3.866944,-43.468611
br,canafistula,Canafístula,17,,-6.983333,-35.566667
br,canafistula,Canafístula,20,,-3.897222,-42.277778
br,canafistula,Canafístula,22,,-5.380833,-36.533611
br,canafistula,Canafistula,30,,-7.883333,-37.5
br,canafistulas,Canafístulas,02,,-9.4,-36.7
br,canaguape,Canaguapé,04,,-6.964167,-71.414167
br,canaiba,Canaíba,05,,-14.033333,-42.783333
br,canais,Canais,05,,-11.833333,-41.583333
br,canal,Canal,05,,-11.35,-41.666667
br,canal de sao simao,Canal de São Simão,29,,-18.933333,-50.5
br,canama,Canamã,04,,-5.616667,-72.1
br,canamari,Canamari,01,,-10.133333,-69.266667
br,cananea,Cananéa,13,,-4.516667,-44.35
br,cananea,Cananéa,27,,-25.016667,-47.95
br,cananeia,Cananéia,13,,-4.516667,-44.35
br,cananeia,Cananéia,20,,-7.333333,-41.766667
br,cananeia,Cananéia,26,,-26.845,-49.021
br,cananeia,Cananéia,27,13786,-25.016667,-47.95
br,canapi,Canapi,02,4219,-9.133333,-37.5
br,canapolis,Canápolis,15,,-18.733333,-49.216667
br,canarama,Canarama,24,,-10.666667,-62.65
br,canarana,Canarana,05,10785,-11.683333,-41.766667
br,canarana,Canarana,13,,-4.45,-44.533333
br,canarias,Canárias,13,,-2.766944,-41.850833
br,canario,Canário,24,,-12.3125,-60.6375
br,canas,Canas,15,,-14.95,-42.7
br,canas,Canas,27,,-22.716667,-45.05
br,canastra,Canastra,02,,-8.933333,-35.85
br,canastra,Canastra,05,,-11.816667,-42.233333
br,canastrao,Canastrão,15,,-18.566667,-45.75
br,canasvieiras,Canasvieiras,26,,-27.433333,-48.5
br,canatiba,Canatiba,05,,-13.083333,-42.866667
br,canauani,Canauani,25,,2.8,-60.533333
br,canavani,Canavani,25,,2.8,-60.533333
br,cana verde,Cana Verde,15,,-21.016667,-45.183333
br,canavial,Canavial,04,,-2.75,-67.633333
br,canavial,Canavial,23,,-27.533333,-51.983333
br,canavieira,Canavieira,05,,-10.916667,-40.65
br,canavieira,Canavieira,20,,-7.066667,-41.883333
br,canavieiras,Canavieiras,05,26376,-15.65,-38.95
br,canavieiras,Canavieiras,18,,-25.6572,-48.8132
br,canca,Cancã,18,,-24.583333,-52.183333
br,cancela,Cancela,06,,-4.783333,-40.016667
br,cancela,Cancela,13,,-3.1,-42.978611
br,cancela,Cancela,14,,-14.716667,-56.283333
br,cancela,Cancela,15,,-16.316667,-42.716667
br,cancelao,Cancelão,23,,-31.383333,-53.116667
br,cancela preta,Cancela Preta,21,,-22.849816,-43.456318
br,canche,Canché,05,,-9.883333,-38.9
br,candeal,Candeal,05,,-11.816667,-39.116667
br,candeeiro,Candeeiro,20,,-3.505,-42.364722
br,candeia,Candeia,05,,-17.233333,-39.666667
br,candeia,Candeia,22,,-6.116667,-37.833333
br,candeia,Candeia,23,,-28.25,-51.55
br,candeia de baixo,Candeia de Baixo,06,,-4.283333,-38.85
br,candeial,Candeial,05,,-15.016667,-41.933333
br,candeias,Candeias,05,75673,-12.666667,-38.55
br,candeias,Candeias,13,,-3.101389,-42.092222
br,candeias,Candeias,15,,-20.783333,-45.266667
br,candeias,Candeias,30,,-8.233333,-34.933333
br,candeiras,Candeiras,05,,-12.583333,-39.366667
br,candelaria,Candelaria,15,,-22.5814,-45.6351
br,candelaria,Candelária,21,,-22.901199,-43.17823
br,candelaria,Candelária,23,15200,-29.666667,-52.8
br,candia,Cândia,27,,-20.9,-47.983333
br,candial,Candial,05,,-11.95,-42.3
br,candiba,Candiba,05,,-14.4,-42.866667
br,candido,Cândido,06,,-4.8,-39.383333
br,candido de abreu,Cândido de Abreu,18,5102,-24.583333,-51.333333
br,candido godoi,Cândido Godói,23,,-27.95,-54.766667
br,candido mendes,Cândido Mendes,13,8613,-1.45,-45.716667
br,candido mota,Cândido Mota,27,28145,-22.716667,-50.383333
br,candido motta,Candido Motta,27,,-22.716667,-50.383333
br,candido ramalho,Cândido Ramalho,15,,-17.033333,-41.983333
br,candido rodrigues,Cândido Rodrigues,27,,-21.333333,-48.633333
br,candiota,Candiota,23,,-31.6,-53.733333
br,candoca velha,Candoca Velha,16,,-6.95,-53.533333
br,candoi,Candói,18,,-25.716667,-52.183333
br,candomba,Candomba,05,,-14.133333,-40.6
br,candonga,Candonga,18,,-25.5855,-48.8042
br,candoso,Candoso,11,,-20.65,-57.65
br,candoy,Candoy,18,,-25.716667,-52.183333
br,candumba,Candumba,14,,-16.183333,-56.566667
br,canea,Canea,16,,-1.85,-54.933333
br,caneapo,Canéapo,16,,1.566667,-54.766667
br,caneiras,Caneiras,30,,-7.583333,-35.216667
br,canela,Canela,20,,-3.786667,-42.409167
br,canela,Canela,23,33529,-29.366667,-50.833333
br,canela,Canela,30,,-8.8,-37.366667
br,canela,Canela,31,,-10.22,-48.411111
br,canela da ema,Canela da Ema,20,,-6.883333,-41.25
br,canela de ema,Canela de Ema,05,,-14.2,-41.866667
br,canela oca,Canela Oca,27,,-24.9051,-48.021
br,canelinha,Canelinha,18,,-25.246487,-48.918742
br,canelinha,Canelinha,26,,-27.283333,-48.783333
br,canella,Canella,23,,-29.366667,-50.833333
br,canga,Canga,05,,-17.283333,-40.183333
br,canga,Canga,14,,-16.077222,-56.570556
br,cangaira,Cangaira,22,,-6.033333,-37.5
br,cangalha,Cangalha,11,,-19.55,-52.8
br,cangalha,Cangalha,15,,-17.666667,-47.183333
br,cangalha,Cangalha,30,,-7.433333,-37.083333
br,cangalhas,Cangalhas,15,,-17.666667,-47.183333
br,cangas,Cangas,14,,-16.077222,-56.570556
br,cangati,Cangati,06,,-5.433333,-39.183333
br,cangaty,Cangaty,06,,-5.566667,-38.983333
br,cangau,Cangaú,30,,-9.133333,-36.316667
br,cangica,Cangica,13,,-7.966667,-46.95
br,cangicas,Cangicas,27,,-23.271361,-46.599856
br,cangonhal,Cangonhal,15,,-21.933333,-45.816667
br,cangoritgo,Cangoritgo,05,,-11.95,-37.7
br,cangote,Cangote,13,,-3.733333,-44.966667
br,canguaretama,Canguaretama,22,18873,-6.383333,-35.133333
br,cangucu,Canguçu,23,20134,-31.4,-52.683333
br,cangueira,Cangueira,18,,-25.066667,-50.5
br,canguera,Canguera,27,,-23.5028,-47.7089
br,canguinha,Canguinha,14,,-14.7,-55.666667
br,canguinho,Canguinho,14,,-14.7,-55.666667
br,cangussu,Cangussú,23,,-31.4,-52.683333
br,canhoba,Canhoba,28,,-10.133333,-36.95
br,canhoe,Canhoé,04,,-6.041389,-63.372222
br,canhotinho,Canhotinho,06,,-5.35,-39.266667
br,canhotinho,Canhotinho,30,12074,-8.883333,-36.2
br,canhuma,Canhumã,04,,-3.916667,-59.15
br,canicora,Canicorã,11,,-21.616667,-55.416667
br,canicura,Canicurã,11,,-21.616667,-55.416667
br,caninae,Caninae,06,,-4.366667,-39.316667
br,caninana,Caninana,14,,-16.233333,-57.583333
br,caninde,Canindé,04,,-3.6375,-62.998611
br,caninde,Canindé,06,42721,-4.366667,-39.316667
br,caninde,Canindé,16,,-2.566667,-46.516667
br,caninde,Canindé,20,,-6.966667,-40.916667
br,caninde,Canindé,28,,-9.65,-37.8
br,caninde de sao francisco,Canindé de São Francisco,28,11053,-9.65,-37.8
br,canindezinho,Canindézinho,06,,-5.8,-38.2
br,canindezinho,Canindézinho,22,,-6.233333,-38.533333
br,caninha branca,Caninha Branca,15,,-20.116667,-41.55
br,caninha,Caninha,20,,-7.066667,-40.783333
br,canitar,Canitar,27,,-23.006204,-49.783344
br,canivete,Canivete,02,,-9.316667,-37.266667
br,canjarana,Canjarana,31,,-10.866667,-46.35
br,canjerana,Canjerana,31,,-10.866667,-46.35
br,canjica,Canjica,13,,-7.966667,-46.95
br,canjica,Canjica,15,,-17.983333,-43.466667
br,canjicas,Canjicas,15,,-17.983333,-43.466667
br,canna brava,Canna Brava,02,,-9.633333,-36.483333
br,canna brava,Canna Brava,05,,-10.833333,-38.533333
br,cannabrava,Cannabrava,05,,-13.616667,-42.6
br,canna brava,Canna Brava,05,,-9.2,-39.7
br,cannabrava,Cannabrava,15,,-17.4,-45.85
br,cannabrava,Cannabrava,30,,-7.5,-39.833333
br,canna brava do miranda,Canna Brava do Miranda,05,,-11.683333,-41.766667
br,cannabrava dos goncalves,Cannabrava dos Gonçalves,05,,-11.333333,-42.133333
br,canna,Canna,20,,-6.766667,-43.133333
br,cannarias,Cannarias,13,,-2.766944,-41.850833
br,cannasvieiras,Cannasvieiras,26,,-27.433333,-48.5
br,canna verde,Canna Verde,15,,-21.016667,-45.183333
br,cannavieiras,Cannavieiras,05,,-15.65,-38.95
br,canoa,Canôa,05,,-10.4,-40.116667
br,canoa,Canoa,13,,-5.283333,-43.083333
br,canoa,Canoã,14,,-14.55,-56.866667
br,canoa,Canoa,17,,-7.2,-38.116667
br,canoa grande,Canoa Grande,13,,-5.366667,-46.016667
br,canoana,Canoanã,31,,-11.927778,-49.899722
br,canoao,Canoão,05,,-11.516667,-42.016667
br,canoa quebrada,Canoa Quebrada,06,,-4.516667,-37.683333
br,canoas,Canoas,05,,-12.35,-37.883333
br,canoas,Canoas,15,,-16.37,-44.784722
br,canoas,Canoas,17,,-6.533333,-35.966667
br,canoas,Canoas,18,,-24.7755,-48.956055
br,canoas,Canoas,21,,-22.3972,-42.883849
br,canoas,Canoas,23,328297,-29.933333,-51.183333
br,canoas,Canoas,26,,-27.566667,-50.4
br,canoeira,Canoeira,14,,-16.9,-55.95
br,canoeiro,Canoeiro,18,,-25.803112,-50.187881
br,canoeiros,Canoeiros,15,,-18.033333,-45.516667
br,canoinhas,Canoinhas,18,,-24.016667,-49.95
br,canoinhas,Canoinhas,26,38863,-26.166667,-50.4
br,cansancao,Cansanção,05,9905,-10.683333,-39.516667
br,cansancao,Cansanção,20,,-7.083333,-40.966667
br,cansa-perna,Cansa-Perna,16,,-1.766667,-46.616667
br,cantagallo,Cantagallo,21,,-21.966667,-42.366667
br,canta-galo,Canta-Galo,04,,-4.448611,-58.114722
br,cantagalo,Cantagalo,04,,-8.233333,-60.7
br,canta-galo,Canta-Galo,04,,-8.35,-58.783333
br,cantagalo,Cantagalo,06,,-4.25,-38.683333
br,canta galo,Canta Galo,11,,-17.7,-56.016667
br,canta galo,Canta Galo,14,,-14.65,-57.216667
br,cantagalo,Cantagalo,15,,-18.533333,-42.616667
br,cantagalo,Cantagalo,18,,-25.111693,-48.898233
br,cantagalo,Cantagalo,21,14019,-21.966667,-42.366667
br,canta galo,Canta Galo,22,,-5.644722,-36.9325
br,cantagalo,Cantagalo,25,,3.533333,-61.1
br,cantagalo,Cantagalo,27,,-22.5959,-45.6852
br,cantanhede,Cantanhede,13,8344,-3.65,-44.4
br,cantao,Cantão,13,,-9.733333,-46.383333
br,cantareia,Cantareia,27,,-23.466667,-46.633333
br,cantareira,Cantareira,27,,-23.466667,-46.633333
br,cantarem,Cantarém,20,,-6.9,-42.65
br,canteiro,Canteiro,05,,-12.2,-38.9
br,canteiro,Canteiro,21,,-22.273333,-43.738889
br,cantinho,Cantinho,05,,-10.733333,-42.666667
br,cantinho,Cantinho,13,,-3.412778,-42.6325
br,cantinho,Cantinho,17,,-7.2,-37.916667
br,cantinho,Cantinho,20,,-3.474167,-42.345833
br,cantinho,Cantinho,22,,-5.481389,-36.478611
br,cantinho,Cantinho,30,,-8.166667,-37.233333
br,cantinho do boi,Cantinho do Boi,17,,-6.833333,-37.783333
br,cantinho ii,Cantinho II,13,,-3.856111,-43.274722
br,canto alegre,Canto Alegre,13,,-5.083333,-42.95
br,canto alegre,Canto Alegre,20,,-5.633333,-41.8
br,canto bom,Canto Bom,13,,-3.818056,-43.328333
br,canto bonito,Canto Bonito,31,,-8.920556,-48.370556
br,canto,Canto,05,,-12.883333,-39.35
br,canto,Canto,06,,-5.3,-40.566667
br,canto,Canto,15,,-22.512087,-45.521332
br,canto,Canto,20,,-6.266667,-42.5
br,canto,Canto,28,,-9.8,-37.416667
br,canto cercado,Canto Cercado,05,,-10.333333,-42.433333
br,canto comprido,Canto Comprido,22,,-5.2,-36.833333
br,canto da catinga,Canto da Catinga,20,,-3.467222,-42.358611
br,canto da folha,Canto da Folha,20,,-3.724722,-42.346111
br,canto da ilha de cima,Canto da Ilha de Cima,22,,-5.083333,-35.833333
br,canto da ipoeira,Canto da Ipoeira,20,,-6.483333,-41.983333
br,canto da lagoa,Canto da Lagoa,22,,-5.07,-36.842222
br,canto da moca,Canto da Moça,22,,-5.733333,-35.466667
br,canto da palmeira,Canto da Palmeira,20,,-3.845833,-42.111111
br,canto da parnaiba,Canto da Parnaíba,20,,-3.949167,-42.410278
br,canto da passagem,Canto da Passagem,13,,-3.364722,-42.464444
br,canto da porta,Canto da Porta,13,,-3.425556,-42.456944
br,canto da raposa,Canto da Raposa,20,,-3.294444,-42.058056
br,canto da roca,Canto da Roca,20,,-6.7,-42.416667
br,canto da serra,Canto da Serra,13,,-6.283333,-43.383333
br,canto da serra,Canto da Serra,20,,-7.316667,-41.583333
br,canto da varzea,Canto da Várzea,05,,-9.866667,-38.966667
br,canto de areia,Canto de Areia,13,,-7.366667,-44.8
br,canto de baixo,Canto de Baixo,20,,-3.423333,-42.1375
br,canto de baixo,Canto de Baixo,22,,-5.083333,-35.866667
br,canto de cima,Canto de Cima,20,,-3.413611,-42.151944
br,canto do araca,Canto do Araçá,13,,-3.731111,-43.410833
br,canto do boi,Canto do Boi,13,,-3.847222,-43.456389
br,canto do buriti,Canto do Buriti,20,11715,-8.116667,-42.966667
br,canto do caboclo,Canto do Caboclo,20,,-3.711389,-42.101667
br,canto do coco,Canto do Côco,20,,-9.883333,-45.166667
br,canto do engenho,Canto do Engenho,15,,-16.925,-44.1125
br,canto do feijao,Canto do Feijão,22,,-5.616667,-37.6
br,canto do ferreira,Canto do Ferreira,20,,-6.6,-42.15
br,canto do jateba,Canto do Jatebá,20,,-6.3,-42.566667
br,canto do juazeiro,Canto do Juàzeiro,06,,-6.1,-38.866667
br,canto do junco,Canto do Junco,22,,-5.15,-37.333333
br,canto do mangue,Canto do Mangue,22,,-5.068333,-36.780278
br,canto do mimoso,Canto do Mimoso,20,,-6.883333,-42.35
br,canto do morcego,Canto do Morcego,13,,-3.391111,-42.188333
br,canto do murici,Canto do Murici,20,,-3.331944,-42.094444
br,canto do riacho,Canto do Riacho,05,,-14.3,-43.6
br,canto do rio,Canto do Rio,04,,-3.912778,-62.661944
br,canto do rio verde,Canto do Rio Verde,05,,-10.416667,-42.316667
br,canto do rodeio,Canto do Rodeio,13,,-3.444444,-42.524444
br,canto do rumo,Canto do Rumo,05,,-12.05,-39.733333
br,canto do saco,Canto do Saco,13,,-3.146111,-42.019444
br,canto dos bezerra,Canto dos Bezerra,20,,-7.583333,-43.1
br,canto dos bois,Canto dos Bois,13,,-3.773889,-43.360278
br,canto dos cocos,Canto dos Côcos,20,,-5.983333,-42.466667
br,canto dos negros,Canto dos Negros,13,,-3.670278,-42.975
br,canto do travessao,Canto do Travessão,20,,-3.3475,-42.0175
br,canto do umari,Canto do Umarí,06,,-3.15,-40.116667
br,cantofe,Cantofe,20,,-7.566667,-41.516667
br,canto fundo,Canto Fundo,13,,-3.766111,-43.285
br,canto grande,Canto Grande,05,,-10.166667,-43.316667
br,canto grande,Canto Grande,13,,-3.105833,-43.425
br,canto grande,Canto Grande,20,,-3.584722,-42.5225
br,canto grande,Canto Grande,22,,-5.403611,-36.83
br,canto grande,Canto Grande,26,,-27.196389,-48.499444
br,canto grande i,Canto Grande I,20,,-3.306389,-42.064444
br,canto grande iii,Canto Grande III,13,,-3.271944,-42.238333
br,cantori,Cantori,04,,-9.333333,-66.633333
br,cantos,Cantos,22,,-6.066667,-37.883333
br,cantos dos cocos,Cantos dos Cocos,20,,-6.033333,-41.816667
br,canto serrote,Canto Serrote,22,,-5.172778,-37.224444
br,canto sujo,Canto Sujo,13,,-3.160556,-42.544722
br,canuana,Canuanã,31,,-11.927778,-49.899722
br,canudos,Canudos,02,,-9.583333,-36.483333
br,canudos,Canudos,04,,-7.253611,-58.103611
br,canudos,Canudos,05,,-11.533333,-45.083333
br,canudos,Canudos,06,,-5.483333,-38.516667
br,canudos,Canudos,17,,-7.466667,-37.7
br,canudos,Canudos,18,,-25.61564,-50.37611
br,canudos,Canudos,22,,-5.317778,-37.449722
br,canudos,Canudos,23,,-29.333333,-52.25
br,canudos,Canudos,30,,-7.833333,-38.616667
br,canudo velho,Canudo Velho,02,,-9.55,-36.483333
br,canuma,Canumã,04,,-4.038889,-59.0725
br,canutama,Canutama,04,6320,-6.533333,-64.333333
br,canxe,Canxé,05,,-9.883333,-38.9
br,canzianopolis,Canzianópolis,18,,-25.95,-53.7
br,canzionopolis,Canziónopolis,18,,-25.95,-53.7
br,caovi,Caovi,18,,-25.9541,-48.8264
br,caovi,Caovi,26,,-25.984996,-48.838127
br,capa,Capa,05,,-16.2,-39.366667
br,capacete,Capacete,04,,-4.3725,-69.749722
br,capacete,Capacete,18,,-25.383333,-54.316667
br,capa de cima,Capa de Cima,22,,-6.1,-38.166667
br,capado,Capado,11,,-19.916667,-54.35
br,capalazia,Capalazia,25,,2.866667,-60.833333
br,capana,Capana,04,,-1.866667,-68.95
br,capane,Capané,23,,-30.266667,-52.85
br,capanema,Capanema,05,,-12.85,-38.95
br,capanema,Capanema,14,,-13.316667,-57.866667
br,capanema,Capanema,16,47768,-1.2,-47.183333
br,capanema,Capanema,18,,-25.666667,-53.8
br,capanema,Capanema,27,,-23.509253,-47.708565
br,capanga,Capangá,15,,-20.183333,-46.083333
br,capao alto,Capão Alto,11,,-18.9,-54.866667
br,capao alto,Capão Alto,14,,-15.716667,-56.166667
br,capao alto,Capão Alto,18,,-24.75,-49.95
br,capao alto,Capão Alto,26,,-27.933333,-50.5
br,capao alto,Capão Alto,27,,-23.5719,-47.8233
br,capao bonito,Capão Bonito,11,,-21.233333,-54.783333
br,capao bonito,Capão Bonito,23,,-28.116667,-51.4
br,capao bonito,Capão Bonito,27,37207,-24.016667,-48.333333
br,capao,Capão,05,,-11.782778,-45.23
br,capao,Capão,13,,-3.8525,-43.086667
br,capao,Capão,15,,-16.566667,-41.95
br,capao,Capão,18,,-24.75,-49.95
br,capao,Capão,20,,-3.5075,-42.515556
br,capao,Capão,29,,-14.683333,-46.35
br,capao,Capão,31,,-11.65,-47.516667
br,capao comprido,Capão Comprido,05,,-13.566667,-41.85
br,capao da anta,Capão da Anta,14,,-15.4,-60.266667
br,capao da areia,Capão da Areia,05,,-13.416667,-43.433333
br,capao da areia,Capão da Areia,06,,-5.133333,-40.716667
br,capao da caca,Capão da Caça,15,,-19.35,-48.35
br,capao da canoa,Capão da Canoa,23,35896,-29.766667,-50.016667
br,capao da cruz,Capão da Cruz,27,,-21.433333,-47.9
br,capao da onca,Capão da Onça,05,,-12.066667,-41.45
br,capao da velha,Capão da Velha,20,,-7,-42.5
br,capao da volta,Capão da Volta,05,,-13.5,-41.466667
br,capao de heranca,Capão de Herança,23,,-28.366667,-51.016667
br,capao do boi,Capão do Boi,31,,-7.483333,-48.2
br,capao do cedro,Capão do Cedro,18,,-25.86426,-50.182205
br,capao do jeronimo,Capão do Jerônimo,05,,-11.866667,-45.766667
br,capao do jucu,Capão do Jucu,05,,-12.9,-41.683333
br,capao do leao,Capão do Leão,23,,-31.766667,-52.5
br,capao do mato,Capão do Mato,05,,-14.366667,-44.666667
br,capao do meio,Capão do Meio,05,,-12.1,-45.216667
br,capao do meio,Capão do Meio,23,,-29.6,-51.5
br,capao dos oleos,Capão dos Óleos,15,,-21.416667,-45.2
br,capao dos patos,Capão dos Patos,23,,-28.633333,-50.1
br,capao do tigre,Capão do Tigre,23,,-28.733333,-50.133333
br,capao frio,Capão Frio,05,,-13.033333,-41.633333
br,capao grande,Capão Grande,13,,-3.671944,-43.161667
br,capao grande,Capão Grande,14,,-15.716667,-56.166667
br,capao grande,Capão Grande,23,,-28.533333,-51.216667
br,capao i,Capão I,13,,-3.373889,-43.248056
br,capao ii,Capão II,13,,-3.329167,-42.975278
br,capao limpo,Capão Limpo,11,,-21.383333,-54.383333
br,capao nossa senhora de fatima,Capão Nossa Senhora de Fátima,23,,-27.933333,-51.05
br,capao preto,Capão Prêto,15,,-18.766667,-45.7
br,capao queimado,Capão Queimado,05,,-12.9,-41.583333
br,capao real,Capão Real,18,,-25.45,-51.8
br,capao redondo,Capão Redondo,05,,-12.283333,-41.4
br,capao redondo,Capão Redondo,15,,-16.666667,-45.4
br,capao redondo,Capão Redondo,27,,-23.612724,-47.634207
br,capao redondo de cima,Capão Redondo de Cima,27,,-23.640663,-47.631042
br,capao secco,Capão Secco,23,,-31.85,-52.333333
br,capao seco,Capão Sêco,11,,-21.066667,-54.683333
br,capao seco,Capão Sêco,23,,-31.85,-52.333333
br,capao seco,Capão Sêco,27,,-20.833333,-47.783333
br,capao taquarivahy,Capão Taquarivahy,27,,-23.933333,-48.683333
br,capao verde,Capão Verde,11,,-20.066667,-56.066667
br,capao vermelho,Capão Vermelho,05,,-12.9,-41.683333
br,capaozinho,Capãozinho,13,,-3.346111,-42.812778
br,caparao,Caparaó,08,,-20.533333,-41.666667
br,caparao,Caparaó,15,,-20.516667,-41.9
br,caparao velho,Caparaó Velho,15,,-20.433333,-41.866667
br,capas de anta,Cápas de Anta,14,,-15.4,-60.266667
br,capatana,Capatana,04,,-2.8,-67.066667
br,capatara,Capatará,01,,-10.283333,-67.816667
br,capatera,Capatera,01,,-10.283333,-67.816667
br,capa-vaca,Capa-Vaca,15,,-20.933333,-42.283333
br,capecu,Capeçu,04,,-2.716667,-66.85
br,capela,Capela,02,12520,-9.416667,-36.066667
br,capela,Capela,04,,-2.966667,-57.85
br,capela,Capela,05,,-13.75,-39.366667
br,capela,Capela,11,,-18.316667,-53.166667
br,capela,Capela,15,,-21.333333,-44.55
br,capela,Capela,22,,-5.6,-35.45
br,capela,Capela,23,,-29.7,-51.333333
br,capela,Capela,28,16024,-10.5,-37.066667
br,capela,Capela,29,,-16.366667,-49.85
br,capela da palma,Capela da Palma,05,,-13.133333,-39.15
br,capela de conceicao,Capela de Conceição,05,,-11.883333,-38.166667
br,capela de santana,Capela de Santana,23,,-29.7,-51.333333
br,capela de sao benedito,Capela de São Benedito,27,,-20.833333,-48.966667
br,capela de sao miguel,Capela de São Miguel,27,,-20.9,-48.85
br,capela do alto alegre,Capela do Alto Alegre,05,,-11.666667,-39.85
br,capela do alto,Capela do Alto,27,11991,-23.466667,-47.75
br,capela do bom jesus,Capela do Bom Jesus,27,,-23.3761,-46.1405
br,capela do jaguara,Capela do Jaguara,15,,-21.266667,-44.533333
br,capela do saco,Capela do Saco,15,,-21.333333,-44.55
br,capela ivapurunduva,Capela Ivapurunduva,27,,-24.55,-48.383333
br,capela nova,Capela Nova,15,,-20.916667,-43.616667
br,capela nova,Capela Nova,30,,-7.933333,-35.983333
br,capela nova das dores,Capela Nova das Dores,15,,-20.916667,-43.616667
br,capela sao benedito,Capela São Benedito,27,,-20.233333,-47.883333
br,capela sao miguel,Capela São Miguel,27,,-20.9,-48.85
br,capelinha,Capelinha,15,20074,-17.7,-42.516667
br,capelinha,Capelinha,27,,-24.844191,-48.231054
br,capelinha,Capelinha,29,,-15.716667,-49.8
br,capelinha do amparo,Capelinha do Amparo,21,,-22.133333,-41.716667
br,capelinha do chumbo,Capelinha do Chumbo,15,,-18.683333,-46.066667
br,capelinha do embirizal,Capelinha do Embirizal,15,,-22.033333,-45.433333
br,capella,Capella,04,,-2.966667,-57.85
br,capella,Capella,15,,-21.333333,-44.55
br,capella,Capella,23,,-29.7,-51.333333
br,capella,Capella,28,,-10.5,-37.066667
br,capella de sao benedicto,Capella de São Benedicto,27,,-20.233333,-47.883333
br,capella nova,Capella Nova,30,,-7.933333,-35.983333
br,capella nova das dores,Capella Nova das Dores,15,,-20.916667,-43.616667
br,capellinha,Capellinha,15,,-17.7,-42.516667
br,capernaum,Capernaúm,05,,-11.7,-41.466667
br,capetinga,Capetinga,15,,-20.6,-47.05
br,capetuva,Capetuva,15,,-21.866667,-46.35
br,capia,Capiá,02,,-9.183333,-37.433333
br,capianga,Capianga,05,,-12.016667,-38.216667
br,capia novo,Capiá Novo,02,,-9.233333,-37.483333
br,capibaribe,Capibaribe,30,,-7.95,-36.2
br,capim acu,Capim Açu,05,,-12.4,-39.7
br,capim-acu,Capim-Açu,13,,-3.116667,-43.666667
br,capim acu,Capim Açu,15,,-15.833333,-40.35
br,capim acu,Capim Açu,22,,-5.9,-35.516667
br,capim azedo,Capim Azêdo,27,,-23.666667,-47.216667
br,capim branco,Capim Branco,15,,-16.266667,-40.8
br,capim,Capim,02,,-9.516667,-37.183333
br,capim,Capim,15,,-18.833333,-41.833333
br,capim,Capim,16,,-1.683333,-47.783333
br,capim,Capim,17,,-6.933333,-35.183333
br,capim,Capim,20,,-7.316667,-41.216667
br,capim,Capim,24,,-12.266667,-60.6375
br,capim,Capim,30,,-8.466667,-38.25
br,capim,Capim,31,,-5.2,-48.483333
br,capim de planta,Capim de Planta,30,,-7.883333,-37.7
br,capim de roca,Capim de Roca,06,,-4.083333,-38.3
br,capim grosso,Capim Grosso,02,,-9.833333,-37.066667
br,capim grosso,Capim Grosso,05,17322,-11.366667,-40.016667
br,capim grosso,Capim Grosso,06,,-4.866667,-38.216667
br,capim grosso,Capim Grosso,20,,-10.666667,-44.85
br,capim grosso,Capim Grosso,30,,-8.566667,-38.783333
br,capim melado,Capim Melado,21,,-22.951881,-43.325423
br,capim planta,Capim Planta,30,,-9.1,-36.25
br,capim puba,Capim Puba,05,,-13.5,-40.933333
br,capim puba,Capim Puba,20,,-6,-42.233333
br,capim queimado,Capim Queimado,22,,-5.410833,-36.570278
br,capinal,Capinal,05,,-15,-40.8
br,capinal,Capinal,13,,-3.355278,-43.4775
br,capinal i,Capínal I,13,,-3.630556,-43.481944
br,capinal ii,Capínal II,13,,-3.826667,-43.217222
br,capinao,Capinão,05,,-12.75,-39.583333
br,capinas,Capinas,11,,-19.016667,-56.35
br,capinha,Capinha,05,,-12.233333,-39.05
br,capinopolis,Capinópolis,15,12486,-18.683333,-49.583333
br,capinzal,Capinzal,14,,-16.383333,-56.583333
br,capinzal,Capinzal,26,23799,-27.333333,-51.6
br,capipi,Capipi,16,,-7.55,-57.7
br,capi ponta,Capi Ponta,04,,1.216667,-69.133333
br,capira,Capira,13,,-3.136667,-43.393333
br,capistrano,Capistrano,06,,-4.466667,-38.916667
br,capitao bonito,Capitão Bonito,23,,-28.966667,-53.266667
br,capitao bras,Capitão Brás,27,,-24.707003,-48.163716
br,capitao,Capitão,04,,-3.116667,-58.15
br,capitao,Capitão,11,,-21.583333,-56.016667
br,capitao,Capitão,28,,-11.05,-38.033333
br,capitao carutu,Capitão Carutu,14,,-14.316667,-54.7
br,capitao de campo,Capitão de Campo,13,,-3.903333,-43.496389
br,capitao de campo,Capitão de Campo,20,,-4.466667,-41.95
br,capitao de campos,Capitão de Campos,13,,-3.989167,-42.873333
br,capitao de campos,Capitão de Campos,20,,-4.466667,-41.95
br,capitao de mato,Capitão de Mato,20,,-4.466667,-41.95
br,capitao do espirito santo,Capitão do Espírito Santo,15,,-21.583333,-44.466667
br,capitao-do-mato,Capitão-do-Mato,20,,-4.466667,-41.95
br,capitao filipe,Capitão Filipe,14,,-14.166667,-54.933333
br,capitao grande,Capitão Grande,08,,-18.633333,-40.1
br,capitao laurindo,Capitão Laurindo,30,,-7.4,-37.05
br,capitao mor,Capitão Mór,06,,-5.083333,-39.366667
br,capitao mor,Capitão Mor,17,,-8.216667,-37.066667
br,capitao poco,Capitão Poço,16,32704,-1.75,-47.083333
br,capitaozinho,Capitãozinho,17,,-7.15,-36.583333
br,capitari,Capitari,04,,-6.566667,-60.333333
br,capitari,Capitari,25,,.85,-61.4
br,capitary,Capitary,25,,.85,-61.4
br,capitoa,Capitoa,28,,-11.05,-38.033333
br,capitolio,Capitólio,15,,-20.6,-46.05
br,capituva,Capituva,15,,-21.083333,-45.35
br,capituva,Capituva,18,,-25.450182,-48.824928
br,capituva,Capituva,27,,-22.883333,-45.383333
br,capivara alta,Capivara Alta,26,,-28.133333,-49.316667
br,capivara,Capivara,02,,-9.766667,-37.016667
br,capivara,Capivara,05,,-12.3,-40.4
br,capivara,Capivara,06,,-5.683333,-39.75
br,capivara,Capivara,11,,-17.316667,-56.716667
br,capivara,Capivara,15,,-19.833333,-45.2
br,capivara,Capivara,20,,-3.766667,-41.65
br,capivara,Capivara,24,,-10.183333,-62.066667
br,capivaras,Capivaras,26,,-28.133333,-49.316667
br,capivari,Capivari,05,,-12.15,-40.366667
br,capivari,Capivari,15,,-18.433333,-43.416667
br,capivari,Capivari,18,,-25.139277,-48.856601
br,capivari,Capivari,21,,-22.083333,-41.333333
br,capivari,Capivari,23,,-29.75,-55.933333
br,capivari,Capìvari,26,,-28.266667,-49.016667
br,capivari,Capivari,27,35519,-23.000722,-47.502026
br,capivari da mata,Capivari da Mata,27,,-20.366667,-47.683333
br,capivarita,Capivarita,23,,-30.3,-52.166667
br,capivary,Capivary,05,,-12.15,-40.366667
br,capivary,Capivary,15,,-22.55,-45.916667
br,capivary,Capivary,21,,-22.65,-42.383333
br,capivary,Capivary,23,,-29.75,-55.933333
br,capivary,Capivary,26,,-28.266667,-49.016667
br,capivary,Capivary,27,,-23.000722,-47.502026
br,capo da canoa,Capo da Canoa,23,,-29.766667,-50.016667
br,capoeira,Capoeira,04,,-4.464167,-61.061111
br,capoeira,Capoeira,05,,-14.433333,-43.033333
br,capoeira,Capoeira,06,,-5.45,-38.7
br,capoeira,Capoeira,13,,-3.25,-45.25
br,capoeira,Capoeira,17,,-6.766667,-37.7
br,capoeira,Capoeira,20,,-5.216667,-41.216667
br,capoeira,Capoeira,22,,-5.983333,-35.516667
br,capoeira,Capoeira,27,,-23.4515,-46.0374
br,capoeira,Capoeira,30,,-8.2,-36.683333
br,capoeira,Capoeira,31,,-5.95,-48.216667
br,capoeiracu,Capoeiraçu,05,,-12.583333,-38.966667
br,capoeira de dentro,Capoeira de Dentro,05,,-13.3,-40.333333
br,capoeira do felipao,Capoeira do Felipão,05,,-14.533333,-45.283333
br,capoeira do filipao,Capoeira do Filipão,05,,-14.533333,-45.283333
br,capoeira do rei,Capoeira do Rei,03,,.95,-50.816667
br,capoeira do santo,Capoeira do Santo,17,,-7.4,-38.166667
br,capoeira grande,Capoeira Grande,13,,-1.85,-45.433333
br,capoeira grande,Capoeira Grande,15,,-16.533333,-41.3
br,capoeira grande,Capoeira Grande,21,,-22.980374,-43.618922
br,capoeiral,Capoeiral,20,,-6.383333,-42.216667
br,capoeirana,Capoeirana,15,,-19.7,-43.066667
br,capoeirao,Capoeirão,29,,-16.266667,-49.366667
br,capoeiras,Capoeiras,17,,-7.6,-38.516667
br,capoeiras,Capoeiras,27,,-24.416667,-48.85
br,capoeiras,Capoeiras,30,4861,-8.75,-36.633333
br,capoeira vermelha,Capoeira Vermelha,17,,-7.65,-38.416667
br,capoeirinha,Capoeirinha,04,,-3.788056,-60.424444
br,capoeirinha,Capoeirinha,18,,-25.433333,-54.033333
br,capoeirinha,Capoeirinha,23,,-28.633333,-51.783333
br,capoeiro,Capoeiro,06,,-7.483333,-38.966667
br,capoeirucu,Capoeiruçu,05,,-12.583333,-38.966667
br,capo-ere,Capo-Erê,23,,-27.75,-52.266667
br,caponga,Caponga,06,,-4.033333,-38.183333
br,caporanga,Caporanga,27,,-22.716667,-49.55
br,capote,Capote,06,,-3.35,-39.516667
br,capote,Capote,15,,-22.366667,-45.55
br,capote,Capote,20,,-3.932778,-42.304444
br,capricho,Capricho,04,,-5.6,-63.05
br,caprichos,Caprichos,04,,-5.6,-63.05
br,capuaba,Capuaba,08,,-20.325,-40.329167
br,capua,Capuá,22,,-5.8,-37.783333
br,capuan,Capuan,06,,-3.716667,-38.683333
br,capuava,Capuava,27,,-23.143036,-47.728758
br,capuavinha,Capuavinha,27,,-23.552,-47.9318
br,capuera do laborde,Capuera do Laborde,04,,-5.624722,-59.546944
br,capumba,Capumba,20,,-5.566667,-43.016667
br,capunga,Capunga,30,,-8.366667,-36.666667
br,caputera,Caputera,27,,-23.7,-48.9
br,caputira,Caputira,15,,-20.166667,-42.266667
br,capuxu,Capuxu,30,,-8.416667,-36.033333
br,caquende,Caquende,15,,-21.333333,-44.55
br,caraa,Caraá,23,,-29.8,-50.3
br,carababa,Carababá,04,,-5.116667,-67.116667
br,carabucu,Carabuçu,21,,-21.216667,-41.583333
br,caraca,Caraça,18,,-24.701271,-48.883256
br,caracanga,Caracanga,06,,-3.933333,-38.533333
br,cara,Cará,15,,-21.366667,-46.033333
br,cara-cara,Cará-Cará,18,,-25.166667,-50.133333
br,caracara,Caracará,20,,-3.7,-40.033333
br,caracarahy,Caracarahy,25,,1.833333,-61.133333
br,caracarai,Caracaraí,25,,1.833333,-61.133333
br,caracinha,Caracinha,18,,-24.697085,-48.869085
br,caracituba,Caracituba,30,,-8.35,-35.366667
br,caracois,Caracóis,15,,-19.783333,-44.233333
br,caracol,Caracol,11,,-22.016667,-57.033333
br,caracol,Caracol,15,,-15.3,-44.8
br,caracol,Caracol,17,,-7.3,-38.4
br,caracol,Caracol,20,,-9.283333,-43.333333
br,caracol,Caracol,23,,-30.183333,-53.033333
br,caracol,Caracol,24,,-9.116667,-64.3
br,caracol,Caracol,31,,-7.066667,-48.033333
br,caracu,Caracu,18,,-25.533333,-51.966667
br,caracuru,Caracuru,16,,-1.066667,-52.416667
br,caraguata,Caraguatá,05,,-13.35,-41.666667
br,caraguata,Caraguatá,26,,-26.783333,-50.833333
br,caraguatai,Caraguataí,05,,-13.35,-41.666667
br,caraguatai,Caraguataí,11,,-23.566667,-55.233333
br,caraguatal,Caraguatal,27,,-23.283333,-47.633333
br,caraguatatuba,Caraguatatuba,27,90844,-23.616667,-45.416667
br,caraguatehy,Caraguatehy,11,,-23.566667,-55.233333
br,caraguatei,Caraguateí,11,,-23.566667,-55.233333
br,carahubas,Carahubas,17,,-7.716667,-36.516667
br,carahubas,Carahubas,22,,-5.783333,-37.566667
br,carahyba,Carahyba,05,,-16.8,-39.15
br,carahyba,Carahyba,30,,-8.466667,-38.533333
br,carahybeira,Carahybeira,30,,-8.916667,-37.866667
br,carahy,Carahy,15,,-17.2,-41.7
br,caraiba,Caraíba,02,,-9.716667,-36.766667
br,caraiba,Caraíba,05,,-11.466667,-38.883333
br,caraiba,Caraíba,13,,-3.067222,-42.178333
br,caraiba,Caraíba,15,,-16.633333,-40.816667
br,caraiba,Caraiba,20,,-6.533333,-42.033333
br,caraiba,Caraíba,29,,-16.916667,-48.416667
br,caraiba,Caraíba,30,,-8.416667,-37.683333
br,caraiba de santa teresa,Caraíba de Santa Teresa,05,,-9.666667,-43.666667
br,caraiba de santa tereza,Caraíba de Santa Tereza,05,,-9.666667,-43.666667
br,caraiba do norte,Caraíba do Norte,13,,-6.416667,-42.883333
br,caraibal,Caraibal,15,,-15.5,-44.75
br,caraibas,Caraíbas,02,,-9.716667,-36.766667
br,caraibas,Caraíbas,05,,-10.466667,-40.433333
br,caraibas,Caraíbas,13,,-3.433333,-42.983333
br,caraibas,Caraíbas,15,,-14.966667,-44.366667
br,caraibas,Caraíbas,17,,-6.75,-37.833333
br,caraibas,Caraíbas,20,,-10.733333,-45.266667
br,caraibas,Caraíbas,30,,-8.716667,-36.983333
br,caraibeira,Caraìbeira,17,,-6.916667,-36.533333
br,caraibeira,Caraibeira,30,,-8.916667,-37.866667
br,caraibeiras,Caraibeiras,02,,-9.216667,-38.033333
br,caraibeiras,Caraìbeiras,17,,-6.766667,-36.083333
br,caraibeiras,Caraibeiras,30,,-8.15,-36.133333
br,caraibinha,Caraibinha,20,,-6.6,-42.083333
br,caraibuna,Caraibuna,05,,-13.75,-41.15
br,carai,Caraí,15,6750,-17.2,-41.7
br,caraipe,Caraípe,05,,-12.783333,-39.083333
br,caraiuva,Caraiuva,26,,-28.883333,-49.483333
br,caraiva,Caraíva,05,,-16.8,-39.15
br,caraja,Carajá,23,,-30.716667,-53.683333
br,caraja,Carajá,27,,-23.584952,-47.313239
br,carajari,Carajari,16,,-4.766667,-54.35
br,carajas,Carajás,16,,-2.95,-51.866667
br,carajazinho,Carajàzinho,23,,-28.55,-54.333333
br,carajuru,Carajuru,04,,.383333,-67.283333
br,carambehy,Carambehy,18,,-24.933333,-50.083333
br,carambei,Carambeí,18,13466,-24.933333,-50.083333
br,carambiu,Carambiú,18,,-25.565273,-48.830079
br,caramuru,Caramuru,18,,-23.366667,-51.216667
br,caramuru,Caramuru,27,,-21.416667,-50.816667
br,carana,Caraná,16,,-1.15,-46.933333
br,carana,Caraná,25,,3.116667,-60.95
br,caranahyba,Caranahyba,15,,-20.883333,-43.733333
br,caranaiba,Caranaíba,15,,-20.883333,-43.733333
br,caranandiua,Caranandiua,13,,-1.45,-46.15
br,carananduba,Carananduba,16,,-1.1,-48.416667
br,caranapatuba,Caranapatuba,04,,-6.754167,-62.591667
br,caranda,Carandá,11,,-20.116667,-55.583333
br,caranda dos veados,Carandá dos Veados,14,,-16.5,-57.1
br,caranda fundo,Carandá Fundo,14,,-16.75,-56.783333
br,carandahy,Carandahy,15,,-20.95,-43.8
br,carandai,Carandaí,15,16657,-20.933333,-43.916667
br,carandazal,Carandàzal,11,,-18.616667,-56.1
br,carandazinho,Carandàzinho,14,,-16.45,-56.133333
br,carandina,Carandina,27,,-22.624167,-47.261944
br,caranduba,Caranduba,16,,-1.1,-48.416667
br,carandububa,Carandububa,16,,-1.1,-48.416667
br,carangola,Carangola,15,25322,-20.733333,-42.033333
br,caranguejo,Caranguejo,21,,-22.901847,-43.43154
br,carao,Carao,13,,-6.45,-42.866667
br,carao,Carão,22,,-5.202222,-36.700556
br,carapai,Carapai,23,,-29.1751,-51.0449
br,carapajo,Carapajó,16,,-2.266667,-49.366667
br,carapana,Carapanã,04,,-4.496389,-62.013611
br,carapanatuba,Carapanatuba,04,,-6.754167,-62.591667
br,caraparu,Caraparu,16,,-1.366667,-48.133333
br,carapebas,Carapebas,20,,-2.966667,-41.45
br,carapebus,Carapebus,08,,-20.233333,-40.216667
br,carapebus,Carapebus,21,,-22.183333,-41.666667
br,carapeva,Carapeva,27,,-23.2,-45.4
br,carapia,Carapiá,21,,-22.968257,-43.578135
br,carapi,Carapi,02,,-9.133333,-37.5
br,carapi,Carapi,16,,-1.15,-47.516667
br,carapicuiba,Carapicuíba,27,361120,-23.516667,-46.833333
br,carapina,Carapina,08,,-20.233333,-40.283333
br,carapina,Carapina,29,,-18.366667,-51.15
br,carapo,Carapó,11,,-22.633333,-54.8
br,carapotos,Carapotós,30,,-8.133333,-36.066667
br,caraquatchi,Caraquatchi,11,,-23.566667,-55.233333
br,carara,Carará,04,,-6.727222,-62.513611
br,carara,Carará,13,,-3.5,-45.25
br,carara poco,Carara Poço,04,,1.066667,-67.533333
br,cararbas,Carárbas,06,,-5.05,-39.183333
br,caras,Caras,06,,-3.516667,-39.933333
br,carasinho,Carasinho,23,,-28.3,-52.8
br,carasinho,Caràsinho,26,,-28.333333,-50.483333
br,carataca,Caratacá,05,,-9.933333,-39.333333
br,caratateua,Caratateua,16,,-1.25,-48.433333
br,caratatiua,Caratatiua,13,,-1.633333,-45.233333
br,caratatiua,Caratatiua,16,,-4.166667,-47.183333
br,caratianas,Caratianas,24,,-9.483333,-63.1
br,caratinga,Caratinga,15,60067,-19.783333,-42.133333
br,caratuva,Caratuva,18,,-23.96602,-50.155993
br,carauari,Carauari,04,18059,-4.879167,-66.898056
br,carauary,Carauary,04,,-4.879167,-66.898056
br,carauba,Caraúba,06,,-2.833333,-40.1
br,carauba,Caraúba,20,,-3.456944,-42.046389
br,carauba,Caraúba,22,,-5.783333,-37.566667
br,caraubas,Caraúbas,06,,-3.633333,-38.85
br,caraubas,Caraúbas,17,,-7.716667,-36.516667
br,caraubas,Caraúbas,22,12462,-5.53,-37.303056
br,caravari,Caravari,04,,-4.879167,-66.898056
br,caravelas,Caravelas,05,11322,-17.75,-39.25
br,caravelas,Caravelas,20,,-5.1,-41.85
br,caravellas,Caravellas,05,,-17.75,-39.25
br,carazinho,Caràzinho,23,59418,-28.3,-52.8
br,carazinho,Caràzinho,26,,-28.333333,-50.483333
br,carbonita,Carbonita,15,,-17.533333,-43.016667
br,carcanha,Carcanha,05,,-13.3,-39.283333
br,carcara,Carçará,20,,-6.983333,-41
br,carcara,Carcara,30,,-7.866667,-39.583333
br,cardeal da silva,Cardeal da Silva,05,,-11.95,-37.95
br,cardosa,Cardosa,06,,-2.933333,-40.283333
br,cardoso,Cardoso,04,,-4.2,-59.25
br,cardoso,Cardoso,11,,-20.65,-57.65
br,cardoso,Cardoso,15,,-15.583333,-46.8
br,cardoso,Cardoso,17,,-7.433333,-38.05
br,cardoso,Cardoso,20,,-3.729722,-42.379722
br,cardoso,Cardoso,22,,-5.55,-35.95
br,cardoso,Cardoso,27,10556,-20.066667,-49.9
br,cardoso moreira,Cardoso Moreira,21,,-21.483333,-41.616667
br,cardoso moreiro,Cardoso Moreiro,21,,-21.483333,-41.616667
br,cardosos,Cardosos,21,,-22.899295,-43.47437
br,cardosos,Cardosos,22,,-6.016667,-37.7
br,cardozo,Cardozo,04,,-4.2,-59.25
br,careacu,Careaçu,15,,-22.033333,-45.7
br,care-assu,Caré-Assú,15,,-22.033333,-45.7
br,careiro,Careiro,04,6659,-3.2,-59.75
br,careiro da varzea,Careiro da Várzea,04,1092,-3.2,-59.75
br,caresalzinho,Caresalzinho,16,,-6.233333,-57.633333
br,cares,Cares,26,,-26.35,-48.85
br,careta,Careta,20,,-6.2,-42.3
br,cariaca,Cariaçá,05,,-10.516667,-40.133333
br,caria,Cariá,20,,-6.416667,-40.833333
br,cariacica,Cariacica,08,330681,-20.266667,-40.416667
br,cariacu,Cariaçu,15,,-22.033333,-45.7
br,cariatuba,Cariatuba,06,,-6.816667,-39.516667
br,caribas,Caribas,30,,-9.05,-37.266667
br,caribe,Caribé,05,,-13.233333,-38.983333
br,caricaca,Caricaca,31,,-7.883333,-48.15
br,carice,Caricé,30,,-7.533333,-35.083333
br,caridade,Caridade,06,,-4.216667,-39.2
br,caridade,Caridade,13,,-3.592222,-43.276389
br,caridade,Caridade,20,,-7.716667,-40.983333
br,carijo grande,Carijo Grande,18,,-25.773049,-50.227195
br,carijos,Carijós,18,,-25.9892,-49.3342
br,carima,Carimã,16,,-5.2,-56.783333
br,carima,Carimã,30,,-8.85,-35.333333
br,carin,Carin,04,,-3,-60.016667
br,carinhanha,Carinhanha,05,11408,-14.3,-43.783333
br,carioca,Carioca,13,,-3.057778,-42.425556
br,carioca,Carioca,15,,-19.816667,-44.75
br,carioca,Carioca,18,,-23.410899,-52.573522
br,carios,Carios,06,,-6.533333,-39.5
br,caripare,Cariparé,05,,-11.522222,-45.055556
br,caripe,Caripé,04,,-7.833333,-60.666667
br,caripi,Caripi,03,,3.75,-51.583333
br,caripi,Caripi,16,,-1.15,-47.516667
br,carira,Carira,28,10276,-10.35,-37.7
br,carire,Cariré,20,5488,-3.95,-40.45
br,caririacu,Caririaçu,06,12971,-7.033333,-39.283333
br,cariri,Cariri,02,,-9.716667,-36.133333
br,cariri,Cariri,04,,-3,-60.016667
br,cariri,Cariri,16,,-4.45,-57.1
br,cariri,Cariri,21,,-22.846273,-43.276752
br,cariri,Cariri,25,,3.85,-59.6
br,cariri do jovelino,Cariri do Jovelino,02,,-9.716667,-36.133333
br,cariri do tocantins,Cariri do Tocantins,31,,-11.888611,-49.073333
br,cariri mirim,Cariri Mirim,30,,-7.55,-39.483333
br,caririmirim,Caririmirim,30,,-7.633333,-39.533333
br,caririzinho,Caririzinho,30,,-7.633333,-39.533333
br,cariry,Cariry,04,,-3,-60.016667
br,caritianas,Caritianas,24,,-9.483333,-63.1
br,cariuacanga,Cariuacanga,04,,-5.016667,-62.8
br,cariucanga,Cariucanga,04,,-5.016667,-62.8
br,cariugonga,Cariugonga,04,,-5.016667,-62.8
br,carius,Cariús,06,,-6.533333,-39.5
br,cariutaba,Cariutaba,06,,-6.816667,-39.516667
br,carlopolis,Carlópolis,18,,-23.416667,-49.683333
br,carlos alves,Carlos Alves,15,,-21.616667,-43.116667
br,carlos barbosa,Carlos Barbosa,23,19106,-29.3,-51.5
br,carlos chagas,Carlos Chagas,15,13206,-17.716667,-40.75
br,carlos dahne,Carlos Dahne,26,,-26.733333,-52.633333
br,carlos dane,Carlos Dane,26,,-26.733333,-52.633333
br,carlos de vasconcelos,Carlos de Vasconcelos,15,,-18.833333,-48.45
br,carlos gomes,Carlos Gomes,06,,-6.533333,-38.9
br,carlos gomes,Carlos Gomes,21,,-21.983333,-41.8
br,carlos gomes,Carlos Gomes,23,,-27.7,-51.916667
br,carlos guinle,Carlos Guinle,21,,-22.452904,-42.967568
br,carlos lobato,Carlos Lobato,15,,-20.05,-45.583333
br,carlos pinheiro,Carlos Pinheiro,05,,-16.533333,-39.916667
br,carlos ribeiro,Carlos Ribeiro,15,,-21.016667,-45.833333
br,carlota,Carlota,11,,-19.783333,-57.65
br,carmelopolis,Carmelópolis,06,,-6.883333,-40.133333
br,carmesia,Carmésia,15,,-19.083333,-43.15
br,carmo,Carmo,03,,1.266667,-50.783333
br,carmo,Carmo,05,,-12.466667,-38.45
br,carmo,Carmo,13,,-3.483333,-44.833333
br,carmo,Carmo,15,,-19.5,-43.366667
br,carmo,Carmo,16,,-1.383333,-47.7
br,carmo,Carmo,21,11555,-21.933333,-42.616667
br,carmo,Carmo,28,,-10.65,-36.983333
br,carmo,Carmo,30,,-7.75,-38.716667
br,carmo,Carmo,31,,-5.4,-48.383333
br,carmo da cachoeira,Carmo da Cachoeira,15,,-21.466667,-45.216667
br,carmo da mata,Carmo da Mata,15,,-20.55,-44.883333
br,carmo da matta,Carmo da Matta,15,,-20.55,-44.883333
br,carmo de cajuru,Carmo de Cajurú,15,,-20.183333,-44.766667
br,carmo de minas,Carmo de Minas,15,,-22.116667,-45.133333
br,carmo de pains,Carmo de Pains,15,,-20.366667,-45.666667
br,carmo do cajuru,Carmo do Cajuru,15,16333,-20.183333,-44.766667
br,carmo do mata,Carmo do Mata,15,,-20.55,-44.883333
br,carmo do paranahyba,Carmo do Paranahyba,15,,-18.983333,-46.35
br,carmo do paranaiba,Carmo do Paranaíba,15,26537,-18.983333,-46.35
br,carmo do rio claro,Carmo do Rio Claro,15,14446,-20.966667,-46.116667
br,carmo do rio verde,Carmo do Rio Verde,29,6053,-15.35,-49.7
br,carmolandia,Carmolândia,31,,-7.000556,-48.254722
br,carmona,Carmona,05,,-12.466667,-41.583333
br,carmopolis,Carmópolis,28,,-10.65,-36.983333
br,carmopolis de minas,Carmópolis de Minas,15,,-20.55,-44.633333
br,carnahyba,Carnahyba,05,,-9.583333,-40.416667
br,carnahyba,Carnahyba,30,,-7.8,-37.816667
br,carnaiba,Carnaíba,05,,-10.566667,-38.916667
br,carnaiba,Carnaíba,13,,-3.934167,-43.429444
br,carnaiba,Carnaiba,20,,-6.683333,-41.7
br,carnaiba,Carnaíba,30,6019,-8.7,-37.666667
br,carnaiba de dento,Carnaíba de Dento,20,,-6.4,-41.4
br,carnaiba de flores,Carnaíba de Flôres,30,,-7.8,-37.816667
br,carnaiba do sertao,Carnaíba do Sertão,05,,-9.583333,-40.416667
br,carnaibas,Carnaíbas,05,,-13.633333,-42.166667
br,carnaibas,Carnaibas,20,,-7.083333,-43.116667
br,carnauba amarela,Carnaúba Amarela,13,,-3.861667,-43.326944
br,carnauba,Carnauba,06,,-2.983333,-39.95
br,carnauba,Carnaúba,13,,-3.619444,-42.985278
br,carnauba,Carnaúba,17,,-6.733333,-37.666667
br,carnauba,Carnaúba,20,,-3.574444,-42.333056
br,carnauba,Carnaúba,22,,-5.75,-35.683333
br,carnauba,Carnaúba,25,,3.4,-60.2
br,carnauba,Carnaúba,30,,-7.516667,-39.833333
br,carnauba comprida,Carnaúba Comprida,20,,-3.565,-42.046389
br,carnauba de forquilha,Carnaúba de Forquilha,20,,-7.25,-41.833333
br,carnauba de pedra,Carnaúba de Pedra,13,,-5.016667,-42.966667
br,carnauba dos dantas,Carnaúba dos Dantas,22,,-6.55,-36.583333
br,carnauba do soares,Carnaúba do Soares,20,,-5.3,-41.216667
br,carnauba enterrada,Carnaúba Enterrada,22,,-5.066667,-35.883333
br,carnaubais,Carnaúbais,22,,-5.347222,-36.832778
br,carnaubal,Carnaubal,06,,-4.166667,-40.95
br,carnaubal,Carnaubal,13,,-3.366667,-44.783333
br,carnaubal,Carnaubal,14,,-15.95,-59.033333
br,carnaubal,Carnaubal,17,,-7.366667,-36.95
br,carnaubal,Carnaubal,20,,-3.649444,-42.540833
br,carnaubal,Carnaubal,22,,-5.363333,-37.489444
br,carnaubalzinho,Carnaubalzinho,06,,-3.716667,-41.3
br,carnaubalzinho,Carnaubalzinho,20,,-5.5,-41.366667
br,carnaubas,Carnaúbas,06,,-5.633333,-39.55
br,carnaubas,Carnaúbas,20,,-3.6875,-42.100278
br,carnaubas,Carnaúbas,22,,-5.951389,-37.098056
br,carnauba seca,Carnaúba Sêca,17,,-7.566667,-38.316667
br,carnauba torta,Carnaúba Torta,20,,-3.833056,-42.068333
br,carnauba verde,Carnaúba Verde,22,,-5.1,-37.316667
br,carnaubeira,Carnaubeira,13,,-2.833611,-41.964167
br,carnaubeir,Carnaubeir,13,,-2.833611,-41.964167
br,carnaubeir,Carnaubeir,30,,-8.433333,-38.85
br,carnaubinha,Carnaùbinha,06,,-5.533333,-39.15
br,carnaubinha,Carnaubinha,13,,-3.775,-43.389167
br,carnaubinha,Carnaùbinha,17,,-6.75,-38.283333
br,carnaubinha,Carnaúbinha,20,,-3.511111,-42.419444
br,carnaubinha,Carnaúbinha,22,,-5.616944,-37.131944
br,carnaubinha,Carnaùbinha,30,,-7.816667,-38.516667
br,carnaubinhas,Carnaubinhas,06,,-4.516667,-37.883333
br,carne de vaca,Carne de Vaca,30,,-7.583333,-34.833333
br,carne gorda,Carne Gorda,22,,-5.468611,-37.022778
br,carneirinho,Carneirinho,15,,-19.7,-43.233333
br,carneirinhos,Carneirinhos,15,,-19.8,-43.183333
br,carneiro,Carneiro,15,,-19.183333,-41.75
br,carneiro,Carneiro,17,,-7.25,-37.916667
br,carneiro,Carneiro,22,,-5.916667,-37.766667
br,carneiro,Carneiro,30,,-7.883333,-38.533333
br,carneiro dos medeiro,Carneiro dos Medeiro,17,,-7.666667,-37.95
br,carneiros,Carneiros,02,,-9.5,-37.433333
br,carneiros,Carneiros,15,,-22.5283,-45.7455
br,carne seca,Carne Sêca,15,,-17.383333,-43.866667
br,carnica,Carniça,26,,-28.533333,-48.816667
br,carnica,Carniça,27,,-24.739801,-48.064333
br,carnobi,Carnobi,23,,-29.7,-53.7
br,carnoio,Carnoió,17,,-7.483333,-36.116667
br,caroa,Caroá,17,,-7.466667,-37.633333
br,caroa,Caroá,30,,-8.85,-37.766667
br,caroara,Caroará,13,,-4.133333,-43.3
br,carobas,Carobas,06,,-5.516667,-38.416667
br,carobinha,Carobinha,13,,-3.8125,-42.761944
br,carobinha,Carobinha,21,,-22.855311,-43.531893
br,caro custou,Caro Custou,06,,-6.15,-38.9
br,carolina belo,Carolina Belo,15,,-20.533333,-45.616667
br,carolina,Carolina,08,,-20.533333,-40.833333
br,carolina,Carolina,11,,-20.333333,-55.533333
br,carolina,Carolina,13,16229,-7.333333,-47.466667
br,carolino cruz,Carolino Cruz,15,,-15.166667,-43.35
br,carona,Carona,14,,-16.416667,-56.433333
br,caropanatuba,Caropanatuba,04,,-6.754167,-62.591667
br,caroveira,Caroveira,18,,-25.166667,-53.55
br,carovi,Carovi,23,,-28.933333,-54.833333
br,carpina,Carpina,20,,-3.033333,-41.35
br,carpina,Carpina,30,70690,-7.85,-35.25
br,carqueija,Carqueija,18,,-25.816675,-50.057254
br,carqueja,Carquêja,06,,-4.466667,-38.933333
br,carqueja,Carqueja,30,,-8.333333,-38.416667
br,carquejo,Carquejo,06,,-3.866667,-40.733333
br,carquejo,Carquejo,20,,-7.333333,-41
br,carranca,Carranca,13,,-3.911944,-43.033611
br,carrancas,Carrancas,15,,-21.5,-44.65
br,carranco,Carranco,17,,-7.666667,-38.316667
br,carrancudo,Carrancudo,20,,-6.8,-40.516667
br,carrapateira,Carrapateira,06,,-2.816667,-40.316667
br,carrapateira,Carrapateira,17,,-6.35,-36.35
br,carrapateira,Carrapateira,22,,-5.014444,-37.473611
br,carrapateira,Carrapateira,30,,-8.6,-36.866667
br,carrapateiras,Carrapateiras,06,,-5.95,-40.366667
br,carrapatinho,Carrapatinho,11,,-19.833333,-56.416667
br,carrapato,Carrapato,05,,-13.566667,-41.116667
br,carrapato,Carrapato,13,,-3.661389,-42.840833
br,carrapato,Carrapato,17,,-6.616667,-37.7
br,carrapato,Carrapato,20,,-6.066667,-42.683333
br,carrapato,Carrapato,21,,-21.4,-41.066667
br,carrapichel,Carrapichel,05,,-10.4,-40.183333
br,carrapicho,Carrapicho,06,,-4.9,-38.616667
br,carrapicho,Carrapicho,30,,-7.9,-36.333333
br,carrascao,Carrascão,13,,-3.636944,-43.225556
br,carrasco bonito,Carrasco Bonito,31,,-5.224444,-47.828611
br,carrasco,Carrasco,20,,-5.766667,-42.566667
br,carrasco,Carrasco,31,,-6.383333,-47.75
br,carrasco da faveira,Carrasco da Faveira,20,,-6.25,-42.483333
br,carrasquinho,Carrasquinho,20,,-3.9,-42.558333
br,carrazedo,Carrazedo,16,,-1.6,-51.9
br,carregador,Carregador,14,,-16.016667,-58.35
br,carreira,Carreira,20,,-3.491389,-42.483611
br,carreiras,Carreiras,15,,-20.583333,-43.733333
br,carreiras,Carreiras,20,,-7.55,-41.866667
br,carretao,Carretão,13,,-9.45,-46.166667
br,carretao,Carretão,17,,-6.616667,-38.516667
br,carretao,Carretão,20,,-5.9,-42.466667
br,carrocal,Carroçal,04,,-6.883333,-57.883333
br,carrocalzinho,Carroçalzinho,16,,-6.233333,-57.633333
br,carro,Carro,20,,-6.333333,-42.25
br,carro de boi,Carro de Boi,14,,-16.233333,-56.583333
br,carro quebrado,Carro Quebrado,20,,-7.25,-41.033333
br,carro quebrado,Carro Quebrado,22,,-4.962222,-37.180556
br,carro velho,Carro Velho,20,,-6.6,-42.316667
br,carsevenne,Carsevenne,03,,2.5,-50.95
br,cartucho,Cartucho,31,,-8.084722,-47.508056
br,carua,Caruá,05,,-15.966667,-39.8
br,carualina,Carualina,30,,-8.3,-37.583333
br,caruara,Caruara,13,,-3.4425,-42.652222
br,caruara,Caruara,23,,-29.25,-51.416667
br,caruaru,Caruaru,30,235375,-8.283333,-35.966667
br,caruatai,Caruataí,06,,-3.816667,-40.966667
br,caruauba,Caruaúba,06,,-5.083333,-38.916667
br,caru,Caru,26,,-27.666667,-50.583333
br,carumbe,Carumbé,11,,-21.983333,-55.016667
br,caruru,Caruru,13,,-4.766667,-46.583333
br,carutapera,Carutapera,13,12819,-1.216667,-46.016667
br,carvalho,Carvalho,16,,-2.283333,-51.45
br,carvalho,Carvalho,27,,-20.483333,-50.016667
br,carvalhos,Carvalhos,06,,-4.75,-40.433333
br,carvalhos,Carvalhos,15,,-22.083333,-44.483333
br,carvoal,Carvoal,14,,-16.383333,-56.3
br,carvoalzinho,Carvoalzinho,14,,-16.533333,-56.75
br,carvo branco,Carvo Branco,18,,-25.566667,-52.05
br,carvoeira,Carvoeira,04,,-1.383333,-62
br,carvoeiro,Carvoeiro,04,,-1.383333,-62
br,carvoeiro,Carvoeiro,06,,-3.2,-39.983333
br,carvoeiro,Carvoeiro,17,,-7.316667,-38.25
br,carvoeiro,Carvoeiro,22,,-6.116667,-37.733333
br,casa amarela,Casa Amarela,21,,-22.940569,-43.470067
br,casa branca,Casa Branca,05,,-12.183333,-41.183333
br,casa branca,Casa Branca,14,,-17.633333,-55.266667
br,casa branca,Casa Branca,15,,-20.1,-44.05
br,casa branca,Casa Branca,21,,-21.6,-41.716667
br,casa branca,Casa Branca,23,,-30.7074,-52.3773
br,casa branca,Casa Branca,25,,3.686579,-59.726517
br,casa branca,Casa Branca,27,22498,-21.766667,-47.083333
br,casa branca da serra,Casa Branca da Serra,21,,-22.474836,-42.996085
br,casa casimiro,Casa Casimiro,04,,-3.133333,-59.333333
br,casa da serra,Casa da Serra,05,,-12.116667,-39.35
br,casa das pedras,Casa das Pedras,18,,-25.335465,-48.908361
br,casa da telha,Casa da Telha,05,,-13.566667,-41.716667
br,casa de pedra,Casa de Pedra,20,,-4.233333,-41.116667
br,casa de pedra,Casa de Pedra,30,,-7.85,-39.616667
br,casa de telha,Casa de Telha,15,,-18.383333,-43.183333
br,casa do crispim,Casa do Crispim,31,,-10.501389,-49.700278
br,casa do rodrigues,Casa do Rodrigues,04,,-3.55,-60.883333
br,casa forte,Casa Forte,06,,-5.7,-39.733333
br,casa grande,Casa Grande,05,,-13.666667,-41.816667
br,casa grande,Casa Grande,15,,-20.783333,-43.933333
br,casa grande,Casa Grande,27,,-22.433333,-49.933333
br,casal,Casal,21,,-22.25,-43.5
br,casalvasco,Casalvasco,14,,-15.316667,-59.983333
br,casa morta,Casa Morta,05,,-9.95,-41.366667
br,casa nova,Casa Nova,05,33319,-9.416667,-41.133333
br,casa nova,Casa Nova,06,,-5.683333,-38.933333
br,casa nova,Casa Nova,11,,-21.166667,-54.05
br,casa nova,Casa Nova,20,,-5.766667,-42.15
br,casas velhas,Casas Velhas,17,,-6.566667,-38.466667
br,casa velha,Casa Velha,05,,-14.316667,-43.283333
br,casa verde,Casa Verde,05,,-9.883333,-42.7
br,casca,Casca,23,,-28.566667,-51.983333
br,casca de pedra,Casca de Pedra,15,,-17.833333,-40.816667
br,cascadura,Cascadura,21,,-22.886932,-43.330788
br,cascalho,Cascalho,05,,-14.766667,-43.566667
br,cascalho,Cascalho,21,,-22.991201,-43.498671
br,cascalho,Cascalho,26,,-27.2,-53.333333
br,cascalho rico,Cascalho Rico,15,,-18.566667,-47.866667
br,cascao,Cascão,15,,-18.466667,-48.166667
br,cascao,Cascão,17,,-6.933333,-37.85
br,cascata,Cascata,05,,-17.466667,-39.8
br,cascata,Cascata,13,,-8.709444,-46.720556
br,cascata,Cascata,23,,-27.533333,-54.25
br,cascatinha,Cascatinha,18,,-26.2,-51.366667
br,cascatinha,Cascatinha,21,,-22.481111,-43.155556
br,cascavel,Cascavel,05,,-13.166667,-41.4
br,cascavel,Cascavel,06,52357,-4.116667,-38.233333
br,cascavel,Cascavel,11,,-21.933333,-57.783333
br,cascavel,Cascavel,15,,-20.55,-47.066667
br,cascavel,Cascavel,17,,-8.166667,-36.766667
br,cascavel,Cascavel,18,257174,-24.95,-53.466667
br,cascavel,Cascavel,20,,-7.466667,-44.116667
br,cascavel,Cascavel,27,,-22.066667,-46.966667
br,cascavel de alexandre,Cascavel de Alexandre,17,,-8.15,-36.783333
br,cascavel do alexandre,Cascavel do Alexandre,17,,-8.15,-36.783333
br,cascudo,Cascudo,05,,-12.533333,-41.783333
br,cascudo,Cascudo,13,,-3.125,-43.388889
br,caseara,Caseara,31,,-9.211111,-49.836944
br,caseiros,Caseiros,23,,-28.266667,-51.7
br,casemiro,Casemiro,06,,-6.55,-40.65
br,casemiro costa,Casemiro Costa,15,,-20.85,-46.15
br,casemiro de abreu,Casemiro de Abreu,21,,-22.483333,-42.2
br,casimiro andrade,Casimiro Andrade,05,,-13.666667,-40.183333
br,casimiro,Casimiro,03,,.366667,-51.216667
br,casimiro,Casimiro,04,,-6.733333,-59.083333
br,casimiro de abreu,Casimiro de Abreu,21,19087,-22.483333,-42.2
br,casimiro pulgaz,Casimiro Pulgaz,23,,-29.0678,-51.0303
br,casinha,Casinha,16,,-1.083333,-49.65
br,casinha,Casinha,30,,-7.766667,-35.666667
br,casinhas,Casinhas,30,,-7.766667,-35.666667
br,casino,Casino,23,,-32.183333,-52.166667
br,casmorra,Casmorra,05,,-12.833333,-39.116667
br,casquilho,Casquilho,05,,-13.133333,-41.6
br,cassange,Cassange,14,,-16.8925,-56.720833
br,cassange,Cassange,15,,-21.2,-44.716667
br,cassarangongo,Cassarangongo,05,,-12.6,-38.616667
br,casseb,Casseb,16,,-.883333,-47.233333
br,cassia,Cassiã,04,,-5.915556,-64.5125
br,cassia,Cássia,15,14391,-20.6,-46.933333
br,cassia dos coqueiros,Cássia dos Coqueiros,27,,-21.283333,-47.166667
br,cassiana,Cassianã,04,,-7.266667,-64.883333
br,cassiano,Cassiano,15,,-18.883333,-42.25
br,cassiara,Cassiara,04,,-7.266667,-64.883333
br,cassilandia,Cassilândia,11,18498,-19.15,-51.75
br,cassino,Cassino,23,,-32.183333,-52.166667
br,cassinum,Cassinum,05,,-12.683333,-38.866667
br,cassio,Cássio,11,,-21.2,-56.333333
br,cassipore,Cassipore,03,,3.433333,-51.166667
br,cassique doble,Cassique Dóble,23,,-27.75,-51.616667
br,cassiterita,Cassiterita,15,,-21.116667,-44.466667
br,casso,Cassó,13,,-3.016667,-43.35
br,cassual,Cassual,18,,-25.494141,-48.327875
br,cassu,Cassú,29,,-18.616667,-51.066667
br,cassununga,Cassununga,14,,-16.05,-53.633333
br,cassurova,Cassurova,27,,-22.45,-47.983333
br,casta,Casta,20,,-3.95,-42.483333
br,castanarana,Castanarana,04,,-5.897778,-61.381389
br,castanha,Castanha,04,,-2.9,-57.55
br,castanha,Castanha,22,,-6.116667,-35.383333
br,castanha,Castanha,23,,-32.1168,-52.5985
br,castanha,Castanha,25,,.881111,-61.658333
br,castanha-cupu,Castanha-Cupu,04,,-4.167778,-60.825833
br,castanhal,Castanhal,04,,-2.9,-57.55
br,castanhal,Castanhal,16,137410,-1.3,-47.916667
br,castanhal,Castanhal,24,,-11.366667,-61.666667
br,castanhal grande,Castanhal Grande,16,,-1.716667,-55.433333
br,castanha-mirim,Castanha-mirim,04,,-4.2625,-62.193056
br,castanhao,Castanhão,05,,-13.95,-40.166667
br,castanhao,Castanhão,06,,-5.466667,-38.383333
br,castanheira,Castanheira,01,,-10.416667,-68.016667
br,castanheira,Castanheira,04,,-2.831111,-60.75
br,castanheira,Castanheira,05,,-11.8,-42.266667
br,castanheiro,Castanheiro,01,,-10.683333,-69.583333
br,castanheiro,Castanheiro,04,,-2.831111,-60.75
br,castanheiro,Castanheiro,20,,-9.816667,-45.283333
br,castanho,Castanho,04,,.35,-64.016667
br,castanho,Castanho,16,,-1.316667,-46.9
br,castanho,Castanho,17,,-6.533333,-37.666667
br,castelandia,Castelândia,20,,-5.85,-43.083333
br,castel,Castel,16,,-5.066667,-56.35
br,castelhano,Castelhano,20,,-2.816667,-40.35
br,castelhanos,Castelhanos,20,,-2.816667,-40.35
br,castelhanos de fora,Castelhanos de Fora,18,,-25.5722,-49.95
br,castell,Castell,16,,-5.066667,-56.35
br,castello,Castello,08,,-20.6,-41.2
br,castello,Castello,11,,-18.633333,-57.55
br,castello,Castello,20,,-5.333333,-41.55
br,castelo,Castelo,04,,-3.5,-68.3
br,castelo,Castelo,08,20198,-20.6,-41.2
br,castelo,Castelo,11,,-18.633333,-57.55
br,castelo,Castelo,13,,-3.5,-45.533333
br,castelo,Castelo,16,,-5.066667,-56.35
br,castelo,Castelo,17,,-6.783333,-37.533333
br,castelo,Castelo,18,,-25.166667,-53.266667
br,castelo,Castelo,20,,-5.333333,-41.55
br,castelo,Castelo,21,,-22.909151,-43.172155
br,castelo da torre,Castelo da Tôrre,05,,-12.583333,-38.033333
br,castelo do piaui,Castelo do Piauí,20,8589,-5.333333,-41.55
br,castelo novo,Castelo Novo,05,,-14.633333,-39.2
br,castilho,Castilho,27,11419,-20.866667,-51.483333
br,castilhos,Castilhos,23,,-27.816667,-52.166667
br,castolandia,Castolândia,06,,-5.516667,-38.266667
br,castrinopolis,Castrinópolis,29,,-15.35,-49.5
br,castro alres,Castro Alres,23,,-29.033333,-51.416667
br,castro alves,Castro Alves,04,,-3.366667,-68.95
br,castro alves,Castro Alves,05,13869,-12.75,-39.433333
br,castro alves,Castro Alves,23,,-29.033333,-51.416667
br,castro,Castro,02,,-10.216667,-36.783333
br,castro,Castro,18,42092,-24.783333,-50
br,castro,Castro,20,,-3.95,-42.483333
br,castro,Castro,22,,-6.516667,-38.166667
br,castro,Castro,28,,-11.416667,-37.416667
br,castrolandia,Castrolândia,29,,-15.35,-49.5
br,casualidade,Casualidade,11,,-22.05,-57
br,cata branca,Cata Branca,15,,-20.2224,-43.8477
br,catadupas,Catadupas,15,,-22.35,-45.783333
br,cataguarinho,Cataguarinho,15,,-21.3,-42.716667
br,cataguarino,Cataguarino,15,,-21.3,-42.716667
br,cataguases,Cataguases,15,62619,-21.4,-42.683333
br,cataguazes,Cataguazes,15,,-21.4,-42.683333
br,catajal,Catajal,15,,-16.633333,-40.333333
br,catakeamain,Catakeamain,24,,-11.133333,-63.15
br,catalao,Catalão,29,63545,-18.166667,-47.95
br,catana,Catana,05,,-12.083333,-38.083333
br,catanduva,Catanduva,23,,-29.766667,-50.566667
br,catanduva,Catanduva,27,109615,-21.133333,-48.966667
br,catanduva de dentro,Catanduva de Dentro,18,,-24.966667,-49.883333
br,catanduvas,Catanduvas,18,,-25.2,-53.133333
br,catanduvas,Catanduvas,26,,-27.066667,-51.683333
br,catangara,Catangara,26,,-26.9411,-49.9372
br,catao,Catão,05,,-12.3,-44.833333
br,cataqueama,Cataqueamã,24,,-11.133333,-63.15
br,cataquesma,Cataquesmã,24,,-11.133333,-63.15
br,catarina,Catarina,06,,-2.966667,-39.983333
br,catarina,Catarina,20,,-5.133333,-42.783333
br,catarina guimaraes,Catarina Guimarães,11,,-19.416667,-54.65
br,catarinenses,Catarinenses,18,,-23.033333,-52.666667
br,catas altas,Catas Altas,15,,-20.066667,-43.4
br,catas altas da noruega,Catas Altas da Noruega,15,,-20.683333,-43.5
br,cataua,Catauá,15,,-20.783333,-43.683333
br,catauara,Catauara,16,,-3.35,-56.383333
br,catavento,Catavento,06,,-6.216667,-38.666667
br,ca-te-espero,Cá-te-espero,04,,-5.859722,-61.326389
br,ca-te-espero,Cá-te-Espero,16,,-1.333333,-50.416667
br,catende,Catende,30,23323,-8.666667,-35.716667
br,catequese,Catequese,27,,-22.433333,-50.15
br,cateriangongo,Cateriangongo,15,,-16.083333,-41.5
br,catesporo,Catesporo,16,,-1.333333,-50.416667
br,catete,Catete,13,,-5.583333,-45.4
br,catete,Catete,15,,-21.166667,-46.366667
br,catete,Catete,21,,-22.925416,-43.181371
br,catete,Catete,26,,-26.730848,-49.543817
br,cateto,Cateto,18,,-23.2024,-50.2483
br,cateto,Cateto,27,,-20.4,-48.7
br,catetu,Catetu,06,,-2.85,-40.183333
br,cathe,Cathé,18,,-24.033333,-50.45
br,catiara,Catiara,15,,-19.166667,-46.666667
br,catigua,Catiguá,27,,-21.05,-49.05
br,catimbau,Catimbau,30,,-8.6,-37.25
br,catinga,Catinga,04,,-4.171944,-60.616944
br,catinga,Catinga,06,,-5.333333,-40.583333
br,catinga,Catinga,15,,-17.166667,-45.883333
br,catinga,Catinga,17,,-7.033333,-36.6
br,catinga da areia,Catinga da Areia,22,,-5.619722,-36.076667
br,catinga da moura,Catinga da Moura,05,,-10.966667,-40.75
br,catinga de cima,Catinga de Cima,05,,-11.283333,-38.033333
br,catinga de porco,Catinga de Porco,20,,-6.516667,-42.266667
br,catinga do moura,Catinga do Moura,05,,-10.966667,-40.75
br,catinga grande,Catinga Grande,06,,-6.483333,-39.05
br,catingal,Catingal,05,,-14.066667,-40.216667
br,catingas,Catingas,05,,-13.6,-39.983333
br,catingueira,Catingueira,06,,-6.3,-39.1
br,catingueira,Catingueira,17,,-6.5,-38.466667
br,catingueiro,Catingueiro,06,,-5.7,-40.633333
br,catingueiro,Catingueiro,20,,-10.65,-45.183333
br,catingueiro,Catingueiro,27,,-22.166667,-46.866667
br,catinguinha,Catinguinha,13,,-3.346944,-42.374167
br,catinqueiro,Catinqueiro,20,,-10.65,-45.183333
br,catipe,Catipé,13,,-3.119167,-42.403333
br,catipora,Catiporã,23,,-29.016667,-51.7
br,catirina,Catirina,06,,-7.233333,-38.966667
br,catita,Catita,05,,-9.516667,-43.016667
br,catita,Catita,15,,-19.55,-44.733333
br,catita,Catita,17,,-8.15,-36.983333
br,catole,Catolé,05,,-12.633333,-38.9
br,catole,Catolé,06,,-4.066667,-38.5
br,catole,Catolé,17,,-6.316667,-37.683333
br,catole,Catolé,22,,-5.383333,-35.466667
br,catole,Catolé,30,,-7.533333,-39.783333
br,catole do monte,Catolé do Monte,17,,-7.383333,-36.1
br,catole do rocha,Catolé do Rocha,17,19812,-6.35,-37.75
br,catole sabambaia de cima,Catolé Sabambaia de Cima,05,,-13.283333,-41.883333
br,catoles,Catolés,05,,-13.3,-41.833333
br,catolezinho,Catolèzinho,05,,-15.133333,-40.45
br,catolezinho,Catolézinho,06,,-5.783333,-39.65
br,catolezinho,Catolèzinho,17,,-6.483333,-37.95
br,catolezinho,Catolèzinho,22,,-6.2,-38.333333
br,catone,Catoné,15,,-20.916667,-42.15
br,catonho,Catonho,21,,-22.907192,-43.37531
br,catonho,Catonho,30,,-8.666667,-37.216667
br,catorze de julho,Catorze de Julho,21,,-22.764965,-43.289678
br,catrimani,Catrimani,25,,.45,-61.683333
br,catrimany,Catrimany,25,,.45,-61.683333
br,cattas altas,Cattas Altas,15,,-20.066667,-43.4
br,cattas altas de noruega,Cattas Altas de Noruega,15,,-20.683333,-43.5
br,catuana,Catuana,06,,-3.683333,-38.916667
br,catucaba,Catuçaba,27,,-23.25,-45.2
br,catu,Catu,05,39933,-12.35,-38.383333
br,catude,Catude,11,,-20.133333,-56.083333
br,catugi,Catugi,15,,-17.333333,-41.5
br,catugi,Catugi,18,,-23.766667,-51.416667
br,catu grande,Catu Grande,05,,-12.7,-38.866667
br,catuicara,Catuiçara,05,,-12.283333,-38.6
br,catuipe,Catuípe,23,,-28.25,-54.016667
br,catuira,Catuíra,26,,-27.666667,-49.4
br,catule,Catulé,05,,-14.916667,-45.433333
br,catule,Catulé,06,,-5.933333,-39.733333
br,catule-do-rocha,Catulé-do-Rocha,17,,-6.35,-37.75
br,catules,Catulés,05,,-13.3,-41.833333
br,catumbi,Catumbi,18,,-25.366667,-48.7
br,catumbi,Catumbi,21,,-22.916504,-43.193204
br,catunda,Catunda,06,,-4.533333,-40.2
br,catune,Catuné,15,,-20.916667,-42.15
br,catuni,Catuni,05,,-10.316667,-40.183333
br,catuni,Catuni,15,,-16.25,-43.316667
br,catu pequeno,Catu Pequeno,05,,-12.733333,-38.866667
br,catupi,Catupi,23,,-29.616667,-51.6
br,caturai,Caturaí,29,,-16.466667,-49.5
br,caturama,Caturama,05,,-13.316667,-42.3
br,catureta,Caturetã,23,,-29.166667,-51.633333
br,caturia,Caturiá,04,,-3.5,-68.416667
br,caturiaro,Caturiaro,20,,-6.933333,-41.733333
br,caturite,Caturité,17,,-7.4,-35.983333
br,caua,Cauã,22,,-5.833333,-35.983333
br,cauacu,Cauaçu,22,,-5.466667,-35.3
br,cauan,Cauan,22,,-5.083333,-35.8
br,cauarru,Cauarrú,13,,-5.1,-43.85
br,cauassu,Cauassu,17,,-6.883333,-37.483333
br,caubi,Caubi,05,,-14.2,-39.033333
br,caubi,Caubi,25,,2.533333,-60.933333
br,caucaia,Caucaia,06,275023,-3.7,-38.65
br,caucaia do alto,Caucaia do Alto,27,,-23.687967,-47.020966
br,cauhipe,Cauhipe,06,,-3.7,-38.85
br,cauipe,Cauípe,06,,-3.7,-38.85
br,cauitau,Cauitau,04,,-3.483333,-66.066667
br,cauna,Caúna,26,,-26.35,-50.883333
br,causa boa,Causa Boa,05,,-12.85,-41.316667
br,cavaca,Cavaca,13,,-3.826944,-43.419722
br,cava,Cava,15,,-21.516667,-45.333333
br,cava,Cava,21,,-22.684722,-43.459444
br,cavaco,Cavaco,05,,-13.05,-39.65
br,cavaco,Cavaco,15,,-21.166667,-46.1
br,cavaco,Cavaco,18,,-25.2,-52.116667
br,cavaco,Cavaco,30,,-8.383333,-37.7
br,cava da onca,Cava da Onça,05,,-12.283333,-38.35
br,cavagnoli,Cavagnoli,18,,-26.150278,-53.576944
br,cavaidaruco,Cavaidaruco,04,,1.1,-67.25
br,cavalaria,Cavalaria,06,,-4.183333,-38.516667
br,cavalcante,Cavalcante,24,,-8.4,-63.4
br,cavalcante,Cavalcante,29,3747,-13.8,-47.5
br,cavalcanti,Cavalcanti,21,,-22.87171,-43.315977
br,cavalcanti,Cavalcanti,24,,-8.4,-63.4
br,cavalcanti,Cavalcanti,29,,-13.8,-47.5
br,cavaleiro,Cavaleiro,20,,-9.1,-42.366667
br,cavaleiro,Cavaleiro,30,,-8.033333,-35.016667
br,cavalheiro,Cavalheiro,20,,-9.1,-42.366667
br,cavalheiro,Cavalheiro,29,,-17.25,-48.033333
br,cavalheiros,Cavalheiros,29,,-17.25,-48.033333
br,cavalin,Cavalin,27,,-22.233333,-50.15
br,cavalinho,Cavalinho,08,,-19.7,-40.383333
br,cavalo,Cavalo,14,,-14.683333,-56.283333
br,cavalo,Cavalo,28,,-9.983333,-37.066667
br,cavalo-de agua,Cavalo-de Água,27,,-24.799,-48.4848
br,cavalos,Cavalos,06,,-5.466667,-38.983333
br,cavalos,Cavalos,13,,-9.9,-46.316667
br,cavaru,Cavaru,21,,-22.250556,-43.346667
br,caveira,Caveira,30,,-7.583333,-35.216667
br,caveiras,Caveiras,05,,-12.8,-39.05
br,caveiras,Caveiras,23,,-30.85,-54.85
br,caverazinho,Caveràzinho,26,,-28.966667,-49.5
br,caverria do diabo,Caverria do Diabo,27,,-24.6355,-48.4044
br,caviana,Cavianã,13,,-3.561944,-42.705
br,cavi,Cavi,27,,-24.721006,-48.060175
br,caviuna,Caviúna,18,,-23.3,-51.366667
br,caviuna,Caviúna,27,,-24.579564,-48.960685
br,cavunge,Cavunge,05,,-12.25,-39.333333
br,cavuvu,Cavuvu,27,,-24.6854,-48.3839
br,caxambu,Caxambu,15,22701,-21.983333,-44.933333
br,caxambu,Caxambu,26,,-27.166667,-52.866667
br,caxanga,Caxangá,16,,-6.6,-51.983333
br,caxanga,Caxangá,30,,-8.483333,-35.4
br,caxe,Caxé,20,,-8.45,-42.4
br,caxeta,Caxeta,26,,-26.804474,-49.581785
br,caxias,Caxias,04,,-4.4825,-71.435556
br,caxias,Caxias,13,117393,-4.833333,-43.35
br,caxias,Caxias,21,,-22.790321,-43.325009
br,caxias,Caxias,23,,-29.1689,-51.1785
br,caxias das aldeias altas,Caxias das Aldeias Altas,13,,-4.833333,-43.35
br,caxias do sul,Caxias do Sul,23,381277,-29.1689,-51.1785
br,caximba,Caximba,27,,-21.25,-50.233333
br,caxinana,Caxinana,04,,-6.75,-70.133333
br,caxinaua,Caxinauá,01,,-8.716667,-71.883333
br,caxinaua,Caxinauá,04,,-6.75,-70.133333
br,caxinga,Caxingá,20,,-3.366667,-41.933333
br,caxingo,Caxingó,05,,-12.25,-42.766667
br,caxingo,Caxingó,13,,-3.620556,-42.655278
br,caxingo,Caxingó,20,,-10.498056,-45.220278
br,caxingo,Caxingó,30,,-8.9,-36.6
br,caxitore,Caxitoré,06,,-3.733333,-39.35
br,caxius do sul,Caxius do Sul,23,,-29.1689,-51.1785
br,caxixa,Caxixa,08,,-20.483333,-41.133333
br,caxumba,Caxumba,21,,-22.282132,-42.983321
br,cayambe,Cayambé,04,,-3.566667,-64.383333
br,cayaue,Cayaué,04,,-3.05,-65.966667
br,cayru,Cayru,05,,-13.5,-39.05
br,cayua,Cayuá,27,,-21.883333,-51.966667
br,caze,Cazé,06,,-5.1,-40.283333
br,cazuqui,Cazuqui,20,,-7.2,-41.85
br,cazuza,Cazuza,06,,-5.616667,-39.866667
br,cazuza ferreira,Cazuza Ferreira,23,,-28.95,-50.666667
br,ceara,Ceará,01,,-7.983333,-71.983333
br,ceara,Ceará,06,,-3.716667,-38.5
br,ceara,Ceará,13,,-1.75,-44.833333
br,ceara-mirim,Ceará-Mirim,22,32668,-5.633333,-35.433333
br,cearenses,Cearenses,08,,-19.666667,-40.833333
br,cebolao,Cebolão,18,,-23.466667,-50.883333
br,ceci,Ceci,11,,-23.45,-55
br,cecilia,Cecília,06,,-5.033333,-40.1
br,cedral,Cedral,27,,-20.9,-49.316667
br,cedro,Cedro,02,,-10,-36.6
br,cedro,Cedro,05,,-12.416667,-38.95
br,cedro,Cedro,06,14644,-6.6,-39.05
br,cedro,Cedro,11,,-18.283333,-55.033333
br,cedro,Cedro,13,,-2.533333,-43.55
br,cedro,Cedro,14,,-13.283333,-56.1
br,cedro,Cedro,15,,-16.666667,-43.916667
br,cedro,Cedro,16,,-5.6,-49.233333
br,cedro,Cedro,17,,-7.266667,-38.483333
br,cedro,Cedro,20,,-5.35,-42.466667
br,cedro,Cedro,21,,-22.938291,-43.458891
br,cedro,Cedro,27,,-24.9558,-48.4778
br,cedro,Cedro,28,,-10.25,-36.883333
br,cedro,Cedro,29,,-17.566667,-52.6
br,cedro,Cedro,30,,-7.5,-39.6
br,cedro de cima,Cedro de Cima,17,,-6.933333,-38.283333
br,cedro de sao joao,Cedro de São João,28,,-10.25,-36.883333
br,cedro do abaete,Cedro do Abaeté,15,,-19.133333,-45.7
br,cedrolandia,Cedrolândia,08,,-18.8,-40.683333
br,cedrolina,Cedrolina,29,,-14.5,-49.566667
br,cedro medio,Cedro Médio,26,,-28.716667,-49.583333
br,cego,Cego,16,,-.25,-50.033333
br,cego,Cego,30,,-8.483333,-36.816667
br,ceilandia,Ceilândia,07,,-15.816667,-48.116667
br,celina,Celina,08,,-20.766667,-41.583333
br,celso,Celso,03,,1.933333,-50.8
br,celsolandia,Celsolândia,06,,-2.983333,-40.116667
br,celso ramos,Celso Ramos,26,,-27.616667,-51.4
br,ceminario gravatai,Ceminário Gravataí,23,,-29.9399,-50.9888
br,cemiterio grande,Cemitério Grande,25,,-2.05,-61.016667
br,cemoaba,Cemoaba,06,,-3.433333,-39.433333
br,centenario,Centenário,11,,-19.466667,-56.05
br,centenario,Centenário,15,,-19.683333,-41.466667
br,centenario,Centenário,21,,-22.780661,-43.325123
br,centenario,Centenário,23,,-27.783333,-52.05
br,centenario,Centenário,31,,-8.894722,-47.183333
br,centenario do sul,Centenário do Sul,18,8358,-22.8,-51.616667
br,central,Central,03,,-.333333,-51.6
br,central,Central,05,,-11.133333,-42.133333
br,central,Central,06,,-6.066667,-40.433333
br,central,Central,18,,-25.470348,-48.837065
br,central de minas,Central de Minas,15,,-18.75,-41.333333
br,central de santa helena,Central de Santa Helena,15,,-18.75,-41.583333
br,centralina,Centralina,15,9497,-18.566667,-49.216667
br,centralito,Centralito,18,,-24.983333,-53.333333
br,central lupion,Central Lupion,18,,-25,-53.566667
br,central santa cruz,Central Santa Cruz,18,,-24.683333,-53.383333
br,centro,Centro,13,,-3.125278,-42.7375
br,centro,Centro,15,,-22.6323,-45.5495
br,centro,Centro,20,,-4.483333,-41.5
br,centro,Centro,21,,-22.891313,-43.126134
br,centro da agua branca,Centro da Água Branca,13,,-3.902778,-43.261944
br,centro da agua rica,Centro da Água Rica,13,,-3.7025,-43.036667
br,centro da barra,Centro da Barra,21,,-23.004838,-43.323975
br,centro da mata da varjota,Centro da Mata da Varjota,13,,-3.986389,-43.415278
br,centro da sabina,Centro da Sabina,13,,-3.428333,-43.143333
br,centro do diamante,Centro do Diamante,13,,-5.283333,-43.333333
br,centro dos abreus,Centro dos Abreus,13,,-3.671667,-42.847222
br,centro do santo antonio,Centro do Santo Antônio,13,,-3.375278,-43.495556
br,centro dos boas,Centro dos Boas,13,,-4.066667,-45.166667
br,centro dos ferreiras,Centro dos Ferreiras,13,,-3.639722,-43.443333
br,centro dos gomes,Centro dos Gomes,13,,-3.744722,-43.183611
br,centro dos jeronimos,Centro dos Jerônímos,13,,-3.656944,-43.311667
br,centro dos jonas,Centro dos Jonas,13,,-3.666389,-43.320556
br,centro dos lopes,Centro dos Lopes,13,,-3.673889,-43.330278
br,centro dos messias,Centro dos Messias,13,,-3.813333,-43.232778
br,centro dos monteis,Centro dos Montéis,13,,-3.7275,-43.196667
br,centro dos paulos,Centro dos Paulos,13,,-3.578611,-43.453056
br,centro dos teixeiras,Centro dos Teixeiras,13,,-3.643333,-42.931944
br,centro grande,Centro Grande,13,,-3.216667,-43.766667
br,centro i,Centro I,13,,-3.169167,-43.209722
br,centro ii,Centro II,13,,-3.183889,-43.229444
br,centro iii,Centro III,13,,-3.196944,-43.249167
br,centro jose machado,Centro José Machado,13,,-4.366667,-45.033333
br,centro novo,Centro Novo,13,,-4.233333,-44.183333
br,centro seco,Centro Sêco,13,,-3.216667,-43.8
br,centro velho,Centro Velho,13,,-3.775,-43.316944
br,ceo aberto,Céo Aberto,04,,-7.733333,-67.916667
br,cepa,Cepa,05,,-15.983333,-39.116667
br,cepa forte,Cepa Forte,05,,-11.566667,-37.7
br,cepo forte,Cepo Forte,05,,-11.566667,-37.7
br,ceraima,Ceraíma,05,,-14.266667,-42.75
br,ceramica,Cerámica,15,,-19.166667,-46.566667
br,ceramica,Cerâmica,20,,-5.016667,-42.8
br,cercadinho,Cercadinho,18,,-23.8,-49.883333
br,cercadinho,Cercadinho,27,,-23.468938,-47.761705
br,cercadinho,Cercadinho,31,,-9.805278,-48.723889
br,cercado,Cercado,05,,-10.7,-44.166667
br,cercado,Cercado,14,,-16.483333,-56.333333
br,cercado,Cercado,15,,-19.866667,-44.983333
br,cercado,Cercado,20,,-6.95,-41.4
br,cercado,Cercado,27,,-23.5869,-47.7549
br,cercado,Cercado,30,,-9.35,-36.966667
br,cercado do meio,Cercado do Meio,06,,-5.1,-37.95
br,cercado velho,Cercado Velho,06,,-3.816667,-41.283333
br,cerca velha,Cêrca Velha,15,,-19.516667,-46.083333
br,cerca velha,Cerca Velha,20,,-7.466667,-41.783333
br,cerco,Cêrco,05,,-12.166667,-41.4
br,cerco,Cêrco,22,,-5.868056,-36.670833
br,cerejeira,Cerejeira,08,,-21.133333,-41.316667
br,cerejeiras,Cerejeiras,27,,-23.3647,-46.06
br,ceres,Ceres,29,18760,-15.283333,-49.583333
br,ceresopolis,Ceresópolis,29,,-15.066667,-49.683333
br,cernambi,Cernambi,04,,-3.221944,-62.991389
br,cerne,Cerne,18,,-25.294916,-48.990693
br,cerobas,Cerobas,02,,-9.816667,-35.983333
br,cerqueira cesar,Cerqueira César,27,14261,-23.05,-49.166667
br,cerqueira cezar,Cerqueira Cezar,27,,-23.05,-49.166667
br,cerquilho,Cerquilho,27,35367,-23.201218,-47.757822
br,cerquilho velho,Cerquilho Velho,27,,-23.182753,-47.74501
br,cerquinha,Cerquinha,05,,-13.833333,-42.583333
br,cerquinha,Cerquinha,14,,-14.4,-55.966667
br,cerquinho,Cerquinho,30,,-8.883333,-36.266667
br,cerquinilha,Cerquinilha,30,,-8.883333,-36.266667
br,cerradinho,Cerradinho,18,,-23.8,-49.883333
br,cerrado,Cerrado,18,,-24.083333,-49.95
br,cerrado,Cerrado,27,,-23.5523,-47.8344
br,cerrito alegre,Cerrito Alegre,23,,-31.533333,-52.35
br,cerrito,Cerrito,11,,-23.516667,-54.483333
br,cerrito,Cerrito,23,,-31.85,-52.816667
br,cerrito,Cerrito,26,,-26.116667,-50.483333
br,cerro alegre,Cêrro Alegre,11,,-22.883333,-55.616667
br,cerro alegre,Cerro Alegre,18,,-25.758021,-50.049325
br,cerro azul,Cêrro Azul,18,,-24.833333,-49.25
br,cerro azul,Cerro Azul,23,,-28.15,-54.75
br,cerro azul,Cerro Azul,26,,-26.589107,-49.622915
br,cerro branco,Cêrro Branco,14,,-15.983333,-58.616667
br,cerro branco,Cêrro Branco,23,,-29.566667,-53.05
br,cerro,Cêrro,18,,-25.45,-50.916667
br,cerro chato,Cêrro Chato,23,,-29.683333,-53.266667
br,cerro-cora,Cerro-Corá,22,,-6.05,-36.35
br,cerro da arvore,Cêrro da Árvore,23,,-30.65,-52.75
br,cerro da canela,Cerro da Canela,23,,-30.6301,-52.2681
br,cerro da madeira,Cerro da Madeira,23,,-30.5574,-52.3656
br,cerro do leao,Cêrro do Leão,18,,-25.566667,-51.016667
br,cerro grande,Cêrro Grande,23,,-30.6,-51.75
br,cerro largo,Cêrro Largo,23,9548,-28.15,-54.75
br,cerro lindo,Cerro Lindo,18,,-25.936768,-50.231356
br,cerro negro,Cêrro Negro,26,,-27.8,-50.883333
br,cerro pelado,Cêrro Pelado,23,,-27.9,-55.133333
br,cerro pelado,Cêrro Pelado,26,,-26.45,-51.166667
br,cerros de mairipora,Cerros de Mairiporã,27,,-23.33699,-46.621906
br,cerro torim,Cêrro Torim,11,,-23.533333,-55.516667
br,cerro verde,Cêrro Verde,18,,-25.166667,-51.75
br,cerveja,Cerveja,06,,-7.233333,-40.5
br,cervinho,Cervinho,27,,-22.6,-50.45
br,cervo,Cervo,11,,-19.866667,-56.383333
br,cervo,Cervo,14,,-15.833333,-55.75
br,cervo,Cervo,15,,-21.2,-45.783333
br,cesarao,Cesarão,21,,-22.936075,-43.656877
br,cesar correia,César Correia,15,,-21.933333,-45.566667
br,cesar de pina,César de Pina,15,,-21.066667,-44.216667
br,cesarino afonso,Cesarino Afonso,27,,-22.25,-52.233333
br,cesario alvim,Cesário Alvim,21,,-22.666667,-42.45
br,cesario,Cesário,14,,-16.3,-57.433333
br,cesario lange,Cesário Lange,27,,-23.2247,-47.9536
br,ceu aberto,Céu Aberto,04,,-7.733333,-67.916667
br,ceu azul,Céu Azul,18,,-25.1502,-53.847
br,ceu azul,Céu Azul,27,,-24.741806,-48.075856
br,ceu azul,Céu Azul,30,,-8.016667,-38.916667
br,cevadongo,Cevadongo,11,,-21.15,-55.65
br,ceveira,Ceveira,27,,-22.366667,-47.983333
br,chacara acacia,Chácara Acácia,23,,-30.7035,-52.4737
br,chacara aurora,Chácara Aurora,04,,-2.755556,-60.0375
br,chacara,Chácara,15,,-15.733333,-42.35
br,chacara,Chácara,18,,-25.496667,-50.078333
br,chacara das palmeiras,Chácara das Palmeiras,15,,-20.45,-45.4
br,chacara do ceu,Chácara do Ceu,21,,-22.990771,-43.235058
br,chacara dois irmaos,Chácara Dois Irmãos,23,,-30.7235,-52.3502
br,chacara sao joao,Chácara São João,23,,-30.5465,-52.449
br,chacaras,Chácaras,14,,-15.2,-56.416667
br,chacaras coloniais village interlagos,Chácaras Coloniais Village Interlagos,27,,-23.357297,-46.659415
br,cha,Chã,02,,-9.616667,-36.45
br,chacorore,Chacororé,14,,-16.216667,-55.966667
br,cha da alegria,Chã da Alegria,30,,-7.983333,-35.216667
br,cha d'alegria,Cha d'Alegria,30,,-7.983333,-35.216667
br,cha de imbira,Chã de Imbira,02,,-9.833333,-36.266667
br,cha do estevam,Châ do Estevam,30,,-7.8,-35.05
br,cha do estevao,Chã do Estêvão,30,,-7.8,-35.05
br,cha do imbira,Chã do Imbira,02,,-9.833333,-36.266667
br,cha do rocha,Chã do Rocha,30,,-7.65,-35.566667
br,chafariz,Chafariz,20,,-3.733333,-41.416667
br,chafariz,Chafariz,22,,-5.462778,-37.303611
br,chagas,Chagas,01,,-10.883333,-68.483333
br,chagas,Chagas,23,,-31.9,-53.066667
br,chagas,Chagas,27,,-20.783333,-47.433333
br,chagas,Chagas,29,,-15.916667,-49.266667
br,cha grande,Chã Grande,30,17117,-8.233333,-35.45
br,chagu,Chagu,18,,-25.366667,-52.583333
br,chalana,Chalana,26,,-27.183333,-52.766667
br,chale,Chalé,15,,-20.033333,-41.7
br,chale,Chalé,21,,-21.6,-41.916667
br,chalet,Chalet,15,,-20.033333,-41.7
br,chambica,Chambica,31,,-6.4325,-48.381944
br,chambicazinho,Chambicazinho,31,,-6.4325,-48.381944
br,chambioa,Chambioá,16,,-6.4,-48.55
br,chambioazinho,Chambioàzinho,31,,-6.4325,-48.381944
br,chambivas,Chambivás,31,,-6.4325,-48.381944
br,chamego,Chamego,05,,-12.383333,-41.15
br,chamengo,Chamengo,05,,-12.383333,-41.15
br,champanha,Champanha,04,,-6.2,-59.033333
br,champs prives,Champs Privés,27,,-23.251874,-46.709593
br,chamu,Chamu,20,,-3.318056,-42.061944
br,chamuscada,Chamuscada,05,,-10.033333,-42.633333
br,chanaan,Chanaan,15,,-20.683333,-42.616667
br,chanchavocaia,Chanchavocaia,01,,-8.65,-73.183333
br,chane,Chané,11,,-18.15,-57.366667
br,changondo,Changondo,28,,-9.716667,-37.633333
br,chapada,Chapada,05,,-11.05,-41.966667
br,chapada,Chapada,06,,-4.283333,-38.8
br,chapada,Chapada,11,,-21.433333,-55.566667
br,chapada,Chapada,13,,-3.696389,-43.044722
br,chapada,Chapada,14,,-15.433333,-55.75
br,chapada,Chapada,15,,-17.116667,-42.533333
br,chapada,Chapada,17,,-7.566667,-37.75
br,chapada,Chapada,18,,-23.495605,-49.860886
br,chapada,Chapada,20,,-3.983611,-42.561944
br,chapada,Chapada,23,,-28.05,-53.066667
br,chapada,Chapada,31,,-10.598611,-49.108333
br,chapada da lagoa,Chapada da Lagoa,20,,-6.25,-42.533333
br,chapada da sinda,Chapada da Sindá,20,,-3.865833,-42.433611
br,chapada da vereda,Chapada da Vereda,20,,-6.283333,-42.616667
br,chapada de minas,Chapada de Minas,15,,-18.583333,-47.633333
br,chapada de sao francisco,Chapada de São Francisco,20,,-7.416667,-44.4
br,chapada de sao miguel,Chapada de São Miguel,20,,-3.795833,-42.092222
br,chapada do acude,Chapada do Acude,20,,-5.766667,-42.283333
br,chapada do arroz,Chapada do Arroz,05,,-12.4,-42.883333
br,chapada do barrocao,Chapada do Barrocão,20,,-3.682778,-42.5175
br,chapada do elias,Chapada do Elias,20,,-3.488056,-42.111667
br,chapada do guimaraes,Chapada do Guimarães,14,,-15.433333,-55.75
br,chapada do jatoba,Chapada do Jatobá,20,,-6.866667,-43.45
br,chapada do meio,Chapada do Meio,13,,-3.718889,-43.333333
br,chapada do pau de mel,Chapada do Pau de Mel,20,,-6.483333,-42.3
br,chapada do paulino,Chapada do Paulino,20,,-6.383333,-42.366667
br,chapada do severo,Chapada do Severo,30,,-7.85,-39.966667
br,chapada dos guimaraes,Chapada dos Guimarães,14,13657,-15.433333,-55.75
br,chapada i,Chapada I,20,,-3.413611,-42.088056
br,chapada ii,Chapada II,20,,-3.504722,-42.007778
br,chapada iii,Chapada III,13,,-3.385556,-42.4175
br,chapadao,Chapadão,13,,-3.688333,-43.369444
br,chapadao,Chapadão,14,,-15.1,-56.716667
br,chapadao,Chapadão,15,,-18.233333,-47.1
br,chapadao,Chapadão,21,,-22.822984,-43.373282
br,chapadao grande,Chapadão Grande,27,,-23.5901,-47.9755
br,chapadas,Chapadas,15,,-20.483333,-43.566667
br,chapada velha,Chapada Velha,05,,-12.016667,-42.166667
br,chapadinha,Chapadinha,13,40805,-3.733333,-43.35
br,chapadinha,Chapadinha,20,,-3.835278,-42.523333
br,chapadinha,Chapadinha,27,,-23.633333,-48.033333
br,chapadinho,Chapadinho,20,,-5.283333,-42.716667
br,chapeco,Chapecó,26,160160,-27.083333,-52.983333
br,chapelao,Chapelão,04,,-4.003333,-60.58
br,chapena,Chapena,11,,-20.466667,-56.383333
br,chapeo,Chapeo,23,,-28.9,-50.383333
br,chapeo,Chapeo,27,,-24.466667,-49.033333
br,chapeo,Chapeo,29,,-13.233333,-47.166667
br,chapeu,Chapéu,11,,-20.083333,-55.383333
br,chapeu,Chapéu,15,,-19.883333,-47.216667
br,chapeu,Chapéu,17,,-7.25,-38.516667
br,chapeu,Chapéu,18,,-23.55,-52.233333
br,chapeu,Chapéu,20,,-8.183333,-40.883333
br,chapeu,Chapéu,23,,-28.9,-50.383333
br,chapeu,Chapéu,29,,-13.233333,-47.166667
br,chapeu de couro,Chapéu de Couro,13,,-3.443056,-42.354722
br,chapeu de sol,Chapéu de Sol,02,,-9.766667,-36.433333
br,chapeu de sol,Chapéu de Sol,18,,-26.2,-50.733333
br,chapeu do gato,Chapéu do Gato,05,,-12.016667,-40.7
br,chapeu virado,Chapéu Virado,16,,-1.15,-48.466667
br,cha preta,Chã Preta,02,,-9.266667,-36.3
br,charco,Charco,05,,-13.466667,-40.233333
br,charco,Charco,15,,-18.216667,-46.25
br,charco do cedro,Charco do Cedro,05,,-13.6,-40.233333
br,charcos das pedras,Charcos das Pedras,05,,-13.216667,-40.05
br,chargeada,Chargeada,27,,-22.5,-47.766667
br,charitas,Charitas,06,,-4.6,-40.633333
br,charitas,Charitas,21,,-22.933333,-43.1
br,charito,Charito,06,,-4.6,-40.633333
br,charqueada,Charqueada,23,,-29.266667,-56.583333
br,charqueada,Charqueada,27,12391,-22.5,-47.766667
br,charqueada,Charqueada,31,,-8.879167,-48.440833
br,charqueadas,Charqueadas,23,32076,-29.966667,-51.633333
br,charqueadinha,Charqueadinha,27,,-22.516667,-47.75
br,charque,Charque,26,,-26.59425,-49.987357
br,charrua,Charrua,23,,-27.916667,-52.033333
br,chata,Chata,30,,-8.583333,-36.083333
br,chatelodo,Chatelodo,11,,-21.316667,-57.466667
br,chatinho,Chatinho,20,,-5.2,-42.583333
br,chatuba,Chatuba,21,,-22.809638,-43.434196
br,chaval,Chaval,06,,-3.033333,-41.25
br,chavantes,Chavantes,27,10306,-23.033333,-49.716667
br,chavantina,Chavantina,14,,-14.666667,-52.35
br,chave arpard,Chave Arpard,27,,-21.8,-52.033333
br,chave de ouro,Chave de Ouro,21,,-22.902696,-43.2967
br,chave do barao,Chave do Barão,27,,-22.766667,-47.633333
br,chave do faria,Chave do Faria,21,,-21.616667,-42.1
br,chaves,Chaves,04,,-4.204444,-60.723611
br,chaves,Chaves,06,,-5.283333,-40.683333
br,chaves,Chaves,14,,-16.166667,-56.366667
br,chaves,Chaves,16,,-.166667,-49.916667
br,chcara kabu,Chcara Kabu,27,,-23.3655,-46.158
br,chcaras boa vista,Chcaras Boa Vista,27,,-23.3546,-46.2402
br,chcaras eldorado,Chcaras Eldorado,27,,-23.2922,-46.2159
br,chcara tsurumatsu seki,Chcara Tsurumatsu Seki,27,,-23.3421,-46.0874
br,cherente,Cherente,31,,-9.529167,-48.319722
br,cheruan,Cheruan,04,,-6.05,-67.833333
br,chervor,Chervor,04,,-6.05,-67.833333
br,chiador,Chiador,15,,-22.004167,-43.058889
br,chiapeta,Chiapeta,23,,-27.916667,-53.95
br,chiapetta,Chiapetta,23,,-27.916667,-53.95
br,chiba,Chiba,18,,-24.983333,-53.5
br,chibiu,Chibiu,14,,-16.35,-53.583333
br,chicao,Chicão,11,,-18.433333,-56.283333
br,chicao,Chicão,30,,-8.116667,-35.95
br,chicaozinho,Chicãozinho,02,,-9.266667,-37.333333
br,chicha,Chichá,05,,-10.066667,-43.133333
br,chico antonio,Chico Antônio,14,,-14.7,-57.283333
br,chico baiano,Chico Baiano,29,,-16.216667,-52.266667
br,chico dias,Chico Dias,13,,-3.963889,-43.322222
br,chico herrera,Chico Herrera,04,,-.316667,-65.383333
br,chico lunia,Chico Lunia,23,,-29.966667,-50.6
br,chico magro,Chico Magro,30,,-7.816667,-38.566667
br,chico mana,Chico Mana,01,,-8.183333,-73.483333
br,chico manoel,Chico Manoel,13,,-3.828333,-43.450556
br,chico marques,Chico Marques,05,,-11.033333,-43.933333
br,chico martins,Chico Martins,16,,-8.616667,-49.666667
br,chico pirara,Chico Pirará,25,,3.05,-61.15
br,chico roberto,Chico Roberto,14,,-10.316667,-50.466667
br,chico til,Chico Til,15,,-15.8,-40.616667
br,chicuru,Chicuru,30,,-9.133333,-36.683333
br,chifre de veado,Chifre de Veado,11,,-21.716667,-54.933333
br,chile,Chile,15,,-16.4,-40.75
br,chilelandia,Chilelândia,11,,-21.816667,-54.316667
br,chimarrao,Chimarrão,23,,-28.633333,-51.5
br,china,China,11,,-21.133333,-56.7
br,chinela,Chinela,13,,-7.766667,-46.033333
br,chinesa,Chinesa,15,,-16.083333,-40.116667
br,chiniqua,Chiniquá,23,,-29.666667,-54.366667
br,chique-chique,Chique-Chique,05,,-10.833333,-42.733333
br,chique chique,Chique Chique,05,,-9.516667,-43.6
br,chique-chique,Chique-Chique,06,,-7.1,-40
br,chiqueirao,Chiqueirão,16,,-4.35,-49.55
br,chiqueirinho,Chiqueirinho,02,,-9.566667,-36.433333
br,chiqueiro,Chiqueiro,05,,-11.866667,-37.733333
br,chiqueiro,Chiqueiro,13,,-3.850278,-43.063056
br,chiqueiro velho,Chiqueiro Velho,30,,-7.85,-38.933333
br,chiquito,Chiquito,29,,-15.183333,-49.7
br,chiriri,Chiriri,25,,3.233333,-60.516667
br,chiruan,Chiruan,04,,-6.05,-67.833333
br,chiru,Chiru,11,,-21.183333,-56.433333
br,choa,Choa,15,,-19.75,-48.05
br,chocalho,Chocalho,06,,-3.583333,-40.1
br,chocolatal,Chocolatal,24,,-10.166667,-65.283333
br,chomm grande,Chomm Grande,15,,-18.633333,-42.05
br,chonim,Chonim,15,,-18.633333,-42.05
br,chonim de baixo,Chonim de Baixo,15,,-18.666667,-41.966667
br,chonin,Chonin,15,,-18.633333,-42.05
br,chopeiro,Chopeiro,20,,-6.816667,-40.45
br,chopim,Chopim,18,,-25.85,-52.5
br,chopin,Chopin,18,,-25.85,-52.5
br,chopinzinho,Chopinzinho,18,14142,-25.85,-52.5
br,chora,Chora,06,,-3.35,-40.116667
br,chorador,Chorador,06,,-4.783333,-41.083333
br,chora menino,Chora Menino,27,,-23.49961,-46.645202
br,chorao,Chorão,17,,-7.566667,-38.433333
br,chorao,Chorão,20,,-3.713333,-42.468333
br,chorao,Chorão,23,,-28.333333,-53.9
br,chorocho,Chorochó,05,,-8.983333,-39.1
br,choro,Choró,06,,-4.816667,-39.15
br,chorona,Chorona,08,,-20.9,-41.45
br,chorozinho,Choròzinho,06,9755,-4.3,-38.483333
br,chorrocho,Chorrochó,05,,-8.983333,-39.1
br,christiano ottoni,Christiano Ottoni,15,,-20.833333,-43.8
br,christina,Christina,15,,-22.216667,-45.266667
br,christovinho,Christovinho,20,,-7.05,-41.5
br,chui,Chuí,23,,-33.683333,-53.45
br,chumbado,Chumbado,13,,-6.116667,-43
br,chumbo,Chumbo,04,,-4.411667,-59.874167
br,chumbo,Chumbo,15,,-18.616667,-46.2
br,chumichuga,Chumichuga,20,,-7.366667,-41.233333
br,chuna,Chuna,16,,-1.033333,-46.3
br,chupador,Chupador,18,,-23.966667,-51.466667
br,chupador de baixo,Chupador de Baixo,06,,-4.883333,-40.116667
br,chupeiro,Chupeiro,20,,-8.05,-43.466667
br,chupeta,Chupeta,02,,-9.266667,-37.866667
br,chure,Churé,05,,-11.933333,-42.433333
br,chuva,Chuva,15,,-16.583333,-41.966667
br,chuvarada,Chuvarada,11,,-21.383333,-57.883333
br,chuy,Chuy,23,,-33.683333,-53.45
br,cianita,Cianita,15,,-21.483333,-44.333333
br,cianorte,Cianorte,18,55995,-23.616667,-52.616667
br,cibauma,Cibaúma,22,,-6.283333,-35.033333
br,cibrao,Cibrão,15,,-18.183333,-41.616667
br,cicaba,Cicaba,23,,-28.9,-50.383333
br,cicero dantas,Cícero Dantas,05,18317,-10.6,-38.383333
br,cidade alta,Cidade Alta,21,,-22.815596,-43.292357
br,cidade anico la da barra,Cidade Aníco la da Barra,30,,-9.016667,-38.266667
br,cidade avicola da barra,Cidade Avícola da Barra,30,,-9.016667,-38.266667
br,cidade,Cidade,05,,-10.716667,-42.183333
br,cidade,Cidade,22,,-6.1,-38.45
br,cidade das criancas,Cidade das Crianças,21,,-22.891808,-43.689904
br,cidade de deus,Cidade de Deus,21,,-22.948798,-43.364928
br,cidade de minas,Cidade de Minas,15,,-19.916667,-43.933333
br,cidade dos meninos,Cidade dos Meninos,21,,-22.670278,-43.327778
br,cidade felipea,Cidade Felipéa,17,,-7.116667,-34.866667
br,cidade gaucha,Cidade Gaúcha,18,,-23.366667,-53.016667
br,cidade industrial,Cidade Industrial,15,,-19.95,-44.016667
br,cidade jardim laranjeiras,Cidade Jardim Laranjeiras,21,,-22.93902,-43.193126
br,cidade jardim montevideo,Cidade Jardim Montevideo,21,,-22.619444,-43.3975
br,cidade martins,Cidade Martins,27,,-23.431488,-46.512137
br,cidade nova,Cidade Nova,13,,-3.688889,-43.286944
br,cidade nova,Cidade Nova,21,,-22.91164,-43.200492
br,cidade pirituba,Cidade Pirituba,27,,-23.475144,-46.724969
br,cidade progresso,Cidade Progresso,18,,-22.766667,-51.5
br,cidade satelite,Cidade Satélite,15,,-19.95,-44.016667
br,cidade universitaria,Cidade Universitária,21,,-22.856817,-43.226644
br,cidreira,Cidreira,20,,-7.35,-43.283333
br,cidreira,Cidreira,23,8965,-30.183333,-50.2
br,cigana,Cigana,05,,-11.6,-40.383333
br,cigana,Cigana,13,,-2.583333,-45.366667
br,cigana,Cigana,16,,-5.55,-48.966667
br,cigana,Cigana,20,,-7.35,-41.783333
br,cigana,Cigana,22,,-5.269444,-36.126389
br,cigano,Cigano,06,,-5.833333,-40.633333
br,cigano,Cigano,13,,-3.956389,-43.248611
br,cigano,Cigano,22,,-5.109722,-37.419444
br,cilandia,Cilândia,21,,-22.470833,-43.545833
br,cima da serra,Cima da Serra,05,,-8.95,-38.533333
br,cimbres,Cimbres,30,,-8.35,-36.85
br,cinco anzois,Cinco Anzóis,16,,-1.65,-54.9
br,cincoenta e um,Cincoenta e Um,08,,-19.266667,-40.483333
br,cinco folhas,Cinco Fôlhas,15,,-18.333333,-42.566667
br,cinco ilhas,Cinco Ilhas,15,,-18.333333,-42.566667
br,cinco ilhas,Cinco Ilhas,27,,-20.516667,-51.433333
br,cinco irmaos,Cinco Irmãos,14,,-17.166667,-57.7
br,cinco lagoas,Cinco Lagoas,21,,-22.483889,-43.733333
br,cinco pontoes,Cinco Pontões,08,,-19.816667,-40.933333
br,cinco portoes,Cinco Portões,08,,-19.816667,-40.933333
br,cinco rios,Cinco Rios,05,,-12.433333,-38.533333
br,cinco vargens,Cinco Vargens,05,,-11.733333,-40.566667
br,cinelandia,Cinelândia,21,,-22.912332,-43.175825
br,ciniaco,Ciniaco,23,,-28.35,-51.883333
br,cinquentenario,Cinquentenário,23,,-27.666667,-54.6
br,cintra,Cintra,04,,-5.570556,-64.141111
br,cintra,Cintra,16,,-.766667,-47.45
br,cintra pimenta,Cintra Pimenta,18,,-22.816667,-52.966667
br,cintra pimentel,Cintra Pimentel,18,,-22.816667,-52.966667
br,cinzas,Cinzas,18,,-23.45,-50.283333
br,cinzeiro,Cinzeiro,13,,-3.441111,-42.73
br,cipoal,Cipoal,04,,-1.783333,-65.85
br,cipoal,Cipoal,15,,-15.816667,-44.75
br,cipoal,Cipoal,16,,-1.716667,-55.433333
br,cipoal,Cipoal,20,,-7.95,-43.166667
br,cipo,Cipó,05,,-11.1,-38.516667
br,cipo,Cipó,06,,-4.5,-41.066667
br,cipo,Cipó,13,,-3.968056,-43.342778
br,cipo,Cipó,17,,-6.9,-37.533333
br,cipo,Cipó,20,,-3.664167,-42.501667
br,cipo,Cipó,30,,-8.183333,-38.3
br,cipo de fogo,Cipo de Fogo,13,,-3.325,-43.489722
br,cipo de leite,Cipó de Leite,05,,-10.2,-37.783333
br,cipo do assu,Cipó do Assú,05,,-12.266667,-38.05
br,cipo dos anjos,Cipó dos Anjos,06,,-5,-38.716667
br,cipo iii,Cipó III,13,,-3.658056,-43.405
br,cipolandia,Cipolândia,11,,-20.133333,-55.4
br,cipool,Cipool,04,,-6.433333,-61.733333
br,cipo poco,Cipó Poço,04,,1.215,-69.384444
br,cipotanea,Cipotânea,15,,-20.9,-43.366667
br,cipotania,Cipotânia,15,,-20.9,-43.366667
br,cipotuba,Cipotuba,14,,-15.866667,-57.616667
br,cipriano,Cipriano,06,,-6.716667,-38.883333
br,cipriano,Cipriano,15,,-19.75,-43.95
br,ciriaco,Ciríaco,23,,-28.35,-51.883333
br,cirilo,Cirilo,15,,-15.45,-45.066667
br,cirurgiao,Cirurgião,20,,-5.583333,-43.033333
br,cisneiros,Cisneiros,15,,-21.433333,-42.366667
br,cisterna,Cisterna,15,,-19.1,-48.316667
br,citrolandia,Citrolândia,21,,-22.6,-43.016667
br,ciza,Ciza,24,,-12.616667,-62.066667
br,clara aurora,Clara Aurora,04,,-5.686111,-64.351667
br,clara,Clara,23,,-29.55,-54.35
br,claraiba,Claraíba,26,,-27.2,-48.916667
br,clarana,Claranã,30,,-7.65,-39.933333
br,claraval,Claraval,15,,-20.4,-47.283333
br,claretiana,Claretiana,29,,-14.033333,-46.616667
br,clarimunda,Clarimunda,15,,-18.433333,-48.55
br,clarimundo,Clarimundo,15,,-16.3,-40.55
br,clarindo barbosa,Clarindo Barbosa,15,,-16.133333,-40.483333
br,clarinia,Clarínia,27,,-22.75,-49.45
br,claro,Claro,20,,-3.7425,-42.396667
br,claro de minas,Claro de Minas,15,,-17.916667,-47
br,claro dos pocoes,Claro dos Poções,15,,-17.083333,-44.266667
br,claros,Claros,15,,-17.083333,-44.266667
br,claudino machado,Claudino Machado,08,,-20.1,-41.333333
br,claudio,Cláudio,04,,-3.033611,-61.517778
br,claudio,Cláudio,13,,-3.531944,-42.975833
br,claudio,Cláudio,15,21825,-20.433333,-44.766667
br,claudio manoel,Claúdio Manoel,15,,-20.216667,-43.2
br,claudio manuel,Cláudio Manuel,15,,-20.216667,-43.2
br,clavasio alves da silva,Clavásio Alves da Silva,23,,-30.916667,-55.816667
br,clemente apolonio,Clemente Apolônio,15,,-17.633333,-41.633333
br,clemente argolo,Clemente Argôlo,23,,-28,-51.45
br,clemente branco,Clemente Branco,15,,-17.133333,-41.416667
br,clemente,Clemente,15,,-16.1,-42.816667
br,clemente,Clemente,18,,-23.899346,-50.181131
br,clemente,Clemente,28,,-9.983333,-37.816667
br,clemente neri,Clemente Néri,05,,-17.65,-40.266667
br,clemente rocha,Clemente Rocha,15,,-17.9,-41.016667
br,clementina,Clementina,27,,-21.533333,-50.45
br,clementino,Clementino,17,,-6.533333,-38.016667
br,clementino cunha,Clementino Cunha,15,,-20.05,-46.7
br,clementino leite,Clementino Leite,15,,-20.15,-46.3
br,clevelandia,Clevelandia,03,,3.816667,-51.866667
br,clevelandia,Clevelândia,18,14701,-26.4,-52.35
br,clevelandia do norte,Clevelândia do Norte,03,,3.816667,-51.866667
br,clevlandia,Clevlandia,03,,3.816667,-51.866667
br,climerio,Climério,05,,-17.516667,-39.266667
br,cliza,Cliza,24,,-12.616667,-62.066667
br,clodoaldo pedroso,Clodoaldo Pedroso,23,,-30.016667,-56.05
br,clodomiro de oliveira,Clodomiro de Oliveira,15,,-19.583333,-45.45
br,clovis,Clóvis,15,,-17.1,-40.633333
br,coadi,Coadi,04,,-3.016667,-64.983333
br,coady,Coady,04,,-3.016667,-64.983333
br,coapoa,Coapoã,17,,-6.766667,-36.8
br,coaraci,Coaraci,05,32345,-14.633333,-39.533333
br,coaracy nunes,Coaracy Nunes,03,,.883333,-51.283333
br,coari amazonas,Coari Amazonas,04,,-4.109444,-63.138889
br,coari,Coari,04,50491,-4.109444,-63.138889
br,coari,Coari,16,,-4.35,-49.533333
br,coary,Coary,04,,-4.109444,-63.138889
br,coassu,Coassu,06,,-2.85,-40.033333
br,coata,Coatá,04,,-6.983333,-70.833333
br,coataquara,Coataquará,16,,-5.45,-56.866667
br,coaticaba,Coatiçaba,29,,-13.983333,-46.516667
br,coatinga do porco,Coatinga do Porco,20,,-7.8,-42.633333
br,coatis,Coatis,05,,-13.583333,-41.966667
br,cobe,Cobé,05,,-11.833333,-40.45
br,cobica,Cobiça,15,,-21.466667,-45.333333
br,cobra,Cobra,06,,-7.066667,-39.85
br,cobra,Cobra,13,,-3.860556,-43.451389
br,cobra,Cobra,17,,-6.966667,-37.8
br,cobra,Cobra,25,,.741667,-61.676944
br,cobral,Cobral,27,,-24.8243,-48.5181
br,cobras,Cobras,14,,-7.9,-57.8
br,cobras,Cobras,26,,-27.333333,-49.616667
br,cocaes,Cocaes,15,,-19.85,-43.45
br,cocaina,Cocaína,27,,-20.5,-47.716667
br,cocais,Cocais,14,,-15.066667,-56.55
br,cocais,Cocais,15,,-19.85,-43.45
br,cocais,Cocais,27,,-23.669429,-47.70826
br,cocais da estrela,Cocais da Estrêla,15,,-19.45,-42.866667
br,cocala,Cocala,04,,-8.233333,-60.7
br,cocal,Cocal,03,,2.6,-50.866667
br,cocal,Cocal,05,,-12.183333,-42.266667
br,cocal,Cocal,13,,-1.983333,-46.216667
br,cocal,Cocal,15,,-21.25,-46.216667
br,cocal,Cocal,16,,-1.066667,-49.583333
br,cocal,Cocal,20,12097,-3.466667,-41.566667
br,cocal,Cocal,26,,-28.616667,-49.35
br,cocal,Cocal,29,,-14.666667,-48.683333
br,cocal da ilha,Cocal da Ilha,20,,-3.968056,-42.187222
br,cocal das montanhas,Cocal das Montanhas,20,,-3.789722,-42.089722
br,cocal dos alves,Cocal dos Alves,20,,-3.616667,-41.533333
br,cocal grande,Cocal Grande,13,,-3.796667,-43.337778
br,cocal i,Cocal I,13,,-3.259167,-43.473889
br,cocal ii,Cocal II,13,,-3.494722,-43.448056
br,cocal iii,Cocal III,13,,-3.531944,-43.475278
br,cocalinho,Cocalinho,13,,-3.109167,-43.438889
br,cocalinho,Cocalinho,14,,-14.366667,-51
br,cocalinho,Cocalinho,20,,-4.533333,-41.983333
br,cocal iv,Cocal IV,13,,-3.233611,-43.293611
br,cocal v,Cocal V,13,,-3.047222,-43.380278
br,cocal vi,Cocal VI,13,,-3.486944,-43.225833
br,cocal vii,Cocal VII,13,,-3.255556,-43.457222
br,cocalzinho,Cocalzinho,16,,-2.966667,-46.65
br,cocamera,Cocamera,01,,-8.5,-71.15
br,cocamora,Cocamorá,01,,-8.5,-71.15
br,cocao,Cocão,05,,-12.65,-39.066667
br,cocau,Cocaú,30,,-8.65,-35.266667
br,coceira,Coceira,13,,-3.390556,-42.940556
br,coceira de baixo,Coceira de Baixo,13,,-3.411667,-42.946111
br,cocelinho,Cocelinho,14,,-14.366667,-51
br,cocha,Cochá,06,,-7,-38.883333
br,cochichola,Cochichola,17,,-7.616667,-36.616667
br,cochilha,Cochilha,23,,-28.116667,-52.283333
br,cochilha grande,Cochilha Grande,23,,-28.233333,-50.983333
br,cochinho,Cochinho,23,,-28.566667,-52.75
br,cocho,Cocho,27,,-22.912951,-45.006106
br,cocho de agua,Cocho de Água,15,,-20.1309,-43.7609
br,cocho do malheiro,Cocho do Malheiro,05,,-12.416667,-41.633333
br,cocho grande,Cocho Grande,18,,-25.216667,-52.583333
br,cochos,Cochos,06,,-7.516667,-39.116667
br,cochos,Cochos,17,,-7.216667,-38.183333
br,cocoal,Cocoal,13,,-1.983333,-46.216667
br,cococa,Cococa,06,,-6.3,-40.483333
br,coco,Coco,06,,-3.766667,-38.5
br,coco,Côco,15,,-20.3,-44
br,coco,Côco,16,,-1.066667,-46.5
br,coco,Coco,20,,-5.85,-42.433333
br,coco,Côco,31,,-10.083333,-48.866667
br,coco do pote,Côco do Pote,08,,-20.616667,-40.716667
br,cocoi,Cocoi,06,,-6.416667,-40.5
br,cocos,Côcos,05,,-12.716667,-44.566667
br,cocos,Côcos,13,,-4.583333,-43.666667
br,cocos,Côcos,20,,-10.351667,-45.331389
br,cocota,Cocotá,21,,-22.806328,-43.181397
br,coculo,Coculo,05,,-14.05,-39.5
br,cocuruto,Cocuruto,23,,-32.05,-52.05
br,codajas,Codajás,04,11185,-3.833333,-62.083333
br,codajaz,Codajáz,04,,-3.833333,-62.083333
br,codia,Codia,06,,-5.633333,-39.333333
br,codo,Codó,13,83289,-4.483333,-43.883333
br,codoz,Codoz,06,,-3.616667,-41.366667
br,codoz do baixo,Codoz do Baixo,20,,-3.616667,-41.466667
br,codozinho,Codòzinho,13,,-4.766667,-44.166667
br,coelho,Coelho,05,,-11.2,-42.8
br,coelho,Coelho,15,,-18.55,-48.1
br,coelho,Coelho,17,,-6.9,-35.816667
br,coelho,Coelho,18,,-22.9,-51.05
br,coelho,Coelho,25,,2.35,-60.866667
br,coelho da rocha,Coelho da Rocha,21,,-22.773185,-43.382543
br,coelho neto,Coelho Neto,13,36185,-4.25,-43
br,coelho neto,Coelho Neto,21,,-22.834363,-43.352521
br,coimbra,Coimbra,11,,-18.3,-55.3
br,coimbra,Coimbra,15,,-20.866667,-42.8
br,coimbra,Coimbra,23,,-28.816667,-54.483333
br,coimbra,Coimbra,24,,-11.466667,-65.3
br,coimbra lara,Coimbra Lara,11,,-18.3,-55.3
br,coimelemong,Coimelemong,25,,4.216667,-60.816667
br,coipe,Coipé,05,,-12.7,-38.6
br,coite,Coité,02,,-9.633333,-36.583333
br,coite,Coité,05,,-11.466667,-39.183333
br,coite,Coité,06,,-7.433333,-38.716667
br,coite,Coite,20,,-6.583333,-42.3
br,coite,Coité,22,,-6.3,-38.416667
br,coite,Coité,30,,-8.8,-38.766667
br,coite comprido,Coité Comprido,06,,-7.366667,-38.633333
br,coite do noa,Coité do Noá,02,,-9.666667,-36.5
br,coite do noia,Coité do Nóia,02,2529,-9.666667,-36.5
br,coite do nois,Coite do Nois,02,,-9.666667,-36.5
br,coitezeira,Coitèzeira,06,,-7.666667,-39.116667
br,coitezeiro,Coitezeiro,06,,-3.2,-40.216667
br,coito de cima,Coito de Cima,05,,-13.15,-38.9
br,coitos de cima,Coitos de Cima,05,,-13.15,-38.9
br,coivara,Coivara,13,,-3.8,-44.583333
br,coivaras,Coivaras,20,,-5.083333,-42.216667
br,cojubim,Cojubim,24,,-9.2,-61.783333
br,colado,Colado,05,,-13.083333,-38.8
br,colares,Colares,04,,-5.518056,-60.836389
br,colares,Colares,16,,-1.016667,-48.266667
br,colatina,Colatina,08,101193,-19.533333,-40.616667
br,colectoria,Colectoria,23,,-27.45,-52.85
br,colegio agricola,Colégio Agricola,06,,-7.2,-39.45
br,colegio,Colégio,21,,-22.633333,-42.733333
br,colegio,Colégio,27,,-23.711314,-47.307933
br,colegio,Colégio,28,,-11.066667,-37.266667
br,coleta,Coleta,17,,-7.416667,-37.516667
br,coletoria do estado de mato grosso,Coletoria do Estado de Mato Grosso,04,,-7.333333,-58.1
br,coletoria do estado do mato grosso,Coletoria do Estado do Mato Grosso,04,,-7.333333,-58.1
br,coletoria do estado do para,Coletoria do Estado do Pará,16,,-7.316667,-58.05
br,colheres,Colheres,20,,-8.5,-44.866667
br,colina,Colina,05,,-13.85,-41.266667
br,colina,Colina,27,15042,-20.733333,-48.583333
br,colinas,Colinas,13,25159,-6.033333,-44.233333
br,colinas,Colinas,29,,-14.2,-48.05
br,colinas,Colinas,30,,-7.9,-39.683333
br,colinas de caucaia do alto,Colinas de Caucaia do Alto,27,,-23.661085,-47.019087
br,colinas do magarca,Colinas do Magarça,21,,-22.940904,-43.587982
br,colinas do tocantins,Colinas do Tocantins,31,,-8.021667,-48.378611
br,collares,Collares,16,,-.933333,-48.283333
br,collatina,Collatina,08,,-19.533333,-40.616667
br,collectoria,Collectoria,23,,-27.45,-52.85
br,collectoria do estado do para,Collectoria do Estado do Pará,16,,-7.316667,-58.05
br,collina,Collina,27,,-20.733333,-48.583333
br,colmeia,Colméia,31,,-8.679722,-48.647222
br,colocacao arati,Colocação Arati,04,,-9.316667,-67.466667
br,colocacao areal,Colocação Areal,01,,-9.983333,-67.15
br,colocacao areia branca,Colocação Areia Branca,04,,-9.4,-67.35
br,colocacao barra grande,Colocação Barra Grande,01,,-9.933333,-67.3
br,colocacao barro vermelho,Colocação Barro Vermelho,04,,-9.3,-67.466667
br,colocacao beija flor,Colocação Beija Flor,04,,-9.4,-67.283333
br,colocacao bela flor,Colocação Bela Flor,01,,-9.583333,-67.333333
br,colocacao bela vista,Colocação Bela Vista,04,,-9.408333,-67.283333
br,colocacao boa fe,Colocação Boa Fé,01,,-9.95,-67.083333
br,colocacao boa sorte,Colocação Boa Sorte,01,,-9.75,-67.433333
br,colocacao boa uniao,Colocação Boa União,01,,-9.933333,-67.416667
br,colocacao boa vista,Colocação Boa Vista,01,,-10.483333,-69.283333
br,colocacao bom jardim,Colocação Bom Jardim,04,,-9.266667,-67.466667
br,colocacao bom jesus,Colocação Bom Jesus,04,,-9.25,-67.283333
br,colocacao cafundo,Colocação Cafundo,04,,-9.4,-67.316667
br,colocacao cajui,Colocação Cajui,04,,-9.3,-67.316667
br,colocacao canaviera,Colocação Canaviera,01,,-10.366667,-69.416667
br,colocacao caruaru,Colocação Caruaru,01,,-9.8,-67.416667
br,colocacao centrinho,Colocação Centrinho,01,,-9.8,-67.183333
br,colocacao chave de ouro,Colocação Chave de Ouro,01,,-9.8,-67.416667
br,colocacao china,Colocação China,04,,-9.316667,-67.483333
br,colocacao combate,Colocacão Combate,24,,-10.266667,-62.968056
br,colocacao comitiu,Colocação Comitiú,04,,-9.05,-67.366667
br,colocacao dois de maio,Colocação Dois de Maio,01,,-9.933333,-67.483333
br,colocacao esperanca,Colocação Esperança,01,,-9.95,-67.1
br,colocacao expedito,Colocação Expedito,04,,-9.15,-67.2
br,colocacao extrema,Colocação Extrema,01,,-9.916667,-67.45
br,colocacao felisbino,Colocação Felisbino,04,,-9.033333,-67.333333
br,colocacao geral,Colocação Geral,04,,-9.15,-67.4
br,colocacao goianinha,Colocação Goianinha,04,,-9.383333,-67.283333
br,colocacao ico,Colocação Icó,04,,-9.05,-67.383333
br,colocacao independencia,Colocação Independência,04,,-9.416667,-67.283333
br,colocacao iquiri,Colocação Iquiri,01,,-9.8,-67.283333
br,colocacao jucelino,Colocação Jucelino,04,,-9.133333,-67.233333
br,colocacao lagoa de barro,Colocação Lagoa de Barro,01,,-9.75,-67.25
br,colocacao laranjeira,Colocação Laranjeira,04,,-9.15,-67.4
br,colocacao madeirinha,Colocação Madeirinha,04,,-9.05,-67.383333
br,colocacao mineiros,Colocação Mineiros,04,,-9.083333,-67.25
br,colocacao moco,Colocação Moco,04,,-9.15,-67.4
br,colocacao monte negro,Colocação Monte Negro,04,,-9.383333,-67.283333
br,colocacao montevideu,Colocação Montevidéu,01,,-9.7,-67.333333
br,colocacao moreira,Colocação Moreira,01,,-9.916667,-67.466667
br,colocacao natal,Colocação Natal,04,,-9.416667,-67.491667
br,colocacao nossa senhora aparecida,Colocação Nossa Senhora Aparecida,01,,-9.8,-67.416667
br,colocacao nossa senhora de fatima,Colocação Nossa Senhora de Fátima,01,,-9.833333,-67.416667
br,colocacao paquara,Colocação Paquara,01,,-10.483333,-69.2
br,colocacao pau mulato,Colocação Pau Mulato,04,,-9.083333,-67.416667
br,colocacao pelotas,Colocação Pelotas,04,,-9.35,-67.5
br,colocacao piratini,Colocação Piratini,01,,-10,-67.366667
br,colocacao porto alegre,Colocação Porto Alegre,04,,-9.25,-67.433333
br,colocacao porto rico,Colocação Porto Rico,04,,-9.25,-67.45
br,colocacao poti,Colocação Poti,01,,-10.416667,-69.366667
br,colocacao quatro bocas,Colocação Quatro Bocas,01,,-9.933333,-67.483333
br,colocacao quilometro 100,Colocação Quilômetro 100,04,,-9.516667,-67.3
br,colocacao quilometro 102,Colocação Quilômetro 102,04,,-9.516667,-67.283333
br,colocacao quilometro 105,Colocação Quilômetro 105,04,,-9.483333,-67.283333
br,colocacao quilometro 106,Colocação Quilômetro 106,04,,-9.45,-67.283333
br,colocacao quilometro 109,Colocação Quilômetro 109,04,,-9.433333,-67.283333
br,colocacao quilometro 110,Colocação Quilômetro 110,04,,-9.433333,-67.283333
br,colocacao quilometro 112,Colocação Quilômetro 112,04,,-9.416667,-67.283333
br,colocacao quilometro 117,Colocação Quilômetro 117,04,,-9.4,-67.283333
br,colocacao quilometro 121,Colocação Quilômetro 121,04,,-9.366667,-67.283333
br,colocacao quilometro 124,Colocação Quilômetro 124,04,,-9.333333,-67.283333
br,colocacao quilometro 133,Colocação Quilômetro 133,04,,-9.3,-67.316667
br,colocacao quilometro 140,Colocação Quilômetro 140,04,,-9.233333,-67.283333
br,colocacao quilometro 48,Colocação Quilômetro 48,04,,-9.166667,-67.283333
br,colocacao quilometro 84,Colocação Quilômetro 84,01,,-9.65,-67.333333
br,colocacao quilometro 87,Colocação Quilômetro 87,01,,-9.633333,-67.333333
br,colocacao quilometro 98,Colocação Quilômetro 98,04,,-9.533333,-67.3
br,colocacao raposa,Colocação Raposa,04,,-9.25,-67.35
br,colocacao redencao nova,Colocação Redenção Nova,04,,-9.316667,-67.483333
br,colocacao redencao velha,Colocação Redenção Velha,04,,-9.35,-67.483333
br,colocacao ribeira,Colocação Ribeira,04,,-9.1,-67.4
br,colocacao salvacao,Colocação Salvação,04,,-9.266667,-67.466667
br,colocacao samauma,Colocação Samauma,04,,-9.133333,-67.4
br,colocacao santa cruz,Colocação Santa Cruz,01,,-9.866667,-67.05
br,colocacao santa luzia,Colocação Santa Luzia,04,,-9.05,-67.383333
br,colocacao santa maria,Colocação Santa Maria,01,,-9.95,-67.483333
br,colocacao santa rosa,Colocação Santa Rosa,01,,-9.883333,-67.45
br,colocacao santa teresinha,Colocação Santa Teresinha,01,,-9.95,-67.483333
br,colocacao santo antonio,Colocação Santo Antônio,01,,-9.816667,-67.416667
br,colocacao sao francisco,Colocação São Francisco,01,,-9.8,-67.366667
br,colocacao sao francisco,Colocação São Francisco,04,,-9.116667,-67.266667
br,colocacao sao jose,Colocação São José,01,,-9.85,-67.25
br,colocacao sao jose,Colocação São José,04,,-9.25,-67.45
br,colocacao sao luis,Colocação São Luís,01,,-9.7,-67.333333
br,colocacao sao pedro,Colocação São Pedro,01,,-9.916667,-67.466667
br,colocacao sao sebastiao,Colocação São Sebastião,01,,-9.816667,-67.333333
br,colocacao sapucaia,Colocação Sapucaia,01,,-9.866667,-67.433333
br,colocacao saudade,Colocação Saudade,04,,-9.383333,-67.333333
br,colocacao segredo,Colocação Segredo,04,,-9.083333,-67.416667
br,colocacao tabatinga,Colocação Tabatinga,04,,-9.05,-67.35
br,colocacao tapiri,Colocação Tapiri,04,,-9.4,-67.491667
br,colocacao veneza,Colocação Veneza,01,,-9.933333,-67.116667
br,colocacao vertente,Colocação Vertente,01,,-9.983333,-67.2
br,colocacao xavier,Colocação Xavier,01,,-9.916667,-67.466667
br,cologne,Cologne,03,,3.216667,-51.233333
br,colombia,Colômbia,27,,-20.166667,-48.666667
br,colombina,Colombina,05,,-13.1,-40.233333
br,colombo,Colombo,18,217002,-25.283333,-49.233333
br,colombo,Colombo,23,,-28.933333,-51.866667
br,colombo,Colombo,27,,-20.816667,-49.783333
br,colona,Colôna,30,,-7.583333,-39.733333
br,colonia 15 de novembro,Colonia 15 de Novembro,23,,-28.75,-53.1
br,colonia agricola do matapi,Colônia Agrícola do Matapi,03,,.683333,-51.433333
br,colonia agricola knust,Colônia Agricola Knust,21,,-22.491525,-42.829268
br,colonia agro-pecuaria brasilandia,Colônia Agro-Pecuária Brasilândia,15,,-16.983333,-46.15
br,colonia amelia,Colônia Amélia,13,,-1.7,-45.583333
br,colonia argollo,Colonia Argollo,23,,-28,-51.45
br,colonia augusta vitoria,Colônia Augusta Vitória,18,,-24.25,-50.85
br,colonia barao do triumpho,Colonia Barão do Triumpho,23,,-30.383333,-51.733333
br,colonia barreiro terra indigena kaingang,Colônia Barreiro Terra Indígena Kaingang,18,,-23.822714,-50.967949
br,colonia bela vista,Colônia Bela Vista,18,,-25.2595,-50.7042
br,colonia benfica,Colônia Benfica,18,,-25.370833,-50.018611
br,colonia boa vista,Colônia Boa Vista,04,,-3.298611,-60.441944
br,colonia bom retiro,Colonia Bom Retiro,23,,-30.116667,-51.5
br,colonia braga,Colônia Braga,27,,-20.633333,-50.3
br,colonia bromado,Colônia Bromado,18,,-25.665351,-50.207006
br,colonia cachoeira,Colônia Cachoeira,18,,-25.661926,-50.723685
br,colonia campina,Colônia Campina,18,,-25.833333,-52.55
br,colonia campo esperimenta,Colonia Campo Esperimenta,04,,-3.25,-60.25
br,colonia campo novo,Colônia Campo Novo,18,,-25.45,-52.916667
br,colonia castelhanos,Colônia Castelhanos,18,,-25.796266,-48.915261
br,colonia cocalinho,Colônia Cocalinho,16,,-7.816667,-49.266667
br,colonia,Colônia,01,,-8.366667,-73.166667
br,colonia,Colônia,04,,-4.425833,-62.182778
br,colonia,Colônia,05,,-13.8,-44.45
br,colonia,Colônia,11,,-19.333333,-57.316667
br,colonia,Colônia,15,,-17.883333,-41.066667
br,colonia,Colônia,16,,-1.433333,-47.533333
br,colonia,Colônia,18,,-25.383333,-50.1
br,colonia,Colônia,20,,-6.733333,-41.333333
br,colonia,Colônia,21,,-21.383333,-41.416667
br,colonia,Colônia,22,,-5.452778,-37.326111
br,colonia,Colônia,23,,-29.7,-53.7
br,colonia,Colônia,27,,-23.526104,-47.651825
br,colonia,Colônia,30,,-8.733333,-35.816667
br,colonia correa grande,Colônia Correa Grande,14,,-16.616667,-55.266667
br,colonia correctional,Colonia Correctional,21,,-21.666667,-41.9
br,colonia corrego grande,Colônia Córrego Grande,14,,-16.616667,-55.266667
br,colonia correz grande,Colónia Correz Grande,14,,-16.616667,-55.266667
br,colonia da barra,Colonia da Barra,23,,-28.35,-54.266667
br,colonia da boa vista,Colônia da Boa Vista,30,,-7.666667,-37.7
br,colonia da fazenda boa vista,Colônia da Fazenda Boa Vista,15,,-22.5281,-45.6143
br,colonia da fazenda imaculada conceicao,Colônia da Fazenda Imaculada Conceição,15,,-22.5089,-45.6169
br,colonia da fazenda sao bernardo,Colônia da Fazenda São Bernardo,27,,-23.036946,-47.531699
br,colonia da fepasa,Colônia da FEPASA,27,,-23.8552,-46.6958
br,colonia daltro,Colônia Daltro,23,,-29.95,-51.566667
br,colonia dantas,Colônia Dantas,18,,-24.1,-50.283333
br,colonia de bracinho,Colônia de Bracinho,11,,-18.583333,-56.716667
br,colonia de ferias,Colônia de Férias,27,,-24.35,-47.166667
br,colonia de ferias securitario,Colônia de Férias Securitário,15,,-21.946389,-43.319722
br,colonia de itapua,Colônia de Itapuã,23,,-30.35,-51
br,colonia de matapi,Colônia de Matapi,03,,.683333,-51.433333
br,colonia de mineracao,Colonia de Mineraçao,14,,-14.666667,-56.716667
br,colonia do educandario,Colônia do Educandário,21,,-22.30219,-42.812852
br,colonia do lago,Colônia do Lago,18,,-25.351667,-50.042222
br,colonia do miranda,Colonia do Miranda,11,,-21.683333,-56.083333
br,colonia do pescadores,Colônia do Pescadores,03,,2.133333,-50.5
br,colonia do piagui,Colônia do Piagui,27,,-22.754634,-45.180821
br,colonia do prata,Colônia do Prata,16,,-1.3,-47.6
br,colonia dos mineiros,Colônia dos Mineiros,14,,-13.901389,-59.755556
br,colonia dos pescadores,Colônia dos Pescadores,03,,2.133333,-50.5
br,colonia dos tachos,Colônia dos Tachos,14,,-15.55,-53
br,colonia fernando costa,Colônia Fernando Costa,25,,-2.5,-60.9
br,colonia ferreira gomes,Colonia Ferreira Gomes,03,,.8,-51.133333
br,colonia itapeti,Colonia Itapeti,27,,-23.3633,-46.1732
br,colonia jatahy,Colonia Jatahy,18,,-23.216667,-50.966667
br,colonia joanisdorf,Colônia Joanisdorf,18,,-25.738611,-49.765278
br,colonia joao vigesimo terceiro,Colônia João Vigésimo Terceiro,18,,-24.9952,-48.8041
br,colonia joao xxiii,Colônia João XXIII,18,,-24.9952,-48.8041
br,colonia juliano moreira,Colônia Juliano Moreira,21,,-22.936841,-43.397508
br,colonia lagoa,Colônia Lagoa,18,,-25.722808,-50.153567
br,colonia lago do caldeirao,Colônia Lago do Caldeirão,04,,-3.255278,-60.225556
br,colonia lago do limao,Colônia Lago do Limão,04,,-3.186667,-60.341944
br,colonia lajedo,Colonia Lajedo,22,,-5,-37.65
br,colonia langare,Colônia Langare,23,,-28.133333,-52.133333
br,colonia langaro,Colônia Langaro,23,,-28.133333,-52.133333
br,colonia leopoldina,Colônia Leopoldina,02,11914,-8.95,-35.65
br,colonia maciel,Colônia Maciel,18,,-25.428611,-50.136389
br,colonia mallet,Colonia Mallet,18,,-25.4,-52.233333
br,colonia manuel ribas,Colônia Manuel Ribas,18,,-24.516667,-51.65
br,colonia marcelino,Colônia Marcelino,18,,-25.772401,-49.233989
br,colonia marechal floriano,Colonia Marechal Floriano,29,,-15.95,-51.25
br,colonia maria brava,Colônia Maria Brava,18,,-25.256025,-50.612368
br,colonia marques de abrantes,Colônia Marquês de Abrantes,18,,-24.978733,-48.928895
br,colonia merure,Colônia Meruré,14,,-15.55,-53.083333
br,colonia militar,Colônia Militar,13,,-1.8,-46.2
br,colonia militar pedro ii,Colônia Militar Pedro II,03,,.966667,-50.966667
br,colonia mineira,Colonia Mineira,18,,-23.6877,-49.8295
br,colonia miranda,Colônia Miranda,11,,-21.683333,-56.083333
br,colonia moema,Colônia Moema,18,,-25.1,-50.283333
br,colonia municipal bela vista,Colônia Municipal Bela Vista,11,,-22.016667,-56.083333
br,colonia municipal,Colônia Municipal,18,,-25.840426,-49.75598
br,colonia murici,Colônia Murici,18,,-25.583333,-49.083333
br,colonia nova,Colônia Nova,26,,-26.133333,-50.066667
br,colonia nova varsovia,Colônia Nova Varsóvia,18,,-23.5287,-49.9429
br,colonia osorio,Colônia Osório,13,,-1.816667,-46.1
br,colonia ozorio,Colonia Ozorio,13,,-1.816667,-46.1
br,colonia padre paulo,Colônia Padre Paulo,18,,-26.0992,-49.3105
br,colonia paricatuba,Colônia Paricatuba,04,,-3.083333,-60.236389
br,colonia pascal,Colônia Pascal,18,,-24.833333,-53.116667
br,colonia pascoal,Colônia Pascoal,18,,-24.833333,-53.116667
br,colonia passo lancare,Colonia Passo Lancare,23,,-28.133333,-52.133333
br,colonia paulista,Colônia Paulista,27,,-23.8466,-46.6992
br,colonia pequeri,Colônia Pequeri,18,,-24.95,-51.933333
br,colonia piagui,Colônia Piaguí,27,,-22.754634,-45.180821
br,colonia piquiri,Colônia Piquiri,18,,-24.95,-51.933333
br,colonia piragara,Colonia Piragara,14,,-16.983333,-56.433333
br,colonia polidoro,Colônia Polidoro,26,,-26.783333,-51.083333
br,colonia queiroz,Colonia Queiroz,18,,-25.4,-52.233333
br,colonia residencial da fazenda sao pedro,Colônia Residencial da Fazenda São Pedro,27,,-23.5567,-47.5025
br,colonia residencial secretaria da agricultura do estado de sao paulo,Colônia Residencial Secretaria da Agricultura do Estado de São Paulo,27,,-23.0025,-47.7272
br,colonia retiro,Colônia Retiro,18,,-25.7884,-49.2794
br,colonia rio branco,Colonia Rio Branco,04,,-2.766667,-67.666667
br,colonia rio do pinto,Colônia Rio do Pinto,18,,-25.5077,-48.8203
br,colonia rio-jana,Colonia Rio-Jana,04,,-2.766667,-67.666667
br,colonia rio matapi,Colônia Rio Matapi,03,,.683333,-51.433333
br,colonia rodrigues alves,Colônia Rodrigues Alves,01,,-7.716667,-72.65
br,colonia sagrado coracao de jesus,Colônia Sagrado Coração de Jesus,14,,-15.55,-53
br,colonia santa cruz numero 1,Colônia Santa Cruz Número 1,18,,-25.303611,-50.090278
br,colonia santa cruz numero 2,Colônia Santa Cruz Número 2,18,,-25.283889,-50.113056
br,colonia santa cruz numero dois,Colônia Santa Cruz Número Dois,18,,-25.283889,-50.113056
br,colonia santa cruz numero um,Colônia Santa Cruz Número Um,18,,-25.303611,-50.090278
br,colonia santa isabel,Colônia Santa Isabel,14,,-16.683333,-56.016667
br,colonia santa rosa,Colônia Santa Rosa,20,,-6.8,-42.283333
br,colonia santa teresinha,Colônia Santa Teresinha,18,,-25.9,-52.65
br,colonia santa terezinha,Colônia Santa Terezinha,18,,-25.9,-52.65
br,colonia sao bras,Colônia São Brás,26,,-28.466667,-48.866667
br,colonia sao feliciano,Colonia São Feliciano,23,,-30.7,-52.116667
br,colonia sao joao,Colônia São João,18,,-24.95,-53.233333
br,colonia sao jose,Colonia São José,04,,-9.4,-67.083333
br,colonia sao lourenco,Colônia São Lourenço,18,,-25.508614,-50.590901
br,colonia sao miguel,Colônia São Miguel,18,,-23.494279,-49.987652
br,colonia sao paulo,Colonia São Paulo,23,,-29.416667,-53.133333
br,colonia sao pedro,Colônia São Pedro,18,,-24.933333,-53.183333
br,colonia sapucai,Colônia Sapucaí,18,,-24.883333,-53.266667
br,colonia sarandy,Colonia Sarandy,23,,-27.933333,-52.916667
br,colonia sebastiao,Colônia Sebastião,24,,-11.05,-65.333333
br,colonia serrinha,Colônia Serrinha,05,,-16.366667,-39.616667
br,colonia sete barras,Colônia Sete Barras,18,,-24.678901,-48.809952
br,colonia suruqua,Colônia Suruquá,18,,-23.297619,-52.630529
br,colonia taquaral,Colônia Taquaral,18,,-25.833333,-50.366667
br,colonia tavares bastos,Colônia Tavares Bastos,18,,-25.15,-50.2
br,colonia thesoura,Colonia Thesoura,23,,-28.116667,-53.083333
br,colonia velha,Colônia Velha,27,,-24.8486,-48.0277
br,colonia vieira,Colônia Vieira,26,,-26.316667,-50.333333
br,colonia vieiras,Colonia Vieiras,26,,-26.316667,-50.333333
br,colonia vilinha,Colônia Vilinha,18,,-25.388611,-50.102222
br,colono miranda,Colono Miranda,11,,-21.683333,-56.083333
br,colorado,Colorado,18,20449,-22.816667,-51.95
br,colorado,Colorado,23,,-28.516667,-53
br,columna,Columna,15,,-18.233333,-42.833333
br,coluna,Coluna,06,,-4.05,-38.5
br,coluna,Coluna,15,,-18.233333,-42.833333
br,comandahy,Comandahy,23,,-28.133333,-54.566667
br,comandante arbues,Comandante Arbues,27,,-21.15,-51.1
br,comandante,Comandante,05,,-9.8,-43.433333
br,comandante,Comandante,20,,-6.783333,-42.233333
br,comandatuba,Comandatuba,05,,-15.35,-39
br,comandulli,Comandulli,23,,-29.1886,-51.0576
br,combate,Combate,24,,-10.266667,-62.968056
br,combuti,Combuti,13,,-3.147222,-43.114167
br,come-assado,Come-Assado,31,,-10.6,-46.3
br,comendador gomes,Comendador Gomes,15,,-19.683333,-49.083333
br,comendador levy gasparian,Comendador Levy Gasparian,21,,-22.028333,-43.206944
br,comendador soares,Comendador Soares,21,,-22.742165,-43.479066
br,comendador venancio,Comendador Venâncio,21,,-21.183333,-42.1
br,comendador viana,Comendador Viana,15,,-19.433333,-45.783333
br,comercinho,Comercinho,05,,-13.966667,-39.75
br,comercinho,Comercinho,15,,-16.316667,-41.783333
br,comercinho de palha,Comercinho de Palha,08,,-18.133333,-40.35
br,comercio,Comércio,05,,-12.85,-39.216667
br,comercio,Comércio,23,,-29.366667,-53.366667
br,comercio de fora,Comércio de Fora,05,,-13.016667,-41.433333
br,cometa,Cometa,13,,-8.960833,-46.302222
br,commandador gomes,Commandador Gomes,15,,-19.683333,-49.083333
br,commandatuba,Commandatuba,05,,-15.35,-39
br,commercinho,Commercinho,15,,-16.316667,-41.783333
br,comocoxico,Comocoxico,05,,-14.533333,-42.283333
br,comodoro,Comodoro,14,,-13.656944,-59.788889
br,comoxatiba,Comoxatiba,05,,-17.1,-39.183333
br,companhia,Companhia,08,,-21.166667,-41.2
br,companhia,Companhia,15,,-22.833333,-46.133333
br,companugamu,Companugamu,25,,4.316667,-60.133333
br,compasso,Compasso,22,,-6.183333,-37.783333
br,compensa,Compensa,04,,-3.106667,-60.058056
br,compestre,Compestre,15,,-21.716667,-46.25
br,compestre,Compestre,20,,-7.016667,-44.233333
br,compina,Compina,16,,-5.8,-48.333333
br,comportas,Comportas,30,,-8.183333,-34.95
br,compos das almas,Compos das Almas,17,,-7.733333,-36.15
br,comum,Comum,22,,-6.133333,-35.416667
br,comunidade piraque,Comunidade Piraquê,21,,-22.993853,-43.610348
br,comunidade zepelin,Comunidade Zepelin,21,,-22.924515,-43.700494
br,comur,Comur,18,,-23.05,-53.05
br,conani,Conaní,03,,2.866667,-51.1
br,concaicao do jacuipe,Concaição do Jacuípe,05,,-12.3,-38.766667
br,concao,Concão,06,,-7.2,-39.733333
br,concecao do pompeo,Conceção do Pompeó,15,,-19.2,-44.983333
br,conceicao coite,Conceicao Coite,05,,-11.55,-39.266667
br,conceicao,Conceição,03,,1.15,-50.833333
br,conceicao,Conceição,04,,-3.05,-57.783333
br,conceicao,Conceição,05,,-11.15,-43.166667
br,conceicao,Conceição,06,,-3.783333,-40.2
br,conceicao,Conceição,08,,-19.416667,-40.7
br,conceicao,Conceição,11,,-19.383333,-55.8
br,conceicao,Conceição,13,,-2.75,-43.666667
br,conceicao,Conceição,14,,-15.016667,-58.016667
br,conceicao,Conceição,15,,-16.183333,-40.45
br,conceicao,Conceição,16,,-1.05,-52.516667
br,conceicao,Conceição,17,,-6.266667,-37.683333
br,conceicao,Conceição,18,,-24.45,-50.55
br,conceicao,Conceição,20,,-6.55,-42.866667
br,conceicao,Conceição,21,,-21.766667,-41.6
br,conceicao,Conceicão,22,,-5.479444,-36.401389
br,conceicao,Conceição,23,,-28.9,-53.783333
br,conceicao,Conceição,24,,-10.316667,-61.85
br,conceicao,Conceição,25,,2.183333,-60.966667
br,conceicao,Conceição,26,,-26.25,-53.333333
br,conceicao,Conceição,27,,-21.5,-46.766667
br,conceicao,Conceição,30,,-7.883333,-34.833333
br,conceicao,Conceicão,31,,-11.468889,-46.7825
br,conceicao da aparecida,Conceição da Aparecida,15,,-21.1,-46.2
br,conceicao da apparecida,Conceiçao da Apparecida,15,,-21.1,-46.2
br,conceicao da barra,Conceição da Barra,08,19310,-18.583333,-39.75
br,conceicao da barra,Conceição da Barra,15,,-21.116667,-44.466667
br,conceicao da boa vista,Conceição da Boa Vista,15,,-21.55,-42.433333
br,conceicao da feira,Conceição da Feira,05,15838,-12.5,-39
br,conceicao da ibitipoca,Conceição da Ibitipoca,15,,-21.716667,-43.916667
br,conceicao da pedra,Conceição da Pedra,15,,-22.15,-45.45
br,conceicao da pedras,Conceicão da Pedras,15,,-22.15,-45.45
br,conceicao das alagoas,Conceição das Alagoas,15,16152,-19.916667,-48.383333
br,conceicao das creoulas,Conceição das Creoulas,30,,-8.316667,-38.933333
br,conceicao das crioulas,Conceição das Crioulas,30,,-8.316667,-38.933333
br,conceicao das laranjeiras,Conceição das Laranjeiras,15,,-18.866667,-41.4
br,conceicao da vargem,Conceição da Vargem,15,,-16.163056,-44.773611
br,conceicao de baixo,Conceição de Baixo,18,,-25.709265,-50.580079
br,conceicao de bento simoes,Conceição de Bento Simões,05,,-12.15,-38.733333
br,conceicao de campinas,Conceição de Campinas,27,,-22.9,-47.083333
br,conceicao de ipanema,Conceição de Ipanema,15,,-19.916667,-41.683333
br,conceicao de itagua,Conceição de Itaguá,15,,-20.133333,-44.233333
br,conceicao de jacarei,Conceição de Jacareí,21,,-23.033333,-44.15
br,conceicao de jacuipe,Conceição de Jacuípe,05,,-12.3,-38.766667
br,conceicao de macabu,Conceição de Macabu,21,,-22.066667,-41.866667
br,conceicao de monte alegre,Conceição de Monte Alegre,27,,-22.466667,-50.633333
br,conceicao de muquy,Conceição de Muquy,08,,-20.983333,-41.533333
br,conceicao de piracicaba,Conceição de Piraciçaba,15,,-19.9,-43.1
br,conceicao de salinas,Conceição de Salinas,05,,-12.866667,-38.783333
br,conceicao de tronqueiras,Conceição de Tronqueiras,15,,-18.683333,-42.25
br,conceicao de vera cruz,Conceição de Vera Cruz,05,,-13.033333,-38.633333
br,conceicao do almeida,Conceição do Almeida,05,9691,-12.8,-39.2
br,conceicao do araguaia,Conceição do Araguaia,16,27116,-8.241111,-49.296111
br,conceicao do araguaya,Conceicao Do Araguaya,16,,-8.241111,-49.296111
br,conceicao do araxa,Conceição do Araxá,15,,-19.35,-47.283333
br,conceicao do arroio,Conceição do Arroio,23,,-29.9,-50.266667
br,conceicao do arrolo,Conceicao do Arrolo,23,,-29.9,-50.266667
br,conceicao do barreiro,Conceição do Barreiro,15,,-17.316667,-44.466667
br,conceicao do bento simoes,Conceição do Bento Simões,05,,-12.15,-38.733333
br,conceicao do caninde,Conceição do Canindé,20,,-7.9,-41.566667
br,conceicao do capim,Conceição do Capim,15,,-19.566667,-41.233333
br,conceicao do cariri,Conceição do Cariri,06,,-7.516667,-39.116667
br,conceicao do castello,Conceicao do Castello,08,,-20.366667,-41.25
br,conceicao do castelo,Conceição do Castelo,08,4538,-20.366667,-41.25
br,conceicao do coite,Conceição do Coité,05,35172,-11.55,-39.266667
br,conceicao do formoso,Conceição do Formoso,15,,-21.416667,-43.35
br,conceicao do gato,Conceição do Gato,05,,-12.533333,-41.533333
br,conceicao do ibitipoca,Conceição do Ibitipoca,15,,-21.716667,-43.916667
br,conceicao do mato dentro,Conceição do Mato Dentro,15,10708,-19.016667,-43.416667
br,conceicao do mau,Conceição do Maú,25,,3.583333,-59.883333
br,conceicao do monte alegre,Conceição do Monte Alegre,27,,-22.466667,-50.633333
br,conceicao do muqui,Conceição do Muqui,08,,-20.983333,-41.533333
br,conceicao do mutum,Conceição do Mutum,08,,-19.416667,-40.7
br,conceicao do norte,Conceição do Norte,08,,-20.35,-41.4
br,conceicao do norte,Conceição do Norte,31,,-11.468889,-46.7825
br,conceicao do orico,Conceicão do Orico,05,,-14.3,-39.366667
br,conceicao do para,Conceição do Pará,15,,-19.733333,-44.9
br,conceicao do paraiba,Conceição do Paraíba,02,,-9.416667,-36.066667
br,conceicao do paraiba,Conceição do Paraíba,15,,-21.75,-42.383333
br,conceicao do rio acima,Conceição do Rio Acima,15,,-20.083333,-43.583333
br,conceicao do rio verde,Conceição do Rio Verde,15,12402,-21.883333,-45.083333
br,conceicao dos ganchos,Conceição dos Ganchos,04,,-4.735556,-59.929167
br,conceicao dos ouros,Conceição dos Ouros,15,,-22.416667,-45.783333
br,conceicao do tocantins,Conceição do Tocantins,31,,-12.264444,-47.232778
br,conceicao do turvo,Conceição do Turvo,15,,-20.916667,-43.1
br,conceicao ii,Conceição II,13,,-3.778056,-43.298056
br,conceicao velha,Conceição Velha,05,,-12.783333,-39.083333
br,conceicao velha,Conceição Velha,20,,-7.883333,-41.55
br,conceicas,Conceicas,04,,-7.033333,-60.333333
br,concha,Concha,11,,-21.183333,-57.633333
br,concha,Concha,14,,-16.05,-58.8
br,concha,Concha,21,,-21.4,-41.416667
br,conchal,Conchal,11,,-21.183333,-57.633333
br,conchal,Conchal,27,21351,-22.333333,-47.166667
br,conchas,Conchas,11,,-21.183333,-57.633333
br,conchas,Conchas,14,,-16.05,-58.8
br,conchas,Conchas,18,,-25.066667,-50.366667
br,conchas,Conchas,27,14301,-23.016667,-48
br,concordia,Concórdia,04,,-4.596111,-66.623611
br,concordia,Concórdia,15,,-21.6,-45.766667
br,concordia,Concórdia,16,,-1.85,-49.033333
br,concordia,Concórdia,18,,-25.933333,-51.1
br,concordia,Concórdia,20,,-4.633333,-41.633333
br,concordia,Concórdia,23,,-29.55,-51.766667
br,concordia,Concórdia,26,55368,-27.233333,-52.016667
br,concordia,Concórdia,27,,-20.483333,-47.35
br,concordia de mucuri,Concórdia de Mucuri,15,,-17.7,-41.866667
br,concordia do mucuri,Concórdia do Mucuri,15,,-17.7,-41.866667
br,condado,Condado,06,,-5.433333,-39.066667
br,condado,Condado,17,,-6.35,-37.55
br,condado,Condado,20,,-6.766667,-40.65
br,condado,Condado,25,,-3.2,-60.45
br,condado,Condado,30,19585,-7.583333,-35.1
br,condado do norte,Condado do Norte,15,,-15.8,-44.05
br,conde,Conde,05,15565,-11.816667,-37.616667
br,conde,Conde,16,,-1.566667,-48.75
br,conde,Conde,17,,-7.266667,-34.9
br,conde,Condé,23,,-29.966667,-51.8
br,conde de araruama,Conde de Araruama,21,,-22.066667,-41.616667
br,condeixa,Condeixa,16,,-.9,-48.6
br,conde sao miguel,Conde São Miguel,27,,-20.9,-48.85
br,condessa,Condessa,17,,-5.85,-35.85
br,condessa,Condêssa,22,,-5.883333,-35.783333
br,condeuba,Condeúba,05,,-14.883333,-41.983333
br,condicao,Condição,25,,2.183333,-60.966667
br,condominio blue,Condomínio Blue,21,,-23.00198,-43.429575
br,condominio eldorado,Condomínio Eldorado,21,,-22.943697,-43.32727
br,condominio floresta,Condomínio Floresta,21,,-22.970149,-43.32733
br,condominio mansoes,Condomínio Mansões,21,,-23.002547,-43.415793
br,condominio pedra de itauna,Condomínio Pedra de Itauna,21,,-23.005901,-43.422357
br,condominio pitocos,Condomínio Pitocos,21,,-22.935312,-43.632396
br,condominio urussanga,Condomínio Urussanga,21,,-22.946977,-43.331828
br,condor,Condor,23,,-28.2,-53.483333
br,conduru,Conduru,08,,-20.683333,-41.2
br,conduru,Conduru,13,,-5.566667,-44.333333
br,conego joao pio,Cônego João Pio,15,,-20,-42.933333
br,conego lira,Cônego Lira,30,,-8.133333,-36.316667
br,conego marinho,Cônego Marinho,15,,-15.233333,-44.45
br,confins,Confins,15,,-19.616667,-43.983333
br,confusao,Confusão,15,,-20.483333,-46.25
br,confusao,Confusão,27,,-20.616667,-47.166667
br,congo,Congo,05,,-12.216667,-37.8
br,congo,Congo,17,,-7.8,-36.666667
br,congonha,Congonha,06,,-3.766667,-41.283333
br,congonhal,Congonhal,15,,-21.933333,-45.816667
br,congonhal de baixo,Congonhal de Baixo,27,,-23.42117,-47.81096
br,congonhal de cima,Congonhal de Cima,27,,-23.451476,-47.822305
br,congonhas,Congonhas,15,48819,-20.5,-43.866667
br,congonhas,Congonhas,18,,-23.2,-50.733333
br,congonhas,Congonhas,27,,-23.7274,-47.8115
br,congonhas do campo,Congonhas do Campo,15,,-20.5,-43.866667
br,congonhas do norte,Congonhas do Norte,15,,-18.8,-43.666667
br,congonhas do norte,Congonhas do Norte,18,,-23.2,-50.733333
br,congonhinhas,Congonhinhas,18,,-23.5495,-50.5508
br,congorito,Congorito,05,,-11.95,-37.7
br,conjugado habitacao companhia de habitacao do parana,Conjugado Habitação Companhia de Habitação do Paraná,18,,-23.029809,-50.072102
br,conjugado habitacao vila mariana,Conjugado Habitação Vila Mariana,26,,-26.229515,-49.508792
br,conjuncao residencial bela vista,Conjunção Residencial Bela Vista,26,,-26.1997,-49.271
br,conjunto alvorada,Conjunto Alvorada,21,,-22.898991,-43.721623
br,conjunto antares,Conjunto Antares,21,,-22.919768,-43.659831
br,conjunto bandeirantes,Conjunto Bandeirantes,21,,-22.934367,-43.366297
br,conjunto boa esperanca,Conjunto Boa Esperança,21,,-22.905622,-43.667552
br,conjunto campinho,Conjunto Campinho,21,,-22.880717,-43.613711
br,conjunto dom jamie camara,Conjunto Dom Jamie Camara,21,,-22.86623,-43.458205
br,conjunto dom pedro i,Conjunto Dom Pedro I,21,,-22.884654,-43.426888
br,conjunto esperanca,Conjunto Esperança,21,,-22.809421,-43.31989
br,conjunto habitacao doutor jamidas,Conjunto Habitação Doutor Jamidas,18,,-23.280591,-50.069796
br,conjunto habitacao joaquim c. da silveira,Conjunto Habitação Joaquim C. da Silveira,18,,-23.305579,-50.089423
br,conjunto habitacional companhia de habitacao do parana ii,Conjunto Habitacional Companhia de Habitação do Paraná II,18,,-25.802709,-48.538626
br,conjunto habitacional pica-pau-amarelo,Conjunto Habitacional Pica-Pau-Amarelo,18,,-25.796,-48.5255
br,conjunto joao saldanha,Conjunto João Saldanha,21,,-22.846278,-43.462129
br,conjunto joao xxiii,Conjunto João XXIII,21,,-22.904824,-43.702702
br,conjunto manguariba,Conjunto Manguariba,21,,-22.872372,-43.632949
br,conjunto miecimo da silva,Conjunto Miécimo da Silva,21,,-22.900895,-43.712587
br,conjunto missoes,Conjunto Missoes,21,,-22.805243,-43.283028
br,conjunto nelson mandela,Conjunto Nelson Mandela,21,,-22.885388,-43.246687
br,conjunto nova pavuna,Conjunto Nova Pavuna,21,,-22.811076,-43.35424
br,conjunto nova sepetiba,Conjunto Nova Sepetiba,21,,-22.958043,-43.686956
br,conjunto nova sepetiba ii,Conjunto Nova Sepetiba II,21,,-22.968354,-43.661587
br,conjunto novo mundo,Conjunto Novo Mundo,21,,-22.896302,-43.72172
br,conjunto otacilio camara,Conjunto Otacílio Camará,21,,-22.936075,-43.656877
br,conjunto pro-morar,Conjunto Pró-Morar,21,,-22.851688,-43.397404
br,conjunto quafa,Conjunto Quafá,21,,-22.850834,-43.488401
br,conjunto residencia frei joao e. couto,Conjunto Residência Frei João E. Couto,18,,-23.298246,-50.061345
br,conjunto rio grande,Conjunto Rio Grande,21,,-22.893601,-43.716405
br,conjunto sao fernando,Conjunto São Fernando,21,,-22.888717,-43.719521
br,conjunto sargento joao lima,Conjunto Sargento João Lima,21,,-22.923599,-43.540615
br,conjunto sargento miguel filho,Conjunto Sargento Miguel Filho,21,,-22.858071,-43.481218
br,conjunto seis de novembro,Conjunto Seis de Novembro,21,,-22.852625,-43.457107
br,conjunto taquaral,Conjunto Taquaral,21,,-22.867211,-43.486262
br,conjunto urucania,Conjunto Urucânia,21,,-22.912618,-43.654748
br,conori ponta,Conori Ponta,04,,.05,-67.633333
br,conquista,Conquista,05,,-11.816667,-41.516667
br,conquista,Conquista,15,,-19.733333,-44.6
br,conquista,Conquista,21,,-22.283333,-42.683333
br,conquista,Conquista,26,,-26.3796,-48.6685
br,conquista,Conquista,27,,-21.166667,-47.883333
br,conrado,Conrado,21,,-22.535556,-43.567222
br,conselheiro josino,Conselheiro Josino,21,,-21.5,-41.35
br,conselheiro joviano,Conselheiro Joviano,21,,-21.5,-41.35
br,conselheiro jovino,Conselheiro Jovino,21,,-21.5,-41.35
br,conselheiro lafaiete,Conselheiro Lafaiete,15,111598,-20.666667,-43.8
br,conselheiro lafayete,Conselheiro Lafayete,15,,-20.666667,-43.8
br,conselheiro mairinck,Conselheiro Mairinck,18,,-23.622841,-50.169004
br,conselheiro mairink,Conselheiro Mairink,18,,-23.622841,-50.169004
br,conselheiro mata,Conselheiro Mata,15,,-18.283333,-43.983333
br,conselheiro matta,Conselheiro Matta,15,,-18.283333,-43.983333
br,conselheiro mayrinck,Conselheiro Mayrinck,18,,-23.622841,-50.169004
br,conselheiro paulino,Conselheiro Paulino,21,,-22.216667,-42.516667
br,conselheiro pena,Conselheiro Pena,15,12735,-19.166667,-41.5
br,conselheiro zacarias,Conselheiro Zacarias,18,,-23.412809,-49.979241
br,conselho,Conselho,05,,-12.816667,-40.383333
br,conselho,Conselho,06,,-7.133333,-38.683333
br,conselho,Conselho,22,,-5.933333,-38.116667
br,conselho martim francisco,Conselho Martim Francisco,27,,-22.516667,-46.95
br,consequencia,Consequência,14,,-16.916667,-57.583333
br,conserva,Conserva,13,,-2.75,-44.95
br,conservatoria,Conservatória,21,,-22.288333,-43.931111
br,consolacao,Consolação,15,,-22.55,-45.916667
br,consolacao,Consolação,20,,-9.883333,-43.816667
br,consolacao,Consolação,21,,-22.912313,-43.26992
br,consolacao,Consolação,25,,3.933333,-60.983333
br,consolacao,Consolação,31,,-10.5,-49.616667
br,constancia,Constância,21,,-22.367056,-42.93291
br,constancia,Constância,27,,-21.383333,-46.8
br,constancia das baetas,Constãncia das Baetas,04,,-6.2,-62.216667
br,constancia dos baetas,Constância dos Baetas,04,,-6.2,-62.216667
br,constantcia baetas,Constantcia Baetas,04,,-6.2,-62.216667
br,constant,Constant,15,,-21.95,-42.883333
br,constantina,Constantina,23,,-27.733333,-52.983333
br,constituinte,Constituinte,06,,-3.683333,-39.566667
br,consuelo,Consuelo,24,,-12.65,-62.133333
br,consulado,Consulado,21,,-22.955574,-43.573667
br,contagem,Contagem,15,627132,-19.916667,-44.1
br,contao,Contão,25,,3.933333,-60.416667
br,contenda,Contenda,05,,-13.7,-41.2
br,contenda,Contenda,18,,-25.7,-49.533333
br,contenda,Contenda,22,,-5.65,-35.233333
br,contendas,Contendas,05,,-11.55,-39.7
br,contendas,Contendas,06,,-3,-39.95
br,contendas,Contendas,15,,-21.9,-45.016667
br,contendas,Contendas,17,,-6.433333,-37.583333
br,contendas,Contendas,20,,-3.666667,-42.45
br,contendas,Contendas,27,,-20.683333,-47.183333
br,contendas,Contendas,29,,-18.05,-47.35
br,contendas do sincora,Contendas do Sincorá,05,,-13.75,-41.033333
br,contentes,Contentes,20,,-6.083333,-41.4
br,contestado,Contestado,01,,-8.358056,-72.72
br,contiguiba,Contiguiba,28,,-10.866667,-37.116667
br,continente,Continente,27,,-24.61609,-48.450426
br,contracto,Contracto,20,,-9.65,-45.183333
br,contrato,Contrato,20,,-9.65,-45.183333
br,contrato,Contrato,23,,-29.083333,-50.766667
br,contria,Contria,15,,-18.233333,-44.516667
br,convenfo,Convenfo,05,,-14.066667,-39.566667
br,convento,Convento,05,,-14.066667,-39.566667
br,convento,Convento,06,,-5.3,-40.716667
br,convento,Convento,18,,-25.569444,-48.312778
br,convento,Convento,28,,-11.466667,-37.45
br,convento da penha,Convento da Penha,08,,-20.333333,-40.283333
br,conventos,Conventos,26,,-28.95,-49.383333
br,convivencia,Convivência,21,,-21.6,-41.016667
br,copacabana,Copacabana,14,,-15.416667,-59.983333
br,copacabana,Copacabana,21,,-22.968532,-43.185787
br,copaiba,Copaíba,04,,-4.325833,-65.278889
br,copasa,Copasa,18,,-25.840943,-48.787556
br,copatana,Copatana,04,,-2.8,-67.066667
br,copichaba,Copichaba,05,,-11.316667,-43.166667
br,copioba,Copioba,05,,-12.116667,-37.966667
br,copixaba,Copixaba,05,,-11.316667,-43.166667
br,coque,Coque,06,,-5.366667,-39.133333
br,coqueiral,Coqueiral,15,,-21.183333,-45.45
br,coqueiral,Coqueiral,30,,-8.083333,-34.966667
br,coqueiral cupe,Coqueiral Cupe,02,,-9.4,-35.5
br,coqueiralzinho,Coqueiralzinho,18,,-23.1156,-50.1363
br,coqueirinho,Coqueirinho,17,,-6.766667,-34.95
br,coqueiro,Coqueiro,02,,-9.383333,-37.266667
br,coqueiro,Coqueiro,05,,-11.483333,-37.4
br,coqueiro,Coqueiro,06,,-7.183333,-40.483333
br,coqueiro,Coqueiro,11,,-21.216667,-56.383333
br,coqueiro,Coqueiro,13,,-3.083333,-42.4
br,coqueiro,Coqueiro,14,,-15.8,-57.2
br,coqueiro,Coqueiro,15,,-19.65,-44.833333
br,coqueiro,Coqueiro,18,,-26.174167,-53.562222
br,coqueiro,Coqueiro,20,,-2.907778,-41.578889
br,coqueiro,Coqueiro,21,,-21.216667,-41.433333
br,coqueiro,Coqueiro,22,,-5.026667,-37.461944
br,coqueiro,Coqueiro,25,,3.083333,-61.183333
br,coqueiro,Coqueiro,30,,-7.6,-37.583333
br,coqueiro grande,Coqueiro Grande,05,,-12.716667,-38.55
br,coqueiros,Coqueiros,05,,-12.15,-38.683333
br,coqueiros,Coqueiros,08,,-20.866667,-41.25
br,coqueiros,Coqueiros,14,,-15.416667,-57
br,coqueiros,Coqueiros,15,,-19.133333,-42.616667
br,coqueiros,Coqueiros,21,,-21.883333,-41.3
br,coqueiros,Coqueiros,23,,-28.116667,-52.783333
br,coqueiros,Coqueiros,26,,-26.4878,-48.7241
br,coqueiros,Coqueiros,27,,-21,-47.833333
br,coqueiros,Coqueiros,31,,-7.883333,-48.583333
br,coqueiro secco,Coqueiro Secco,02,,-9.633333,-35.783333
br,coqueiro seco,Coqueiro Sêco,02,,-9.633333,-35.783333
br,coquiero,Coquiero,14,,-15.716667,-57.033333
br,coquinhos,Coquinhos,05,,-14.55,-40.683333
br,coracao,Coração,26,,-26.95,-51.766667
br,coracao de jesus,Coração de Jesus,05,,-11.65,-39.933333
br,coracao de jesus,Coração de Jesus,15,12410,-16.684444,-44.360278
br,coracao de jesus,Coração de Jesus,26,,-27.283333,-51.1
br,coracao de maria,Coração de Maria,05,6571,-12.233333,-38.75
br,coracao de maria,Coração de Maria,30,,-8.616667,-40.916667
br,coracao do brasil,Coração do Brasil,15,,-17.85,-40.866667
br,corbelia,Corbélia,18,12725,-24.8,-53.3
br,corcovado,Corcovado,15,,-15.966667,-41.1
br,corcovado,Corcovado,16,,-1.65,-50.533333
br,corcunda,Corcunda,06,,-5.2,-38.283333
br,corcunda,Corcunda,11,,-19.983333,-56.45
br,corda,Corda,31,,-6.466667,-48.216667
br,cordeiro,Cordeiro,02,,-9.383333,-38.116667
br,cordeiro,Cordeiro,21,15602,-22.033333,-42.366667
br,cordeiro,Cordeiro,22,,-5.583333,-35.266667
br,cordeiro,Cordeiro,27,,-22.483333,-47.466667
br,cordeiro,Cordeiro,30,,-8.866667,-36.95
br,cordeiropolis,Cordeirópolis,27,25639,-22.483333,-47.466667
br,cordeiros,Cordeiros,05,,-15.016667,-41.933333
br,cordeiros,Cordeiros,17,,-7.383333,-36.8
br,cordeiros,Cordeiros,21,,-22.866667,-42.95
br,cordeiros,Cordeiros,27,,-22.483333,-47.466667
br,cordilheira,Cordilheira,23,,-30.3,-52.85
br,cordilheiras,Cordilheiras,23,,-30.7,-53.816667
br,cordisburgo,Cordisburgo,15,,-19.116667,-44.35
br,cordovil,Cordovil,21,,-22.825276,-43.303956
br,cordozal,Cordozal,04,,.625,-62.651111
br,coreahu,Coreahú,06,,-3.366667,-40.766667
br,coreau,Coreaú,06,12383,-3.55,-40.65
br,coremas,Coremas,17,11897,-7.016667,-37.966667
br,corguinho,Córguinho,06,,-2.816667,-40.4
br,corguinho,Corguinho,11,,-19.883333,-54.866667
br,corguinho dos agostinho,Corguinho dos Agostinho,06,,-2.916667,-40.05
br,coribe,Coribe,05,,-13.833333,-44.466667
br,corimbata,Corimbatá,11,,-21.25,-57.266667
br,corimbota,Corimbota,11,,-21.25,-57.266667
br,corina,Corina,11,,-22.216667,-56.183333
br,corintho,Corintho,15,,-18.35,-44.45
br,corinto,Corinto,15,22121,-18.35,-44.45
br,coripos,Coripós,30,,-8.816667,-39.816667
br,corisco,Corisco,13,,-3.308056,-42.335833
br,corisco,Corisco,27,,-23.289665,-46.506647
br,corityba,Corityba,18,,-25.416667,-49.25
br,corixa,Corixa,14,,-16.466667,-55.666667
br,corixao,Corixão,11,,-18.333333,-56.533333
br,corixo,Corixo,14,,-16.25,-56.166667
br,cornelio procopio,Cornélio Procópio,18,45031,-23.133333,-50.65
br,cornelios,Cornélios,23,,-29.65,-50.05
br,cornelius,Cornélius,23,,-29.65,-50.05
br,cornicha,Cornicha,05,,-13.366667,-40.216667
br,coroaci,Coroaci,15,,-18.583333,-42.283333
br,coroa,Coroa,05,,-13.016667,-38.616667
br,coroa,Coroa,14,,-17.2,-54.5
br,coroacy,Coroacy,15,,-18.583333,-42.283333
br,coroa da ilha,Coroa da Ilha,05,,-9.683333,-41.966667
br,coroa da onca,Coroa da Onça,08,,-20.95,-40.883333
br,coroados,Coroados,27,,-21.366667,-50.25
br,coroa grande,Coroa Grande,06,,-2.816667,-40.15
br,coroa grande,Coroa Grande,21,,-22.898611,-43.863889
br,coroa grande,Coroa Grande,22,,-5.734722,-36.811667
br,coroas,Coroas,15,,-21.016667,-44.233333
br,coroas,Coroas,21,,-22.129444,-43.735
br,coroas limpas,Coroas Limpas,22,,-5.89,-36.581389
br,coroata,Coroatá,06,,-4.4,-40.883333
br,coroata,Coroatá,13,34130,-4.133333,-44.133333
br,coroata,Coroatá,20,,-6.983333,-41.516667
br,corocoro,Corocoró,04,,.066667,-67.683333
br,coromandel,Coromandel,15,22648,-18.466667,-47.216667
br,corona,Corona,11,,-22.45,-55.016667
br,coronel albuquerque,Coronel Albuquerque,14,,-15.45,-54.783333
br,coronel barros,Coronel Barros,11,,-18.65,-56.783333
br,coronel barros,Coronel Barros,23,,-28.383333,-54.066667
br,coronel bicaco,Coronel Bicaco,23,,-27.716667,-53.716667
br,coronel cardoso,Coronel Cardoso,21,,-22.15,-43.966667
br,coronel carlos,Coronel Carlos,22,,-5.381111,-36.938056
br,coronel,Coronel,05,,-12.566667,-41.816667
br,coronel ezequiel,Coronel Ezequiel,22,,-6.383333,-36.183333
br,coronel fabriciano,Coronel Fabriciano,15,100918,-19.516667,-42.633333
br,coronel flores,Coronel Flores,23,,-30.4,-55.9
br,coronel freitas,Coronel Freitas,26,,-26.933333,-52.783333
br,coronel galvao,Coronel Galvão,11,,-18.933333,-54.866667
br,coronel goulart,Coronel Goulart,27,,-22.2,-51.533333
br,coronel joao pessoa,Coronel João Pessoa,22,,-6.266667,-38.483333
br,coronel macedo,Coronel Macedo,27,,-23.633333,-49.316667
br,coronel maia,Coronel Maia,17,,-6.233333,-37.733333
br,coronel manoel viana,Coronel Manoel Viana,23,,-29.583333,-55.483333
br,coronel martim francisco,Coronel Martim Francisco,27,,-22.516667,-46.95
br,coronel martins,Coronel Martins,26,,-26.5,-52.65
br,coronel murta,Coronel Murta,15,,-16.616667,-42.183333
br,coronel pacheco,Coronel Pacheco,15,,-21.583333,-43.266667
br,coronel passos maia,Coronel Passos Maia,26,,-26.816667,-52.016667
br,coronel pilar,Coronel Pilar,23,,-29.266667,-51.683333
br,coronel ponce,Coronel Ponce,14,,-15.566667,-55.016667
br,coronel retiro,Coronel Retiro,14,,-15.366667,-56.633333
br,coronel soares,Coronel Soares,05,,-14.383333,-39.6
br,coronel teixeira,Coronel Teixeira,23,,-27.4,-52.033333
br,coronel vivida,Coronel Vivida,18,15841,-25.966667,-52.566667
br,coronzo,Coronzó,06,,-6.516667,-40.65
br,coroveira,Coroveira,18,,-25.166667,-53.55
br,cor procopio,Cor Procopio,18,,-23.133333,-50.65
br,corralinho,Corralinho,20,,-6.883333,-42.7
br,correa pinto,Correa Pinto,26,,-27.583333,-50.4
br,corredeira,Corredeira,14,,-16.033333,-56.716667
br,corredeira,Corredeira,20,,-3.5775,-42.342222
br,corredeira,Corredeira,27,,-22.05,-49.633333
br,corredor,Corredor,17,,-6.5,-37.483333
br,corredor,Corredor,22,,-6.183333,-37.95
br,corredores,Corredores,06,,-5.35,-40.783333
br,corredores,Corredores,13,,-5.783333,-43.116667
br,corredores,Corredores,20,,-5.116667,-42.033333
br,corrego alto,Córrego Alto,08,,-20.65,-41.033333
br,corrego azul,Córrego Azul,27,,-21.083333,-50.533333
br,corrego,Córrego,05,,-13.066667,-39.566667
br,corrego,Córrego,06,,-3.033333,-40.35
br,corrego,Córrego,22,,-5.320278,-36.352778
br,corrego da bica,Córrego da Bica,18,,-24.8948,-48.5953
br,corrego da foice,Córrego da Foice,15,,-22.6457,-45.7477
br,corrego da forquiha,Córrego da Forquiha,06,,-2.883333,-40.483333
br,corrego d'agua,Corrego d'Agua,08,,-19.7,-40.266667
br,corrego da lavra,Córrego da Lavra,27,,-24.9582,-48.5495
br,corrego da luz,Córrego da Luz,21,,-22.433333,-42.25
br,corrego d'anta,Corrego d'Anta,08,,-20.45,-41.7
br,corrego danta,Córrego Danta,15,,-19.8,-45.9
br,corrego d'anta,Corrego d'Anta,15,,-20.616667,-45.8
br,corrego dantas,Córrego Dantas,08,,-20.45,-41.7
br,corrego da onca,Córrego da Onça,27,,-24.8119,-48.5265
br,corrego da poeira,Córrego da Poeira,06,,-2.916667,-40.25
br,corrego da prata,Córrego da Prata,21,,-21.866667,-42.466667
br,corrego das panelas,Córrego das Panelas,06,,-2.866667,-40.433333
br,corrego das varas,Córrego das Varas,06,,-2.95,-40.116667
br,corrego da valeria,Córrego da Valéria,15,,-20.016667,-43.366667
br,corrego de dentro,Córrego de Dentro,06,,-2.922778,-40.524167
br,corrego de ouro,Córrego de Ouro,29,,-16.3,-50.533333
br,corrego do barro,Córrego do Barro,27,,-24.749686,-48.464115
br,corrego do bom jesus,Córrego do Bom Jesus,15,,-22.633333,-46.033333
br,corrego do cafe,Córrego do Café,08,,-18.85,-40.75
br,corrego do diamante,Córrego do Diamante,18,,-24.7622,-48.932
br,corrego do franco,Córrego do Franco,18,,-24.7995,-48.5512
br,corrego do franco,Córrego do Franco,27,,-24.8075,-48.5531
br,corrego do frango,Córrego do Frango,18,,-24.7948,-48.5599
br,corrego do meio,Córrego do Meio,06,,-2.933333,-40.466667
br,corrego do meio,Córrego do Meio,08,,-20.266667,-41.1
br,corrego do monjolo,Córrego do Monjolo,18,,-24.76337,-48.909082
br,corrego do ouro,Córrego do Ouro,15,,-21.366667,-45.783333
br,corrego do prata,Corrego do Prata,21,,-21.866667,-42.466667
br,corrego do retiro,Córrego do Retiro,06,,-4.6,-37.65
br,corrego do rodrigues,Córrego do Rodrigues,06,,-4.55,-37.716667
br,corrego dos ana,Córrego dos Ana,06,,-2.866667,-40.383333
br,corrego dos borges,Córrego dos Borges,06,,-2.916667,-40.45
br,corrego dos manos,Córrego dos Manos,08,,-20.883333,-41.2
br,corrego do soldado,Córrego do Soldado,15,,-20.183333,-44.566667
br,corrego fundo,Córrego Fundo,06,,-3.35,-39.35
br,corrego fundo,Córrego Fundo,08,,-19.85,-40.283333
br,corrego fundo,Córrego Fundo,15,,-20.466667,-45.533333
br,corrego fundo,Córrego Fundo,27,,-21.616667,-47.35
br,corrego grande,Córrego Grande,05,,-16.25,-39.683333
br,corrego grande,Córrego Grande,06,,-2.906111,-40.629444
br,corrego grande,Córrego Grande,08,,-18.583333,-40.616667
br,corrego grande,Córrego Grande,18,,-24.755585,-48.863228
br,corrego grande do bee,Corrego Grande do Beé,06,,-2.966667,-39.966667
br,corrego novo,Córrego Novo,06,,-3.016667,-39.966667
br,corrego novo,Córrego Novo,15,,-19.833333,-42.383333
br,corrego rico,Córrego Rico,27,,-21.283333,-48.266667
br,corrego rico,Córrego Rico,29,,-15.233333,-47.8
br,corrego salgado,Córrego Salgado,06,,-4.966667,-37.716667
br,corrego sao luis,Córrego São Luís,26,,-26.9825,-49.9563
br,corregos,Córregos,15,,-18.883333,-43.516667
br,corregos,Córregos,17,,-6.433333,-37.883333
br,corregos,Córregos,18,,-24.962731,-48.96971
br,corrego seco,Córrego Sêco,27,,-20.966667,-48.933333
br,corrego sujo,Córrego Sujo,21,,-22.253698,-42.832709
br,corregozinho,Còrregozinho,15,,-20.166667,-45.266667
br,corregozinho,Corregozinho,18,,-24.804947,-48.916128
br,correia,Correia,14,,-16.8,-53.05
br,correia,Correia,15,,-20.816667,-45.666667
br,correia de almeida,Correia de Almeida,15,,-21.283333,-43.633333
br,correia pinto,Correia Pinto,26,13752,-27.583333,-50.4
br,correias,Correias,15,,-21.75,-46.333333
br,correias,Correias,18,,-25.51641,-50.217265
br,correias,Correias,22,,-5,-37.5
br,correias,Correias,27,,-23.492979,-47.796283
br,correntao,Correntão,13,,-7.916667,-45.983333
br,corrente,Corrente,05,,-11.9,-45.066667
br,corrente,Corrente,06,,-7.666667,-39.15
br,corrente,Corrente,11,,-17.616667,-54.983333
br,corrente,Corrente,13,,-3.5725,-42.849722
br,corrente,Corrente,20,13967,-10.436111,-45.131111
br,correntes,Correntes,11,,-17.616667,-54.983333
br,correntes,Correntes,26,,-27.083333,-50.633333
br,correntes,Correntes,30,,-9.133333,-36.316667
br,correnteza,Correnteza,04,,-3.5,-68.316667
br,correnteza,Correnteza,21,,-21.283333,-41.316667
br,correntezas,Correntezas,21,,-22.5,-42.516667
br,correntina,Correntina,05,13187,-13.333333,-44.65
br,correntinho,Correntinho,15,,-18.666667,-42.783333
br,corrida,Corrida,15,,-19.5,-42.833333
br,cortada,Cortada,17,,-7.133333,-37.933333
br,corta dedos,Corta Dedos,17,,-7.133333,-36.166667
br,cortado,Cortado,20,,-6.633333,-41.783333
br,cortado,Cortado,23,,-29.75,-52.966667
br,cortado,Cortado,27,,-21.533333,-47.766667
br,corta mao,Corta Mão,05,,-13.05,-39.5
br,corte,Côrte,23,,-30.15,-55.066667
br,corte,Corte,30,,-9.083333,-38.05
br,corte de pedra,Corte de Pedra,05,,-13.5,-39.45
br,corte grande,Corte Grande,05,,-12.066667,-37.766667
br,corte grande,Corte Grande,27,,-22.15,-47.4
br,cortes,Cortês,30,,-8.466667,-35.55
br,cortez,Cortez,30,,-8.466667,-35.55
br,cortume,Cortume,20,,-5.133333,-41.166667
br,cortume,Cortume,30,,-8.183333,-36
br,coruja,Coruja,15,,-17.25,-41.7
br,coruja,Coruja,30,,-8.066667,-36.6
br,corujas,Corujas,06,,-6.016667,-38.95
br,corujas,Corujás,26,,-28.266667,-49.116667
br,corumba,Corumbá,05,,-15.916667,-48.8
br,corumba,Corumbá,11,96523,-19.016667,-57.65
br,corumba,Corumbá,27,,-23.243056,-46.563333
br,corumba de goias,Corumbá de Goiás,05,,-15.916667,-48.8
br,corumbahyba,Corumbahyba,29,,-18.15,-48.566667
br,corumbaiba,Corumbaíba,29,,-18.15,-48.566667
br,corumbalina,Corumbalina,29,,-17.316667,-48.5
br,corumbatahy,Corumbatahy,27,,-22.233333,-47.633333
br,corumbatai,Corumbataí,27,,-22.233333,-47.633333
br,corumbazul,Corumbazul,29,,-18.25,-48.866667
br,corunha,Corunhã,11,,-18.4,-56.183333
br,corupa,Corupá,26,,-26.433333,-49.233333
br,coruripe,Coruripe,02,31428,-10.133333,-36.166667
br,corveta,Corveta,26,,-26.4504,-48.7445
br,corvo branco,Corvo Branco,18,,-25.566667,-52.05
br,corvo,Corvo,23,,-29.366667,-51.866667
br,cosme de brito,Cosme de Brito,17,,-6.45,-38.55
br,cosme pais,Cosme Pais,06,,-5.433333,-39.133333
br,cosme pinto,Cosme Pinto,17,,-7.133333,-36.8
br,cosme velho,Cosme Velho,21,,-22.933333,-43.2
br,cosmo,Cosmo,21,,-22.90862,-43.616594
br,cosmo,Cosmo,22,,-5.566667,-35.383333
br,cosmopolis,Cosmópolis,27,47773,-22.633333,-47.2
br,cosmorama,Cosmorama,27,,-20.466667,-49.783333
br,cosmos,Cosmos,21,,-22.90862,-43.616594
br,cosso,Cossó,13,,-3.016667,-43.35
br,cosstana,Cosstanã,04,,-7.266667,-64.883333
br,costa barros,Costa Barros,21,,-22.816916,-43.373008
br,costa,Costa,14,,-16.533333,-57.516667
br,costa,Costa,20,,-7.75,-42.25
br,costa,Costa,21,,-22.716667,-41.983333
br,costa da cadeia,Costa da Cadeia,23,,-29.7,-51.683333
br,costa da praia,Costa da Praia,26,,-28.766667,-49.166667
br,costa da salvacao,Costa da Salvação,04,,-3.843611,-62.530556
br,costa do anajatuba,Costa do Anajatuba,04,,-2.801944,-60.771667
br,costa do ipiranga,Costa do Ipiranga,04,,-4.3625,-59.764167
br,costa do julio,Costa do Júlio,04,,-3.873056,-62.6425
br,costa do ladrao,Costa do Ladrão,23,,-30.6692,-52.3272
br,costa do mamuripana,Costa do Mamuripana,25,,-.338611,-61.859722
br,costa dos rosa,Costa Dos Rosa,04,,-4.5775,-62.061944
br,costa do trocaris,Costa do Trocaris,04,,-3.900278,-62.863611
br,costa machado,Costa Machado,27,,-22.2,-51.833333
br,costa marques,Costa Marques,24,,-12.466667,-64.266667
br,costaneira,Costaneira,20,,-7.333333,-41.766667
br,costao,Costão,23,,-29.45,-51.966667
br,costa pereira,Costa Pereira,08,,-20.416667,-40.65
br,costa rica,Costa Rica,11,12931,-23.416667,-54.65
br,costa rica,Costa Rica,27,,-23.013779,-47.657411
br,costas,Costas,06,,-6,-40.533333
br,costas,Costas,15,,-19.966667,-44.933333
br,costas,Costas,27,,-23.75,-48.65
br,costa sena,Costa Sena,15,,-18.666667,-43.666667
br,costeira,Costeira,26,,-26.4465,-48.6248
br,costela,Costela,05,,-12.966667,-41.466667
br,costello,Costello,20,,-5.333333,-41.55
br,costinha,Costinha,17,,-6.965556,-34.858333
br,cotaxe,Cotaxé,08,,-18.2,-40.716667
br,cotegipe,Cotegipe,05,,-12.033333,-44.25
br,cotegipe,Cotegipe,23,,-27.616667,-52.383333
br,cotejipe,Cotejipe,05,,-12.033333,-44.25
br,cotia,Cotia,02,,-9.016667,-37.5
br,cotia,Cotia,08,,-20.75,-41.55
br,cotia,Cotia,13,,-9.533333,-46.116667
br,cotia,Cotia,14,,-15.966667,-56.466667
br,cotia,Cotia,27,174832,-23.616667,-46.933333
br,cotia fria,Cotia Fria,13,,-2.533333,-45.35
br,cotia gorda,Cotia Gorda,13,,-3.548056,-43.375
br,cotias,Cotias,13,,-3.166667,-45.166667
br,coti,Coti,05,,-11.95,-38.1
br,cotingo,Cotingo,25,,3.9,-60.483333
br,cotinguiba,Cotingüiba,28,,-10.866667,-37.116667
br,cotipora,Cotiporã,23,,-29.016667,-51.7
br,coto,Cotó,13,,-3.266667,-42.883333
br,coto,Cotó,22,,-5.383333,-37.066667
br,cotovello,Cotovello,22,,-5.933333,-35.933333
br,cotovelo,Cotovelo,04,,.8575,-62.584444
br,cotovelo,Cotovêlo,15,,-17.883333,-44.683333
br,cotovelo,Cotovêlo,22,,-6.166667,-38.3
br,cotovelo,Cotovêlo,23,,-31.666667,-52.1
br,counani,Counani,03,,2.866667,-51.1
br,courao,Courão,05,,-12.833333,-39.233333
br,couro d'anta,Couro d'Anta,30,,-8.316667,-36.766667
br,couro de porco,Couro de Porco,20,,-3.966944,-42.251111
br,coutinho,Coutinho,06,,-5.816667,-40.683333
br,coutinho,Coutinho,27,,-24.871569,-48.11342
br,couto de magalhaes,Couto de Magalhães,15,,-18.066667,-43.416667
br,couto de magalhaes,Couto de Magalhães,31,,-8.310278,-49.056944
br,couto magalhaes,Couto Magalhães,31,,-8.310278,-49.056944
br,coutos,Coutos,05,,-14.85,-39.066667
br,couves,Couves,20,,-9.316667,-44.516667
br,cova,Cóva,05,,-10.866667,-40.016667
br,cova da onca,Cova da Onça,05,,-12.283333,-38.35
br,cova de mandioca,Cova de Mandioca,05,,-14.683333,-42.666667
br,cova donga,Cova Donga,20,,-6.583333,-40.75
br,covanca,Covanca,15,,-20.233333,-43.016667
br,covanca,Covanca,21,,-22.914716,-43.339308
br,covao,Covão,05,,-12.466667,-38.066667
br,covas,Covas,05,,-10.866667,-40.016667
br,covas,Covas,30,,-8.516667,-36.6
br,coxilha butia,Coxilha Butiá,23,,-30.6013,-52.2767
br,coxilha,Coxilha,23,,-28.116667,-52.283333
br,coxilha do meio,Coxilha do Meio,18,,-25.65,-50.25
br,coxilha grande,Coxilha Grande,23,,-28.233333,-50.983333
br,coxilhao das ameixeiras,Coxilhão das Ameixeiras,18,,-25.708293,-50.179952
br,coxilhao de cima,Coxilhão de Cima,18,,-25.652592,-50.23711
br,coxilhao de santa rosa,Coxilhão de Santa Rosa,18,,-25.643074,-50.254351
br,coxilhao do meio,Coxilhão do Meio,18,,-25.676943,-50.236377
br,coxilhao vitoriano,Coxilhão Vitoriano,18,,-25.668815,-50.24242
br,coxilha rica,Coxilha Rica,18,,-26,-52.833333
br,coxim,Coxim,11,30216,-18.5,-54.75
br,coxinhos,Coxinhos,18,,-25.4116,-50.595
br,coxipo-acu,Coxipó-Açu,14,,-15.35,-56.15
br,coxipo,Coxipo,14,,-15.633333,-56.066667
br,coxipo da ponte,Coxipó da Ponte,14,,-15.633333,-56.066667
br,coxipo do ouro,Coxipó do Ouro,14,,-15.45,-55.983333
br,coxipozinho,Coxipozinho,14,,-15.35,-56.15
br,coxixola,Coxixola,17,,-7.616667,-36.616667
br,coxo,Coxo,06,,-3.766667,-40.2
br,coxo,Coxo,20,,-5.7,-43.033333
br,coxos,Coxos,18,,-25.735616,-50.634748
br,craiba,Craíba,02,,-9.716667,-36.766667
br,crajau,Crajaú,21,,-22.921111,-43.262222
br,cramerim,Cramerim,08,,-20.05,-40.35
br,craolandia,Craolândia,31,,-8.106944,-47.012222
br,crasto,Crasto,28,,-11.416667,-37.416667
br,crateus,Crateús,06,52934,-5.166667,-40.666667
br,cratheus,Cratheús,06,,-5.166667,-40.666667
br,crato,Crato,04,,-7.483333,-63.033333
br,crato,Crato,06,88788,-7.233333,-39.383333
br,crauna,Craúna,20,,-5.983333,-42.516667
br,crauta,Crautá,30,,-8.15,-37.316667
br,cravaio,Cravaio,28,,-9.983333,-37.066667
br,cravari,Cravari,14,,-12.466667,-57.966667
br,cravinhos,Cravinhos,27,32690,-21.316667,-47.75
br,cravo,Cravo,04,,-5.273889,-59.953611
br,cravo,Cravo,16,,-1.783333,-47.983333
br,creca,Creca,22,,-5.966667,-37.328611
br,creciuna,Creciúna,26,,-28.666667,-49.383333
br,creolas,Creolas,14,,-15.116667,-57.6
br,creoulas,Creoulas,05,,-13.516667,-42.016667
br,crescencio,Crescêncio,11,,-23.266667,-55.533333
br,cresciuma,Cresciuma,18,,-25.433333,-54.4
br,cresciuma,Cresciúma,26,,-28.666667,-49.383333
br,crichas,Crichas,29,,-14.45,-49.966667
br,criciuma,Criciuma,08,,-20.216667,-41.616667
br,criciuma,Criciúma,18,,-24.74859,-48.941097
br,criciuma,Criciúma,26,161957,-28.666667,-49.383333
br,criciumal,Criciumal,23,,-27.5,-54.116667
br,crimea,Criméa,13,,-5.416667,-43.4
br,crimeia,Criméia,13,,-5.416667,-43.4
br,criminoso,Criminoso,13,,-3.981111,-42.94
br,crioli,Crioli,13,,-4.35,-43.35
br,crioli,Crioli,20,,-3.512778,-42.454722
br,crioli da sinha,Crioli da Sinhá,13,,-5.4,-44.366667
br,crioulas,Crioulas,05,,-13.516667,-42.016667
br,crioulas,Crioulas,06,,-6.966667,-38.95
br,crisanto,Crisanto,06,,-5.266667,-39.183333
br,crisciuma,Crisciúma,08,,-20.216667,-41.616667
br,crisciuma,Crisciuma,18,,-26.016667,-51.716667
br,crisolia,Crisólia,15,,-22.25,-46.416667
br,crisolita,Crisólita,15,,-17.25,-40.933333
br,crisopolis,Crisópolis,05,,-11.516667,-38.166667
br,crispim jaques,Crispim Jaques,15,,-17.833333,-41.133333
br,crissiumal,Crissiumal,23,,-27.5,-54.116667
br,cristai,Cristai,27,,-23.3,-46.816667
br,cristais,Cristais,05,,-14,-41.45
br,cristais,Cristais,06,,-4.5,-38.35
br,cristais,Cristais,15,,-20.866667,-45.516667
br,cristais,Cristais,27,,-20.4,-47.416667
br,cristalandia,Cristalândia,05,,-14,-41.45
br,cristalandia,Cristalândia,31,,-10.598611,-49.108333
br,cristal,Cristal,05,,-11.816667,-41.316667
br,cristal,Cristal,08,,-18.083333,-40.1
br,cristal,Cristal,11,,-21.5,-54.366667
br,cristal,Cristal,23,,-27.9,-54.95
br,cristal,Cristal,31,,-13.011389,-47.788333
br,cristalia,Cristália,15,,-16.716667,-42.866667
br,cristalia,Cristália,30,,-8.816667,-40.366667
br,cristalina,Cristalina,08,,-18.783333,-40.583333
br,cristalina,Cristalina,29,36532,-16.75,-47.6
br,cristalino,Cristalino,08,,-18.783333,-40.583333
br,cristalino,Cristalino,29,,-16.75,-47.6
br,cristiano guimaraes,Cristiano Guimarães,15,,-17.733333,-41.583333
br,cristiano otoni,Cristiano Otoni,15,,-20.833333,-43.8
br,cristianopolis,Cristianópolis,28,,-11.483333,-37.766667
br,cristianopolis,Cristianópolis,29,,-17.216667,-48.75
br,cristina,Cristina,15,,-22.216667,-45.266667
br,cristina,Cristina,28,,-11.483333,-37.766667
br,cristinapolis,Cristinápolis,28,6430,-11.483333,-37.766667
br,cristino castro,Cristino Castro,20,,-8.816667,-44.216667
br,cristino,Cristino,11,,-22.05,-52.75
br,cristino valadao,Cristino Valadão,15,,-20.366667,-45.383333
br,cristo rei,Cristo Rei,18,,-22.7,-52.466667
br,cristovao,Cristóvão,06,,-7.633333,-38.883333
br,cristovao,Cristóvão,15,,-16.233333,-40.583333
br,cristovao,Cristóvão,20,,-7.35,-41.816667
br,cristovao,Cristóvão,22,,-4.928333,-36.961944
br,cristovao,Cristóvão,27,,-23.5772,-47.5778
br,criuva,Criúva,23,,-28.983333,-50.966667
br,crixalandia,Crixalândia,29,,-15.3,-47.25
br,crixas,Crixás,29,11560,-14.45,-49.966667
br,crixas,Crixás,31,,-11.105833,-48.846111
br,croa,Croá,17,,-6.65,-38.533333
br,croas,Croás,30,,-7.85,-38.133333
br,croata(1),Croatá(1),06,,-4.033333,-38.5
br,croata,Croatá,06,,-3.65,-39.116667
br,croata,Croatá,13,,-4.133333,-44.133333
br,croata,Croatá,17,,-6.916667,-38.4
br,croata,Croata,20,,-6.883333,-42.45
br,croata,Croatá,22,,-6.166667,-37.7
br,croata,Croata,30,,-7.633333,-39.6
br,croata,Croatá,31,,-5.7,-48.033333
br,crobas,Crobas,14,,-14.9,-56.533333
br,crominia,Cromínia,29,,-17.283333,-49.35
br,cruangi,Cruangi,30,,-7.566667,-35.35
br,cruangy,Cruangy,30,,-7.566667,-35.35
br,cruanji,Cruanji,30,,-7.566667,-35.35
br,crubixa,Crubixá,08,,-20.65,-40.85
br,crubixais,Crubixais,21,,-22.233333,-42.066667
br,crubixe,Crubixê,08,,-20.65,-40.85
br,crucilandia,Crucilândia,15,,-20.383333,-44.35
br,crueira,Crueira,05,,-12.35,-37.966667
br,cruena,Cruena,05,,-12.35,-37.966667
br,crumatai,Crumataí,05,,-12.416667,-39.183333
br,crupiara,Crupiara,15,,-17.083333,-41.9
br,crussai,Crussaí,05,,-12.833333,-39.383333
br,cruxati,Cruxati,06,,-3.266667,-39.633333
br,cruxeiro,Cruxeiro,06,,-4.333333,-38.116667
br,cruzalia,Cruzália,27,,-22.75,-50.8
br,cruz alta,Cruz Alta,11,,-19.066667,-55.566667
br,cruz alta,Cruz Alta,23,65276,-28.65,-53.6
br,cruz alta,Cruz Alta,27,,-22.75,-50.8
br,cruz altinha,Cruz Altinha,23,,-28.283333,-51.95
br,cruzamento,Cruzamento,22,,-5.283333,-35.75
br,cruz,Cruz,05,,-12.6,-38.483333
br,cruz,Cruz,06,8723,-2.95,-40.183333
br,cruz,Cruz,13,,-3.696667,-42.976944
br,cruz,Cruz,15,,-20.6,-45.933333
br,cruz,Cruz,20,,-10.35,-45.066667
br,cruz,Cruz,22,,-6.183333,-38.516667
br,cruz,Cruz,30,,-8.9,-36.583333
br,cruz da esperanca,Cruz da Esperança,27,,-21.3,-47.416667
br,cruz das almas,Cruz das Almas,05,47846,-12.666667,-39.1
br,cruz das almas,Cruz das Almas,20,,-6.1,-42.8
br,cruz das almas,Cruz das Almas,21,,-21.783333,-41.3
br,cruz das almas,Cruz das Almas,27,,-22.733333,-46.85
br,cruz das posses,Cruz das Posses,27,,-21.083333,-47.9
br,cruz da teresa,Cruz da Teresa,17,,-7.016667,-37.916667
br,cruz de almas,Cruz de Almas,22,,-6.066667,-37.766667
br,cruz de malta,Cruz de Malta,30,,-8.25,-40.333333
br,cruz de palhano,Cruz de Palhano,06,,-4.733333,-37.95
br,cruz descoberta,Cruz Descoberta,27,,-22.75,-46.8
br,cruz do amapa,Cruz do Amapá,03,,2.183333,-50.8
br,cruz do bento joao,Cruz do Bento João,15,,-22.316667,-45.816667
br,cruz do espirito santo,Cruz do Espírito Santo,17,5812,-7.133333,-35.1
br,cruz do meio,Cruz do Meio,02,,-9.5,-36.833333
br,cruz do palhano,Cruz do Palhano,06,,-4.733333,-37.95
br,cruz dos anjos,Cruz dos Anjos,05,,-12.933333,-39.366667
br,cruzeirinho,Cruzeirinho,06,,-6.283333,-38.733333
br,cruzeiro bondao,Cruzeiro Bondão,05,,-12.016667,-38.966667
br,cruzeiro bordao,Cruzeiro Bordão,05,,-12.016667,-38.966667
br,cruzeiro,Cruzeiro,04,,-5.24,-60.55
br,cruzeiro,Cruzeiro,06,,-4.333333,-38.116667
br,cruzeiro,Cruzeiro,15,,-18.833333,-42.916667
br,cruzeiro,Cruzeiro,18,,-23.438879,-49.861796
br,cruzeiro,Cruzeiro,20,,-3.940278,-42.426111
br,cruzeiro,Cruzeiro,21,,-21.433333,-41.9
br,cruzeiro,Cruzeiro,23,,-27.866667,-54.433333
br,cruzeiro,Cruzeiro,25,,3.45,-61.2
br,cruzeiro,Cruzeiro,26,,-27.166667,-51.5
br,cruzeiro,Cruzeiro,27,72023,-22.566667,-44.966667
br,cruzeiro da fortaleza,Cruzeiro da Fortaleza,15,,-18.966667,-46.666667
br,cruzeiro da paz,Cruzeiro da Paz,05,,-11.9,-38.2
br,cruzeiro das araras,Cruzeiro das Araras,04,,-5.24,-60.55
br,cruzeiro da tapera d'agua limpa,Cruzeiro da Tapera d'Agua Limpa,11,,-19.35,-54.7
br,cruzeiro do norte,Cruzeiro do Norte,06,,-5.516667,-39.15
br,cruzeiro do norte,Cruzeiro do Norte,18,,-23.233333,-50.85
br,cruzeiro do oeste,Cruzeiro do Oeste,18,15058,-23.766667,-53.066667
br,cruzeiro dos peixotos,Cruzeiro dos Peixotos,15,,-18.7,-48.366667
br,cruzeiro do sul,Cruzeiro do Sul,01,45517,-7.633333,-72.6
br,cruzeiro do sul,Cruzeiro do Sul,05,,-14.1,-39.083333
br,cruzeiro do sul,Cruzeiro do Sul,18,,-22.933333,-52.15
br,cruzeiro do sul,Cruzeiro do Sul,23,,-29.516667,-51.983333
br,cruzeiro do sul,Cruzeiro do Sul,26,,-27.166667,-51.5
br,cruzeiro do sul,Cruzeiro do Sul,30,,-8.583333,-36.3
br,cruzeiros dos peixotos,Cruzeiros dos Peixotos,15,,-18.7,-48.366667
br,cruzes,Cruzes,02,,-9.65,-36.483333
br,cruzes,Cruzes,27,,-21.533333,-50.533333
br,cruzes,Cruzes,30,,-8.65,-36.116667
br,cruzeta,Cruzeta,06,,-6.566667,-39.866667
br,cruzeta,Cruzeta,22,,-6.416667,-36.783333
br,cruz i,Cruz I,13,,-3.454722,-43.102778
br,cruz ii,Cruz II,13,,-3.450833,-43.088611
br,cruzilandia,Cruzilândia,13,,-3.920833,-43.376389
br,cruzilha,Cruzilha,15,,-21.833333,-44.8
br,cruzilia,Cruzília,15,12816,-21.833333,-44.8
br,cruzinha,Cruzinha,20,,-5.466667,-42.766667
br,cruzinha,Cruzinha,22,,-5.937778,-36.148056
br,cruzinha,Cruzinha,23,,-28.266667,-52.95
br,cruz machado,Cruz Machado,18,,-26.016667,-51.35
br,cruz muchado,Cruz Muchado,18,,-26.016667,-51.35
br,cruz velha,Cruz Velha,11,,-20.916667,-57.166667
br,cruz vera,Cruz Vera,15,,-22.5037,-45.6866
br,crystaes,Crystaes,15,,-20.866667,-45.516667
br,crystaes,Crystaes,27,,-20.4,-47.416667
br,crystallina,Crystallina,15,,-16.716667,-42.866667
br,crystallina,Crystallina,29,,-16.75,-47.6
br,cta. alegre,Cta. Alegre,20,,-5.033333,-42.216667
br,cuapiacu,Cuapiaçu,27,,-20.833333,-49.216667
br,cubas,Cubas,15,,-18.583333,-43.666667
br,cubatao,Cubatão,18,,-25.826451,-48.77469
br,cubatao,Cubatão,26,,-26.216667,-48.833333
br,cubatao,Cubatão,27,118412,-23.883333,-46.416667
br,cubataozinho,Cubatáozinho,18,,-25.7238,-48.7616
br,cubati,Cubati,17,,-6.85,-36.35
br,cubiculo,Cubículo,26,,-28.566667,-49.1
br,cucaia,Cucaia,16,,-1.4,-48.116667
br,cucau,Cucaú,30,,-8.65,-35.266667
br,cucui,Cucuí,04,,1.178333,-66.841111
br,cucuy,Cucuy,04,,1.178333,-66.841111
br,cue,Cuê,11,,-22.9,-55.316667
br,cueira,Cueira,05,,-13.6,-38.883333
br,cuiaba,Cuiabá,04,,-2.533333,-66.383333
br,cuiaba,Cuiabá,14,521961,-15.583333,-56.083333
br,cuiaba,Cuiabá,15,,-18.416667,-43.816667
br,cuiaba,Cuiabá,27,,-22.3,-52.1
br,cuiaba,Cuiabá,28,,-9.7,-37.816667
br,cuiaba da larga,Cuiabá da Larga,14,,-14.35,-55.35
br,cuiaba de larga,Cuiabá de Larga,14,,-14.35,-55.35
br,cuiaba paulista,Cuiabá Paulista,27,,-22.3,-52.1
br,cuiabazinho,Cuiabazinho,14,,-14.383333,-55.616667
br,cuiari,Cuiari,04,,1.5,-68.183333
br,cuiary,Cuiary,04,,.216667,-67.266667
br,cuinarana,Cuinarana,16,,-.783333,-47.583333
br,cuipeua,Cuipeua,16,,-1.883333,-54.883333
br,cuipiranga,Cuipiranga,06,,-4.809722,-37.273056
br,cuite,Cuité,05,,-11.55,-39.266667
br,cuite,Cuité,15,,-19.083333,-41.55
br,cuite,Cuité,17,11392,-6.483333,-36.15
br,cuite,Cuité,20,,-4.3,-42.75
br,cuite,Cuité,22,,-6.416667,-35.3
br,cuitegi,Cuitegi,17,,-6.9,-35.533333
br,cuiteji,Cuiteji,17,,-6.9,-35.533333
br,cuitelos,Cuitelos,27,,-22.116667,-47.1
br,cujubim,Cujubim,04,,-5.777222,-60.946944
br,cujubim,Cujubim,24,,-8.966667,-64.05
br,cujubina,Cujubina,24,,-9.45,-62.633333
br,cujuhim,Cujuhim,04,,-1.686389,-69.163611
br,cujuim,Cujuim,04,,-1.686389,-69.163611
br,culuim,Culuim,04,,-1.686389,-69.163611
br,culuvana,Culuvana,16,,-4.1,-55.833333
br,cuma,Cumã,13,,-2.116667,-44.6
br,cumanda,Cumandá,25,,.836667,-61.661667
br,cumari,Cumari,29,,-18.266667,-48.183333
br,cumaru,Cumaru,04,,-1.116667,-62.733333
br,cumaru,Cumaru,16,,-1.716667,-47.816667
br,cumaru,Cumaru,25,,2.9,-60.9
br,cumaru,Cumaru,30,6861,-8,-35.7
br,cumaruma,Cumarumã,03,,-3.416667,-50.3
br,cumary,Cumary,29,,-18.266667,-48.183333
br,cumati,Cumati,17,,-6.816667,-36.366667
br,cumbaru,Cumbaru,14,,-15.516667,-56.933333
br,cumbauba,Cumbaúba,20,,-8.8,-45.383333
br,cumbaubas,Cumbaúbas,20,,-8.8,-45.383333
br,cumbe,Cumbe,05,,-10.516667,-39.016667
br,cumbe,Cumbe,06,,-4.483333,-37.75
br,cumbe,Cumbe,13,,-3.878889,-43.396389
br,cumbe,Cumbe,20,,-5.516667,-41.466667
br,cumbe,Cumbe,22,,-6.05,-37.933333
br,cumbe,Cumbe,28,,-10.35,-37.233333
br,cumbe,Cumbe,30,,-7.633333,-37.733333
br,cumbica,Cumbica,27,,-23.466667,-46.466667
br,cumbre,Cumbre,13,,-3.867222,-43.285278
br,cumiranga,Cumiranga,16,,-1.8,-46.283333
br,cumuruxatiba,Cumuruxatiba,05,,-17.1,-39.183333
br,cunani,Cunani,03,,2.866667,-51.1
br,cunany,Cunany,03,,2.866667,-51.1
br,cuncas,Cuncas,06,,-7.1,-38.733333
br,cunha,Cunha,15,,-20.333333,-42.966667
br,cunha,Cunha,26,,-26.9,-53.15
br,cunha,Cunha,27,11896,-23.083333,-44.966667
br,cunha,Cunha,30,,-8.116667,-36.533333
br,cunhambebe,Cunhambebe,21,,-23,-44.333333
br,cunhamporanga,Cunhamporanga,18,,-24.716667,-49.8
br,cunhangi,Cunhangi,05,,-13.133333,-39.15
br,cunhanji,Cunhanji,05,,-13.133333,-39.15
br,cunha pora,Cunha Porã,26,,-26.9,-53.15
br,cunhaporanga,Cunhaporanga,18,,-24.716667,-49.8
br,cunhas,Cunhas,15,,-20.333333,-42.966667
br,cunhupuca,Cunhupuca,04,,-9.083333,-68.116667
br,cunuman,Cunuman,04,,-6.133333,-60.166667
br,cuo,Cuó,22,,-5.571389,-36.873889
br,cupaoba,Cupaoba,17,,-6.683333,-35.433333
br,cuparaque,Cuparaque,15,,-18.966667,-41.1
br,cupatana,Cupatana,04,,-2.8,-67.066667
br,cupe,Cupê,02,,-9.4,-35.5
br,cupe,Cupe,30,,-8.466667,-34.983333
br,cupia,Cupia,04,,-4.910556,-62.632222
br,cupicara,Cupiçara,17,,-7.483333,-34.95
br,cupido,Cupido,08,,-19.066667,-40.133333
br,cupido,Cupido,17,,-7.416667,-37.6
br,cupijo,Cupijó,16,,-2.166667,-49.616667
br,cupim,Cupim,04,,-4.568056,-59.862778
br,cupim,Cupim,14,,-16.266667,-56.833333
br,cupim,Cupim,21,,-21.8,-41.4
br,cupim,Cupim,28,,-9.866667,-37.616667
br,cupim grande,Cupim Grande,13,,-6.416667,-43.116667
br,cupins,Cupins,05,,-12.7,-44.683333
br,cupins,Cupins,11,,-19.85,-51.05
br,cupins,Cupins,20,,-4.4,-42.6
br,cupira,Cupira,02,,-9.483333,-37.283333
br,cupira,Cupira,30,19096,-8.616667,-35.95
br,cupiras de cima,Cupiras de Cima,17,,-6.966667,-37.483333
br,cupissara,Cupissara,17,,-7.483333,-34.95
br,cupixi,Cupixi,03,,.633333,-51.783333
br,cupuba,Cupuba,05,,-17.966667,-39.566667
br,cupyra,Cupyra,30,,-8.616667,-35.95
br,curaca,Curaçá,05,11858,-8.983333,-39.9
br,cura,Cura,13,,-3.0725,-42.220556
br,curador,Curador,02,,-5.25,-44.5
br,curaja,Curajá,16,,-.783333,-47.95
br,curapaity,Curapaity,04,,-5.609722,-63.328611
br,curaru,Curaru,04,,-4.187778,-60.641111
br,curati,Curati,25,,2.516667,-60.033333
br,curatis,Curatis,06,,-4.983333,-40.266667
br,curato do santa catarina,Curato do Santa Catarina,21,,-22.116667,-41.8
br,cure,Curé,11,,-21.416667,-56.416667
br,curema,Curema,17,,-7.016667,-37.966667
br,curiango,Curiango,15,,-16.166667,-40.65
br,curiau,Curiaú,03,,.133333,-51.066667
br,curicaca,Curicaca,30,,-7.45,-39.816667
br,curicaca,Curicaca,31,,-7.883333,-48.15
br,curicha,Curicha,16,,1.933333,-54.916667
br,curicica,Curicica,21,,-22.953823,-43.38384
br,curima,Curima,16,,-2.183333,-49.466667
br,curima,Curimã,22,,-5.866667,-35.766667
br,curima,Curimã,30,,-8.85,-35.333333
br,curimata,Curimatá,04,,-4.816667,-66.766667
br,curimata,Curimata,06,,-4.183333,-38.533333
br,curimata,Curimatá,20,,-10.033333,-44.283333
br,curimatai,Curimataí,15,,-17.85,-43.983333
br,curimatau,Curimataú,17,,-6.716667,-35.5
br,curinhaem,Curinhãem,17,,-7.133333,-35.45
br,curio,Curió,06,,-5.533333,-39.833333
br,curipare,Curiparé,05,,-11.522222,-45.055556
br,curipi,Curipi,03,,3.716667,-51.683333
br,curitbanos,Curitbanos,27,,-22.883333,-46.55
br,curite,Curite,16,,-4.1,-55.666667
br,curitiba,Curitiba,18,1718433,-25.416667,-49.25
br,curitibanos,Curitibanos,26,32142,-27.3,-50.6
br,curituba,Curituba,28,,-9.65,-37.8
br,curituba velha,Curituba Velha,28,,-9.65,-37.933333
br,curityba,Curityba,18,,-25.416667,-49.25
br,curitybanos,Curitybanos,26,,-27.3,-50.6
br,curiuva,Curiúva,18,,-24.033333,-50.45
br,curraes novos,Curraes Novos,22,,-6.25,-36.516667
br,currahnho,Currahnho,06,,-4.133333,-38.366667
br,currais barauna,Currais Baraúna,22,,-5.083333,-37.616667
br,currais,Currais,05,,-9.566667,-43.233333
br,currais,Currais,13,,-3.383056,-42.503611
br,currais,Currais,15,,-16.066667,-40.816667
br,currais,Currais,17,,-7.083333,-38.616667
br,currais,Currais,20,,-8.966667,-44.416667
br,currais novo,Currais Novo,22,,-5.971667,-36.788056
br,currais novos,Currais Novos,22,35561,-6.25,-36.516667
br,currais velhos,Currais Velhos,06,,-2.85,-40.083333
br,curral alto,Curral Alto,23,,-32.95,-52.766667
br,curral,Curral,05,,-13.383333,-38.966667
br,curral,Curral,17,,-6.833333,-38.2
br,curral,Curral,20,,-6.816667,-40.516667
br,curral da igreja,Curral da Igreja,13,,-3.383333,-44.8
br,curral das minas,Curral das Minas,26,,-26.9906,-49.0145
br,curral das pedras,Curral das Pedras,05,,-12.366667,-39.533333
br,curral das pedras,Curral das Pedras,28,,-9.966667,-37.083333
br,curral da vaizea,Curral da Vaizea,06,,-6.55,-39.116667
br,curral de arame,Curral de Arame,11,,-22.35,-54.966667
br,curral de baixo,Curral de Baixo,22,,-5.322222,-37.2875
br,curral de dentro,Curral de Dentro,15,,-15.95,-41.883333
br,curral de pedra,Curral de Pedra,17,,-6.716667,-37.816667
br,curral de pedra,Curral de Pedra,23,,-30.416667,-54.85
br,curral de pedra,Curral de Pedra,27,,-20.216667,-47.566667
br,curral de pedras,Curral de Pedras,05,,-13.616667,-44.516667
br,curral de pedras,Curral de Pedras,20,,-6.116667,-40.9
br,curral de pedro,Curral de Pedro,23,,-30.416667,-54.85
br,curral de vacas,Curral de Vacas,31,,-7.416667,-48.266667
br,curral de varas,Curral de Varas,15,,-15.65,-41.733333
br,curral do gato,Curral do Gato,05,,-10.883333,-38.966667
br,curral do meio,Curral do Meio,02,,-9.533333,-37.7
br,curral do meio,Curral do Meio,05,,-12.6,-39.616667
br,curral do meio,Curral do Meio,13,,-3.108611,-42.11
br,curral do mel,Curral do Mel,05,,-12.6,-39.616667
br,curral do pedra,Curral do Pedra,23,,-30.416667,-54.85
br,curral dos bois,Curral dos Bois,05,,-9.183333,-38.3
br,curral dos bois,Curral dos Bois,28,,-10.516667,-36.916667
br,curral dos bois,Curral dos Bois,30,,-8.95,-38.15
br,curral falso,Curral Falso,05,,-12.416667,-39.233333
br,curral falso,Curral Falso,21,,-22.935509,-43.667128
br,curral feio,Curral Feio,05,,-10.7,-38.566667
br,curral grande,Curral Grande,06,,-3.533333,-39.166667
br,curral grande,Curral Grande,20,,-3.815833,-42.34
br,curralinha,Curralinha,05,,-11.15,-43.166667
br,curralinha,Curralinha,20,,-3.803333,-42.396667
br,curralinho,Curralinho,02,,-9.266667,-37.783333
br,curralinho,Curralinho,04,,-3.866667,-59.216667
br,curralinho,Curralinho,05,,-10.866667,-41.633333
br,curralinho,Curralinho,06,,-3.233333,-39.383333
br,curralinho,Curralinho,11,,-21.383333,-54.766667
br,curralinho,Curralinho,13,,-3.342222,-42.178611
br,curralinho,Curralinho,15,,-21.516667,-43.866667
br,curralinho,Curralinho,16,,-1.8,-49.783333
br,curralinho,Curralinho,17,,-6.266667,-37.6
br,curralinho,Curralinho,18,,-24.433333,-50.05
br,curralinho,Curralinho,20,,-3.473889,-42.1825
br,curralinho,Curralinho,22,,-5.856389,-37.109167
br,curralinho,Curralinho,28,,-10.75,-36.833333
br,curralinho,Curralinho,30,,-8.65,-38.6
br,curralinho de baixo,Curralinho de Baixo,05,,-13.933333,-41.516667
br,curralinho de cima,Curralinho de Cima,05,,-13.95,-41.533333
br,curralinho do meio,Curralinho do Meio,05,,-13.95,-41.516667
br,curralinho dos paula,Curralinho dos Paula,15,,-20.8,-44.25
br,curralinho dos paulas,Curralinho dos Paulas,15,,-20.8,-44.25
br,curralito,Curralito,11,,-23.183333,-55.383333
br,curral moreira,Curral Moreira,15,,-20.483333,-44.166667
br,curral novo,Curral Novo,05,,-10.4,-43.166667
br,curral novo,Curral Nôvo,06,,-6.033333,-38.833333
br,curral novo,Curral Nôvo,20,,-7.816667,-40.9
br,curral novo,Curral Novo,22,,-5.971667,-36.788056
br,curral novo,Curral Novo,23,,-32.95,-52.766667
br,curral preto,Curral Prêto,22,,-5.433333,-35.633333
br,curral queimado,Curral Queimado,20,,-5.233333,-42.483333
br,curral queimado,Curral Queimado,22,,-6.766667,-37.2
br,curral queimado,Curral Queimado,30,,-8.733333,-36.633333
br,curral taquara,Curral Taquara,11,,-20.433333,-56.3
br,curral varo santana,Curral Varo Santana,13,,-6.066667,-43.183333
br,curral velho,Curral Velho,05,,-10.5,-43.5
br,curral velho,Curral Velho,06,,-5.05,-40.7
br,curral velho,Curral Velho,13,,-3.567778,-42.605833
br,curral velho,Curral Velho,16,,-1.850833,-56.243611
br,curral velho,Curral Velho,17,,-7.533333,-38.2
br,curral velho,Curral Velho,20,,-3.948056,-42.081389
br,curral velho,Curral Velho,30,,-7.683333,-37.683333
br,curral velho dos ramos,Curral Velho dos Ramos,30,,-7.716667,-37.683333
br,curralzinho,Curralzinho,13,,-4.25,-43
br,curriola,Curriola,18,,-25.083333,-49.4
br,curro velho,Curro Velho,16,,-1.430556,-48.488889
br,currupira,Currupira,21,,-23.031682,-43.497123
br,curtume,Curtume,06,,-7.283333,-38.616667
br,curtume,Curtume,17,,-7.166667,-37.666667
br,curtume,Curtume,20,,-5.133333,-41.166667
br,curua,Curuá,16,,-1.85,-55.15
br,curuai,Curuaí,16,,-2.283333,-55.483333
br,curuay,Curuay,16,,-2.283333,-55.483333
br,curuca,Curuçá,04,,-3.483333,-57.966667
br,curuca,Curuçá,16,10843,-.716667,-47.833333
br,curucambaba,Curuçambaba,16,,-2.133333,-49.3
br,curucambabiaca,Curuçambabiaca,16,,-1.616667,-48.566667
br,curucamba,Curuçambá,16,,-1.616667,-48.566667
br,curucazinho,Curuçàzinho,16,,-.633333,-47.466667
br,curuci,Curuci,16,,-4.35,-57.033333
br,curucurana,Curucurana,26,,-27.1258,-49.7137
br,curu,Curú,06,,-3.666667,-39.233333
br,curucutu,Curucutu,27,,-23.8892,-46.6125
br,curumatahy,Curumatahy,15,,-17.85,-43.983333
br,curumu,Curumu,16,,-1.016667,-51.05
br,curundundum,Curundundum,05,,-9.733333,-39.266667
br,curunhu,Curunhu,06,,-4.116667,-40.866667
br,curupa,Curupá,13,,-9.9,-45.9
br,curupai,Curupai,11,,-22.833333,-53.883333
br,curupaiti,Curupaiti,04,,-3.4,-68.866667
br,curupari,Curupari,16,,-1.616667,-52.7
br,curupasse,Curupasse,20,,-5.316667,-41.15
br,curupati,Curupati,04,,-5.609722,-63.328611
br,curupati,Curupati,17,,-7.833333,-36.966667
br,curupeba,Curupeba,05,,-12.716667,-38.6
br,curupira,Curupira,04,,-.2,-63.2
br,curupira,Curupira,06,,-4.516667,-38.533333
br,curupira,Curupira,14,,-15.116667,-56.8
br,cururipe,Cururipe,02,,-10.133333,-36.166667
br,cururu,Cururú,04,,1.233333,-68.983333
br,cururu,Cururu,13,,-4.766667,-46.583333
br,cururu,Cururu,16,,-7.2,-58.066667
br,cururu,Cururu,22,,-6.133333,-35.1
br,cururupe,Cururupe,05,,-14.85,-39.033333
br,cururu poco,Cururu Poço,04,,1.233333,-68.983333
br,cururupu,Cururupu,13,22007,-1.833333,-44.866667
br,curutari,Curutari,04,,-3.921111,-62.930833
br,curuzu,Curuzu,04,,-6.1,-64.283333
br,curuzu,Curuzu,13,,-3.333333,-43.583333
br,curva,Curva,13,,-1.366667,-45.933333
br,curva grande,Curva Grande,13,,-2.616667,-45.45
br,curvello,Curvello,15,,-18.75,-44.416667
br,curvelo,Curvelo,11,,-21.183333,-56.733333
br,curvelo,Curvelo,15,63955,-18.75,-44.416667
br,curytiba,Curytiba,18,,-25.416667,-49.25
br,custodia,Custodia,06,,-4.983333,-39.183333
br,custodia,Custódia,30,18107,-8.116667,-37.65
br,custodia freire,Custódia Freire,01,,-9.917222,-67.8875
br,custodio,Custódio,05,,-17.7,-40.25
br,custodio,Custódio,06,,-4.983333,-39.183333
br,custodio,Custódio,13,,-3.200833,-43.329444
br,custodio,Custódio,14,,-16.316667,-55.966667
br,custodio,Custódio,15,,-17.15,-41.8
br,custodio lima,Custódio Lima,13,,-3.25,-42.066667
br,cutade,Cutade,11,,-20.133333,-56.083333
br,cutape,Cutape,11,,-20.133333,-56.083333
br,cutia,Cutia,04,,-1.609722,-61.401111
br,cutia,Cutia,06,,-3.2,-40.283333
br,cutia,Cutia,13,,-1.883333,-45.45
br,cutia,Cutia,20,,-2.790833,-41.8
br,cutia,Cutia,26,,-27.1901,-49.5258
br,cutia,Cutia,27,,-23.616667,-46.933333
br,cutia fria,Cutia Fria,13,,-2.533333,-45.35
br,cutias,Cutias,13,,-3.166667,-45.166667
br,cutiu,Cutiú,16,,-1.416667,-46.166667
br,cuyaba,Cuyabá,14,,-15.583333,-56.083333
br,cuyaba,Cuyabá,15,,-19.85,-43.733333
br,cuyaba de larga,Cuyaba de Larga,14,,-14.35,-55.35
br,cuyaba larga,Cuyabá Larga,14,,-14.35,-55.35
br,cuyabasinho,Cuyabasinho,14,,-14.383333,-55.616667
br,cuyari,Cuyarí,04,,1.5,-68.183333
br,dacabi,Dacabi,25,,3.533333,-60.383333
br,dairel,Dairel,15,,-18.4,-45.333333
br,daiva,Daiva,04,,-7.343333,-71.022222
br,dalbergia,Dalbérgia,26,,-27.0324,-49.5906
br,daltro filho,Daltro Filho,23,,-29.333333,-51.766667
br,damasio,Damásio,13,,-2.916667,-42.383333
br,damasio sapa,Damásio Sapa,15,,-18.2,-43.716667
br,damianopolis,Damianópolis,29,,-14.55,-46.166667
br,damolandia,Damolândia,29,,-16.266667,-49.366667
br,dandanho,Dandanho,25,,2.666667,-60.95
br,danguer,Danguer,13,,-6.133333,-43.766667
br,daniel,Daniel,03,,.4,-51.266667
br,daniel de queiroz,Daniel de Queiroz,06,,-4.816667,-38.983333
br,dansia,Dansia,16,,1.85,-56.216667
br,dantas,Dantas,18,,-24.1,-50.283333
br,dao dos ferros,Dao Dos Ferros,22,,-6.116667,-38.166667
br,darabi,Darabi,04,,.766667,-66.883333
br,darcilandia,Darcilândia,27,,-21.433333,-51.65
br,darcilena,Darcilena,28,,-10.25,-36.883333
br,darcynopolis,Darcynópolis,31,,-6.704444,-47.588889
br,dario,Dário,04,,-2.833333,-68.7
br,dario,Dário,08,,-19.266667,-40.5
br,das flores,Das Flôres,15,,-22.079167,-43.556667
br,data,Data,05,,-12.7,-42.216667
br,datas,Datas,15,,-18.416667,-43.666667
br,dattas,Dattas,15,,-18.416667,-43.666667
br,davi caldas,Davi Caldas,20,,-4.75,-42.933333
br,davinopolis,Davinópolis,29,,-15.966667,-50.133333
br,d. cruz,D. Cruz,23,,-27.416667,-53.416667
br,deca martins,Deca Martins,23,,-31.166667,-55.166667
br,decana,Deçana,04,,.05,-67.333333
br,decarle,Decarle,27,,-22.708333,-47.326944
br,dedo grosso,Dedo Grosso,26,,-26.366667,-48.95
br,defunto,Defunto,06,,-7.066667,-40.233333
br,defuntos,Defuntos,22,,-6.166667,-35.266667
br,degredo,Degrêdo,13,,-4.266667,-43.166667
br,deixe-comigo,Deixe-Comigo,05,,-12.716667,-39.166667
br,del castilho,Del Castilho,21,,-22.882215,-43.272891
br,deleite,Deleite,06,,-5.916667,-39.15
br,delfim moreira,Delfim Moreira,15,,-22.5,-45.283333
br,delfina,Delfina,16,,-1.183333,-56.05
br,delfino,Delfino,05,,-10.45,-41.2
br,delfino,Delfino,23,,-30.6633,-52.4773
br,delfinopolis,Delfinópolis,15,,-20.333333,-46.85
br,delgado,Delgado,29,,-14.5,-48.733333
br,deliberador,Deliberador,18,,-23.1,-51.116667
br,delicia,Delícia,04,,-5.579167,-60.955556
br,deliciosa,Deliciosa,20,,-5.5,-41.333333
br,del lago residencias,Del Lago Residencias,21,,-22.990745,-43.380515
br,delmiro,Delmiro,02,,-9.383333,-37.983333
br,delmiro gouveia,Delmiro Gouveia,02,35260,-9.383333,-37.983333
br,delvino,Delvino,15,,-16.516667,-41.4
br,demanda,Demanda,25,,3.833333,-61.4
br,demarcacao,Demarcação,30,,-8.45,-35.4
br,demerval lobao,Demerval Lobão,20,15285,-5.366667,-42.683333
br,demetrio lemos,Demétrio Lemos,22,,-6.216667,-37.9
br,demetrio ribeiro,Demétrio Ribeiro,21,,-22.395,-43.734722
br,demetrio ribeiro,Demétrio Ribeiro,23,,-29.566667,-54.55
br,democracia,Democracia,04,,-5.801389,-61.434722
br,dende,Dendê,05,,-12.9,-38.75
br,dende,Dendê,21,,-22.800668,-43.185845
br,dende grande,Dendê Grande,05,,-12.95,-39.366667
br,dendes,Dendês,05,,-12.9,-38.75
br,dendezeiro,Dendezeiro,05,,-12.4,-38.05
br,dendezeiros,Dendezeiros,05,,-12.4,-38.05
br,dentro,Dentro,22,,-6.1,-37.916667
br,deocleciano faria,Deocleciano Faria,15,,-16.133333,-41.266667
br,deodoro da fonseca,Deodoro da Fonseca,22,,-5.45,-36.85
br,deodoro,Deodoro,21,,-22.844483,-43.389646
br,deodoro,Deodoro,23,,-29.466667,-52.266667
br,deposito,Depósito,01,,-8.366667,-73.316667
br,deposito,Depósito,25,,3.2,-60.583333
br,dermeval lobao,Dermeval Lobão,20,,-5.366667,-42.683333
br,derradeira varzea,Derradeira Várzea,30,,-8.133333,-38.65
br,derramado,Derramado,11,,-18.55,-56.683333
br,derribadinha,Derribadinha,15,,-18.85,-41.833333
br,derrubada,Derrubada,16,,-.733333,-47.416667
br,derrubadas,Derrubadas,23,,-27.25,-53.866667
br,derrubadinha,Derrubadinha,15,,-17.85,-40.733333
br,desagua,Deságua,05,,-12.033333,-40.766667
br,desamparada,Desamparada,05,,-14.616667,-41.783333
br,desapregados,Desapregados,06,,-7.316667,-40.15
br,descalvado,Descalvado,14,,-16.75,-57.7
br,descalvado,Descalvado,18,,-24.85,-50.533333
br,descalvado,Descalvado,27,26138,-21.9,-47.616667
br,descalvados,Descalvados,14,,-16.75,-57.7
br,descampadinho,Descampadinho,18,,-24.804947,-48.916128
br,descampado,Descampado,18,,-24.715815,-48.946491
br,descanco,Descanço,11,,-18.383333,-54.966667
br,descanco,Descanço,13,,-6.1,-43.05
br,descanso da vida,Descanso da Vida,27,,-24.659183,-48.247192
br,descanso,Descanso,11,,-18.383333,-54.966667
br,descanso,Descanso,13,,-6.1,-43.05
br,descanso,Descanso,20,,-6.266667,-42.8
br,descanso,Descanso,26,,-26.833333,-53.583333
br,descanso,Descanso,30,,-7.833333,-39.933333
br,descarocador,Descaroçador,15,,-21.166667,-45.816667
br,descarreiro,Descarreiro,31,,-5.65,-47.466667
br,descarreto,Descarreto,31,,-5.65,-47.466667
br,descida da boiada,Descida da Boiada,20,,-7.633333,-41.866667
br,descoberta,Descoberta,05,,-12.183333,-43.416667
br,descoberta,Descoberta,16,,.45,-53.283333
br,descoberta,Descoberta,20,,-5.9,-42.116667
br,descoberta,Descoberta,22,,-5.8,-35.516667
br,descoberto,Descoberto,05,,-13.983333,-44.3
br,descoberto,Descoberto,15,,-21.45,-42.966667
br,descoberto,Descoberto,18,,-25.907,-48.7116
br,descoberto,Descoberto,29,,-13.433333,-49.166667
br,desegnano,Desegnano,04,,-6.7,-70.416667
br,desejo,Desejo,21,,-21.45,-41.316667
br,desembargador otoni,Desembargador Otoni,15,,-17.716667,-43.3
br,desemboque,Desemboque,15,,-20.016667,-47.05
br,desempenho,Desempenho,05,,-12.566667,-38.65
br,desengano,Desengano,04,,-6.7,-70.416667
br,desengano,Desengano,08,,-19.616667,-40.283333
br,desengano,Desengano,14,,-13.4,-57.483333
br,desengano,Desengano,18,,-24.95,-52.783333
br,desengano,Desengano,21,,-22.343889,-43.682778
br,deserto,Deserto,04,,-7.083333,-58.833333
br,deserto,Deserto,06,,-3.5,-39.483333
br,deserto,Deserto,13,,-2.516667,-44.8
br,deserto,Deserto,16,,-3.366667,-51.8
br,deserto,Deserto,20,,-3.65,-41.6
br,deserto i,Deserto I,13,,-3.472778,-43.475833
br,deserto ii,Deserto II,13,,-3.081667,-43.428611
br,designio,Desígnio,20,,-4.333333,-42.966667
br,despenhado,Despenhado,15,,-20.116667,-46.233333
br,destacamenta das pedras,Destacamenta das Pedras,24,,-12.85,-62.9
br,destacamento da corixa,Destacamento da Corixa,14,,-16.333333,-58.316667
br,destampina,Destampina,05,,-14.283333,-39.85
br,destero,Destero,26,,-27.583333,-48.566667
br,desterro de entre rios,Destêrro de Entre Rios,15,,-20.666667,-44.333333
br,desterro,Destêrro,05,,-12.166667,-38.15
br,desterro,Desterro,06,,-2.816667,-40.4
br,desterro,Destêrro,17,5374,-7.283333,-37.1
br,desterro,Destêrro,22,,-5.862222,-36.847222
br,desterro,Desterro,26,,-27.583333,-48.566667
br,desterro do mello,Desterro do Mello,15,,-21.15,-43.516667
br,desterro do melo,Destêrro do Melo,15,,-21.15,-43.516667
br,destino,Destino,13,,-3.904722,-43.48
br,desvio erval,Desvio Erval,23,,-31.883333,-53.166667
br,desvio machado,Desvio Machado,23,,-29.266667,-51.466667
br,desvio ribas,Desvio Ribas,18,,-25.2,-50.066667
br,desvio rizzo,Desvio Rizzo,23,,-29.1935,-51.2348
br,de tras da serra,De Trás da Serra,20,,-7.783333,-41.666667
br,deus andou,Deus Andou,05,,-12.516667,-39.85
br,deus-me-guia,Deus-me-Guia,22,,-5.423056,-36.3225
br,deus-me-livre,Deus-me-Livre,05,,-12.25,-45.033333
br,deus quer,Deus Quer,13,,-3.418889,-43.476667
br,dez de maio,Dez de Maio,18,,-24.7,-53.916667
br,dez de novembro,Dez de Novembro,26,,-27.033333,-50.933333
br,dez de novembro,Dez de Novembro,27,,-21.216667,-51.35
br,dezessete,Dezessete,24,,-11.083333,-61.916667
br,diadema,Diadema,27,390641,-23.7,-46.616667
br,diamante de uba,Diamante de Ubá,15,,-21.2,-42.916667
br,diamante,Diamante,05,,-11.166667,-42.566667
br,diamante,Diamante,06,,-4.216667,-38.733333
br,diamante,Diamante,17,,-7.416667,-38.25
br,diamante,Diamante,18,,-24.916667,-54.133333
br,diamantina,Diamantina,04,,-4.5425,-60.488611
br,diamantina,Diamantina,13,,-4.216667,-44.2
br,diamantina,Diamantina,15,37344,-18.25,-43.6
br,diamantina,Diamantina,16,,-.466667,-49.1
br,diamantina,Diamantina,17,,-7.466667,-38.316667
br,diamantina,Diamantina,18,,-25.5122,-50.45927
br,diamantina,Diamantina,20,,-6.183333,-41.95
br,diamantina,Diamantina,22,,-5.383611,-36.399167
br,diamantino,Diamantino,14,15700,-14.416667,-56.45
br,diamentina,Diamentina,14,,-14.416667,-56.45
br,dianopolis,Dianópolis,31,12896,-11.700556,-46.743056
br,dias coelho,Dias Coelho,05,,-11.516667,-40.783333
br,dias d'avila,Dias d'Avila,05,,-12.6,-38.3
br,dias,Dias,15,,-22.466667,-45.566667
br,dias,Dias,27,,-23.816667,-47.583333
br,dico leopoldina,Dico Leopoldina,20,,-5.85,-41.35
br,dilermando aguiar,Dilermando Aguiar,23,,-2.7,-54.2
br,dilermanno aguiar,Dilermanno Aguiar,23,,-2.7,-54.2
br,dinarie m. perreira,Dinarie M. Perreira,23,,-31.066667,-55.3
br,dinisia,Dinísia,27,,-21.416667,-49.8
br,diogenes sampaio,Diógenes Sampaio,05,,-12.95,-39.583333
br,diogo de vasconcelos,Diogo de Vasconcelos,15,,-20.483333,-43.2
br,diogo,Diogo,06,,-4.183333,-38.05
br,diogo lopes,Diogo Lopes,22,,-5.084722,-36.454444
br,diogo lopez,Diogo Lopez,22,,-5.084722,-36.454444
br,dionisio cerqueira,Dionísio Cerqueira,26,,-26.25,-53.633333
br,dionisio,Dionísio,05,,-12.183333,-40.816667
br,dionisio,Dionísio,15,,-19.816667,-42.75
br,diorama,Diorama,29,,-16.35,-51.233333
br,dique,Dique,13,,-6.183333,-42.95
br,dirceu barcelos,Dirceu Barcelos,23,,-30.066667,-56.983333
br,dirceu,Dirceu,16,,-1.366667,-46.55
br,dirceu,Dirceu,27,,-22.116667,-49.916667
br,direcao,Direcão,20,,-6.05,-41.85
br,divina pastora,Divina Pastora,05,,-11.95,-37.95
br,divina pastora,Divina Pastôra,28,,-10.666667,-37.15
br,divineia,Divinéia,21,,-22.922996,-43.639509
br,divininho,Divininho,15,,-20.75,-41.883333
br,divino das laranjeiras,Divino das Laranjeiras,15,,-18.766667,-41.483333
br,divino de guanhaes,Divino de Guanhães,15,,-18.8,-42.633333
br,divino de laranjeiras,Divino de Laranjeiras,15,,-18.766667,-41.483333
br,divino de uba,Divino de Ubá,15,,-20.983333,-43.016667
br,divino de virginopolis,Divino de Virginópolis,15,,-18.8,-42.633333
br,divino,Divino,08,,-21,-41.6
br,divino,Divino,11,,-18.75,-55.483333
br,divino,Divino,15,,-19.083333,-41.966667
br,divino do carangola,Divino do Carangola,15,,-20.616667,-42.15
br,divino do cibrao,Divino do Cibrão,15,,-18.266667,-41.35
br,divino espirito santo,Divino Espírito Santo,04,,-5.769167,-61.282222
br,divino espirito santo do carangola,Divino Espirito Santo do Carangola,15,,-20.616667,-42.15
br,divinolandia,Divinolândia,27,,-21.666667,-46.666667
br,divinopolis,Divinópolis,15,193835,-20.15,-44.9
br,divinopolis,Divinópolis,17,,-6.85,-38.416667
br,divinopolis,Divinopolis,22,,-5.983333,-37.816667
br,divinopolis,Divinópolis,29,,-18.183333,-49.35
br,divinopolis do tocantins,Divinópolis do Tocantins,31,,-9.742778,-49.119722
br,divisa,Divisa,06,,-5.016667,-39.95
br,divisa,Divisa,08,,-19.116667,-40.566667
br,divisa,Divisa,11,,-21.5,-54.666667
br,divisa,Divisa,15,,-15.7,-41.333333
br,divisa,Divisa,18,,-26.066667,-50.35
br,divisa,Divisa,21,,-22.4509,-44.3024
br,divisa,Divisa,27,,-21.116667,-50.933333
br,divisa nova,Divisa Nova,15,,-21.516667,-46.2
br,divisao,Divisão,06,,-5.283333,-38.283333
br,divisao,Divisão,20,,-6.15,-41.933333
br,divisao,Divisão,22,,-5.25,-35.966667
br,divisopolis,Divisópolis,15,,-15.733333,-41
br,dix-sept rosado,Dix-sept Rosado,22,,-5.45,-37.516667
br,djalma coutinho,Djalma Coutinho,08,,-20.033333,-40.45
br,djalma dutra,Djalma Dutra,05,,-11.433333,-40.6
br,dobrada,Dobrada,27,,-21.516667,-48.383333
br,dobrado,Dobrado,27,,-21.516667,-48.383333
br,doce fino,Doce Fino,18,,-25.9691,-49.4413
br,doce grande,Doce Grande,18,,-26.0235,-49.4287
br,docimhas,Docimhas,06,,-5.15,-40.4
br,d'oeste esperanca,d'Oeste Esperanca,27,,-21.866667,-51.216667
br,dogelo,Dogelo,26,,-27.7,-50.55
br,dois amigos,Dois Amigos,20,,-3.362778,-42.111389
br,dois buritis,Dois Buritis,05,,-11.3,-42.816667
br,dois caminhos,Dois Caminhos,17,,-6.65,-38.166667
br,dois corregos,Dois Córregos,14,,-15.05,-56.366667
br,dois corregos,Dois Córregos,27,20975,-22.366667,-48.35
br,dois de abril,Dois de Abril,15,,-16.833333,-40.3
br,dois de julho,Dois de Julho,05,,-12.066667,-38.966667
br,dois de maio,Dois de Maio,18,,-25.1,-53.75
br,dois de novembro,Dois de Novembro,24,,-8.85,-62.283333
br,dois irma,Dois Irma,18,,-24.866667,-54.366667
br,dois irmaos do goias,Dois Irmãos do Goiás,31,,-9.211389,-48.955556
br,dois irmaos,Dois Irmãos,05,,-10.15,-43.133333
br,dois irmaos,Dois Irmãos,08,,-20.716667,-40.75
br,dois irmaos,Dois Irmãos,11,,-21.683333,-57.166667
br,dois irmaos,Dois Irmãos,13,,-6.583333,-43.45
br,dois irmaos,Dois Irmãos,18,,-24.1,-49.983333
br,dois irmaos,Dois Irmãos,20,,-5.45,-42.283333
br,dois irmaos,Dois Irmãos,22,,-5.714722,-36.19
br,dois irmaos,Dois Irmãos,23,28926,-29.583333,-51.083333
br,dois irmaos,Dois Irmãos,26,,-27.283333,-51.866667
br,dois irmaos,Dois Irmãos,30,,-8.833333,-35.95
br,dois irmaos,Dois Irmãos,31,,-11.75,-48.633333
br,dois irmaos do tocantins,Dois Irmãos do Tocantins,31,,-9.211389,-48.955556
br,dois lageados,Dois Lageados,23,,-28.983333,-51.85
br,dois lajeados,Dois Lajeados,23,,-28.983333,-51.85
br,dois mil reis,Dois Mil Réis,11,,-18.4,-55.866667
br,dois paus,Dois Paus,13,,-3.146389,-43.462778
br,dois riachos,Dois Riachos,02,4565,-9.383333,-37.083333
br,dois riachos,Dois Riachos,06,,-6.333333,-38.8
br,dois riachos,Dois Riachos,17,,-6.233333,-37.616667
br,dois riachos,Dois Riachos,30,,-7.666667,-37.633333
br,dois rios de baixo,Dois Rios de Baixo,06,,-5.533333,-39.566667
br,dois rios,Dois Rios,21,,-23.183333,-44.183333
br,dois serrotes,Dois Serrotes,30,,-8.216667,-37.3
br,dois vizinhos,Dois Vizinhos,18,22766,-25.783333,-53.083333
br,dolcinopolis,Dolcinópolis,27,,-20.133333,-50.516667
br,dolearina,Dolearina,15,,-18.683333,-47.8
br,dom alexandre,Dom Alexandre,14,,-8.7,-58.016667
br,dom basilio,Dom Basílio,05,,-13.733333,-41.766667
br,dom bosco,Dom Bosco,15,,-16.616667,-41.916667
br,dom cavati,Dom Caváti,15,,-19.383333,-42.1
br,domelia,Domélia,27,,-22.733333,-49.3
br,dom eugenio marculino,Dom Eugênio Marculino,22,,-5.45,-35.383333
br,dom feliciano,Dom Feliciano,23,,-30.7,-52.116667
br,domiciano lemos,Domiciano Lemos,15,,-20.333333,-46.916667
br,domiciano ribeiro,Domiciano Ribeiro,29,,-16.933333,-47.766667
br,domicilio,Domicilio,20,,-5.1,-42.633333
br,domingada,Domingada,27,,-22.683333,-47.916667
br,domingao,Domingão,05,,-12.05,-38.1
br,domingo,Domingo,15,,-15.8,-46.65
br,domingo joao,Domingo João,06,,-5.7,-38.316667
br,domingos campos,Domingos Campos,15,,-21.3,-46.05
br,domingos da costa,Domingos da Costa,06,,-5.15,-39.666667
br,domingos,Domingos,13,,-3.058056,-43.4875
br,domingos,Domingos,15,,-15.8,-46.65
br,domingos martins,Domingos Martins,08,6061,-20.366667,-40.666667
br,dominguinho,Dominguinho,20,,-7.883333,-41.866667
br,dom joaquim,Dom Joaquim,15,,-18.95,-43.266667
br,dom lara,Dom Lara,15,,-19.766667,-42.216667
br,dom leme,Dom Leme,06,,-7.3,-39.766667
br,dom macedo costa,Dom Macedo Costa,05,,-12.9,-39.15
br,dom mauricio,Dom Maurício,06,,-4.9,-39.15
br,dom pedrito,Dom Pedrito,23,36912,-30.983333,-54.666667
br,dom pedrito,Dom Pedrito,24,,-11.433333,-65.316667
br,dom pedro,Dom Pedro,13,15570,-4.483333,-44.45
br,dom quintino,Dom Quintino,06,,-7.083333,-39.483333
br,dom rodrigo,Dom Rodrigo,18,,-25.416667,-49.616667
br,dom silverio do bonfim,Dom Silvério do Bonfim,15,,-20.383333,-44.35
br,dom silverio,Dom Silvério,15,,-20.15,-42.966667
br,dom vicoso,Dom Viçoso,15,,-20.766667,-42.516667
br,dom vital,Dom Vital,06,,-7.25,-39.65
br,dona amelia,Dona Amélia,27,,-22.733333,-49.3
br,dona america,Dona América,08,,-21.166667,-41.433333
br,dona candida,Dona Cândida,27,,-21.416667,-46.883333
br,dona carlota,Dona Carlota,11,,-19.783333,-57.65
br,dona,Dona,02,,-9.45,-37.133333
br,dona ema,Dona Ema,26,,-26.985465,-49.724472
br,dona eusebia,Dona Eusébia,15,,-21.3,-42.8
br,dona euzebia,Dona Euzébia,15,,-21.3,-42.8
br,dona francisca,Dona Francisca,23,,-29.616667,-53.35
br,dona ines,Dona Inês,17,3709,-6.616667,-35.633333
br,dona isabel,Dona Isabel,15,,-18.15,-43.166667
br,dona josefa,Dona Josefa,11,,-21.4,-54.366667
br,dona luisa,Dona Luísa,27,,-23.119612,-47.79444
br,dona mariana,Dona Mariana,21,,-22.166667,-42.633333
br,donatos,Donatos,30,,-7.983333,-38.75
br,don rodrigo,Don Rodrigo,18,,-25.416667,-49.616667
br,doradoquara,Doradoquara,15,,-18.416667,-47.616667
br,dorandia,Dorândia,21,,-22.464444,-43.945278
br,dores da boa esperanca,Dores da Boa Esperanca,15,,-21.083333,-45.566667
br,dores da victoria,Dores da Victoria,15,,-21.1,-42.6
br,dores da vitoria,Dores da Vitória,15,,-21.1,-42.6
br,dores de campo,Dores de Campo,15,,-21.1,-44.033333
br,dores de campos,Dores de Campos,15,,-21.1,-44.033333
br,dores de guanhaes,Dores de Guanhães,15,,-19.05,-42.95
br,dores de macabu,Dores de Macabu,21,,-21.983333,-41.516667
br,dores de santa juliana,Dôres de Santa Juliana,15,,-19.316667,-47.533333
br,dores do indaia,Dores do Indaiá,15,12859,-19.45,-45.6
br,dores do indaya,Dôres do Indayá,15,,-19.45,-45.6
br,dores do paraibuna,Dores do Paraibuna,15,,-21.516667,-43.65
br,dores,Dôres,15,,-19.05,-42.95
br,dores,Dores,29,,-14.433333,-46.133333
br,dores do rio preto,Dores do Rio Preto,08,,-20.7,-41.833333
br,dores do turvo,Dores do Turvo,15,,-20.966667,-43.183333
br,dorgelo,Dorgelo,26,,-27.7,-50.55
br,doris irmaos,Doris Irmãos,06,,-4.883333,-38.466667
br,dorizon,Dorizon,18,,-25.933333,-50.866667
br,dormida,Dormida,25,,-2.55,-60.116667
br,dormideira,Dormideira,06,,-5.883333,-40.633333
br,dos macacos,Dos Macacos,16,,-1.183333,-50.466667
br,dos macaos,Dos Macaos,16,,-1.183333,-50.466667
br,do tapaua boca,do Tapauá Bôca,04,,-5.620278,-63.1875
br,dourada,Dourada,02,,-9.383333,-36.266667
br,douradao,Douradão,11,,-20.666667,-55.4
br,douradinho,Douradinho,11,,-21.583333,-53.266667
br,douradinho,Douradinho,15,,-18.55,-47.2
br,douradinho,Douradinho,23,,-30.4,-51.2
br,dourado,Dourado,06,,-5.033333,-38.3
br,dourado,Dourado,15,,-22.05,-45.966667
br,dourado,Dourado,18,,-23.1299,-50.0641
br,dourado,Dourado,20,,-6.016667,-41.833333
br,dourado,Dourado,23,,-27.416667,-52.233333
br,dourado,Dourado,26,,-27.083333,-53.683333
br,dourado,Dourado,27,,-22.116667,-48.3
br,douradoquara,Douradoquara,15,,-18.416667,-47.616667
br,dourados,Dourados,06,,-4.083333,-38.733333
br,dourados,Dourados,11,162206,-22.216667,-54.8
br,dourados,Dourados,15,,-19.9,-48.7
br,dourados,Dourados,27,,-20.65,-47.716667
br,dous corregos,Dous Corregos,27,,-22.366667,-48.35
br,doutor almeida,Doutor Almeida,05,,-12.316667,-41.066667
br,doutor bozano,Doutor Bozano,23,,-28.4,-53.7
br,doutor camargo,Doutor Camargo,18,,-23.55,-52.233333
br,doutor elias,Doutor Elias,21,,-22.2,-42.233333
br,doutor faria,Doutor Faria,15,,-16.016667,-41.533333
br,doutor loreti,Doutor Loréti,21,,-22.033333,-41.983333
br,doutor luna,Doutor Luna,15,,-19.65,-44.016667
br,doutor lund,Doutor Lund,15,,-19.65,-44.016667
br,doutor mauricio cardoso,Doutor Maurício Cardoso,23,,-27.5,-54.366667
br,doutor paula sousa,Doutor Paula Sousa,29,,-17.966667,-51.65
br,doutor pedrinho,Doutor Pedrinho,26,,-26.742619,-49.573393
br,doutor pestana,Doutor Pestana,23,,-28.516667,-53.983333
br,doutor sampaio,Doutor Sampaio,20,,-6.866667,-42.866667
br,doutor seabra,Doutor Seabra,05,,-12.416667,-41.766667
br,doutor severiano,Doutor Severiano,22,,-6.083333,-38.366667
br,dracena,Dracena,27,37940,-21.533333,-51.483333
br,duarte dias,Duarte Dias,30,,-8.066667,-35.4
br,duartina,Duartina,27,11903,-22.4,-49.416667
br,duas antas,Duas Antas,13,,-1.8,-45.733333
br,duas antas,Duas Antas,18,,-25.22199,-48.987322
br,duas barras do morro,Duas Barras do Morro,05,,-11.966667,-40.966667
br,duas barras,Duas Barras,05,,-11.966667,-40.966667
br,duas barras,Duas Barras,08,,-20.75,-40.883333
br,duas barras,Duas Barras,15,,-16.483333,-40.633333
br,duas barras,Duas Barras,17,,-7.666667,-38.166667
br,duas barras,Duas Barras,20,,-8.95,-42.1
br,duas barras,Duas Barras,21,,-21.383333,-41.65
br,duas barras,Duas Barras,22,,-6.216667,-37.216667
br,duas barras,Duas Barras,27,,-21.183333,-50.266667
br,duas barras,Duas Barras,30,,-7.883333,-37.433333
br,duas bocas,Duas Bôcas,08,,-20.283333,-40.466667
br,duas e dois,Duas e Dois,05,,-14.9,-42.333333
br,duas estradas,Duas Estradas,17,,-6.683333,-35.416667
br,duas fontes,Duas Fontes,31,,-11.585556,-46.531389
br,duas lagoas,Duas Lagoas,05,,-13.183333,-40.233333
br,duas lagoas,Duas Lagoas,20,,-7.233333,-43.416667
br,duas lagoas,Duas Lagoas,31,,-11.933333,-47.65
br,duas palmeiras,Duas Palmeiras,05,,-12.116667,-41.116667
br,duas passagens,Duas Passagens,05,,-12.6,-41.8
br,duas passagens,Duas Passagens,22,,-5.6,-35.516667
br,duas ponies,Duas Ponìes,08,,-20.583333,-40.833333
br,duas pontas,Duas Pontas,31,,-11.585556,-46.531389
br,duas pontes,Duas Pontes,08,,-20.583333,-40.833333
br,duas pontes,Duas Pontes,31,,-11.585556,-46.531389
br,duas serras,Duas Serras,05,,-10.416667,-38.383333
br,duas umburanas,Duas Umburanas,05,,-13.566667,-40.983333
br,duere,Dueré,31,,-11.359444,-49.187222
br,dula,Dula,13,,-3.7425,-43.278611
br,dulcinopolis,Dulcinópolis,27,,-20.133333,-50.516667
br,dumont,Dumont,27,,-21.15,-47.966667
br,dumontina,Dumontina,27,,-22.283333,-51.666667
br,dunas,Dunas,23,,-31.75,-52.283333
br,duplo ceu,Duplo Céu,27,,-20.216667,-49.566667
br,duque bacelar,Duque Bacelar,13,,-4.15,-42.95
br,duque de caxias,Duque de Caxias,05,,-17.616667,-40.033333
br,duque de caxias,Duque de Caxias,21,818339,-22.790321,-43.325009
br,durande,Durandé,15,,-20.2,-41.8
br,duro,Duro,05,,-12.95,-38.616667
br,duros,Duros,20,,-6.116667,-40.966667
br,duro velho,Duro Velho,15,,-18.083333,-41.216667
br,dutra,Dutra,27,,-21.85,-47.566667
br,dyonisio cerqueira,Dyonisio Cerqueira,26,,-26.25,-53.633333
br,eao,Eão,23,,-29.2,-52.233333
br,echapora,Echaporã,27,,-22.433333,-50.2
br,eclerica,Eclérica,29,,-16.166667,-51.75
br,ecoporanga,Ecoporanga,08,13774,-18.383333,-40.833333
br,edeia,Edéia,29,9838,-17.3,-49.916667
br,eden,Éden,21,,-22.794028,-43.398897
br,eden,Éden,27,,-23.416667,-47.416667
br,edgard verneque,Edgard Verneque,30,,-8.083333,-34.933333
br,edgar werneck,Edgar Werneck,30,,-8.083333,-34.933333
br,edil,Edil,06,,-5.25,-40.616667
br,edmundo abreu,Edmundo Abreu,23,,-30.25,-50.85
br,edmundo,Edmundo,15,,-18.516667,-48.066667
br,edson passos,Edson Passos,21,,-22.791208,-43.419659
br,eduardo dietrich,Eduardo Dietrich,08,,-20.283333,-40.65
br,eduardo dietrick,Eduardo Dietrick,08,,-20.283333,-40.65
br,eduardo,Eduardo,15,,-20.683333,-45.2
br,eduardo gomes,Eduardo Gomes,22,,-5.916667,-35.25
br,eduardo luis,Eduardo Luís,11,,-19.066667,-54.033333
br,educandario,Educandário,27,,-23.9205,-46.7359
br,educandos,Educandos,04,,-3.144167,-60.008056
br,edu,Edu,22,,-5.966667,-38.066667
br,efigenia,Efigênia,15,,-19.883333,-41.516667
br,ega,Ega,04,,-3.366667,-64.7
br,egidio,Egidio,06,,-5.15,-37.8
br,egidio,Egídio,27,,-22.883333,-46.983333
br,egon,Egon,18,,-26.214722,-53.609722
br,eirunepe,Eirunepé,04,17175,-6.666667,-69.866667
br,el aduar,El Aduar,23,,-32.283333,-52.25
br,elba,Elba,04,,-5.166667,-62.85
br,el borach,El Borach,24,,-9.666667,-65.433333
br,eldorado,Eldorado,05,,-12.833333,-40.916667
br,eldorado,Eldorado,11,9075,-23.783333,-54.316667
br,eldorado,Eldorado,18,,-23.766667,-51.25
br,eldorado,Eldorado,27,,-24.522222,-48.1075
br,eldorado paulista,Eldorado Paulista,27,,-24.522222,-48.1075
br,elela,Elela,25,,4.416667,-60.15
br,elesbao,Elesbão,21,,-21.966667,-41.65
br,elesbao veloso,Elesbão Veloso,20,10430,-6.216667,-42.133333
br,elesboa veloso,Elesboa Veloso,20,,-6.216667,-42.133333
br,eletra,Eletra,23,,-2.333333,-50.683333
br,eleuterio,Eleutério,27,,-22.316667,-46.716667
br,elias fausto,Elias Fausto,27,12705,-23.033333,-47.383333
br,eliseu brasus,Eliseu Brasus,18,,-25.066667,-53.683333
br,eliseu martins,Eliseu Martins,20,,-8.216667,-43.7
br,elisiario,Elisiário,27,,-21.166667,-49.116667
br,elisiario lemos,Elisiário Lemos,15,,-20.716667,-46.316667
br,eliziario,Eliziário,27,,-21.166667,-49.116667
br,el marco,El Marco,04,,-4.233611,-69.941667
br,eloi,Elói,14,,-8.766667,-58.266667
br,eloi mendes,Elói Mendes,15,19413,-21.616667,-45.566667
br,el oso,El Oso,14,,-15.25,-60.35
br,eloy mendes,Eloy Mendes,15,,-21.616667,-45.566667
br,el ozo,El Ozo,14,,-15.25,-60.35
br,elvira,Elvira,04,,-5.166667,-72.85
br,ema,Ema,05,,-11.683333,-43.266667
br,ema,Ema,06,,-2.95,-40.25
br,ema,Ema,13,,-3.945833,-43.408611
br,ema,Ema,20,,-6.966667,-41.133333
br,ema,Ema,30,,-8.283333,-38.383333
br,emanuel ramalho,Emanuel Ramalho,15,,-17.5,-40.783333
br,emas,Emas,05,,-11.683333,-43.266667
br,emas,Emas,17,,-7.1,-37.716667
br,emas,Emas,22,,-6.366667,-38.25
br,ematuba,Ematuba,06,,-5.133333,-40.216667
br,embare,Embaré,27,,-21.95,-47.933333
br,embauba,Embaúba,27,,-20.983333,-48.833333
br,embauba,Embaúba,31,,-11.683333,-48.766667
br,embaubas,Embaúbas,15,,-17.616667,-42.8
br,embaubas,Embaúbas,21,,-22.6,-42.416667
br,embau,Embaú,21,,-22.6,-42.416667
br,embauval,Embauval,14,,-16.316667,-55.35
br,embira,Embira,05,,-12.65,-39.15
br,embiral,Embiral,13,,-5.383333,-47.716667
br,embirizal,Embirizal,15,,-22.033333,-45.433333
br,embirucu,Embiruçu,15,,-19.383333,-44.316667
br,emboaba,Emboaba,23,,-29.3,-51.333333
br,emboabas,Emboabas,15,,-21.3,-44.133333
br,emboracica,Emboracica,05,,-12.6,-38.133333
br,emborahy,Emborahy,16,,-1.15,-46.5
br,emborai,Emboraí,16,,-1.15,-46.5
br,emboscaba,Emboscaba,11,,-22.8,-55.55
br,emboscada,Emboscada,11,,-22.8,-55.55
br,embosoada,Embosoada,11,,-22.8,-55.55
br,embu,Embu,27,221737,-23.65,-46.85
br,embu-guacu,Embu-Guaçu,27,76311,-23.816667,-46.8
br,embu-mirim,Embu-Mirim,27,,-22.533333,-45.083333
br,embura,Embura,27,,-23.8824,-46.7422
br,emburana,Emburana,22,,-5.2,-35.8
br,emburrado,Emburrado,05,,-14.116667,-39.75
br,eme,Eme,15,,-19.166667,-41.3
br,emendada,Emendada,02,,-9.616667,-37.566667
br,e. mendes,E. Mendes,11,,-20.566667,-56.116667
br,emericiano borges,Emericiano Borges,15,,-16.9,-41.65
br,emidio da rosa,Emídio da Rosa,11,,-19.6,-55.033333
br,emidio,Emídio,15,,-17.366667,-40.833333
br,emidios,Emídios,15,,-21.133333,-42.666667
br,emile,Emile,04,,-4.166667,-59.216667
br,emilianopolis,Emilianópolis,27,,-21.816667,-51.483333
br,emilia paulista,Emília Paulista,27,,-21.75,-50.966667
br,emilio,Emílio,04,,-4.166667,-59.216667
br,emilio magno,Emílio Magno,05,,-16.133333,-38.966667
br,emilio meier,Emílio Méier,23,,-30.266667,-50.516667
br,emilio meyer,Emílio Meyer,23,,-30.266667,-50.516667
br,emilio ribas,Emílio Ribas,27,,-22.716667,-45.566667
br,emilio timo,Emílio Timo,15,,-17.916667,-41.75
br,emmas,Emmas,05,,-11.683333,-43.266667
br,emparedado,Emparedado,20,,-6.4,-42.666667
br,empatacao,Empatação,13,,-6.383333,-42.983333
br,empocado,Empoçado,18,,-26.166667,-51.45
br,empresa,Emprêsa,01,,-9.966667,-67.8
br,empresa,Emprêsa,05,,-13.633333,-39.5
br,emvira,Emvira,04,,-7.3,-70.216667
br,enamuna,Enamuna,25,,4.65,-60.116667
br,enamung,Enamung,25,,4.65,-60.116667
br,encano alto,Encano Alto,26,,-26.9894,-49.1716
br,encano baixo,Encano Baixo,26,,-26.8862,-49.1855
br,encano central,Encano Central,26,,-26.9266,-49.1938
br,encano do norte,Encano do Norte,26,,-26.8674,-49.2024
br,encano,Encano,26,,-26.9901,-49.1107
br,encantado,Encantado,06,,-5.483333,-39.3
br,encantado,Encantado,13,,-6.15,-43.15
br,encantado,Encantado,21,,-22.892808,-43.299706
br,encantado,Encantado,23,16637,-29.25,-51.883333
br,encanto,Encanto,06,,-5.516667,-39.3
br,encanto,Encanto,22,,-6.116667,-38.316667
br,encanto,Encanto,25,,2.9,-60.95
br,encarnacao,Encarnação,05,,-12.933333,-38.75
br,enchente,Enchente,16,,-1.15,-49.633333
br,enchu,Enchu,31,,-7.166667,-48.233333
br,encosta,Encosta,17,,-6.2,-37.4
br,encruzilhada do sul,Encruzilhada do Sul,23,17199,-30.533333,-52.516667
br,encruzilhada,Encruzilhada,05,4711,-15.516667,-40.9
br,encruzilhada,Encruzilhada,06,,-4.516667,-37.95
br,encruzilhada,Encruzilhada,13,,-3.411944,-42.414444
br,encruzilhada,Encruzilhada,15,,-21.833333,-44.8
br,encruzilhada,Encruzilhada,18,,-25.45,-50.233333
br,encruzilhada,Encruzilhada,21,,-22.183889,-43.296389
br,encruzilhada,Encruzilhada,23,,-28.25,-51.383333
br,encruzilhada,Encruzilhada,26,,-26.216667,-50.466667
br,encruzilhada,Encruzilhada,30,,-7.533333,-39.416667
br,encruzo,Encruzo,05,,-12.616667,-39.15
br,encruzo,Encruzo,08,,-19.983333,-40.433333
br,eneida,Eneida,27,,-21.916667,-51.3
br,enemutu,Enemutu,25,,4.033333,-59.883333
br,enganado,Enganado,05,,-17.033333,-39.566667
br,engano,Engano,04,,-4.816667,-72.366667
br,engano,Engano,06,,-4.933333,-39.116667
br,engano,Engano,08,,-20.616667,-40.85
br,engano,Engano,11,,-21.383333,-54.066667
br,engano,Engano,20,,-3.968056,-42.398889
br,engano,Engano,21,,-22.32263,-42.987556
br,engano,Engano,26,,-27.083333,-52.133333
br,engasgo,Engasgo,20,,-8.633333,-45.4
br,engenheiro avidos,Engenheiro Ávidos,17,,-6.983333,-38.466667
br,engenheiro balduino,Engenheiro Balduíno,27,,-20.683333,-49.7
br,engenheiro beltrao,Engenheiro Beltrão,18,14955,-23.783333,-52.25
br,engenheiro blei,Engenheiro Blei,18,,-25.616667,-49.75
br,engenheiro bley,Engenheiro Bley,18,,-25.616667,-49.75
br,engenheiro carvalhais,Engenheiro Carvalhais,21,,-22.033333,-43.4
br,engenheiro correia,Engenheiro Correia,15,,-20.333333,-43.783333
br,engenheiro dodt,Engenheiro Dodt,20,,-8.816667,-45.933333
br,engenheiro franca,Engenheiro Franca,05,,-13.25,-39.766667
br,engenheiro gutierrez,Engenheiro Gutierrez,18,,-25.517425,-50.655997
br,engenheiro joao tome,Engenheiro João Tomé,06,,-4.6,-40.633333
br,engenheiro jose lopes,Engenheiro José Lopes,06,,-5.666667,-39.433333
br,engenheiro junqueira,Engenheiro Junqueira,21,,-22.983333,-44.05
br,engenheiro leal,Engenheiro Leal,21,,-22.877436,-43.322833
br,engenheiro lisboa,Engenheiro Lisboa,15,,-19.8,-47.6
br,engenheiro marsilac,Engenheiro Marsilac,27,,-23.9078,-46.7069
br,engenheiro morbech,Engenheiro Morbech,14,,-16.05,-53.633333
br,engenheiro morbeck,Engenheiro Morbeck,14,,-16.05,-53.633333
br,engenheiro morsing,Engenheiro Morsing,21,,-22.540556,-43.776944
br,engenheiro navarro,Engenheiro Navarro,15,,-17.283333,-43.95
br,engenheiro nicanor pereira,Engenheiro Nicanor Pereira,21,,-22.624167,-43.705278
br,engenheiro nobrega,Engenheiro Nóbrega,21,,-22.451389,-43.700556
br,engenheiro passos,Engenheiro Passos,21,,-22.5,-44.683333
br,engenheiro paulo de frontin,Engenheiro Paulo de Frontin,21,,-22.549444,-43.683889
br,engenheiro pedreira,Engenheiro Pedreira,21,,-22.689444,-43.595556
br,engenheiro pontes,Engenheiro Pontes,05,,-13.066667,-39.45
br,engenheiro raul goncalves,Engenheiro Raul Gonçalves,29,,-17.85,-48.183333
br,engenheiro schmidt,Engenheiro Schmidt,27,,-20.866667,-49.3
br,engenheiro schnoor,Engenheiro Schnoor,15,,-17.166667,-42.083333
br,engenheiro taveira,Engenheiro Taveira,27,,-21.15,-50.5
br,engenheiro vieira cortes,Engenheiro Vieira Cortês,21,,-22.183333,-43.433333
br,engenhinho,Engenhinho,14,,-14.983333,-56.633333
br,engenho agua branca,Engenho Água Branca,05,,-12,-40.666667
br,engenho araci,Engenho Araci,16,,-1.116667,-48.266667
br,engenhoca,Engenhoca,05,,-12.616667,-38.866667
br,engenhoca,Engenhoca,13,,-3.860556,-43.361111
br,engenho central,Engenho Central,13,,-3.616667,-45.35
br,engenho central,Engenho Central,21,,-22.416667,-44.3
br,engenho d'agua,Engenho d'Agua,05,,-12.616667,-38.633333
br,engenho d'agua,Engenho d'Agua,13,,-4.866667,-43.183333
br,engenho d'agua,Engenho d'Agua,21,,-21.566667,-41.883333
br,engenho da rainha,Engenho da Rainha,21,,-22.866943,-43.289473
br,engenho da raiz,Engenho da Raiz,05,,-12.25,-38.85
br,engenho da serra,Engenho da Serra,21,,-22.921749,-43.321663
br,engenho de dentro,Engenho de Dentro,21,,-22.899791,-43.295592
br,engenho de quicama,Engenho de Quiçamã,21,,-22.1,-41.55
br,engenho de quissama,Engenho de Quissamã,21,,-22.1,-41.55
br,engenho de serra,Engenho de Serra,15,,-21.3,-45.15
br,engenho doldt,Engenho Doldt,20,,-8.816667,-45.933333
br,engenho do mato,Engenho do Mato,21,,-22.865,-43.296944
br,engenho do ribeiro,Engenho do Ribeiro,15,,-19.566667,-45.283333
br,engenho,Engenho,05,,-10.7,-44.25
br,engenho,Engenho,06,,-6.183333,-38.566667
br,engenho,Engenho,13,,-4.416667,-44.75
br,engenho,Engenho,14,,-14.816667,-56.333333
br,engenho,Engenho,15,,-15.183333,-43.083333
br,engenho,Engenho,16,,-1.016667,-47.366667
br,engenho,Engenho,21,,-22.918056,-43.834444
br,engenho,Engenho,22,,-6.033333,-38.083333
br,engenho gutierrez,Engenho Gutierrez,18,,-25.535033,-50.65262
br,engenho irmaos gnatta marumbi,Engenho Irmãos Gnatta Marumbi,18,,-25.5078,-48.8764
br,engenho novo,Engenho Novo,05,,-12.183333,-38.583333
br,engenho novo,Engenho Novo,15,,-21.814722,-43.002222
br,engenho novo,Engenho Novo,21,,-22.905921,-43.265956
br,engenho novo,Engenho Novo,30,,-8.783333,-36.016667
br,engenho pederneiras,Engenho Pederneiras,27,,-22.970556,-47.792222
br,engenho prata,Engenho Prata,02,,-9.916667,-36.116667
br,engenho sao jose,Engenho São José,22,,-5.616667,-35.333333
br,engenho velho,Engenho Velho,05,,-10.7,-44.25
br,engenho velho,Engenho Velho,13,,-3.266667,-42.683333
br,engenho velho,Engenho Velho,14,,-15.783333,-56.133333
br,engenho velho,Engenho Velho,15,,-20.95,-46.6
br,engenho velho,Engenho Velho,17,,-7.666667,-38.616667
br,engenho velho,Engenho Velho,21,,-22.922038,-43.217414
br,engenho velho,Engenho Velho,30,,-7.666667,-37.75
br,enio pepino,Ênio Pepino,27,,-22.483333,-52.333333
br,enjeitado,Enjeitado,13,,-2.89,-41.903611
br,enjeitado,Enjeitado,20,,-3.718611,-42.465833
br,enseada da cutia,Enseada da Cutia,04,,-3.476111,-63.350833
br,enseada de brito,Enseada de Brito,26,,-27.779167,-48.633889
br,enseada de fogo,Enseada de Fogo,02,,-9.966667,-36.083333
br,enseada do brito,Enseada do Brito,26,,-27.779167,-48.633889
br,enseada do fogo,Enseada do Fogo,02,,-9.966667,-36.083333
br,enseada do jenipapo,Enseada do Jenipapo,04,,-4.945556,-62.424444
br,enseada do membeca,Enseada do Membeca,04,,-5.549444,-63.106389
br,enseada,Enseada,20,,-9.953889,-45.122222
br,enseada,Enseada,27,,-23.483333,-45.083333
br,enseadinha,Enseadinha,30,,-8.083333,-38.466667
br,entrada da torre,Entrada da Torre,27,,-24.578575,-48.106114
br,entrada do campo,Entrada do Campo,23,,-28.733333,-51.266667
br,entrada,Entrada,20,,-8.666667,-41.883333
br,entre folhas,Entre Fôlhas,15,,-19.616667,-42.233333
br,entre ijuis,Entre Ijuís,23,,-28.35,-54.266667
br,entre monte,Entre Monte,02,,-9.666667,-37.65
br,entremontes,Entremontes,02,,-9.666667,-37.65
br,entre montes,Entre Montes,06,,-4.633333,-40.25
br,entremontes,Entremontes,30,,-7.55,-39.816667
br,entre morros,Entre Morros,20,,-3.474444,-42.074722
br,entrepelado,Entrepelado,23,,-29.733333,-50.75
br,entre rios de minas,Entre Rios de Minas,15,,-20.683333,-44.066667
br,entre rios,Entre Rios,04,,-4.116667,-58.7
br,entre rios,Entre Rios,05,27406,-11.933333,-38.083333
br,entre rios,Entre Rios,06,,-4.2,-40.433333
br,entre rios,Entre Rios,11,,-19.366667,-54.15
br,entre rios,Entre Rios,15,,-20.683333,-44.066667
br,entre-rios,Entre-Rios,16,,-5.4,-54.466667
br,entre rios,Entre Rios,17,,-6.866667,-35.6
br,entre rios,Entre Rios,18,,-25.274167,-50.235556
br,entre-rios,Entre-Rios,20,,-6.783333,-42.483333
br,entre-rios,Entre-Rios,21,,-22.111389,-43.207778
br,entre rios,Entre Rios,23,,-28.55,-51.35
br,entre rios,Entre Rios,27,,-20.65,-51.383333
br,entre val,Entre Val,05,,-12.583333,-39.25
br,entroncamento,Entroncamento,05,,-13.2,-40.333333
br,entroncamento,Entroncamento,22,,-5.265278,-36.801944
br,entroncamento,Entroncamento,23,,-29.85,-54.933333
br,entronoamento,Entronoamento,06,,-6.333333,-38.916667
br,entupido,Entupido,27,,-22.5,-44.85
br,envira,Envira,04,9957,-7.3,-70.216667
br,envira,Envira,14,,-4.370278,-58.1225
br,enxofre,Enxofre,27,,-23.000393,-47.615523
br,enxovia de baixo,Enxovia de Baixo,27,,-23.387749,-47.937582
br,enxovia do meio,Enxovia do Meio,27,,-23.397363,-47.975034
br,enxu,Enxu,05,,-11.05,-39.683333
br,enxu,Enxu,13,,-3.320833,-42.587222
br,enxu,Enxu,20,,-8.5,-44.583333
br,epaminondas matos,Epaminondas Matos,15,,-16.783333,-41.3
br,epaminondas otoni,Epaminondas Otoni,15,,-17.916667,-41.016667
br,epaminondas ridiculo,Epaminondas Ridículo,05,,-16.216667,-39.833333
br,ephigenia,Ephigenia,15,,-19.883333,-41.516667
br,epigua,Epiguá,27,,-20.65,-49.366667
br,epistasio,Epistasio,22,,-5.520278,-36.383611
br,epistasio pessoa,Epistasio Pessôa,22,,-5.520278,-36.383611
br,epitacio pessoa,Epitácio Pessoa,18,,-24.7814,-48.983
br,epitacio pessoa,Epitácio Pessoa,22,,-5.520278,-36.383611
br,equador,Equador,22,,-6.95,-36.716667
br,era crista rio branco,Era Cristã Rio Branco,27,,-22.742222,-47.329167
br,era,Era,05,,-13.1,-40.8
br,erale,Eralé,16,,.3,-54.016667
br,era nova,Era Nova,15,,-18.933333,-41.933333
br,ercilio vargas,Ercílio Vargas,11,,-23.366667,-54.65
br,erebango,Erebango,23,,-27.883333,-52.3
br,erecatu,Erecatú,23,,-28.316667,-52.05
br,erechim,Erechim,23,96089,-27.633333,-52.283333
br,eremetu,Eremetú,25,,4.033333,-59.883333
br,eremita,Eremita,15,,-21.583333,-45.066667
br,eremiterio santa clara,Eremitério Santa Clara,18,,-25.819,-49.144
br,erequim,Erequim,23,,-27.633333,-52.283333
br,erere,Ererê,06,,-6.033333,-38.35
br,erere,Ererê,16,,-1.983333,-54.166667
br,eretreia,Eretréia,27,,-22.3,-47.583333
br,erexim,Erexim,23,,-27.633333,-52.283333
br,erial,Erial,15,,-19.783333,-47.666667
br,eritima,Eritimã,16,,.583333,-54.116667
br,eritiman,Eritiman,16,,.583333,-54.116667
br,eritrea,Eritréa,27,,-22.3,-47.583333
br,eritreia,Eritréia,27,,-22.3,-47.583333
br,ermenegildo,Ermenegildo,14,,-10.283333,-60.516667
br,ermida,Ermida,27,,-23.2,-47
br,ermidinha,Ermidinha,15,,-16.432222,-44.090556
br,ermo,Ermo,06,,-6.516667,-38.616667
br,ernestina,Ernestina,23,,-28.5,-52.566667
br,ernesto alves,Ernesto Alves,23,,-29.366667,-54.733333
br,ernesto guedes,Ernesto Guedes,04,,-3,-65.95
br,ernesto machado,Ernesto Machado,21,,-21.633333,-41.65
br,ernesto pires,Ernesto Pires,15,,-20.55,-45.466667
br,erva de rato,Erva de Rato,02,,-9.283333,-36.233333
br,erva,Erva,15,,-18.466667,-45.45
br,erva,Erva,18,,-25.15,-49.666667
br,erval de baixo,Erval de Baixo,18,,-24.516667,-50.85
br,erval d'oeste,Erval d'Oeste,26,,-27.216667,-51.566667
br,erval,Erval,01,,-8.133333,-72.833333
br,erval,Erval,11,,-20.733333,-56.283333
br,erval,Erval,15,,-20.833333,-42.65
br,erval,Erval,18,,-23.782994,-50.047793
br,erval,Erval,23,,-31.883333,-53.166667
br,erval,Erval,26,,-26.883333,-53.433333
br,erval grande,Erval Grande,23,,-27.383333,-52.583333
br,ervalia,Ervália,15,,-20.833333,-42.65
br,erval seco,Erval Sêco,23,,-27.55,-53.5
br,erval velho,Erval Velho,26,,-27.283333,-51.433333
br,ervalzinho,Ervalzinho,18,,-24.833333,-51.283333
br,ervania,Ervânia,11,,-21.716667,-55.533333
br,erveira,Erveira,18,,-25.25,-52.533333
br,erveira,Erveira,26,,-26.1784,-49.977
br,erveiras,Erveiras,23,,-29.45,-52.65
br,esburacado,Esburacado,15,,-15.4,-42.75
br,escada,Escada,20,,-5.933333,-40.966667
br,escada,Escada,30,48084,-8.366667,-35.233333
br,escadilha,Escadilha,22,,-5.25,-35.933333
br,escadinha,Escadinha,30,,-8.083333,-38.466667
br,escalvado,Escalvado,15,,-20.233333,-42.816667
br,escalvado,Escalvado,20,,-8.216667,-42.416667
br,escalvado,Escalvado,26,,-26.833333,-48.733333
br,escalvados,Escalvados,13,,-3.751944,-42.706667
br,escapole,Escapole,06,,-2.866667,-40.016667
br,escaramuca,Escaramuça,27,,-20.733333,-47.683333
br,escola de pesca,Escola de Pesca,21,,-23.066667,-43.983333
br,escolvado,Escolvado,20,,-8.216667,-42.416667
br,escondido,Escondido,05,,-17.083333,-39.516667
br,escondido,Escondido,06,,-5.616667,-41.016667
br,escondido,Escondido,13,,-3.2725,-43.205
br,escondido,Escondido,16,,-5.45,-54.316667
br,escondido,Escondido,20,,-7.8,-41.65
br,escondido,Escondido,22,,-5.355278,-36.922778
br,escondido,Escondido,24,,-13.583333,-60.933333
br,escondido,Escondido,29,,-14.583333,-46.2
br,escondido,Escondido,30,,-7.783333,-37.583333
br,esconso,Esconso,05,,-12.3,-41.55
br,escravado,Escravado,20,,-5.6,-41.816667
br,escrivao,Escrivão,16,,-3.05,-55.183333
br,escura,Escura,15,,-19.3,-42.383333
br,escurial,Escurial,21,,-22.7,-42.816667
br,escurinho,Escurinho,26,,-28.083333,-50.483333
br,escuro,Escuro,01,,-8.148611,-72.857222
br,escuta,Escuta,13,,-3.255,-43.424167
br,esfola-carneiro,Esfola-Carneiro,05,,-12.883333,-38.783333
br,eslivas,Eslivas,13,,-4.666667,-45.75
br,esmaratita,Esmaratita,23,,-28.05,-51.2
br,esmeralda,Esmeralda,04,,-.616667,-63.35
br,esmeralda,Esmeralda,15,,-19.333333,-42.866667
br,esmeralda,Esmeralda,23,,-28.05,-51.2
br,esmeraldas,Esmeraldas,04,,-.616667,-63.35
br,esmeraldas,Esmeraldas,15,103252,-19.75,-44.316667
br,esmeril,Esmeril,15,,-20.5,-43.966667
br,esmeril,Esmeril,27,,-20.816667,-47.3
br,espacinha,Espacinha,06,,-4.666667,-40.483333
br,espadim,Espadim,11,,-23.833333,-55.366667
br,espalhado,Espalhado,27,,-22.531389,-47.255556
br,espalha,Espalha,22,,-5.993889,-37.395278
br,espanha,Espanha,16,,-5.933333,-57.466667
br,espanha,Espanha,30,,-8.933333,-37.516667
br,espera d'anta,Espera d'Anta,05,,-11.85,-40.783333
br,espera,Espera,05,,-12.183333,-40.3
br,espera,Espera,20,,-7.283333,-41.55
br,espera feliz,Espera Feliz,15,13031,-20.65,-41.916667
br,esperana,Esperana,27,,-23.315,-46.0112
br,esperanca,Esperança,01,,-8.25,-72.733333
br,esperanca,Esperança,04,,-3.513889,-62.911389
br,esperanca,Esperança,06,,-4.633333,-39.366667
br,esperanca,Esperança,11,,-17.966667,-54.466667
br,esperanca,Esperança,13,,-9.783333,-46.283333
br,esperanca,Esperança,14,,-17.55,-55
br,esperanca,Esperança,16,,-1.75,-52.466667
br,esperanca,Esperança,17,18817,-7.016667,-35.85
br,esperanca,Esperança,18,,-23.565508,-49.778472
br,esperanca,Esperança,20,,-10.8,-45.15
br,esperanca,Esperança,22,,-5.508611,-36.207778
br,esperanca,Esperança,23,,-27.366667,-53.966667
br,esperanca,Esperança,30,,-7.75,-38.616667
br,esperanca feliz,Esperança Feliz,04,,-5.572222,-61.0675
br,esperancinha,Esperancinha,05,,-13.733333,-40.25
br,esperantina,Esperantina,20,21044,-3.9,-42.233333
br,esperantina,Esperantina,31,,-5.313056,-48.415
br,esperantinopolis,Esperantinópolis,13,13167,-4.883333,-44.883333
br,esperanza,Esperanza,04,,-4.408889,-69.864167
br,esperito santo,Esperito Santo,04,,-3.433333,-68.716667
br,espero-em-deus,Espero-em-Deus,04,,-6.35,-60.316667
br,espigao alto,Espigão Alto,18,,-25.416667,-52.8
br,espigao alto,Espigão Alto,23,,-27.6,-51.433333
br,espigao bonito,Espigão Bonito,18,,-23.947229,-50.385707
br,espigao comprido,Espigão Comprido,27,,-24.634741,-48.102103
br,espigao das antas,Espigão das Antas,18,,-25.904756,-49.329364
br,espigao do bugre,Espigão do Bugre,26,,-26.1827,-49.813
br,espigao d'oeste,Espigao d'Oeste,24,,-11.583333,-60.983333
br,espigao,Espigão,15,,-14.983333,-42.583333
br,espigao,Espigão,18,,-25.944214,-50.139135
br,espigao,Espigão,27,,-22.183333,-51.366667
br,espingarda,Espingarda,13,,-3.866944,-43.051111
br,espinhaco,Espinhaço,13,,-3.993611,-43.371667
br,espinha de peixe,Espinha de Peixe,15,,-19.133333,-45.966667
br,espinha do peixe,Espinha do Peixe,15,,-19.133333,-45.966667
br,espinha,Espinha,05,,-13.883333,-40.533333
br,espinha,Espinha,13,,-7.4,-44.7
br,espinhal,Espinhal,16,,-5.583333,-48.183333
br,espinharas,Espinharas,17,,-7.133333,-37.05
br,espinheirinho,Espinheirinho,22,,-5.456944,-37.161944
br,espinheiro de baixo,Espinheiro de Baixo,22,,-5.834722,-37.101389
br,espinheiro,Espinheiro,06,,-7.1,-40.066667
br,espinheiro,Espinheiro,14,,-15.366667,-56.316667
br,espinheiro,Espinheiro,20,,-7.833333,-41.933333
br,espinheiro,Espinheiro,22,,-5.219444,-36.625833
br,espinheiro,Espinheiro,30,,-8.533333,-38.233333
br,espinheiros,Espinheiros,26,,-26.25,-48.8
br,espinho,Espinho,05,,-13.333333,-41.366667
br,espinho,Espinho,06,,-3.266667,-40.15
br,espinhos,Espinhos,20,,-8.183333,-42.483333
br,espinilho,Espinilho,23,,-28.15,-53.733333
br,espinilho,Espinilho,26,,-27.283333,-51.1
br,espinosa,Espinosa,15,17549,-14.933333,-42.833333
br,espirito santo de vitoria,Espírito Santo de Vitória,08,,-20.333333,-40.283333
br,espirito santo do dourado,Espírito Santo do Dourado,15,,-22.05,-45.966667
br,espirito santo do pinhal,Espirito Santo do Pinhal,27,37449,-22.2,-46.75
br,espirito santo do rio pardo,Espírito Santo do Rio Pardo,27,,-23.1,-48.383333
br,espirito santo do turvo,Espírito Santo do Turvo,27,,-22.716667,-49.416667
br,espirito santo,Espírito Santo,03,,1.25,-50.9
br,espirito santo,Espírito Santo,04,,-2.716667,-67.55
br,espirito santo,Espírito Santo,05,,-13.716667,-41.3
br,espirito santo,Espírito Santo,06,,-4.05,-41.183333
br,espirito santo,Espírito Santo,08,,-20.333333,-40.283333
br,espirito santo,Espírito Santo,11,,-21.4,-56.233333
br,espirito santo,Espírito Santo,13,,-6.983333,-44.233333
br,espirito santo,Espirito Santo,14,,-16.766667,-55.533333
br,espirito santo,Espírito Santo,15,,-17.65,-45.933333
br,espirito santo,Espírito Santo,16,,-1.1,-49.216667
br,espirito santo,Espírito Santo,17,,-6.45,-38.4
br,espirito santo,Espírito Santo,18,,-23.366667,-51.216667
br,espirito santo,Espírito Santo,20,,-5.016667,-41.233333
br,espirito santo,Espírito Santo,21,,-21.266667,-41.416667
br,espirito santo,Espírito Santo,22,,-6.316667,-35.283333
br,espirito santo,Espírito Santo,23,,-30.158333,-51.220833
br,espirito santo,Espírito Santo,24,,-10.066667,-62.566667
br,espirito santo,Espírito Santo,25,,3.800941,-59.623694
br,espirito santo,Espírito Santo,28,,-11.533333,-37.516667
br,espirito santo,Espirito Santo,30,,-7.583333,-37.55
br,espirito santo quartal geral,Espirito Santo Quartal Geral,15,,-19.3,-45.55
br,espiritu santo,Espiritu Santo,04,,-2.95,-69.116667
br,esplanada,Esplanada,05,18859,-11.783333,-37.95
br,esplanada,Esplanada,26,,-28.7,-49.183333
br,espraiado,Espraiado,20,,-5.4,-42.75
br,espuma,Espuma,17,,-7.483333,-37.583333
br,espumoso,Espumoso,23,10340,-28.733333,-52.85
br,esquerda,Esquerda,20,,-7.4,-41.816667
br,esquia,Esquia,13,,-3.990278,-43.023889
br,esquina gaucha,Esquina Gaúcha,23,,-27.45,-54.2
br,esquina tucunduva,Esquina Tucunduva,23,,-27.633333,-54.416667
br,esquina tudunduva,Esquina Tudunduva,23,,-27.633333,-54.416667
br,esse,Esse,06,,-4.35,-39.333333
br,estacada,Estacada,17,,-6.766667,-35.316667
br,estacadinha,Estacadinha,22,,-5.250556,-36.771111
br,estacado,Estacado,05,,-12.033333,-38.65
br,estaca,Estaca,11,,-20.3,-54.533333
br,estacao de condado,Estacão de Condado,17,,-6.866667,-37.583333
br,estacao de coronel ponce,Estacão de Coronel Ponce,14,,-15.566667,-55.016667
br,estacao de nhambiquaras,Estacão de Nhambiquaras,14,,-12.75,-59.8
br,estacao de utiarity,Estacão de Utiarity,14,,-13.033333,-58.283333
br,estacao do juruena,Estaçao do Juruena,14,,-12.85,-58.933333
br,estacao engenheiro cornelio,Estação Engenheiro Cornélio,30,,-7.9,-38.083333
br,estacao,Estação,04,,-7,-73.75
br,estacao,Estação,20,,-8.283333,-42.2
br,estacao,Estação,27,,-23.029702,-47.950508
br,estacao experimental,Estação Experimental,18,,-25.4527,-50.5836
br,estacao mandaguari,Estacão Mandaguarí,27,,-22.183333,-51.366667
br,estacao nova,Estação Nova,25,,3.7,-61.383333
br,estacao parecis,Estação Parecis,14,,-14.15,-56.933333
br,estacao rio vermelho,Estação Rio Vermelho,26,,-26.283333,-49.333333
br,estacao telegrafica torno largo,Estação Telegráfica Torno Largo,24,,-9.116667,-63.25
br,estaca zero,Estaca Zero,05,,-10.166667,-39.116667
br,estaca zero,Estaca Zero,20,,-5.716667,-42.633333
br,estacio,Estácio,21,,-22.918166,-43.20397
br,estados unidos,Estados Unidos,04,,-3.293333,-62.923333
br,estaleiro de cima,Estaleiro de Cima,05,,-12.25,-38.633333
br,estaleiro,Estaleiro,05,,-12.25,-38.633333
br,estaleiro,Estaleiro,18,,-25.9016,-48.7679
br,estalo,Estalo,21,,-22.566667,-44.466667
br,estancia da lagoa,Estância da Lagoa,23,,-29.216667,-56.083333
br,estancia da pedreira,Estância da Pedreira,23,,-29.633333,-56.3
br,estancia da saudade,Estância da Saudade,23,,-29.55,-56.816667
br,estancia da sociedade,Estância da Sociedade,23,,-30.266667,-55.65
br,estancia de lima,Estância de Lima,23,,-31.016667,-55.85
br,estancia do castello,Estancia do Castello,08,,-20.6,-41.2
br,estancia do cati,Estância do Cati,23,,-30.483333,-56.15
br,estancia do cerro,Estância do Cêrro,23,,-30.733333,-55.75
br,estancia do junco,Estância do Junco,23,,-30.033333,-56.816667
br,estancia do mormaco,Estância do Mormaço,23,,-30.733333,-55.85
br,estancia do serro,Estância do Serro,23,,-30.733333,-55.75
br,estancia entroncamento,Estância Entroncamento,23,,-29.85,-54.933333
br,estancia esperanca,Estância Esperança,23,,-31,-55.833333
br,estancia,Estância,28,55655,-11.266667,-37.433333
br,estancia funchal,Estância Funchal,23,,-30.566667,-55.883333
br,estancia grande,Estância Grande,23,,-29.9984,-50.9499
br,estancia ibira,Estância Ibira,23,,-30.45,-55.766667
br,estancia jaguareta,Estância Jaguareta,23,,-29.9,-55.083333
br,estancia jose benitez,Estância José Benítez,23,,-30.933333,-55.866667
br,estancia jose m. de sousa,Estância José M. de Sousa,23,,-30.55,-56.2
br,estancia lagoa brilhante,Estância Lagoa Brilhante,14,,-14.451389,-59.6875
br,estancia lula vilela,Estância Lula Vilela,23,,-29.95,-56.633333
br,estancia manoel fialho,Estância Manoel Fialho,23,,-31.066667,-55.983333
br,estancia mimosa,Estância Mimosa,23,,-29.783333,-56.383333
br,estancia mirante,Estância Mirante,23,,-29.633333,-52.083333
br,estancia nova,Estância Nova,23,,-30.133333,-54.516667
br,estancia querencia,Estância Querência,27,,-23.794775,-46.681455
br,estancia rancho felicio,Estância Rancho Felício,23,,-30.716667,-56.033333
br,estancia rosario,Estância Rosário,23,,-30.25,-55.566667
br,estancia santa luisa,Estância Santa Luísa,23,,-29.683333,-54.633333
br,estancia santa rosa,Estância Santa Rosa,23,,-29.283333,-55.8
br,estancia santa ursula,Estância Santa Úrsula,23,,-30.483333,-55.9
br,estancia santo inacio,Estancia Santo Inácio,23,,-30.666667,-55.15
br,estancia sao domingos,Estância São Domingos,23,,-28.966667,-55.6
br,estancia sao francisco,Estância São Francisco,23,,-29.55,-56.433333
br,estancia sao vicente,Estância São Vicente,23,,-29.05,-56.283333
br,estancia sarandi,Estância Sarandi,23,,-30.666667,-55.95
br,estancia teixeira,Estância Teixeira,23,,-30.366667,-54.066667
br,estancia teresinha,Estância Teresinha,23,,-30.016667,-56.583333
br,estancia tres capoes,Estância Três Capões,23,,-29.6,-56.1
br,estancia vargem grande,Estância Vargem Grande,27,,-23.35,-47.066667
br,estancia varola,Estância Varola,23,,-30.716667,-55.7
br,estancia velha,Estância Velha,23,40391,-29.65,-51.183333
br,estancia vista alegre,Estância Vista Alegre,23,,-30.116667,-57.216667
br,estandarte,Estandarte,13,,-1.433333,-45.533333
br,estanhado,Estanhado,15,,-16.116667,-40.4
br,estanhado,Estanhado,20,,-3.95,-42.766667
br,estefania,Estefânia,23,,-29.25,-52.033333
br,esteio,Esteio,11,,-21.45,-54.65
br,esteio,Esteio,23,84903,-29.85,-51.166667
br,esteios,Esteios,15,,-19.916667,-45.733333
br,esteira,Esteira,23,,-28.633333,-50.85
br,esteirao,Esteirão,04,,-7.283333,-58.6
br,esteja quiteo,Esteja Quiteo,20,,-6.616667,-42.5
br,estela maris,Estela Maris,23,,-32.216667,-52.2
br,estendeslau,Estendeslau,06,,-4.033333,-41.15
br,esterao,Esterão,04,,-7.283333,-58.6
br,estevao de araujo,Estêvão de Araújo,15,,-20.616667,-42.533333
br,estevao,Estêvão,06,,-4.9,-39.15
br,estevao,Estevão,20,,-6.716667,-41.433333
br,estevao,Estêvão,26,,-27.583333,-48.716667
br,estevao velho,Estêvão Velho,05,,-12.4,-39.15
br,esteves junior,Esteves Júnior,26,,-27.433333,-51.85
br,estirao comprido,Estirão Comprido,14,,-16.316667,-55.966667
br,estirao do itapuvucu,Estirão do Itapuvuçu,27,,-24.71097,-48.025893
br,estirao do tejo,Estirão do Tejo,01,,-8.989444,-72.733056
br,estirao do tiro,Estirão do Tiro,04,,-5.861667,-64.947222
br,estirao,Estirão,04,,.366667,-64.05
br,estiro,Estiro,13,,-6.383333,-44.983333
br,estiva da gangati,Estiva da Gangati,13,,-3.183611,-43.451389
br,estiva da josefa,Estiva da Josefa,13,,-3.121667,-43.419722
br,estiva de baixo,Estiva de Baixo,05,,-15,-39.583333
br,estiva do arraial,Estiva do Arraial,13,,-2.75,-44.333333
br,estivado,Estivado,05,,-13.85,-39.583333
br,estivado,Estivado,14,,-14.516667,-56.166667
br,estiva dos vidal,Estiva dos Vidal,18,,-25.73844,-50.45512
br,estiva,Estiva,02,,-9.483333,-36.183333
br,estiva,Estiva,05,,-11.9,-40.566667
br,estiva,Estiva,11,,-19.516667,-51.85
br,estiva,Estiva,13,,-2.75,-44.333333
br,estiva,Estiva,14,,-15.5,-55.5
br,estiva,Estiva,15,,-15.366667,-42.616667
br,estiva,Estiva,17,,-7.183333,-38.266667
br,estiva,Estiva,18,,-23.983333,-51.383333
br,estiva,Estiva,20,,-3.92,-42.673333
br,estiva,Estiva,23,,-29.866667,-53.266667
br,estiva,Estiva,26,,-26.35,-50.05
br,estiva,Estiva,27,,-22.716667,-47.916667
br,estiva,Estiva,29,,-13.733333,-46.683333
br,estiva,Estiva,31,,-10.7,-47.483333
br,estiva i,Estiva I,13,,-3.144722,-42.380556
br,estiva ii,Estiva II,13,,-3.113056,-42.429167
br,estivas,Estivas,02,,-9.066667,-36.166667
br,estivas,Estivas,05,,-13.716667,-42.9
br,estivas,Estivas,13,,-6.233333,-35.216667
br,estivas,Estivas,20,,-6.2,-41.366667
br,estivas,Estivas,22,,-5.666667,-35.25
br,estncia guarema,Estncia Guarema,27,,-23.4081,-46.0089
br,estncia zelia,Estncia Zelia,27,,-23.2989,-46.2245
br,estocado,Estocado,20,,-7.016667,-43.116667
br,estopa,Estopa,13,,-3.150833,-42.953889
br,estrada carolina,Estrada Carolina,26,,-26.7872,-49.0658
br,estrada da mulde,Estrada da Mulde,26,,-26.8247,-49.2355
br,estrada do 29,Estrada do 29,16,,-1.1,-46.516667
br,estrada do campo,Estrada do Campo,23,,-28.733333,-51.266667
br,estrada do quinze,Estrada do Quinze,26,,-25.9917,-48.7077
br,estrada,Estrada,05,,-12.283333,-37.816667
br,estrada,Estrada,06,,-6.366667,-39.15
br,estrada nova,Estrada Nova,21,,-21.8,-42.116667
br,estradaozinho,Estradãozinho,23,,-27.516667,-54.166667
br,estrangeiro,Estrangeiro,17,,-7.233333,-37.5
br,estreito,Estreito,05,,-11.166667,-44.15
br,estreito,Estreito,06,,-3.35,-40.183333
br,estreito,Estreito,11,,-21.45,-54.65
br,estreito,Estreito,13,17647,-5.783333,-43.25
br,estreito,Estreito,16,,-6.983333,-51.716667
br,estreito,Estreito,17,,-7.05,-37.916667
br,estreito,Estreito,18,,-24.669599,-48.86494
br,estreito,Estreito,20,,-3.924722,-42.04
br,estreito,Estreito,22,,-5.233333,-37.35
br,estreito,Estreito,23,,-31.833333,-51.733333
br,estreito,Estreito,30,,-7.983333,-38.2
br,estrela da jordania,Estrêla da Jordânia,15,,-15.866667,-40.283333
br,estrela dalva,Estrêla Dalva,15,,-21.75,-42.433333
br,estrela de jordania,Estrêla de Jordânia,15,,-15.866667,-40.283333
br,estrela d'oeste,Estrela d'Oeste,27,,-20.3,-50.416667
br,estrelado,Estrelado,08,,-20.583333,-41.3
br,estrela do garrafao,Estrêla do Garrafão,15,,-20.65,-46.683333
br,estrela do indaia,Estrêla do Indaiá,15,,-19.516667,-45.783333
br,estrela do leste,Estrêla do Leste,14,,-16.283333,-53.566667
br,estrela do norte,Estrêla do Norte,05,,-14.783333,-39.15
br,estrela do norte,Estrêla do Norte,27,,-22.466667,-51.65
br,estrela do norte,Estrêla do Norte,29,,-13.816667,-49.066667
br,estrela do oeste,Estrêla do Oeste,27,,-20.3,-50.416667
br,estrela do rio,Estrela do Rio,05,,-14.783333,-39.15
br,estrela dos anapurus,Estrêla dos Anapurus,13,,-3.666667,-43.1
br,estrela do sul,Estrela do Sul,11,,-18.4,-53.6
br,estrela do sul,Estrêla do Sul,15,,-18.766667,-47.7
br,estrela,Estrêla,05,,-13.016667,-40.25
br,estrela,Estrela,06,,-3.233333,-39.3
br,estrela,Estrêla,11,,-18.4,-53.6
br,estrela,Estrela,13,,-3.891389,-43.479444
br,estrela,Estrela,14,,-15.333333,-57.233333
br,estrela,Estrêla,15,,-19.516667,-45.783333
br,estrela,Estrela,17,,-6.683333,-37.9
br,estrela,Estrêla,21,,-22.627778,-43.199167
br,estrela,Estrêla,23,24200,-28.1,-50.983333
br,estrela,Estrêla,27,,-21.75,-47.333333
br,estrela matutina,Estrela Matutina,04,,-4.485556,-59.8825
br,estrella,Estrella,15,,-19.516667,-45.783333
br,estrella,Estrella,21,,-22.627778,-43.199167
br,estrella,Estrella,23,,-29.483333,-51.966667
br,estrellas,Estrellas,01,,-8.45,-71.683333
br,estrello do sul,Estrello do Sul,15,,-18.766667,-47.7
br,estrema de pixuna,Estrema de Pixuna,04,,-7.25,-72.233333
br,estrema,Estrema,01,,-10.666667,-70.1
br,estrema,Estrema,04,,-7.316667,-71.166667
br,estrema,Estrema,05,,-10.666667,-42.933333
br,estrema,Estrema,06,,-5.45,-39.9
br,estrema,Estrema,13,,-6.283333,-43.966667
br,estrema,Estrema,15,,-15.4,-44.266667
br,estrema,Estrema,17,,-6.533333,-38.433333
br,estrema,Estrema,20,,-7.866667,-40.7
br,estrema,Estrema,22,,-5.933333,-35.966667
br,estrema,Estrema,23,,-28.183333,-51.133333
br,estrema,Estrema,30,,-7.966667,-38.5
br,estrema,Estrema,31,,-11.081389,-48.159167
br,estreminha,Estreminha,01,,-9.746111,-67.566667
br,estremo,Estremo,17,,-7.8,-38.283333
br,estremoz,Estremoz,22,,-5.7,-35.3
br,estrenta,Estrenta,05,,-13.866667,-40.633333
br,estrias,Estrias,13,,-4.666667,-45.75
br,estrondadeira,Estrondadeira,22,,-5.153611,-36.7925
br,estulandia,Estulândia,29,,-17.266667,-49.05
br,estulania,Estulânia,29,,-17.266667,-49.05
br,etiquira,Etiquira,14,,-17.2,-54.116667
br,eubanque,Eubanque,15,,-21.55,-43.5
br,euca,Euca,03,,2.683333,-50.85
br,eucalipto,Eucalipto,23,,-27.8,-51.4
br,euclidelandia,Euclidelândia,21,,-21.9,-42.266667
br,euclides da cunha,Euclides da Cunha,05,29739,-10.516667,-39.016667
br,euclides da cunha,Euclides da Cunha,21,,-21.766667,-42.366667
br,euclydes malta,Euclydes Malta,02,,-9.416667,-36.066667
br,eucum,Eucum,05,,-13.983333,-41.2
br,eufrasina,Eufrasina,18,,-25.4599,-48.5761
br,eufrosina,Eufrosina,18,,-25.933333,-50.683333
br,eufrozina,Eufrozina,18,,-25.933333,-50.683333
br,eugenio de castro,Eugênio de Castro,23,,-28.55,-54.05
br,eugenio de melo,Eugênio de Melo,27,,-23.15,-45.783333
br,eugenio,Eugênio,02,,-9.666667,-36.383333
br,eugenio penzo,Eugênio Penzo,11,,-22.216667,-55.883333
br,eugenopolis,Eugenópolis,15,,-21.1,-42.183333
br,eureca,Eureca,15,,-16.633333,-41.1
br,euriapolis,Euriápolis,05,,-16.366667,-39.583333
br,eurico almeida,Eurico Almeida,15,,-16.633333,-41.033333
br,eurico lima,Eurico Lima,25,,3.433333,-60.633333
br,eurico martelete,Eurico Martelete,23,,-28.6,-53.516667
br,eurico martellet,Eurico Martellet,23,,-28.6,-53.516667
br,europa,Europa,01,,-10.616667,-68.266667
br,europa,Europa,04,,-3.26,-62.856667
br,eusebio de oliveira,Eusébio de Oliveira,18,,-23.8107,-50.3623
br,eusebio,Eusébio,06,37290,-3.9,-38.45
br,eusebio,Eusébio,15,,-15.3,-43.083333
br,euxenita,Euxenita,15,,-18.55,-43.033333
br,euzebio oliveira,Euzebio Oliveira,18,,-23.8107,-50.3623
br,euziebio,Euziebio,06,,-3.9,-38.45
br,eva,Eva,25,,3.15,-59.933333
br,evangelista de sousa,Evangelista de Sousa,27,,-23.9263,-46.6505
br,evangelista,Evangelista,23,,-28.633333,-51.95
br,evangelista,Evangelista,27,,-23.9114,-46.6602
br,evarista,Evarista,23,,-31.2,-52.233333
br,evaristo,Evaristo,15,,-21.933333,-45.766667
br,evaristo,Evaristo,23,,-31.2,-52.233333
br,evaristo melo,Evaristo Melo,15,,-21.166667,-46.75
br,ewbank,Ewbank,15,,-21.55,-43.5
br,exaltacao,Exaltação,04,,-5.646667,-61.156389
br,exapora,Exaporã,27,,-22.433333,-50.2
br,excelsior,Excelsior,21,,-22.941133,-43.271241
br,ex. novo treviso,Ex. Novo Treviso,23,,-28.95,-51.383333
br,expedicionario alicio,Expedicionário Alício,15,,-19.65,-41.3
br,expedito lopes,Expedito Lopes,20,,-6.95,-41.633333
br,extracao,Extração,15,,-18.283333,-43.533333
br,extraccao,Extracção,15,,-18.283333,-43.533333
br,extrato,Extrato,04,,-4.1725,-60.596389
br,extrema de pixuma,Extrema de Pixuma,04,,-7.25,-72.233333
br,extrema,Extrema,01,,-10.666667,-70.1
br,extrema,Extrema,04,,-6.876389,-70.671111
br,extrema,Extrema,05,,-10.666667,-42.933333
br,extrema,Extrema,06,,-6.816667,-39.233333
br,extrema,Extrema,13,,-6.283333,-43.966667
br,extrema,Extrema,15,13682,-22.85,-46.316667
br,extrema,Extrema,20,,-3.604444,-42.294167
br,extrema,Extrema,23,,-28.183333,-51.133333
br,extrema,Extrema,31,,-11.081389,-48.159167
br,extremas,Extremas,20,,-5.166667,-41.816667
br,extremos,Extremós,22,,-5.7,-35.3
br,extremoz,Extremóz,22,17992,-5.7,-35.3
br,exu,Exú,06,,-5.133333,-38.333333
br,exu,Exu,17,,-6.8,-38.283333
br,exu,Exu,20,,-5.216667,-41.633333
br,exu,Exu,22,,-6.133333,-37.8
br,exu,Exu,30,10875,-7.516667,-39.716667
br,exu velho,Exu Velho,30,,-7.416667,-39.716667
br,ezeperio almeida,Ezepério Almeida,15,,-16.266667,-41.683333
br,ezequiel,Ezequiel,11,,-22.05,-54.45
br,ezequiel,Ezequiel,16,,-1.95,-49.1
br,fabiao,Fabião,15,,-15.133333,-44.233333
br,fabrica das chitas,Fábrica das Chitas,21,,-22.929977,-43.230479
br,fabrica,Fábrica,30,,-8.75,-36.866667
br,fabrica santa barbara,Fábrica Santa Bárbara,15,,-18.016667,-44.116667
br,facao,Facão,06,,-5.483333,-39.183333
br,facao,Fação,13,,-3.421389,-42.961944
br,facao,Facão,14,,-16.166667,-57.6
br,facao,Facão,26,,-26.874552,-49.760227
br,facao,Facão,27,,-22.4,-47.383333
br,fachinal do sao joao,Fachinal do Sao Joao,26,,-27.033333,-51.716667
br,fachinal dos guedes,Fachinal dos Guedes,26,,-26.883333,-52.233333
br,fachinal,Fachinal,23,,-28.066667,-53.7
br,fagundes,Fagundes,06,,-3.95,-38.35
br,fagundes,Fagundes,08,,-18.7,-40.816667
br,fagundes,Fagundes,16,,-7.216667,-55.633333
br,fagundes,Fagundes,17,5137,-7.35,-35.8
br,fagundes,Fagundes,22,,-5.228611,-36.277222
br,fagundes varela,Fagundes Varela,23,,-28.883333,-51.7
br,faisca,Faisca,06,,-4.283333,-38.783333
br,faisqueirinha,Faisqueirinha,18,,-25.423675,-48.767161
br,faisqueiro,Faisqueiro,17,,-6.933333,-38.45
br,falas,Falas,17,,-7.616667,-37.85
br,fala verdade,Fala Verdade,11,,-19.666667,-54.783333
br,falcao,Falcão,21,,-22.2877,-44.2531
br,falcao,Falcão,31,,-5.933333,-48.216667
br,falha,Falha,13,,-9.283333,-46.801389
br,fama,Fama,15,,-21.4,-45.833333
br,fama,Fama,30,,-8.783333,-36.433333
br,faminha,Faminha,08,,-20.216667,-41.733333
br,fangueira,Fangueira,15,,-20.366667,-44.633333
br,fangueiro,Fangueiro,15,,-20.366667,-44.633333
br,fao,Fão,23,,-29.2,-52.233333
br,faral,Faral,05,,-18.083333,-39.633333
br,faria,Faria,02,,-9.616667,-37.333333
br,faria,Faria,30,,-8.133333,-36.3
br,faria lemas,Faria Lemas,15,,-20.8,-42.016667
br,faria lemos,Faria Lemos,15,,-20.8,-42.016667
br,faria lemos,Faria Lemos,23,,-29.2454,-51.075
br,farias brito,Farias Brito,06,11288,-6.916667,-39.566667
br,farias,Farias,06,,-7.35,-39.4
br,farias,Farias,15,,-19.016667,-42.833333
br,farias,Farias,17,,-7.383333,-36.666667
br,farias,Farias,22,,-5.183333,-35.883333
br,farias,Farias,23,,-29.066667,-52.733333
br,farias,Farias,28,,-9.866667,-37.25
br,faria velho,Faria Velho,15,,-17.733333,-44.65
br,farinha,Farinha,05,,-13.85,-44.816667
br,farinha,Farinha,17,,-7.116667,-36.133333
br,farinha,Farinha,18,,-23.35,-51
br,farinha,Farinha,23,,-27.183333,-53.133333
br,farinha molhada,Farinha Molhada,05,,-13.6,-41.4
br,farinhas,Farinhas,17,,-7.083333,-37.233333
br,farinhas,Farinhas,23,,-27.183333,-53.133333
br,farinna,Farinna,17,,-7.116667,-36.133333
br,faro,Faro,04,,-7.316667,-62.933333
br,faro,Faro,16,,-2.133333,-56.733056
br,farol,Farol,05,,-12.566667,-38
br,farol,Farol,18,,-24.1,-52.666667
br,farpao,Farpão,15,,-16.1,-40.05
br,farroupilha,Farroupilha,23,57651,-29.233333,-51.35
br,fartura,Fartura,17,,-7.55,-38.4
br,fartura,Fartura,18,,-25.5208,-48.9002
br,fartura,Fartura,20,,-2.994722,-41.315278
br,fartura,Fartura,26,,-26.166667,-50.55
br,fartura,Fartura,27,12405,-23.383333,-49.5
br,fasola,Fasola,30,,-8.633333,-37.133333
br,fatima,Fátima,05,,-10.65,-38.233333
br,fatima,Fátima,14,,-16.183333,-54.966667
br,fatima,Fátima,17,,-6.95,-38.716667
br,fatima,Fatima,21,,-22.917491,-43.188336
br,fatima,Fátima,30,,-7.95,-37.783333
br,fatima,Fátima,31,,-10.764444,-48.827222
br,fau,Faú,27,,-24.25,-47.45
br,faustino,Faustino,05,,-12.883333,-40.083333
br,faustino,Faustino,06,,-7.05,-39.516667
br,faustino,Faustino,13,,-3.359167,-43.432778
br,faustino,Faustino,17,,-7.583333,-38.466667
br,fausto,Fausto,03,,.316667,-51.7
br,fausto,Fausto,21,,-22.433333,-41.95
br,fava,Fava,20,,-7.466667,-41.666667
br,faval,Faval,14,,-15.65,-56.783333
br,favania,Favânia,16,,-3.116667,-51.8
br,faveira,Faveira,02,,-8.966667,-37.766667
br,faveira,Faveira,06,,-4.05,-40.983333
br,faveira,Faveira,13,,-3.787222,-42.822778
br,faveira,Faveira,20,,-3.888611,-42.398333
br,faveirinha,Faveirinha,13,,-3.136667,-42.203889
br,favela,Favela,05,,-10.15,-41.65
br,favela,Favela,06,,-6.3,-40.3
br,favela,Favela,17,,-6.983333,-37.183333
br,favela,Favela,22,,-5.2925,-37.170833
br,favela,Favela,24,,-10.283333,-63.7
br,favela,Favela,30,,-8.216667,-37.516667
br,favelas,Favelas,20,,-7.116667,-40.683333
br,favella,Favella,05,,-10.15,-41.65
br,favella,Favella,24,,-10.283333,-63.7
br,favera,Favera,20,,-6.3,-42.3
br,favinhas,Favinhas,30,,-7.766667,-39.483333
br,favonio,Favónio,04,,-2.683333,-66.75
br,favorita,Favorita,05,,-17.95,-40.033333
br,faxina,Faxina,27,,-20.55,-47.783333
br,faxinal chagu,Faxinal Chagu,18,,-25.366667,-52.583333
br,faxinal da pinguela,Faxinal da Pinguela,18,,-24.95,-50.55
br,faxinal de catanduva,Faxinal de Catanduva,18,,-24.633333,-51.266667
br,faxinal de catanduvas,Faxinal de Catanduvas,18,,-24.633333,-51.266667
br,faxinal de santo antonio,Faxinal de Santo Antônio,18,,-24.716667,-51.283333
br,faxinal de sao joao,Faxinal de São João,18,,-25.116667,-52.733333
br,faxinal de sao pedro,Faxinal de São Pedro,18,,-25.710737,-50.727342
br,faxinal de sao pedro,Faxinal de São Pedro,26,,-26.833333,-50.9
br,faxinal de sao sebastiao,Faxinal de São Sebastião,18,,-23.983333,-51.366667
br,faxinal do louro,Faxinal do Louro,18,,-25.5882,-50.2713
br,faxinal do rio-acima,Faxinal do Rio-Acima,27,,-23.7425,-47.9107
br,faxinal dos andrades,Faxinal dos Andrades,18,,-25.722389,-50.244229
br,faxinal dos augustos,Faxinal dos Augustos,18,,-25.27,-50.6539
br,faxinal dos castilhos,Faxinal dos Castilhos,18,,-25.85,-49.85
br,faxinal dos correas,Faxinal dos Corrêas,18,,-25.7129,-49.9362
br,faxinal dos elois,Faxinal dos Elóis,18,,-24.016667,-51.433333
br,faxinal dos fabricios,Faxinal dos Fabrícios,18,,-25.58318,-50.39106
br,faxinal dos fereiras,Faxinal dos Fereiras,18,,-25.699723,-50.234788
br,faxinal dos ferreiras,Faxinal dos Ferreiras,18,,-25.690917,-50.27085
br,faxinal dos francos,Faxinal dos Francos,18,,-25.596448,-50.587398
br,faxinal dos guedes,Faxinal dos Guedes,26,,-26.883333,-52.233333
br,faxinal do silva,Faxinal do Silva,18,,-25.583333,-50.166667
br,faxinal dos indios,Faxinal dos Índios,18,,-25.166667,-52.433333
br,faxinal dos lapeanos,Faxinal dos Lapeanos,18,,-25.661897,-50.484193
br,faxinal dos mineiros de baixo,Faxinal dos Mineiros de Baixo,18,,-25.52475,-50.39104
br,faxinal dos mineiros de cima,Faxinal dos Mineiros de Cima,18,,-25.5366,-50.41288
br,faxinal dos mineiros,Faxinal dos Mineiros,18,,-25.53873,-50.33662
br,faxinal do soturno,Faxinal do Soturno,23,,-29.616667,-53.433333
br,faxinal dos paula,Faxinal dos Paula,18,,-25.692752,-50.737806
br,faxinal dos pintos,Faxinal dos Pintos,18,,-25.54389,-50.44975
br,faxinal dos pretos,Faxinal dos Pretos,18,,-25.855482,-49.791815
br,faxinal dos quartins,Faxinal dos Quartins,18,,-25.55826,-50.115547
br,faxinal dos rodrigues,Faxinal dos Rodrigues,18,,-25.721388,-50.221168
br,faxinal dos santos,Faxinal dos Santos,18,,-26.283333,-51.5
br,faxinal dos silvas,Faxinal dos Silvas,18,,-25.573102,-50.13258
br,faxinal dos vieiras,Faxinal dos Vieiras,18,,-25.62945,-50.612387
br,faxinal,Faxinal,18,13464,-23.983333,-51.366667
br,faxinal,Faxinal,23,,-29.616667,-53.433333
br,faxinal,Faxinal,26,,-26.8814,-49.9338
br,faxinal,Faxinal,27,,-23.7034,-47.8336
br,faxinal preto,Faxinal Prêto,23,,-28.516667,-49.883333
br,faxinal sao joao,Faxinal São João,18,,-25.116667,-52.733333
br,faxinalsinho,Faxinalsinho,18,,-24,-51.45
br,faxinalzinho do rio azul,Faxinalzinho do Rio Azul,18,,-24,-51.45
br,faxinalzinho,Faxinalzinho,18,,-24,-51.45
br,faz dos fojos,Faz dos Fojos,18,,-25.761369,-50.089885
br,fazenda acude das melancias,Fazenda Açude das Melancias,06,,-4.75,-38.283333
br,fazenda acude grande,Fazenda Açude Grande,06,,-4.95,-40.333333
br,fazenda acude velho,Fazenda Açude Velho,06,,-3.6,-39.366667
br,fazenda acudinho,Fazenda Açudinho,06,,-3.483333,-39.266667
br,fazenda agostinho,Fazenda Agostinho,27,,-21.4,-47.55
br,fazenda agua boa,Fazenda Água Boa,06,,-3.466667,-39.3
br,fazenda agua branca,Fazenda Água Branca,06,,-3.866667,-39.766667
br,fazenda agua branca,Fazenda Agua Branca,14,,-16.25,-55.466667
br,fazenda agua branca,Fazenda Água Branca,15,,-16.183333,-41.466667
br,fazenda agua clara,Fazenda Água Clara,11,,-21.9,-54.183333
br,fazenda agua limpa,Fazenda Agua Limpa,11,,-21.716667,-52.666667
br,fazenda agua limpa,Fazenda Agua Limpa,29,,-17.1,-50.116667
br,fazenda agua limpo,Fazenda Agua Limpo,11,,-19.35,-54.7
br,fazenda alavanca,Fazenda Alavanca,11,,-21.55,-54.3
br,fazenda alceu garcia,Fazenda Alceu Garcia,15,,-18.55,-49.183333
br,fazenda alcidio,Fazenda Alcídio,27,,-21.033333,-47.55
br,fazenda aldeia,Fazenda Aldeia,11,,-18.2,-55.166667
br,fazenda alegre,Fazenda Alegre,06,,-4.233333,-40.383333
br,fazenda alegre,Fazenda Alegre,11,,-17.633333,-56.966667
br,fazenda alegre,Fazenda Alegre,14,,-15.247778,-59.833333
br,fazenda alegrete,Fazenda Alegrete,11,,-21.383333,-54.75
br,fazenda alegria,Fazenda Alegria,06,,-3.833333,-39.516667
br,fazenda alianca,Fazenda Aliança,06,,-3.866667,-39.266667
br,fazenda alianca,Fazenda Aliança,11,,-19.05,-55.266667
br,fazenda alivio,Fazenda Alívio,06,,-4.55,-39.033333
br,fazenda alto da copeira,Fazenda Alto da Copeira,20,,-7.083333,-42.233333
br,fazenda amazonas,Fazenda Amazonas,25,,3.366667,-61.383333
br,fazenda amescla,Fazenda Amescla,20,,-5.6,-42.583333
br,fazenda angical,Fazenda Angical,20,,-5.066667,-41.933333
br,fazenda angico,Fazenda Angico,27,,-21.783333,-47.733333
br,fazenda angicos,Fazenda Angicos,06,,-4.316667,-39.566667
br,fazenda angico torto,Fazenda Angico Torto,06,,-3.75,-40.383333
br,fazenda anhumas,Fazenda Anhumas,14,,-16.933333,-54.666667
br,fazenda ano novo,Fazenda Ano Novo,11,,-21.8,-54.15
br,fazenda ano nuevo,Fazenda Ano Nuevo,11,,-21.8,-54.15
br,fazenda antonio bastos,Fazenda Antônio Bastos,23,,-29.983333,-56.883333
br,fazenda antonio,Fazenda Antônio,20,,-6.1,-41.916667
br,fazenda antonio lima,Fazenda Antônio Lima,15,,-17.366667,-40.666667
br,fazenda antonio rocha,Fazenda Antônio Rocha,15,,-17.416667,-41.5
br,fazenda aparecida,Fazenda aparecida,27,,-20.25,-47.8
br,fazenda apertada,Fazenda Apertada,06,,-4.633333,-38.05
br,fazenda aprazivel,Fazenda Aprazível,06,,-4.183333,-40.266667
br,fazenda aqua limpo,Fazenda Aqua Limpo,11,,-19.35,-54.7
br,fazenda aquario,Fazenda Aquário,01,,-9.983333,-67.15
br,fazenda aquiri,Fazenda Aquiri,06,,-4.383333,-40.116667
br,fazenda arapuca,Fazenda Arapuca,14,,-16.316111,-56.558056
br,fazenda arara,Fazenda Arara,01,,-9.916667,-67.45
br,fazenda arara,Fazenda Arara,30,,-7.35,-39.733333
br,fazenda argentina,Fazenda Argentina,27,,-21.85,-47.8
br,fazenda arirao,Fazenda Arirão,06,,-4.3,-39.466667
br,fazenda armador,Fazenda Armador,06,,-3.916667,-39.85
br,fazenda aroeira,Fazenda Aroeira,06,,-3.516667,-39.35
br,fazenda arraia,Fazenda Arraia,06,,-3.766667,-39.883333
br,fazenda arroz,Fazenda Arroz,20,,-7.083333,-41.3
br,fazenda artur,Fazenda Artur,18,,-23.314702,-52.713582
br,fazenda asa os pedra,Fazenda Asa os Pedra,06,,-4.25,-39.016667
br,fazenda atalho,Fazenda Atalho,06,,-3.833333,-40.3
br,fazenda atalho,Fazenda Atalho,21,,-22.55,-42.15
br,fazenda atanacio,Fazenda Atanácio,11,,-21.516667,-54.15
br,fazenda aterradinho,Fazenda Aterradinho,27,,-23.45,-48.566667
br,fazenda aurora,Fazenda Aurora,11,,-19.2,-55.483333
br,fazenda bacuri,Fazenda Bacuri,20,,-5.7,-42.8
br,fazenda baia dos passaros,Fazenda Baia dos Passaros,14,,-16.6,-55.866667
br,fazenda baile,Fazenda Baile,11,,-22.233333,-53.4
br,fazenda baixa dos lucas,Fazenda Baixa dos Lucas,06,,-4.566667,-38.133333
br,fazenda baixa grande,Fazenda Baixa Grande,06,,-3.45,-40.3
br,fazenda baixa grande,Fazenda Baixa Grande,20,,-6,-42.666667
br,fazenda baixao,Fazenda Baixão,27,,-21.366667,-47.483333
br,fazenda balbino dias,Fazenda Balbino Dias,15,,-16.95,-40.716667
br,fazenda balsamo,Fazenda Balsamo,11,,-18.05,-54.05
br,fazenda bandeira,Fazenda Bandeira,27,,-21.883333,-47.666667
br,fazenda barao,Fazenda Barão,27,,-21.7,-46.866667
br,fazenda barbada,Fazenda Barbada,06,,-3.3,-39.85
br,fazenda baronesa,Fazenda Baronesa,06,,-3.583333,-40.216667
br,fazenda barra das tabocas,Fazenda Barra das Tabocas,06,,-3.4,-39.75
br,fazenda barra do jua,Fazenda Barra do Juá,06,,-4.316667,-39.866667
br,fazenda barra do leao,Fazenda Barra do Leão,06,,-4.3,-39.066667
br,fazenda barra do lemos,Fazenda Barra do Lemos,06,,-3.933333,-39.05
br,fazenda barragem,Fazenda Barragem,06,,-3.15,-40.283333
br,fazenda barragem,Fazenda Barragem,30,,-7.966667,-39.833333
br,fazenda barranco alto,Fazenda Barranco Alto,11,,-18.216667,-55.483333
br,fazenda barra nova,Fazenda Barra Nova,06,,-3.983333,-39.35
br,fazenda barreira,Fazenda Barreira,06,,-3.7,-39.716667
br,fazenda barreiro,Fazenda Barreiro,11,,-18.033333,-54.166667
br,fazenda barreiro,Fazenda Barreiro,27,,-22.216667,-47.116667
br,fazenda barrero,Fazenda Barrero,11,,-18.366667,-55.983333
br,fazenda barreto,Fazenda Barreto,06,,-3.866667,-39.083333
br,fazenda barriga,Fazenda Barriga,06,,-3.516667,-39.266667
br,fazenda barrigas,Fazenda Barrigas,06,,-4.55,-39.75
br,fazenda barrinha,Fazenda Barrinha,06,,-4.033333,-39.116667
br,fazenda barro prato,Fazenda Barro Prato,27,,-20.816667,-47.8
br,fazenda barro vermelho,Fazenda Barro Vermelho,06,,-4,-40.016667
br,fazenda batalha,Fazenda Batalha,08,,-21.1,-41.016667
br,fazenda batalho,Fazenda Batalho,08,,-21.1,-41.016667
br,fazenda batatal,Fazenda Batatal,27,,-24.605435,-48.294138
br,fazenda batedor,Fazenda Batedor,06,,-3.483333,-39.85
br,fazenda bebedouro,Fazenda Bebedouro,27,,-20.233333,-47.733333
br,fazenda belas artes,Fazenda Belas Artes,11,,-21.683333,-54.383333
br,fazenda bela vista,Fazenda Bela Vista,15,,-22.05,-46.15
br,fazenda bela vista,Fazenda Bela Vista,23,,-30.933333,-55.7
br,fazenda bela vista,Fazenda Bela Vista,27,,-20.033333,-47.85
br,fazenda belmonte,Fazenda Belmonte,20,,-7.066667,-41.183333
br,fazenda belo horizonte,Fazenda Belo Horizonte,11,,-21.316667,-54.483333
br,fazenda belo horizonte,Fazenda Belo Horizonte,20,,-5.066667,-42.216667
br,fazenda benita,Fazenda Benita,11,,-17.9,-54.583333
br,fazenda benlo,Fazenda Benlo,11,,-17.983333,-54.9
br,fazenda benta,Fazenda Benta,11,,-17.9,-54.583333
br,fazenda betania,Fazenda Betânia,06,,-3.733333,-39.85
br,fazenda betania,Fazenda Betãnia,20,,-7,-42.05
br,fazenda bete,Fazenda Bete,06,,-4.116667,-39.05
br,fazenda beto horizonte,Fazenda Beto Horizonte,06,,-4.366667,-40
br,fazenda boa esperanca,Fazenda Boa Esperanca,06,,-4.383333,-38.266667
br,fazenda boa esperanca,Fazenda Boa Esperanca,30,,-7.766667,-40.166667
br,fazenda boa sorte,Fazenda Bôa Sorte,11,,-21.633333,-57.166667
br,fazenda boa sorte,Fazenda Boa Sorte,14,,-15.077778,-59.874722
br,fazenda boa vista,Fazenda Boa Vista,04,,-9.15,-67.3
br,fazenda boa vista,Fazenda Boa Vista,06,,-3.4,-40.216667
br,fazenda boa vista,Fazenda Bõa Vista,11,,-17.85,-54.216667
br,fazenda boa vista,Fazenda Boa Vista,15,,-17.85,-40.833333
br,fazenda boa vista,Fazenda Boa Vista,20,,-5.483333,-42.166667
br,fazenda boa vista,Fazenda Boa Vista,27,,-20.166667,-47.7
br,fazenda boa vista,Fazenda Boa Vista,30,,-7.933333,-39.716667
br,fazenda bocaina,Fazenda Bocaina,27,,-20.5,-47.716667
br,fazenda bofe,Fazenda Bofe,30,,-7.333333,-39.75
br,fazenda boleri,Fazenda Boleri,11,,-22.616667,-55.583333
br,fazenda bolery,Fazenda Bolery,11,,-22.616667,-55.583333
br,fazenda bom fim,Fazenda Bom Fim,27,,-22.966667,-46.116667
br,fazenda bom futuro,Fazenda Bom Futuro,06,,-3.816667,-40.3
br,fazenda bom jardim,Fazenda Bom Jardim,06,,-4.716667,-38.266667
br,fazenda bom jesus,Fazenda Bom Jesus,14,,-16.343056,-56.913611
br,fazenda bom jesus,Fazenda Bom Jesus,20,,-5.583333,-41.6
br,fazenda bom lugar,Fazenda Bom Lugar,06,,-4.116667,-39.6
br,fazenda bom sucesso,Fazenda Bom sucesso,27,,-21.55,-47.016667
br,fazenda bonanca,Fazenda Bonança,06,,-3.533333,-39.05
br,fazenda bonfim,Fazenda Bonfim,06,,-3.5,-39.783333
br,fazenda bonito,Fazenda Bonito,20,,-5.316667,-42.033333
br,fazenda boqueirao,Fazenda Boqueirão,06,,-4.383333,-40.25
br,fazenda boqueirao,Fazenda Boqueirão,20,,-5.1,-41.55
br,fazenda boquirao,Fazenda Boquirão,20,,-5.033333,-42.133333
br,fazenda borery,Fazenda Borery,11,,-22.616667,-55.583333
br,fazenda brasil,Fazenda Brasil,27,,-21.583333,-46.9
br,fazenda brejao,Fazenda Brejao,11,,-21.666667,-54.6
br,fazenda brilhante,Fazenda Brilhante,11,,-20.5,-54.2
br,fazenda brioso,Fazenda Brioso,11,,-19.483333,-54.5
br,fazenda brito,Fazenda Brito,06,,-3.833333,-39.85
br,fazenda bueno,Fazenda Bueno,06,,-3.616667,-39.85
br,fazenda buriti,Fazenda Burití,11,,-18.25,-54.5
br,fazenda buriti,Fazenda Buriti,14,,-15.383333,-55.833333
br,fazenda buritizinho,Fazenda Buritizinho,20,,-6.083333,-41.966667
br,fazenda burity,Fazenda Burity,14,,-15.383333,-55.833333
br,fazenda cabaceiras,Fazenda Cabaceiras,06,,-4.45,-40.183333
br,fazenda cabeca do bol,Fazenda Cabeça do Bol,06,,-3.866667,-39.833333
br,fazenda cacadas,Fazenda Caçadas,06,,-4.7,-39.066667
br,fazenda cachoeira do umbelino,Fazenda Cachoeira do Umbelino,06,,-4.55,-39.516667
br,fazenda cachoeira,Fazenda Cachoeira,06,,-3.65,-40.366667
br,fazenda cachoeira,Fazenda Cachoeira,11,,-19.55,-54.583333
br,fazenda cachoeira,Fazenda Cachoeira,14,,-15.9,-58.366667
br,fazenda cachoeira,Fazenda Cachoeira,15,,-20.666667,-45.3
br,fazenda cachoeira,Fazenda Cachoeira,27,,-20.2,-47.416667
br,fazenda cachoeirinha,Fazenda Cachoeirinha,06,,-3.683333,-39.816667
br,fazenda cachoeirinha,Fazenda Cachoeirinha,11,,-18.166667,-54.25
br,fazenda cachoeirinha,Fazenda Cachoeirinha,24,,-10.268056,-62.698611
br,fazenda cachoeirinha,Fazenda Cachoeirinha,27,,-21.666667,-47.533333
br,fazenda cacimba de cima,Fazenda Cacimba de Cima,06,,-4.033333,-39.316667
br,fazenda cacimba,Fazenda Cacimba,06,,-3.733333,-39.383333
br,fazenda cacimba funda,Fazenda Cacimba Funda,06,,-3.95,-39.583333
br,fazenda cacimba salgada,Fazenda Cacimba Salgada,06,,-3.766667,-39.833333
br,fazenda cacimbas,Fazenda Cacimbas,20,,-5.033333,-42.083333
br,fazenda cacimbinha,Fazenda Cacimbinha,06,,-3.45,-40.383333
br,fazenda cadro,Fazenda Cadro,06,,-3.783333,-39.1
br,fazenda cafe,Fazenda Café,27,,-20.45,-47.8
br,fazenda cafundo,Fazenda Cafundó,06,,-6.083333,-39.516667
br,fazenda caicara,Fazenda Caiçara,06,,-4.8,-39.8
br,fazenda caicarinha,Fazenda Caiçarinha,06,,-3.95,-39.833333
br,fazenda cajazeira,Fazenda Cajazeira,06,,-3.116667,-39.916667
br,fazenda cajazeira,Fazenda Cajazeira,24,,-10.091667,-62.969444
br,fazenda cajazeiras,Fazenda Cajazeiras,06,,-3.733333,-40.183333
br,fazenda cajueiro grande,Fazenda Cajueiro Grande,06,,-3.15,-39.95
br,fazenda cajui,Fazenda Cajuí,06,,-7.05,-39.066667
br,fazenda calabria,Fazenda Calábria,06,,-4.1,-39.083333
br,fazenda calcadinho,Fazenda Calcadinho,20,,-7.183333,-42.85
br,fazenda caldeirao,Fazenda Caldeirão,20,,-7.3,-41.133333
br,fazenda california,Fazenda Califórnia,27,,-21.65,-47.483333
br,fazenda calumbi,Fazenda Calumbi,20,,-5.433333,-41.916667
br,fazenda caminhadeira,Fazenda Caminhadeira,06,,-3.983333,-39.883333
br,fazenda campeira,Fazenda Campeira,13,,-9.492222,-45.931389
br,fazenda campestre,Fazenda Campestre,06,,-4.8,-39.016667
br,fazenda campina,Fazenda Campina,06,,-4.566667,-40.183333
br,fazenda campinas,Fazenda Campinas,06,,-3.766667,-39.716667
br,fazenda campinho,Fazenda Campinho,27,,-20.7,-47.716667
br,fazenda campo alegre,Fazenda Campo Alegre,11,,-19.766667,-55.016667
br,fazenda campo alegre,Fazenda Campo Alegre,14,,-16.116667,-58.05
br,fazenda campo alegre,Fazenda Campo Alegre,27,,-21.05,-47.866667
br,fazenda campo limpo,Fazenda Campo Limpo,11,,-17.933333,-54.633333
br,fazenda campo lindo,Fazenda Campo Lindo,20,,-7.9,-40.85
br,fazenda canaa,Fazenda Canaã,20,,-6,-41.95
br,fazenda canabrava,Fazenda Canabrava,06,,-4.75,-40.2
br,fazenda cana brava,Fazenda Cana Brava,06,,-6.983333,-39.55
br,fazenda canafistula,Fazenda Canafistula,06,,-3.4,-40.1
br,fazenda canafistula,Fazenda Canafistula,30,,-7.383333,-39.633333
br,fazenda cangalha,Fazenda Cangalha,11,,-19.55,-52.8
br,fazenda canto alegre,Fazenda Canto Alegre,20,,-5,-42.25
br,fazenda capao alto,Fazenda capão Alto,11,,-18.9,-54.866667
br,fazenda capao bonito,Fazenda Capão Bonito,11,,-21.366667,-54.4
br,fazenda capao da cruz,Fazenda capão da Cruz,27,,-21.433333,-47.9
br,fazenda capao seco,Fazenda Capão Seco,27,,-20.833333,-47.783333
br,fazenda capao verde,Fazenda Capão Verde,14,,-16.134444,-56.746111
br,fazenda capela,Fazenda Capela,11,,-20.466667,-56.383333
br,fazenda capella,Fazenda Capella,11,,-20.466667,-56.383333
br,fazenda capim acu,Fazenda Capim Açu,06,,-3.7,-39.766667
br,fazenda capim grande,Fazenda Capim Grande,20,,-7.483333,-40.833333
br,fazenda capim grosso,Fazenda Capim Grosso,30,,-7.916667,-40.1
br,fazenda capivari,Fazenda Capivari,27,,-23.939,-46.6811
br,fazenda cara,Fazenda Cara,06,,-3.816667,-39.45
br,fazenda caraibas,Fazenda Caraibas,20,,-5.483333,-42.4
br,fazenda caraibas,Fazenda Caraibas,30,,-7.966667,-40.116667
br,fazenda carao,Fazenda Carão,06,,-3.316667,-40.383333
br,fazenda cararu,Fazenda Cararu,06,,-3.783333,-38.883333
br,fazenda carauba,Fazenda Caraúba,06,,-3.333333,-39.983333
br,fazenda caraubas,Fazenda Caraúbas,06,,-4.083333,-39.5
br,fazenda carima,Fazenda Carima,06,,-4.483333,-40.433333
br,fazenda carius,Fazenda Cariús,06,,-4.483333,-38.166667
br,fazenda carlos lobato,Fazenda Carlos Lobato,15,,-20.05,-45.583333
br,fazenda carnaiba,Fazenda Carnaiba,20,,-5.7,-42.1
br,fazenda carnauba,Fazenda Carnaúba,06,,-3.816667,-39.3
br,fazenda carnaubinha,Fazenda Carnaubinha,06,,-4.216667,-39.983333
br,fazenda carneiro,Fazenda Carneiro,06,,-4.2,-39.033333
br,fazenda carreiras,Fazenda Carreiras,06,,-4.2,-40.233333
br,fazenda caruaru,Fazenda Caruaru,06,,-4.116667,-40.333333
br,fazenda casa de pedra,Fazenda Casa de Pedra,06,,-3.75,-39.066667
br,fazenda casa nova,Fazenda Casa Nova,06,,-4.25,-39.133333
br,fazenda casa nova,Fazenda Casa Nova,20,,-7.75,-42.8
br,fazenda cascavel,Fazenda Cascavel,06,,-4.516667,-40.45
br,fazenda casinha,Fazenda Casinha,06,,-3.666667,-40.083333
br,fazenda castanheiro,Fazenda Castanheiro,20,,-7.583333,-42.083333
br,fazenda castro,Fazenda Castro,06,,-4.766667,-39.366667
br,fazenda catalao,Fazenda Catalão,06,,-4.45,-38.266667
br,fazenda catuana,Fazenda Catuana,06,,-4.633333,-40.2
br,fazenda caua,Fazenda Cauã,06,,-3.833333,-39.65
br,fazenda central,Fazenda Central,06,,-4.9,-39.5
br,fazenda cervo,Fazenda Cervo,11,,-21.683333,-54.966667
br,fazenda chagu,Fazenda Chagu,18,,-25.366667,-52.583333
br,fazenda chaparral,Fazenda Chaparral,04,,-9.066667,-67.25
br,fazenda chapena,Fazenda chapena,11,,-20.466667,-56.383333
br,fazenda chapeu,Fazenda Chapéu,06,,-4.883333,-39.35
br,fazenda chaves,Fazenda Chaves,06,,-4.266667,-38.483333
br,fazenda chupeiro,Fazenda Chupeiro,20,,-7.5,-40.866667
br,fazenda cidade,Fazenda Cidade,06,,-3.916667,-39.866667
br,fazenda cipo,Fazenda Cipó,06,,-3.916667,-39.2
br,fazenda coite,Fazenda Coité,06,,-3.616667,-38.783333
br,fazenda colombia,Fazenda Colômbia,27,,-21.883333,-47.85
br,fazenda conceicao,Fazenda Conceição,06,,-3.5,-39.4
br,fazenda conceicao,Fazenda Conceição,15,,-16.416667,-40.633333
br,fazenda conceicao,Fazenda Conceição,27,,-21.5,-46.766667
br,fazenda constanca,Fazenda Constança,27,,-21.383333,-46.8
br,fazenda consulta,Fazenda Consulta,06,,-3.833333,-39.666667
br,fazenda contenda,Fazenda Contenda,06,,-4.933333,-38.583333
br,fazenda contentes,Fazenda Contentes,22,,-4.983333,-37.316667
br,fazenda coqueiros,Fazenda Coqueiros,21,,-22.873016,-43.491258
br,fazenda coqueiros,Fazenda Coqueiros,27,,-21,-47.833333
br,fazenda corixao,Fazenda Corixão,11,,-18.333333,-56.533333
br,fazenda correa,Fazenda Corrêa,14,,-16.8,-53.05
br,fazenda corrente,Fazenda Corrente,06,,-4.116667,-39.966667
br,fazenda criacao de aporema,Fazenda Criação de Aporema,03,,1.2,-50.883333
br,fazenda crianco,Fazenda Criancó,06,,-4.283333,-38.6
br,fazenda criolinhas,Fazenda Criolinhas,06,,-3.2,-39.583333
br,fazenda cristal,Fazenda Cristal,11,,-21.5,-54.366667
br,fazenda cristino,Fazenda Cristino,11,,-22.05,-52.75
br,fazenda cruz alta,Fazenda Cruz Alta,11,,-19.066667,-55.566667
br,fazenda cruzeiro,Fazenda Cruzeiro,27,,-20.7,-47.333333
br,fazenda cuiaba,Fazenda Cuiabá,27,,-22.3,-52.1
br,fazenda cupim,Fazenda Cupim,06,,-4.666667,-39.833333
br,fazenda curiango,Fazenda Curiango,15,,-16.166667,-40.65
br,fazenda curicaca,Fazenda Curicaca,06,,-3.816667,-40.483333
br,fazenda curral de pedra,Fazenda Curral de Pedra,27,,-20.216667,-47.566667
br,fazenda curralinho,Fazenda Curralinho,11,,-21.383333,-54.766667
br,fazenda curralinho,Fazenda Curralinho,18,,-24.433333,-50.05
br,fazenda curral velho,Fazenda Curral Velho,06,,-3.483333,-39.233333
br,fazenda currupati,Fazenda Currupati,06,,-4.6,-38.9
br,fazenda curu,Fazenda Curu,06,,-3.816667,-39.333333
br,fazenda da aldeia,Fazenda da Aldeia,11,,-18.2,-55.166667
br,fazenda da alianca,Fazenda da Aliança,27,,-20.5,-47.316667
br,fazenda da baia do felix,Fazenda da Baía do Felix,14,,-16.466667,-55.933333
br,fazenda da baia dos passaros,Fazenda da Baía dos Pássaros,14,,-16.6,-55.866667
br,fazenda da baia sao folis,Fazenda da Baia São Folis,14,,-16.466667,-55.933333
br,fazenda da bandeirinha,Fazenda da Bandeirinha,15,,-21.05,-45.4
br,fazenda da barra,Fazenda da Barra,11,,-21.316667,-53.083333
br,fazenda da barra,Fazenda da Barra,15,,-18.45,-47.716667
br,fazenda da bica,Fazenda da Bica,21,,-22.891621,-43.332845
br,fazenda da boa sorte,Fazenda da Boa Sorte,11,,-21.633333,-57.166667
br,fazenda da bocaina,Fazenda da Bocaina,15,,-21.4,-45.033333
br,fazenda da capoeira grande,Fazenda da Capoeira Grande,15,,-16.533333,-41.3
br,fazenda da conceicao,Fazenda da Conceição,11,,-20.833333,-55.783333
br,fazenda da concordia,Fazenda da Concórdia,27,,-20.483333,-47.35
br,fazenda da corixa,Fazenda da Corixa,14,,-16.466667,-55.666667
br,fazenda da estrela,Fazenda da Estrela,14,,-16.283333,-53.566667
br,fazenda da faiza,Fazenda da Faiza,06,,-3.716667,-39.266667
br,fazenda da galha,Fazenda da Galha,15,,-16.1,-40.133333
br,fazenda da ilha,Fazenda da Ilha,11,,-18.483333,-56.416667
br,fazenda da lagoa,Fazenda da Lagoa,20,,-7.683333,-42.716667
br,fazenda da lagoinha,Fazenda da Lagoinha,11,,-20.716667,-54.766667
br,fazenda da mata,Fazenda da Mata,08,,-20.633333,-41.383333
br,fazenda da mata,Fazenda da Mata,14,,-17.033333,-53.9
br,fazenda da matta,Fazenda da Matta,14,,-17.033333,-53.9
br,fazenda da mazela,Fazenda da Mazela,15,,-16.066667,-41.666667
br,fazenda da moata,Fazenda da Moata,14,,-17.033333,-53.9
br,fazenda da pedra,Fazenda da Pedra,27,,-21.2,-47.616667
br,fazenda da ponte,Fazenda da Ponte,15,,-19.3,-44.4
br,fazenda da prata,Fazenda da Prata,27,,-20.283333,-47.866667
br,fazenda da serra,Fazenda da Serra,27,,-21.366667,-47.216667
br,fazenda das palmeiras,Fazenda das Palmeiras,11,,-18.966667,-57.066667
br,fazenda das pedras,Fazenda das Pedras,27,,-23.466667,-45.9
br,fazenda das pombas,Fazenda das Pombas,20,,-7.433333,-40.866667
br,fazenda das violas,Fazenda das Violas,18,,-25.269167,-50.407222
br,fazenda de affonso,Fazenda de Affonso,14,,-14.5,-57
br,fazenda de antonio carmo,Fazenda de Antônio Carmo,15,,-17.266667,-41.916667
br,fazenda de baixo,Fazenda de Baixo,02,,-9.35,-37.066667
br,fazenda de cima,Fazenda de Cima,14,,-15.933333,-56.616667
br,fazenda de dentro,Fazenda de Dentro,05,,-10.2,-38.133333
br,fazenda de fora,Fazenda de Fora,05,,-9.666667,-41.716667
br,fazenda degredo,Fazenda Degredo,20,,-7.433333,-42.3
br,fazenda delicia,Fazenda Delícia,06,,-3.883333,-40.483333
br,fazenda de mosta,Fazenda de Mosta,14,,-17.033333,-53.9
br,fazenda desterro,Fazenda Desterro,06,,-4.066667,-39.1
br,fazenda d. francesa,Fazenda D. Francesa,15,,-16.033333,-39.95
br,fazenda divino,Fazenda Divino,11,,-18.75,-55.483333
br,fazenda divisa,Fazenda Divisa,11,,-21.5,-54.666667
br,fazenda do amazonas,Fazenda do Amazonas,25,,3.366667,-61.383333
br,fazenda do arranca dento,Fazenda do Arranca Dento,15,,-16.166667,-40.983333
br,fazenda do balbino,Fazenda do Balbino,15,,-16.233333,-40.483333
br,fazenda do balsamo,Fazenda do Bálsamo,27,,-20.3,-47.3
br,fazenda do banco,Fazenda do Banco,27,,-23.473005,-47.969966
br,fazenda do barata,Fazenda do Barata,21,,-22.901853,-43.444829
br,fazenda do barranca vermelha,Fazenda do Barranca Vermelha,11,,-19.933333,-56.766667
br,fazenda do barranca vermelho,Fazenda do Barranca Vermelho,11,,-19.933333,-56.766667
br,fazenda do barreiro,Fazenda do Barreiro,15,,-16.283333,-41.183333
br,fazenda do brejao,Fazenda do Brejão,27,,-21.633333,-46.866667
br,fazenda do caete,Fazenda do Caeté,14,,-15.85,-58.283333
br,fazenda do caethe,Fazenda do Caethé,14,,-15.85,-58.283333
br,fazenda do campeiro,Fazenda do Campeiro,11,,-21.183333,-54.75
br,fazenda do campo,Fazenda do Campo,27,,-21.383333,-47.05
br,fazenda do canal,Fazenda do Canal,05,,-11.35,-41.666667
br,fazenda do carlos,Fazenda do Carlos,06,,-3.933333,-39.6
br,fazenda do caxitore,Fazenda do Caxitoré,06,,-3.816667,-39.5
br,fazenda do corregozinho,Fazenda do Còrregozinho,15,,-20.166667,-45.266667
br,fazenda do engenho,Fazenda do Engenho,27,,-24.665705,-48.925795
br,fazenda do fundo,Fazenda do Fundo,15,,-20.333333,-45.966667
br,fazenda dois irmaos,Fazenda Dois Irmãos,01,,-9.816667,-67.416667
br,fazenda dois mil rels,Fazenda Dois Mil Rels,11,,-18.4,-55.866667
br,fazenda do japao,Fazenda do Japão,27,,-20.383333,-47.566667
br,fazenda do jardin,Fazenda do Jardin,15,,-21.833333,-46.083333
br,fazenda do jatoba,Fazenda do Jatobá,11,,-20.05,-55.966667
br,fazenda do macaco,Fazenda do Macaco,11,,-19.116667,-54.25
br,fazenda do mari,Fazenda do Mari,06,,-4.95,-38.05
br,fazenda do meio,Fazenda do Meio,20,,-8.4,-44.7
br,fazenda do melado,Fazenda do Melado,27,,-20.783333,-47.816667
br,fazenda do morias,Fazenda do Morias,14,,-17.516667,-55.083333
br,fazenda do morrinho,Fazenda do Morrinho,14,,-16.283333,-55.7
br,fazenda dona candida,Fazenda Dona Cândida,27,,-21.416667,-46.883333
br,fazenda dona josepha,Fazenda Dona Josepha,11,,-21.4,-54.366667
br,fazenda do paraiso,Fazenda do Paraíso,14,,-17.616667,-55.166667
br,fazenda do pires,Fazenda do Pires,27,,-22.133333,-47.233333
br,fazenda do rio das pedras,Fazenda do Rio das Pedras,27,,-22.183333,-47.016667
br,fazenda do rio nova,Fazenda do Rio Nova,11,,-21.333333,-56.75
br,fazenda do rio novo,Fazenda do Rio Novo,11,,-21.333333,-56.75
br,fazenda do salto,Fazenda do Salto,11,,-20.583333,-54.683333
br,fazenda dos barrosos,Fazenda dos Barrosos,06,,-3.633333,-39.15
br,fazenda dos palmares,Fazenda dos Palmares,15,,-16.333333,-40.766667
br,fazenda dos prazeres,Fazenda dos Prazeres,15,,-17.816667,-41.6
br,fazenda dos quincas-tua,Fazenda dos Quincas-Tua,15,,-16.133333,-40.283333
br,fazenda do tabuleiro,Fazenda do Tabuleiro,20,,-7.05,-42.2
br,fazenda do trapia,Fazenda do Trapiá,06,,-4.75,-40.366667
br,fazenda douradinho,Fazenda Douradinho,11,,-21.583333,-53.266667
br,fazenda dourados,Fazenda Dourados,27,,-20.65,-47.716667
br,fazenda dutra,Fazenda Dutra,27,,-21.85,-47.566667
br,fazenda eduardo,Fazenda Eduardo,15,,-20.683333,-45.2
br,fazenda emerenciano borges,Fazenda Emerenciano Borges,15,,-16.9,-41.65
br,fazenda encantado,Fazenda Encantado,06,,-3.766667,-39.333333
br,fazenda entre rios,Fazenda Entre Rios,11,,-19.366667,-54.15
br,fazenda escaramuca,Fazenda Escaramuça,27,,-20.733333,-47.683333
br,fazenda espera,Fazenda Espera,06,,-3.683333,-39.05
br,fazenda esperanca,Fazenda Esperança,06,,-3.483333,-39.416667
br,fazenda esperanca,Fazenda Esperança,11,,-17.966667,-54.466667
br,fazenda esperantina,Fazenda Esperantina,06,,-3.233333,-40.466667
br,fazenda espinheiro,Fazenda Espinheiro,06,,-4.783333,-39.633333
br,fazenda espirito santo,Fazenda Espírito Santo,04,,-9.266667,-67.016667
br,fazenda espirito santo,Fazenda Espírito Santo,06,,-4.933333,-39.05
br,fazenda estaca,Fazenda Estaca,11,,-20.3,-54.533333
br,fazenda estiva,Fazenda Estiva,06,,-3.966667,-40.05
br,fazenda estreito,Fazenda Estreito,11,,-21.45,-54.65
br,fazenda estreito,Fazenda Estreito,20,,-7.016667,-42
br,fazenda estrela d'oeste,Fazenda Estrela d'Oeste,27,,-21.433333,-47.716667
br,fazenda estrela,Fazenda Estrêla,06,,-4.8,-38.183333
br,fazenda estrela,Fazenda Estrela,11,,-18.4,-53.6
br,fazenda estrella,Fazenda Estrella,14,,-16.283333,-53.566667
br,fazenda eucalipto,Fazenda Eucalipto,30,,-7.416667,-40.383333
br,fazenda extrema,Fazenda Extrema,06,,-3.583333,-39.966667
br,fazenda extremas,Fazenda Extremas,06,,-3.966667,-39.4
br,fazenda famosa,Fazenda Famosa,06,,-3.75,-39.283333
br,fazenda faustina,Fazenda Faustina,06,,-7.05,-39.166667
br,fazenda fechado,Fazenda Fechado,06,,-4.016667,-39.55
br,fazenda feijao,Fazenda Feijão,06,,-3.6,-39.016667
br,fazenda feijiao bravo,Fazenda Feijião Bravo,06,,-4.6,-38.233333
br,fazenda felicio,Fazenda Felício,15,,-16.433333,-40.233333
br,fazenda ferino,Fazenda Ferino,06,,-3.633333,-39.783333
br,fazenda ferrao,Fazenda Ferrão,06,,-3.716667,-39.916667
br,fazenda ferrugem,Fazenda Ferrugem,06,,-3.1,-39.85
br,fazenda fialho,Fazenda Fialho,23,,-29.7756,-50.908
br,fazenda fidelis,Fazenda Fidélis,06,,-4.116667,-39.8
br,fazenda figueira branca,Fazenda Figueira Branca,27,,-21.75,-47.766667
br,fazenda figueira,Fazenda Figueira,11,,-17.666667,-56.85
br,fazenda firme,Fazenda Firme,11,,-19.266667,-57.016667
br,fazenda flamengo,Fazenda Flamengo,06,,-3.933333,-40.35
br,fazenda flor da amescla,Fazenda Flor da Amescla,20,,-5.433333,-41.916667
br,fazenda flores,Fazenda Flores,06,,-4.25,-40.3
br,fazenda floresta,Fazenda Floresta,27,,-20.55,-47.95
br,fazenda fofa,Fazenda Fofa,06,,-3.85,-39.266667
br,fazenda formiga,Fazenda Formiga,11,,-21.3,-54.433333
br,fazenda formosa,Fazenda Formosa,14,,-15.065,-59.875
br,fazenda formosa,Fazenda Formosa,20,,-7.3,-41.15
br,fazenda formosa,Fazenda Formosa,27,,-24.538931,-48.092747
br,fazenda forquilha,Fazenda Forquilha,06,,-6.566667,-39.966667
br,fazenda forquilha,Fazenda Forquilha,11,,-21.566667,-53.616667
br,fazenda forquima,Fazenda Forquima,06,,-3.566667,-39.916667
br,fazenda fortaleza,Fazenda Fortaleza,11,,-18.55,-54.766667
br,fazenda frade,Fazenda Frade,20,,-6.983333,-41.916667
br,fazenda franquilino marques,Fazenda Franquilino Marques,15,,-16.533333,-41.766667
br,fazenda frio,Fazenda Frio,06,,-3.666667,-39.266667
br,fazenda furnas,Fazenda Furnas,06,,-4.316667,-39.133333
br,fazenda galiza,Fazenda Galiza,20,,-7.583333,-40.85
br,fazenda gameleira,Fazenda Gameleira,11,,-20.616667,-54.633333
br,fazenda gameleira,Fazenda Gameleira,14,,-14.830556,-59.801389
br,fazenda gangorra,Fazenda Gangorra,06,,-4.25,-40
br,fazenda gangorrinha,Fazenda Gangorrinha,15,,-17.166667,-41.7
br,fazenda gaviao,Fazenda Gavião,06,,-3.533333,-39.383333
br,fazenda gemeleira,Fazenda Gemeleira,06,,-4.683333,-37.583333
br,fazenda gomalina,Fazenda Gomalina,14,,-15.816667,-59.802778
br,fazenda goncalinho,Fazenda Goncalinho,13,,-6.766667,-43.383333
br,fazenda goncalves,Fazenda Gonçalves,27,,-20.266667,-47.616667
br,fazenda gondim,Fazenda Gondim,06,,-4.783333,-38.25
br,fazenda grande,Fazenda Grande,05,,-11.866667,-43.333333
br,fazenda grossos,Fazenda Grossos,06,,-4.533333,-39.15
br,fazenda grupiara,Fazenda Grupiara,15,,-17.083333,-41.9
br,fazenda gueda,Fazenda Gueda,11,,-18.883333,-55.65
br,fazenda gurupa,Fazenda Gurupa,06,,-4.5,-39.083333
br,fazenda henrique rocha,Fazenda Henrique Rocha,15,,-16.716667,-41.816667
br,fazenda hermes silva,Fazenda Hermes Silva,15,,-18.333333,-41.766667
br,fazenda ibitira,Fazenda Ibitira,27,,-21.85,-47.633333
br,fazenda ilidio rocha,Fazenda Ilídio Rocha,11,,-19.6,-55.033333
br,fazenda imbirussu,Fazenda Imbirussú,11,,-20.6,-54.75
br,fazenda inez,Fazenda Inêz,06,,-3.483333,-40.25
br,fazenda inga,Fazenda Ingá,06,,-4.25,-39.533333
br,fazenda inga,Fazenda Ingá,20,,-5.183333,-41.5
br,fazenda inhare,Fazenda Inharé,06,,-3.983333,-39.3
br,fazenda inhuma,Fazenda Inhuma,13,,-8.746667,-45.968889
br,fazenda invejada,Fazenda Invejada,20,,-5.35,-42.266667
br,fazenda ipe,Fazenda Ipê,01,,-9.833333,-67.433333
br,fazenda ipiranga,Fazenda Ipiranga,06,,-3.766667,-40.283333
br,fazenda ipiranga,Fazenda Ipiranga,27,,-21.8,-47.7
br,fazenda ipueira da areia,Fazenda Ipueira da Areia,06,,-4.483333,-39.133333
br,fazenda ipueira da pedra,Fazenda Ipueira da Pedra,06,,-4.85,-39.75
br,fazenda ipueira da vaca,Fazenda Ipueira da Vaca,06,,-4.55,-39.233333
br,fazenda ipueiras,Fazenda Ipueiras,06,,-3.266667,-40.35
br,fazenda ipueirinha,Fazenda Ipueirinha,06,,-4.983333,-39.55
br,fazenda iracema,Fazenda Iracema,06,,-4.466667,-38.35
br,fazenda itataia,Fazenda Itataia,06,,-4.583333,-39.8
br,fazenda ivai,Fazenda Ivaí,18,,-23.066667,-52.466667
br,fazenda jaburu,Fazenda Jaburu,06,,-3.816667,-39.35
br,fazenda jaburu,Fazenda Jaburu,14,,-16.137222,-56.991944
br,fazenda jabuta,Fazenda Jabuta,20,,-6.683333,-42.3
br,fazenda jacare,Fazenda Jacaré,20,,-5.35,-42.033333
br,fazenda jacutinga,Fazenda Jacutinga,15,,-16.616667,-40.933333
br,fazenda jaguarandi,Fazenda Jaguarandí,27,,-21.85,-47.7
br,fazenda jandira,Fazenda Jandira,06,,-4,-39.083333
br,fazenda japonesa,Fazenda Japonesa,06,,-4.416667,-38.716667
br,fazenda jatoba,Fazenda Jatobá,06,,-3.9,-40.083333
br,fazenda jatoba,Fazenda Jatobá,11,,-20.05,-55.966667
br,fazenda jau,Fazenda Jaú,11,,-20.983333,-55.133333
br,fazenda jauru,Fazenda Jaurú,11,,-21.666667,-53.833333
br,fazenda joao gil,Fazenda João Gil,15,,-16.35,-41.5
br,fazenda joao gualberto,Fazenda João Gualberto,15,,-17.233333,-40.733333
br,fazenda joao pereira,Fazenda João Pereira,06,,-3.883333,-39.966667
br,fazenda joaquim nogueira,Fazenda Joaquim Nogueira,15,,-17.8,-40.8
br,fazenda jocelin bitencourt,Fazenda Jocelin Bitencourt,11,,-21.5,-54.266667
br,fazenda jori,Fazenda Jori,06,,-4.366667,-38.45
br,fazenda jose antonio,Fazenda José Antônio,15,,-16.25,-39.933333
br,fazenda jose bravo,Fazenda José Bravo,15,,-17.066667,-41.116667
br,fazenda jose mendes,Fazenda José Mendes,15,,-17.95,-41.7
br,fazenda jose nino,Fazenda José Nino,11,,-19.683333,-53.75
br,fazenda jose quito,Fazenda José Quito,14,,-17.966667,-53.683333
br,fazenda jose ramos,Fazenda José Ramos,15,,-18.383333,-41.416667
br,fazenda jose rosa,Fazenda José Rosa,27,,-21.4,-47.133333
br,fazenda jua,Fazenda Juá,06,,-4.283333,-39.95
br,fazenda juca,Fazenda Jucá,06,,-3.333333,-40.35
br,fazenda juliao,Fazenda Julião,06,,-3.616667,-40.366667
br,fazenda juliao,Fazenda Julião,30,,-7.916667,-40.316667
br,fazenda juncal,Fazenda Juncal,06,,-3.45,-39.75
br,fazenda junco,Fazenda Junco,06,,-3.866667,-39.716667
br,fazenda jurema,Fazenda Jurema,06,,-3.95,-39.183333
br,fazenda jurema,Fazenda Jurema,20,,-5.433333,-42.15
br,fazenda jurujuba,Fazenda Jurujuba,06,,-4.383333,-40.066667
br,fazenda juventino rocha,Fazenda Juventino Rocha,15,,-17.95,-40.383333
br,fazenda lacerda,Fazenda Lacerda,27,,-21.966667,-47.833333
br,fazenda ladeira vermelha,Fazenda Ladeira Vermelha,06,,-3.316667,-40.3
br,fazenda lageado,Fazenda Lageado,11,,-20.95,-54.783333
br,fazenda lageado,Fazenda Lageado,27,,-21.966667,-47.716667
br,fazenda lagoa achada,Fazenda Lagoa Achada,06,,-4.45,-38.1
br,fazenda lagoa cercada,Fazenda Lagoa Cercada,06,,-3.8,-39.733333
br,fazenda lagoa da cruz,Fazenda Lagoa da Cruz,06,,-3.766667,-39.133333
br,fazenda lagoa da onca,Fazenda Lagoa da Onca,06,,-4.116667,-40.3
br,fazenda lagoa da vereda,Fazenda Lagoa da Vereda,20,,-7.783333,-42.983333
br,fazenda lagoa de dentro,Fazenda Lagoa de Dentro,06,,-3.816667,-39.383333
br,fazenda lagoa de pedra,Fazenda Lagoa de Pedra,06,,-3.9,-40.433333
br,fazenda lagoa desalsa,Fazenda Lagoa Desalsa,22,,-4.85,-37.283333
br,fazenda lagoa do barro,Fazenda Lagoa do Barro,20,,-5.183333,-41.616667
br,fazenda lagoa do felix,Fazenda Lagoa do Félix,06,,-3.816667,-39.133333
br,fazenda lagoa do mato,Fazenda Lagoa do Mato,06,,-3.583333,-39.083333
br,fazenda lagoa do mato,Fazenda Lagoa do Mato,20,,-7.95,-42.783333
br,fazenda lagoa do porco,Fazenda Lagoa do Porco,06,,-4.766667,-39.683333
br,fazenda lagoa dos bois,Fazenda Lagoa dos Bois,06,,-4.85,-39.366667
br,fazenda lagoa dos mouras,Fazenda Lagoa dos Mouras,20,,-5.883333,-42.083333
br,fazenda lagoa dos pintos,Fazenda Lagoa dos Pintos,06,,-3.5,-39.316667
br,fazenda lagoa do trapia,Fazenda Lagoa do Trapiá,06,,-4.583333,-39.966667
br,fazenda lagoa nova,Fazenda Lagoa Nova,06,,-4.416667,-38.433333
br,fazenda lagoa queimada,Fazenda Lagoa Queimada,06,,-3.7,-39.216667
br,fazenda lagoa tapada,Fazenda Lagoa Tapada,06,,-4.833333,-40.433333
br,fazenda lagoa verde,Fazenda Lagoa Verde,06,,-4.55,-39.283333
br,fazenda lagoinha,Fazenda Lagoinha,06,,-3.716667,-39.65
br,fazenda lajeado,Fazenda Lajeado,11,,-20.95,-54.783333
br,fazenda lajes,Fazenda Lajes,06,,-3.933333,-39.383333
br,fazenda lajes,Fazenda Lajes,20,,-6.05,-41.933333
br,fazenda lama podre,Fazenda Lama Podre,06,,-7.2,-39.583333
br,fazenda lama preta,Fazenda Lama Preta,21,,-22.866028,-43.659774
br,fazenda lameiro,Fazenda Lameiro,06,,-7.15,-39.166667
br,fazenda lanceiro,Fazenda Lanceiro,11,,-20.983333,-53.716667
br,fazenda latada,Fazenda Latada,06,,-3.55,-40.016667
br,fazenda laura,Fazenda Laura,06,,-3.816667,-39.583333
br,fazenda lava pes,Fazenda Lava Pés,15,,-17.2,-41.816667
br,fazenda lavorinha,Fazenda Lavorinha,27,,-20.166667,-47.633333
br,fazenda lavrinha,Fazenda Lavrinha,18,,-24.716667,-50.133333
br,fazenda lazaro,Fazenda Lázaro,06,,-4.9,-39.783333
br,fazenda limeira,Fazenda Limeira,27,,-20.95,-47.916667
br,fazenda limoeiro,Fazenda Limoeiro,11,,-21.666667,-54.15
br,fazenda limoeiro,Fazenda Limoeiro,27,,-21.566667,-47.7
br,fazenda linda,Fazenda Linda,06,,-4.583333,-39.6
br,fazenda livramento,Fazenda Livramento,06,,-3.7,-39.383333
br,fazenda lobo,Fazenda Lôbo,14,,-17.766667,-53.783333
br,fazenda lunarda,Fazenda Lunarda,20,,-5.233333,-41.55
br,fazenda lundu,Fazenda Lundu,06,,-3.566667,-39.783333
br,fazenda luzitania,Fazenda Luzitania,11,,-18.416667,-55.783333
br,fazenda macaco,Fazenda Macaco,06,,-3.683333,-39.866667
br,fazenda macaco,Fazenda Macaco,11,,-19.116667,-54.25
br,fazenda macambira,Fazenda Macambira,06,,-4.616667,-39
br,fazenda macapa,Fazenda Macapá,06,,-4.05,-40.016667
br,fazenda macaubas,Fazenda Macaúbas,27,,-21.666667,-46.966667
br,fazenda madrigal,Fazenda Madrigal,20,,-7.166667,-42.516667
br,fazenda madrilha,Fazenda Madrilha,20,,-7.1,-42.45
br,fazenda malhada bonita,Fazenda Malhada Bonita,20,,-7.583333,-40.9
br,fazenda malhada do pau branco,Fazenda Malhada do Pau Branco,06,,-4.966667,-39.9
br,fazenda malhada vermelha,Fazenda Malhada Vermelha,20,,-7.166667,-42.016667
br,fazenda malhadinha,Fazenda Malhadinha,20,,-7.533333,-41.116667
br,fazenda maloca,Fazenda Maloca,01,,-9.75,-67.366667
br,fazenda mamueira,Fazenda Mamueira,20,,-5.583333,-42.616667
br,fazenda mandacaru,Fazenda Mandacaru,06,,-3.833333,-39.783333
br,fazenda mandibira,Fazenda Mandibira,06,,-7.3,-39.616667
br,fazenda manuino,Fazenda Manuíno,30,,-7.733333,-40.1
br,fazenda maraba,Fazenda Maraba,27,,-22.1,-51.933333
br,fazenda maracata,Fazenda Maracatá,06,,-3.933333,-39.55
br,fazenda maracuja,Fazenda Maracujá,06,,-4.683333,-39.733333
br,fazenda maraja,Fazenda Marajá,06,,-4.533333,-40.45
br,fazenda marajo,Fazenda Marajó,06,,-4.65,-39.066667
br,fazenda maranata,Fazenda Maranata,06,,-3.983333,-39.1
br,fazenda mares,Fazenda Marés,06,,-4.433333,-39.066667
br,fazenda marfim,Fazenda Marfim,27,,-20.633333,-47.466667
br,fazenda maria luiza,Fazenda Maria Luíza,18,,-25.6436,-48.7976
br,fazenda mariano guedes,Fazenda Mariano Guedes,15,,-16.85,-41.266667
br,fazenda maria preta,Fazenda María Preta,20,,-7.533333,-41.316667
br,fazenda mari,Fazenda Mari,06,,-3.833333,-39.4
br,fazenda marizeira,Fazenda Marizeira,06,,-3.633333,-39.2
br,fazenda marrecas,Fazenda Marrecas,06,,-3.4,-39.883333
br,fazenda maruai,Fazenda Maruai,25,,3.733333,-60.466667
br,fazenda massape,Fazenda Massapê,06,,-3.933333,-39.333333
br,fazenda massape grande,Fazenda Massapê Grande,06,,-4.916667,-39.383333
br,fazenda mata da chuva,Fazenda Mata da Chuva,27,,-20.916667,-47.95
br,fazenda mata fresca,Fazenda Mata Fresca,06,,-3.533333,-39.25
br,fazenda mateus,Fazenda Mateus,06,,-4,-40.2
br,fazenda matinha,Fazenda Matinha,27,,-20.15,-47.733333
br,fazenda mato grande,Fazenda Mato Grande,14,,-16.2,-56.333333
br,fazenda mato grosso,Fazenda Mato Grosso,06,,-4.666667,-39.45
br,fazenda matoso,Fazenda Matoso,06,,-4.9,-40.383333
br,fazenda melancia dos costas,Fazenda Melancia dos Costas,06,,-3.7,-39.2
br,fazenda melancia,Fazenda Melancia,06,,-3.75,-39.133333
br,fazenda melancias,Fazenda Melancias,06,,-3.6,-39.216667
br,fazenda mel,Fazenda Mel,06,,-4.083333,-39.116667
br,fazenda miguelito,Fazenda Miguelito,11,,-23.716667,-55.4
br,fazenda milagres,Fazenda Milagres,20,,-5.733333,-41.233333
br,fazenda mimosa,Fazenda Mimosa,06,,-3.583333,-39.216667
br,fazenda mimoso,Fazenda Mimoso,11,,-19.683333,-55.1
br,fazenda mina,Fazenda Mina,06,,-4.6,-39.083333
br,fazenda mirador,Fazenda Mirador,06,,-4.166667,-39.866667
br,fazenda miranda,Fazenda Miranda,06,,-3.933333,-39.7
br,fazenda mirante,Fazenda Mirante,27,,-20.116667,-47.716667
br,fazenda missi,Fazenda Missi,06,,-3.45,-39.85
br,fazenda mista,Fazenda Mista,27,,-20.466667,-47.766667
br,fazenda mocambo,Fazenda Mocambo,06,,-4.333333,-39.966667
br,fazenda mocambo,Fazenda Mocambo,20,,-7.433333,-42.466667
br,fazenda mocambo,Fazenda Mocambo,30,,-7.95,-39.766667
br,fazenda modelo,Fazenda Modelo,21,,-22.99267,-43.589936
br,fazenda moises quito,Fazenda Moisés Quito,14,,-17.933333,-53.566667
br,fazenda monte alegre,Fazenda Monte Alegre,06,,-4.85,-38.033333
br,fazenda monte alegre,Fazenda Monte Alegre,27,,-20.333333,-47.816667
br,fazenda monte alvernes,Fazenda Monte Alvernes,06,,-3.866667,-39.366667
br,fazenda monte belo,Fazenda Monte Belo,27,,-20.783333,-47.966667
br,fazenda monte castelo,Fazenda Monte Castelo,06,,-4.816667,-39.3
br,fazenda monte castelo,Fazenda Monte Castelo,20,,-5.083333,-42.016667
br,fazenda monte,Fazenda Monte,06,,-3.6,-39.283333
br,fazenda monte lima,Fazenda Monte Lima,06,,-4.8,-39.15
br,fazenda monte santos,Fazenda Monte Santos,20,,-7.083333,-41.45
br,fazenda montes claros,Fazenda Montes Claros,06,,-3.633333,-39.466667
br,fazenda monte verde,Fazenda Monte Verde,11,,-18.25,-54.683333
br,fazenda moreira,Fazenda Moreira,06,,-3.733333,-39.433333
br,fazenda mororo,Fazenda Mororó,06,,-3.95,-39.016667
br,fazenda morrinhos,Fazenda Morrinhos,06,,-4.566667,-39.833333
br,fazenda morrinhos,Fazenda Morrinhos,20,,-5.15,-42.516667
br,fazenda morro alto,Fazenda Morro Alto,27,,-21.783333,-47.416667
br,fazenda mucungu,Fazenda Mucungu,30,,-7.75,-40.433333
br,fazenda mufumbo,Fazenda Mufumbo,06,,-4.916667,-38.2
br,fazenda mulungu,Fazenda Mulungu,06,,-3.733333,-39.583333
br,fazenda mundo novo,Fazenda Mundo Novo,06,,-4.65,-38.133333
br,fazenda mundubin,Fazenda Mundubin,06,,-3.633333,-39.1
br,fazenda munuo novo,Fazenda Munuo Novo,06,,-3.616667,-39.4
br,fazenda muquem,Fazenda Muquem,20,,-7.566667,-40.833333
br,fazenda mutum,Fazenda Mutum,11,,-20.483333,-53.266667
br,fazenda nascente,Fazenda Nascente,11,,-21.566667,-54.216667
br,fazenda natal,Fazenda Natal,11,,-18.95,-55.716667
br,fazenda nazare,Fazenda Nazaré,06,,-2.966667,-40.116667
br,fazenda nazare,Fazenda Nazaré,27,,-22.116667,-51.966667
br,fazenda nazareno,Fazenda Nazareno,06,,-4.05,-39.816667
br,fazenda nossa senhora aparecida,Fazenda Nossa Senhora Aparecida,01,,-9.25,-70.316667
br,fazenda nossa senhora da conceicao,Fazenda Nossa Senhora da Conceição,14,,-16.307778,-56.530556
br,fazenda nossa senhora da guia,Fazenda Nossa Senhora da Guia,14,,-16.216667,-56.45
br,fazenda nova,Fazenda Nova,02,,-9.45,-37.166667
br,fazenda nova,Fazenda Nova,06,,-3.1,-40.2
br,fazenda nova,Fazenda Nova,11,,-21.866667,-56.533333
br,fazenda nova,Fazenda Nova,13,,-3.9525,-43.006667
br,fazenda nova,Fazenda Nôva,17,,-7.9,-36.833333
br,fazenda nova,Fazenda Nova,20,,-7.25,-41.633333
br,fazenda nova,Fazenda Nova,22,,-5.36,-36.643611
br,fazenda nova,Fazenda Nova,29,,-16.183333,-50.8
br,fazenda nova,Fazenda Nova,30,,-7.916667,-40
br,fazenda nova horizonte,Fazenda Nova Horizonte,11,,-19.266667,-54.75
br,fazenda nova india,Fazenda Nova India,21,,-22.861005,-43.636319
br,fazenda nova olinda,Fazenda Nova Olinda,06,,-4.5,-39.033333
br,fazenda nova veneza,Fazenda Nova Veneza,27,,-22.783333,-47.25
br,fazenda novo axioma,Fazenda Novo Axioma,04,,-9.583333,-67.316667
br,fazenda nuno pereira,Fazenda Nuno Pereira,15,,-16.783333,-40.766667
br,fazenda observacao,Fazenda Observação,20,,-7.6,-40.933333
br,fazenda oiticica,Fazenda Oiticica,06,,-3.633333,-39.683333
br,fazenda oiticica rasteira,Fazenda Oiticica Rasteira,06,,-4.716667,-40.4
br,fazenda oiticiquinha,Fazenda Oiticiquinha,06,,-4.083333,-39.333333
br,fazenda olaria,Fazenda Olaria,15,,-20.1,-46.1
br,fazenda olho d'agua das pedras,Fazenda Olho d'Agua das Pedras,20,,-5.45,-42.033333
br,fazenda olho d'agua do jirau,Fazenda Olho d'Agua do Jirau,06,,-4.933333,-39.85
br,fazenda olho d'agua,Fazenda Olho d'Agua,06,,-3.883333,-39.583333
br,fazenda olho d'agua,Fazenda Olho d'Agua,20,,-6.983333,-41.566667
br,fazenda olhos d'agua,Fazenda Olhos d'Agua,11,,-20.833333,-54.8
br,fazenda olinda,Fazenda Olinda,06,,-4.033333,-39.883333
br,fazenda oriacao da regiao dos lagos,Fazenda Oriação da Região dos Lagos,03,,1.75,-50.8
br,fazenda ouro branco,Fazenda Ouro Branco,06,,-4.8,-39.25
br,fazenda ouro preto,Fazenda Ouro Prêto,01,,-9.783333,-67.366667
br,fazenda ouro preto,Fazenda Ouro Preto,06,,-3.7,-40.05
br,fazenda ouro verde,Fazenda Ouro Verde,11,,-21.9,-54.35
br,fazenda ozorio,Fazenda Ozório,15,,-20.25,-45.766667
br,fazenda pacova,Fazenda Pacova,06,,-3.7,-39.133333
br,fazenda padre cicero,Fazenda Padre Cícero,01,,-9.933333,-67.483333
br,fazenda pae joao,Fazenda Pae João,26,,-28.183333,-50.633333
br,fazenda palestina,Fazenda Palestina,06,,-4.5,-39.133333
br,fazenda palestina,Fazenda Palestina,20,,-5.133333,-42.2
br,fazenda palmeira,Fazenda Palmeira,11,,-21.483333,-54.45
br,fazenda palmeiras,Fazenda Palmeiras,15,,-20.233333,-46.166667
br,fazenda palmeiras,Fazenda Palmeiras,27,,-21.8,-47.633333
br,fazenda palmitos,Fazenda Palmitos,27,,-20.683333,-47.9
br,fazenda palotina,Fazenda Palotina,04,,-9.55,-67.183333
br,fazenda papagaio,Fazenda Papagaio,20,,-7.1,-42.866667
br,fazenda papel,Fazenda Papel,06,,-4.2,-39.55
br,fazenda paracati,Fazenda Paracati,20,,-7.166667,-42.566667
br,fazenda parada,Fazenda Parada,06,,-4.466667,-39.066667
br,fazenda paraiso,Fazenda Paraiso,06,,-4.716667,-38.6
br,fazenda parana,Fazenda Paraná,04,,-9.483333,-67.283333
br,fazenda parana,Fazenda Paraná,15,,-16.216667,-41.316667
br,fazenda passagem,Fazenda Passagem,06,,-4.466667,-40.433333
br,fazenda passagem franca,Fazenda Passagem Franca,06,,-3.966667,-38.733333
br,fazenda passarinha,Fazenda Passarinha,06,,-4.866667,-40.466667
br,fazenda pastos bons,Fazenda Pastos Bons,06,,-4.183333,-39.9
br,fazenda patos,Fazenda Patos,06,,-4.666667,-40.45
br,fazenda patos,Fazenda Patos,20,,-7.6,-40.816667
br,fazenda pau branco,Fazenda Pau Branco,06,,-3.3,-40.466667
br,fazenda pau d'arco,Fazenda Pau d'Arco,06,,-3.633333,-39.066667
br,fazenda pau darco,Fazenda Pau Darco,30,,-7.983333,-39.883333
br,fazenda pau ferrado,Fazenda Pau Ferrado,30,,-7.35,-39.933333
br,fazenda pau ferro,Fazenda Pau Ferro,06,,-4.983333,-39.483333
br,fazenda pau ferro,Fazenda Pau Ferro,30,,-7.716667,-40.033333
br,fazenda pau fincado,Fazenda Pau Fincado,06,,-3.616667,-40.016667
br,fazenda pauliceia,Fazenda Pauliceia,11,,-21.683333,-54.45
br,fazenda paulista,Fazenda Paulista,04,,-9.05,-67.25
br,fazenda pe da serra,Fazenda Pé da Serra,06,,-3.55,-39.7
br,fazenda pedra amarela,Fazenda Pedra Amarela,06,,-4.15,-40.05
br,fazenda pedra arrancada,Fazenda Pedra Arrancada,06,,-3.033333,-39.9
br,fazenda pedra branca,Fazenda Pedra Branca,06,,-3.8,-39.166667
br,fazenda pedra d'agua,Fazenda Pedra d'Agua,06,,-4.833333,-38.3
br,fazenda pedra de amolar,Fazenda Pedra de Amolar,06,,-4.066667,-39.816667
br,fazenda pedra redonda,Fazenda Pedra Redonda,06,,-3.283333,-40.3
br,fazenda pedra vermelha,Fazenda Pedra Vermelha,06,,-3.783333,-40.066667
br,fazenda pedro gomes,Fazenda Pedro Gomes,11,,-18.066667,-54.533333
br,fazenda pedro neto,Fazenda Pedro Neto,27,,-21.266667,-47.616667
br,fazenda pedro severo,Fazenda Pedro Severo,11,,-17.666667,-54.033333
br,fazenda pensilvania,Fazenda Pensilvânia,06,,-4.4,-40.233333
br,fazenda pequiri,Fazenda Pequirí,11,,-17.7,-54.15
br,fazenda perdicao,Fazenda Perdicão,06,,-4.433333,-39.1
br,fazenda pereiro,Fazenda Pereiro,20,,-7.85,-40.916667
br,fazenda piabas,Fazenda Piabas,06,,-4.233333,-39.866667
br,fazenda picada,Fazenda Picada,06,,-3.35,-40.383333
br,fazenda picos,Fazenda Picos,06,,-4.183333,-40.25
br,fazenda pindahyval,Fazenda Pindahyval,14,,-17.15,-56.083333
br,fazenda pindaival,Fazenda Pindaìval,14,,-17.15,-56.083333
br,fazenda pingador,Fazenda Pingador,14,,-15.066667,-55.8
br,fazenda pinhador,Fazenda Pinhador,14,,-15.066667,-55.8
br,fazenda pinheiro,Fazenda Pinheiro,18,,-25.416,-50.5498
br,fazenda pintada,Fazenda Pintada,06,,-4.216667,-39.883333
br,fazenda pintada,Fazenda Pintada,20,,-7.733333,-43.116667
br,fazenda pio ix,Fazenda Pio IX,20,,-6.916667,-41.9
br,fazenda piquizeiro,Fazenda Piquizeiro,20,,-5.566667,-42.516667
br,fazenda pirai,Fazenda Pirai,06,,-3.716667,-40.45
br,fazenda piratininga,Fazenda Piratininga,01,,-9.933333,-67.066667
br,fazenda piripiri,Fazenda Piripiri,20,,-5.433333,-42.166667
br,fazenda pitombeira,Fazenda Pitombeira,06,,-3.8,-40.3
br,fazenda pitombeira,Fazenda Pitombeira,20,,-5.016667,-41.3
br,fazenda pitombeiras,Fazenda Pitombeiras,06,,-3.933333,-39.483333
br,fazenda pituba,Fazenda Pituba,27,,-21.966667,-46.833333
br,fazenda pocinhos,Fazenda Pocinhos,06,,-3.9,-40.183333
br,fazenda poco comprido,Fazenda Poço Comprido,06,,-3.783333,-40.416667
br,fazenda poco da onca,Fazenda Poço da Onça,06,,-3.616667,-39.883333
br,fazenda poco da pedra,Fazenda Poço da Pedra,06,,-4,-39.433333
br,fazenda poco,Fazenda Poço,27,,-20.416667,-47.866667
br,fazenda poco redondo,Fazenda Poço Redondo,06,,-3.816667,-39.516667
br,fazenda poco verde,Fazenda Poço Verde,06,,-3.616667,-39.983333
br,fazenda ponta da mata,Fazenda Ponta da Mata,27,,-20.8,-47.916667
br,fazenda ponta da serra,Fazenda Ponta da Serra,06,,-4.966667,-39.8
br,fazenda ponta,Fazenda Ponta,27,,-21.466667,-46.683333
br,fazenda pontal,Fazenda Pontal,11,,-19.683333,-52.816667
br,fazenda ponte alta,Fazenda Ponte Alta,14,,-15.416667,-55.283333
br,fazenda ponte novo,Fazenda Ponte Novo,15,,-20.05,-46.133333
br,fazenda porteiras,Fazenda Porteiras,20,,-7.083333,-42.7
br,fazenda porto alegre,Fazenda Pôrto Alegre,11,,-18.283333,-55.433333
br,fazenda porto de pedra,Fazenda Pôrto de Pedra,11,,-21.2,-52.966667
br,fazenda posto dourado,Fazenda Posto Dourado,14,,-16.475,-56.2
br,fazenda pouso alto,Fazenda Pouso Alto,11,,-19.416667,-54.133333
br,fazenda prates,Fazenda Prates,08,,-20.916667,-41.016667
br,fazenda pratinha,Fazenda Pratinha,27,,-21.433333,-47.533333
br,fazenda primavera,Fazenda Primavera,18,,-24.872129,-48.74213
br,fazenda primavera,Fazenda Primavera,20,,-7.1,-41.183333
br,fazenda promissao,Fazenda Promissão,11,,-18.65,-55.7
br,fazenda providencia,Fazenda Providéncia,06,,-3.966667,-39.133333
br,fazenda pui,Fazenda Puí,01,,-9.783333,-67.333333
br,fazenda pulador,Fazenda Pulador,11,,-19.05,-54.816667
br,fazenda puruna,Fazenda Puruna,06,,-3.133333,-40.3
br,fazenda quandu,Fazenda Quandu,06,,-4.066667,-38.65
br,fazenda queimada,Fazenda Queimada,30,,-7.566667,-40.1
br,fazenda queimadas,Fazenda Queimadas,06,,-4.85,-37.55
br,fazenda queiroz,Fazenda Queiroz,11,,-20.3,-51.45
br,fazenda quicim,Fazenda Quicim,06,,-3.733333,-39.2
br,fazenda raizama,Fazenda Raizama,11,,-17.85,-54.466667
br,fazenda rajada,Fazenda Rajada,06,,-3.533333,-39.466667
br,fazenda rancharia,Fazenda Rancharia,11,,-18.916667,-55.7
br,fazenda rancho alegre,Fazenda Rancho Alegre,06,,-4.516667,-38.183333
br,fazenda rancho dos mocos,Fazenda Rancho dos Moços,06,,-4.016667,-39.066667
br,fazenda rapina,Fazenda Rapina,06,,-4.033333,-39.6
br,fazenda recife,Fazenda Recife,06,,-4.25,-40.2
br,fazenda recreio,Fazenda Recreio,11,,-17.65,-56.75
br,fazenda recreio,Fazenda Recreio,27,,-21.8,-46.683333
br,fazenda redoma,Fazenda Redoma,20,,-5.416667,-42.133333
br,fazenda reforma,Fazenda Reforma,22,,-4.933333,-37.383333
br,fazenda rejeitado,Fazenda Rejeitado,06,,-4.85,-40.45
br,fazenda remanso,Fazenda Remanso,27,,-20.366667,-47.833333
br,fazenda requejao,Fazenda Requejão,15,,-16.5,-41.583333
br,fazenda resfriado,Fazenda Resfriado,27,,-20.833333,-47.833333
br,fazenda retiro da ponte,Fazenda Retiro da Ponte,27,,-20.8,-47.8
br,fazenda retiro,Fazenda Retiro,06,,-3.8,-39.866667
br,fazenda retiro,Fazenda Retiro,20,,-7.2,-42.516667
br,fazenda retiro seguro,Fazenda Retiro Seguro,11,,-18.2,-56.75
br,fazenda retriano,Fazenda Retriano,06,,-4.416667,-38.166667
br,fazenda riachao,Fazenda Riachão,13,,-6.2,-43.25
br,fazenda riacho cipo,Fazenda Riacho Cipó,05,,-12.35,-39.3
br,fazenda riacho da areia,Fazenda Riacho da Areia,20,,-7.133333,-42.233333
br,fazenda riacho das umburanas,Fazenda Riacho das Umburanas,06,,-4.616667,-38.183333
br,fazenda riacho do divertido,Fazenda Riacho do Divertido,06,,-4.7,-38.166667
br,fazenda riacho do mato,Fazenda Riacho do Mato,06,,-4.283333,-40.433333
br,fazenda riacho do meio,Fazenda Riacho do Meio,06,,-3.716667,-39
br,fazenda riacho do onca,Fazenda Riacho do Onca,20,,-5.583333,-41.866667
br,fazenda riacho dos bois,Fazenda Riacho dos Bois,06,,-4.383333,-39.966667
br,fazenda riacho,Fazenda Riacho,06,,-3.266667,-40.483333
br,fazenda riacho fundo,Fazenda Riacho Fundo,06,,-3.55,-39.266667
br,fazenda riacho novo,Fazenda Riacho Novo,06,,-4.166667,-40.233333
br,fazenda ribeirao claro,Fazenda Ribeirão Claro,11,,-21.05,-53.633333
br,fazenda rio alegre,Fazenda Rio Alegre,14,,-16.8925,-56.720833
br,fazenda rio branco,Fazenda Rio Branco,11,,-21.666667,-53.9
br,fazenda rio branco,Fazenda Rio Branco,20,,-6.9,-42.9
br,fazenda rio manso,Fazenda Rio Manso,27,,-23.366667,-45.4
br,fazenda rio verde,Fazenda Rio Verde,11,,-18.933333,-54.866667
br,fazenda rocilandia,Fazenda Rocilândia,06,,-4.233333,-39.666667
br,fazenda romualda,Fazenda Romualda,15,,-16.066667,-40.466667
br,fazenda rosaria,Fazenda Rosária,27,,-21.466667,-46.783333
br,fazenda rosendo pinto,Fazenda Rosendo Pinto,15,,-17.833333,-41.516667
br,fazenda sabonete,Fazenda Sabonete,06,,-4.033333,-39.7
br,fazenda saco do adelino,Fazenda Saco do Adelino,20,,-5.25,-41.1
br,fazenda saco do vento,Fazenda Saco do Vento,06,,-4,-39.816667
br,fazenda saco,Fazenda Saco,06,,-3.216667,-39.95
br,fazenda saco,Fazenda Saco,20,,-5.183333,-41.183333
br,fazenda saco,Fazenda Saco,30,,-7.916667,-40.216667
br,fazenda saco verde,Fazenda Saco Verde,06,,-3.733333,-39.683333
br,fazenda salgadinho,Fazenda Salgadinho,06,,-3.466667,-40.166667
br,fazenda salgado,Fazenda Salgado,06,,-3.866667,-39.4
br,fazenda salto,Fazenda Salto,11,,-20.583333,-54.683333
br,fazenda salto,Fazenda Salto,27,,-21.8,-47.766667
br,fazenda salvacao,Fazenda Salvação,06,,-4.983333,-39.15
br,fazenda santa alda,Fazenda Santa Alda,11,,-20.716667,-53.766667
br,fazenda santa ambrosina,Fazenda Santa Ambrosina,27,,-21.666667,-47.466667
br,fazenda santa ana,Fazenda Santa Ana,06,,-3.816667,-39.466667
br,fazenda santa barbara,Fazenda Santa Barbara,11,,-22.25,-53.483333
br,fazenda santa barbara,Fazenda Santa Barbara,14,,-15.65,-59.15
br,fazenda santa catarina,Fazenda Santa Catarina,11,,-23.116667,-55.533333
br,fazenda santa catarina,Fazenda Santa Catarina,20,,-5.016667,-42.016667
br,fazenda santa cruz,Fazenda Santa Cruz,11,,-18.533333,-57.2
br,fazenda santa escolastica,Fazenda Santa Escolástica,27,,-21.85,-47.233333
br,fazenda santa etelvina,Fazenda Santa Etelvina,27,,-21.766667,-47.633333
br,fazenda santa eugenia,Fazenda Santa Eugênia,27,,-21.816667,-47.35
br,fazenda santa fe,Fazenda Santa Fé,06,,-3.616667,-39.3
br,fazenda santa fe,Fazenda Santa Fé,11,,-18.633333,-55.8
br,fazenda santa fe,Fazenda Santa Fé,20,,-7.1,-42.25
br,fazenda santa fe,Fazenda Santa Fé,22,,-4.95,-37.266667
br,fazenda santa fe,Fazenda Santa Fé,27,,-20.933333,-47.883333
br,fazenda santa gertrudes,Fazenda Santa Gertrudes,27,,-20.65,-47.866667
br,fazenda santa helena,Fazenda Santa Helena,06,,-4.4,-39.133333
br,fazenda santa helena,Fazenda Santa Helena,20,,-7.15,-41.166667
br,fazenda santa herminia,Fazenda Santa Hermínia,27,,-20.266667,-47.533333
br,fazenda santa ilidia,Fazenda Santa Ilídia,11,,-22.416667,-52.883333
br,fazenda santa ines,Fazenda Santa Inês,27,,-20.566667,-47.816667
br,fazenda santa luzia,Fazenda Santa Lúzia,06,,-3.833333,-39.25
br,fazenda santa luzia,Fazenda Santa Luzia,11,,-17.933333,-54.95
br,fazenda santa luzia,Fazenda Santa Luzia,20,,-5.683333,-41.483333
br,fazenda santa luzia,Fazenda Santa Luzia,27,,-21.816667,-47.733333
br,fazenda santa maria,Fazenda Santa Maria,06,,-3.316667,-39.916667
br,fazenda santa maria,Fazenda Santa Maria,14,,-16.716667,-56.033333
br,fazenda santa maria,Fazenda Santa Maria,18,,-23.183333,-50.533333
br,fazenda santa maria,Fazenda Santa Maria,27,,-20.416667,-47.716667
br,fazenda santa marta,Fazenda Santa Marta,30,,-7.35,-39.633333
br,fazenda santana do piraim,Fazenda Santana do Piraim,14,,-16.333333,-56.083333
br,fazenda santana,Fazenda Santana,06,,-3.85,-40.016667
br,fazenda santa naria,Fazenda Santa Naria,27,,-20.65,-47.416667
br,fazenda santa paz,Fazenda Santa Paz,20,,-7.3,-42.166667
br,fazenda santa rita,Fazenda Santa Rita,14,,-16.313611,-56.590278
br,fazenda santa rita,Fazenda Santa Rita,20,,-7.733333,-42.716667
br,fazenda santa rita,Fazenda Santa Rita,23,,-30.916667,-51.483333
br,fazenda santa rosa,Fazenda Santa Rosa,06,,-3.466667,-38.983333
br,fazenda santa rosa,Fazenda Santa Rosa,20,,-7.05,-41.25
br,fazenda santa sofia,Fazenda Santa Sofia,11,,-21.583333,-53.733333
br,fazenda santa sophia,Fazenda Santa Sophia,11,,-21.583333,-53.733333
br,fazenda santa teresa,Fazenda Santa Teresa,06,,-4.15,-39.1
br,fazenda santa teresinha,Fazenda Santa Teresinha,27,,-21.216667,-47.683333
br,fazenda santa tereza,Fazenda Santa Tereza,20,,-7.166667,-42.066667
br,fazenda santa victoria,Fazenda Santa Victória,20,,-5.15,-42.3
br,fazenda santiago,Fazenda Santiago,27,,-20.6,-47.766667
br,fazenda santo antonia,Fazenda Santo Antonia,22,,-5.45,-36.883333
br,fazenda santo antonio,Fazenda Santo Antõnio,06,,-2.95,-40.116667
br,fazenda santo antonio,Fazenda Santo Antonio,08,,-20.45,-41.266667
br,fazenda santo antonio,Fazenda Santo Antônio,11,,-21.533333,-56.983333
br,fazenda santo antonio,Fazenda Santo Antônio,27,,-20.616667,-47.85
br,fazenda santo expedito,Fazenda Santo Expedito,20,,-5.116667,-41.433333
br,fazenda santo isidio,Fazenda Santo Isídio,06,,-3.116667,-40.25
br,fazenda santos dumont,Fazenda Santos Dumont,06,,-4.85,-40.366667
br,fazenda sao antonio,Fazenda São Antônio,06,,-4.166667,-39.066667
br,fazenda sao benedito,Fazenda São Benedito,11,,-18.8,-56.016667
br,fazenda sao bento,Fazenda São Bento,11,,-17.983333,-54.9
br,fazenda sao bernardo,Fazenda São Bernardo,06,,-3.833333,-40.066667
br,fazenda sao claudio,Fazenda São Claúdio,06,,-3.866667,-40.1
br,fazenda sao clemente,Fazenda São Clemente,27,,-21.816667,-47.583333
br,fazenda sao cristovao,Fazenda São Cristovão,06,,-4.1,-39.1
br,fazenda sao domingos,Fazenda São Domingos,11,,-18.45,-55.966667
br,fazenda sao felix,Fazenda São Felix,11,,-19.95,-55.2
br,fazenda sao fernandes,Fazenda São Fernandes,06,,-3.616667,-40.3
br,fazenda sao francisco do venacio,Fazenda São Francisco do Venâcio,06,,-3.75,-39.516667
br,fazenda sao francisco,Fazenda São Francisco,06,,-3.716667,-40.416667
br,fazenda sao francisco,Fazenda São Francisco,11,,-19.75,-55.216667
br,fazenda sao francisco,Fazenda São Francisco,20,,-5.45,-41.1
br,fazenda sao geraldo,Fazenda São Geraldo,27,,-21.05,-47.75
br,fazenda sao gregorio,Fazenda São Gregório,06,,-4.533333,-39.133333
br,fazenda sao guilherme,Fazenda São Guilherme,27,,-22,-47.633333
br,fazenda sao jeronimo,Fazenda São Jerônimo,27,,-20.866667,-47.916667
br,fazenda sao joao da boa vista,Fazenda São João da Boa Vista,06,,-3.783333,-38.716667
br,fazenda sao joao do guapore,Fazenda São João do Guaporé,14,,-15.977778,-59.886111
br,fazenda sao joao,Fazenda São João,06,,-3.283333,-39.616667
br,fazenda sao joao,Fazenda São João,11,,-18.333333,-55.883333
br,fazenda sao joao,Fazenda São João,14,,-14.429167,-59.566667
br,fazenda sao joao,Fazenda São João,27,,-20.983333,-47.833333
br,fazenda sao joaquim,Fazenda São Joaquim,06,,-3.733333,-39.7
br,fazenda sao joaquim,Fazenda São Joaquim,11,,-20.666667,-53.9
br,fazenda sao joaquim,Fazenda São Joaquim,27,,-21.016667,-47.85
br,fazenda sao jose do rio negrinho,Fazenda São José do Rio Negrinho,11,,-19.1,-54.916667
br,fazenda sao jose,Fazenda São José,04,,-9.25,-67.033333
br,fazenda sao jose,Fazenda São José,06,,-3.483333,-39.166667
br,fazenda sao jose,Fazenda São José,11,,-21.4,-54.366667
br,fazenda sao jose,Fazenda São José,27,,-20.2,-47.383333
br,fazenda sao luis,Fazenda São Luís,06,,-4.466667,-39.966667
br,fazenda sao luis,Fazenda São Luis,22,,-4.966667,-37.433333
br,fazenda sao luis,Fazenda São Luís,27,,-20.383333,-47.616667
br,fazenda sao manoel,Fazenda São Manoel,11,,-20.766667,-53
br,fazenda sao mateus,Fazenda São Mateus,06,,-4.516667,-38.266667
br,fazenda sao miguel,Fazenda São Miguel,14,,-16.866667,-56.633333
br,fazenda sao miguel,Fazenda São Miguel,27,,-21.05,-47.95
br,fazenda sao natalia,Fazenda São Natalia,11,,-18.366667,-55.983333
br,fazenda sao paulo,Fazenda São Paulo,06,,-4.25,-39.416667
br,fazenda sao pedro,Fazenda São Pedro,06,,-4.266667,-40.2
br,fazenda sao pedro,Fazenda São Pedro,11,,-21.833333,-53.6
br,fazenda sao rafael,Fazenda São Rafael,11,,-22.166667,-53.266667
br,fazenda sao raimundo,Fazenda São Raimundo,06,,-4.166667,-38.183333
br,fazenda sao roberto,Fazenda São Roberto,27,,-21.85,-47.966667
br,fazenda sao romao,Fazenda São Romão,06,,-3.466667,-39.883333
br,fazenda sao romao,Fazenda São Romão,11,,-18.55,-54.45
br,fazenda sao roque,Fazenda São Roque,11,,-21.7,-54.25
br,fazenda sao salvador,Fazenda São Salvador,06,,-4.6,-39.316667
br,fazenda sao sebastiao,Fazenda São Sebastião,27,,-22.133333,-49.2
br,fazenda sao vicente,Fazenda São Vicente,06,,-4.15,-39.016667
br,fazenda sao vicente,Fazenda São Vicente,15,,-16.533333,-41.033333
br,fazenda sao vicente,Fazenda São Vicente,20,,-5.083333,-42.333333
br,fazenda sapucaiba,Fazenda Sapucaiba,06,,-4.6,-39.916667
br,fazenda saquinho,Fazenda Saquinho,06,,-3.516667,-39.7
br,fazenda sebastiao ferreira,Fazenda Sebastião Ferreira,15,,-17.466667,-41.433333
br,fazenda sebastiao goncalves,Fazenda Sebastião Gonçalves,15,,-16.916667,-41.733333
br,fazenda serra branca,Fazenda Serra Branca,06,,-4.333333,-39.55
br,fazenda serra branca,Fazenda Serra Branca,20,,-6.066667,-41.45
br,fazenda serrinha,Fazenda Serrinha,06,,-3.6,-39.733333
br,fazenda serrinha,Fazenda Serrinha,27,,-21.483333,-47.516667
br,fazenda serrote do meio,Fazenda Serrote do Meio,06,,-3.8,-39.483333
br,fazenda serrote,Fazenda Serrote,06,,-4.283333,-39.116667
br,fazenda sibirol,Fazenda Sibirol,06,,-4.933333,-39.8
br,fazenda sipauba,Fazenda Sipaúba,30,,-7.55,-40.333333
br,fazenda sitio,Fazenda Sítio,06,,-4.083333,-39.75
br,fazenda soares,Fazenda Soares,06,,-3.233333,-40.233333
br,fazenda sobrado,Fazenda Sobrado,27,,-20.283333,-47.683333
br,fazenda sombreira,Fazenda Sombreira,06,,-4.083333,-39.1
br,fazenda sororo,Fazenda Sororô,06,,-3.466667,-39.633333
br,fazenda sousa,Fazenda Sousa,23,,-29.1236,-51.0127
br,fazenda souza,Fazenda Souza,23,,-29.1236,-51.0127
br,fazenda souze,Fazenda Souze,06,,-4.05,-39.55
br,fazenda s romao,Fazenda S Romão,22,,-4.9,-37.4
br,fazenda sta alice,Fazenda Sta Alice,20,,-5.266667,-41.566667
br,fazenda sta madalena,Fazenda Sta Madalena,20,,-5.016667,-41.833333
br,fazenda sta maria,Fazenda Sta Maria,20,,-5.3,-41.883333
br,fazenda sucuarana,Fazenda Suçuarana,06,,-3.3,-40.383333
br,fazenda sucuri,Fazenda Sucuri,11,,-21.766667,-54.75
br,fazenda sumare,Fazenda Sumaré,06,,-3.666667,-39.166667
br,fazenda taboca,Fazenda Taboca,06,,-3.65,-39.016667
br,fazenda tabocas,Fazenda Tabocas,06,,-3.416667,-39.716667
br,fazenda tabuleiro,Fazenda Tabuleiro,20,,-5.516667,-41.716667
br,fazenda tabuleiro grande,Fazenda Tabuleiro Grande,20,,-6.916667,-42.45
br,fazenda tagy,Fazenda Tagy,20,,-8.733333,-45.866667
br,fazenda talhada,Fazenda Talhada,20,,-6.883333,-41.966667
br,fazenda tanque do aquino,Fazenda Tanque do Aquino,14,,-16.011667,-56.539167
br,fazenda tanque,Fazenda Tanque,06,,-4.683333,-39.966667
br,fazenda tapera,Fazenda Tapera,06,,-4.583333,-39.8
br,fazenda taquaperi,Fazenda Taquaperi,11,,-23.216667,-55.416667
br,fazenda taquara,Fazenda Taquara,11,,-19.283333,-54.933333
br,fazenda taquara,Fazenda Taquara,18,,-24.683333,-50.166667
br,fazenda taquaral,Fazenda Taquaral,27,,-21.683333,-47.566667
br,fazenda tarao,Fazenda Tarão,20,,-7.15,-42.866667
br,fazenda tatajuba,Fazenda Tatajuba,06,,-4.7,-39.833333
br,fazenda taubate,Fazenda Taubaté,06,,-3.983333,-38.983333
br,fazenda tejuba,Fazenda Tejubá,06,,-3.366667,-39.9
br,fazenda telemaco guimaraes,Fazenda Telêmaco Guimarães,15,,-17.65,-41.916667
br,fazenda telha,Fazenda Telha,06,,-3.733333,-40.3
br,fazenda terere,Fazenda Tererê,11,,-21.316667,-55.033333
br,fazenda terra seca,Fazenda Terra Sêca,06,,-4.083333,-38.666667
br,fazenda timbauba,Fazenda Timbaúba,06,,-4.15,-39.566667
br,fazenda toca,Fazenda Toca,27,,-21.3,-47.533333
br,fazenda todos os santos,Fazenda Todos os Santos,06,,-4.283333,-39.566667
br,fazenda torroes,Fazenda Torrões,20,,-7.083333,-41.216667
br,fazenda torto,Fazenda Torto,06,,-3.2,-39.8
br,fazenda touro,Fazenda Touro,06,,-3.95,-39.533333
br,fazenda trairas,Fazenda Traíras,06,,-4.483333,-40.2
br,fazenda trapia,Fazenda Trapiá,06,,-4.2,-39.066667
br,fazenda tremendal,Fazenda Tremendal,20,,-7.116667,-42.45
br,fazenda tres barras,Fazenda Três Barras,11,,-22.066667,-52.933333
br,fazenda tres barras,Fazenda Três Barras,27,,-20.733333,-47.816667
br,fazenda tres lagoas,Fazenda Três Lagoas,06,,-3.766667,-39.2
br,fazenda tres marias,Fazenda Três Marias,06,,-4.3,-39.866667
br,fazenda tres marias,Fazenda Três Marias,11,,-19.133333,-55.35
br,fazenda triangulo,Fazenda Triângulo,11,,-21.683333,-54.866667
br,fazenda triunfo,Fazenda Triunfo,11,,-21.433333,-56.483333
br,fazenda trombas,Fazenda Trombas,06,,-3.766667,-39.616667
br,fazenda trombucas,Fazenda Trombucas,27,,-20.216667,-47.3
br,fazenda tubiba,Fazenda Tubiba,06,,-4.316667,-40.416667
br,fazenda turvo,Fazenda Turvo,11,,-21.35,-55.516667
br,fazenda umari,Fazenda Umari,01,,-4.416667,-38.033333
br,fazenda umburana,Fazenda Umburana,06,,-3.916667,-39.783333
br,fazenda urubu,Fazenda Urubu,06,,-3.883333,-39.883333
br,fazenda vaca branca,Fazenda Vaca Branca,06,,-4.116667,-39.566667
br,fazenda vaca serrada,Fazenda Vaca Serrada,06,,-4.833333,-39.45
br,fazenda vale do guapore,Fazenda Vale do Guaporé,14,,-14.420833,-59.595833
br,fazenda valparaiso,Fazenda Valparaiso,06,,-4.233333,-39.816667
br,fazenda vargem comprida,Fazenda Vargem Comprida,14,,-16.316667,-56.7175
br,fazenda vargem da cruz,Fazenda Vargem da Cruz,06,,-4.066667,-40.083333
br,fazenda varginha,Fazenda Varginha,27,,-21.45,-46.9
br,fazenda varjota,Fazenda Varjota,06,,-3.65,-39.416667
br,fazenda varzea da pedra,Fazenda Varzea da Pedra,06,,-3.733333,-40.416667
br,fazenda varzea de ema,Fazenda Várzea de Ema,06,,-4.316667,-39.283333
br,fazenda varzea do jua,Fazenda Várzea do Juá,06,,-4.25,-40.216667
br,fazenda varzea dos bois,Fazenda Varzea dos Bois,06,,-3.516667,-39.866667
br,fazenda varzea grande,Fazenda Várzea Grande,06,,-4.8,-40.416667
br,fazenda varzea queimada,Fazenda Várzea Queimada,06,,-4.616667,-39.016667
br,fazenda varzea redonda,Fazenda Várzea Redonda,06,,-4.35,-40.4
br,fazenda varzera de cima,Fazenda Várzera de Cima,06,,-4.366667,-39.933333
br,fazenda varzinha,Fazenda Varzinha,06,,-4.866667,-38.866667
br,fazenda vazantes do barroso,Fazenda Vazantes do Barroso,06,,-4.466667,-39.766667
br,fazenda vazea grande,Fazenda Vázea Grande,06,,-4.866667,-38.25
br,fazenda velha,Fazenda Velha,05,,-10.416667,-42.316667
br,fazenda velha,Fazenda Velha,14,,-15.783333,-56.133333
br,fazenda velha,Fazenda Velha,20,,-7.566667,-42.466667
br,fazenda velha,Fazenda Velha,27,,-21.366667,-47.083333
br,fazenda venancio,Fazenda Venâncio,06,,-3.783333,-39.566667
br,fazenda vencaia,Fazenda Vencaia,18,,-23.066667,-50.55
br,fazenda veneza,Fazenda Veneza,06,,-4.566667,-39.166667
br,fazenda vento frio,Fazenda Vento Frio,15,,-16.6,-40.466667
br,fazenda vereda grande,Fazenda Vereda Grande,20,,-7.266667,-42.983333
br,fazenda vertedouro,Fazenda Vertedouro,06,,-4.783333,-38.433333
br,fazenda vertente,Fazenda Vertente,13,,-5.25,-42.833333
br,fazenda vila popular,Fazenda Vila Popular,06,,-3.6,-40.016667
br,fazenda vista alegre,Fazenda Vista Alegre,04,,-4.896944,-60.022222
br,fazenda vista alegre,Fazenda Vista Alegre,06,,-4.633333,-40.2
br,fazenda vista alegre,Fazenda Vista Alegre,11,,-19.816667,-53.966667
br,fazenda vitoria,Fazenda Vitória,06,,-4.583333,-40.166667
br,fazenda vitoriano,Fazenda Vitoriano,06,,-4.45,-38.166667
br,fazenda volta do mateus,Fazenda Volta do Mateus,06,,-4.916667,-38.333333
br,fazenda volta,Fazenda Volta,06,,-4.633333,-40.433333
br,fazenda xinuaque,Fazenda Xinuaquê,06,,-4.266667,-39.633333
br,fazenda xixa,Fazenda Xixá,06,,-3.666667,-39.45
br,fazenda zeca botelho,Fazenda Zeca Botelho,15,,-16.533333,-40.416667
br,fazenda ziemer e companhia,Fazenda Ziemer e Companhia,15,,-17.133333,-41.35
br,fazendinha,Fazendinha,02,,-9.55,-37.116667
br,fazendinha,Fazendinha,04,,-3.5,-58.833333
br,fazendinha,Fazendinha,05,,-11.716667,-38.6
br,fazendinha,Fazendinha,06,,-3.066667,-39.733333
br,fazendinha,Fazendinha,11,,-19.266667,-52.616667
br,fazendinha,Fazendinha,13,,-5.316667,-42.833333
br,fazendinha,Fazendinha,14,,-14.483333,-56.6
br,fazendinha,Fazendinha,15,,-20.5,-41.85
br,fazendinha,Fazendinha,16,,-.933333,-47.733333
br,fazendinha,Fazendinha,18,,-25.433333,-53.016667
br,fazendinha,Fazendinha,20,,-8.083333,-41.066667
br,fazendinha,Fazendinha,21,,-22.766667,-41.966667
br,fazendinha,Fazendinha,22,,-5.166667,-35.65
br,fazendinha,Fazendinha,27,,-21.033333,-50.7
br,fazendinha,Fazendinha,28,,-10.4,-36.616667
br,fazendinha,Fazendinha,30,,-8.883333,-36.983333
br,faz exu,Faz Exu,14,,-16.901667,-56.607778
br,faz ichu,Faz Ichu,14,,-16.901667,-56.607778
br,fechadinho,Fechadinho,17,,-6.633333,-37.583333
br,fechado,Fechado,06,,-5.833333,-39.35
br,fechados,Fechados,15,,-18.816667,-43.866667
br,fedegoso,Fedegoso,05,,-11.466667,-40.883333
br,federacao,Federação,23,,-32.233333,-53.083333
br,feia,Feia,15,,-14.883333,-44.9
br,feijao branco,Feijão Branco,06,,-3.183333,-40.416667
br,feijao,Feijão,04,,-3.088889,-63.124722
br,feijao,Feijão,05,,-9.466667,-43.533333
br,feijao,Feijão,06,,-4.05,-39.716667
br,feijao,Feijão,13,,-3.492222,-43.485556
br,feijao,Feijão,17,,-6.683333,-38.583333
br,feijao,Feijão,20,,-3.645833,-42.256667
br,feijao,Feijão,22,,-5.816667,-35.666667
br,feijao,Feijão,30,,-7.766667,-38.733333
br,feijao gordo,Feijão Gordo,06,,-6.233333,-40.683333
br,feijao sem sal,Feijão Sem Sal,14,,-15.383333,-57.7
br,feijoal,Feijoal,04,,-4.317778,-69.561111
br,feijo,Feijó,01,12951,-8.15,-70.35
br,feijo,Feijo,17,,-7,-36.016667
br,feijo,Feijó,23,,-32.516667,-53.1
br,feira de saint anna,Feira De Saint Anna,05,,-12.25,-38.95
br,feira de santana,Feira de Santana,05,481926,-12.25,-38.95
br,feira de sant'anna,Feira de Sant'Anna,05,,-12.25,-38.95
br,feira do pau,Feira do Páu,05,,-9.166667,-39.066667
br,feira,Feira,05,,-12.25,-38.95
br,feira,Feira,13,,-6.45,-44.2
br,feira grande,Feira Grande,02,3985,-9.85,-36.7
br,feira nova,Feira Nova,30,12985,-7.933333,-35.35
br,feira sucupira,Feira Sucupira,13,,-6.45,-44.2
br,feirinha,Feirinha,05,,-14.1,-40.383333
br,feital,Feital,18,,-24.723816,-48.838678
br,feital,Feital,27,,-24.503077,-48.158547
br,feiticeira,Feiticeira,06,,-5.966667,-38.816667
br,feiticeiro,Feiticeiro,06,,-5.966667,-38.816667
br,feitoria da guariroba,Feitoria da Guariroba,14,,-13.483333,-58.333333
br,feitoria do guariroba,Feitoria do Guariroba,14,,-13.483333,-58.333333
br,feitoria do orlando,Feitoria do Orlando,14,,-14.166667,-57.166667
br,feitoria do papagaio,Feitoria do Papagaio,14,,-13.466667,-58.35
br,feitoria dos 3 jacus,Feitoria dos 3 Jacús,14,,-13.75,-57.333333
br,feitoria dos tres jacus,Feitoria dos Três Jacus,14,,-13.75,-57.333333
br,feitoria do tine,Feitoria do Tiné,14,,-14.583333,-51.516667
br,feitoria,Feitoria,13,,-4.216667,-43.233333
br,feitoria,Feitoria,20,,-2.909167,-41.774722
br,feitoria,Feitoria,30,,-7.533333,-40.1
br,feitoria gelo,Feitoria Gelo,16,,-9.233333,-57.05
br,feitoria pedro pinheiro,Feitoria Pedro Pinheiro,14,,-13.35,-58.416667
br,feitosa,Feitosa,06,,-6.966667,-39.183333
br,feixes,Feixes,16,,-4.8,-56.45
br,feixinho de criviuma,Feixinho de Criviúma,18,,-24.744893,-48.939514
br,fejos,Fejós,06,,-7.566667,-39.133333
br,feliciano,Feliciano,15,,-21.833333,-45.166667
br,feliciano,Feliciano,30,,-8.166667,-37.25
br,feliciano trindade,Feliciano Trindade,11,,-19.083333,-54.233333
br,felicidade,Felicidade,04,,-4.424722,-59.811389
br,felicidade,Felicidade,05,,-16.2,-38.983333
br,felicidade,Felicidade,06,,-7.633333,-38.85
br,felicidade,Felicidade,16,,-.966667,-49.316667
br,felicidale,Felicidale,06,,-5.6,-38.55
br,felicina,Felicina,15,,-19.083333,-42.4
br,felicio dos santos,Felício dos Santos,15,,-18.083333,-43.183333
br,felicio,Felicio,15,,-16.433333,-40.233333
br,felicio peixoto,Felício Peixoto,15,,-20.583333,-46.233333
br,felinto,Felinto,04,,-6.95,-58.283333
br,felipe camarao,Felipe Camarão,13,,-2.85,-46.6
br,felipe camarao,Felipe Camarão,22,,-5.766667,-35.333333
br,felipe,Felipe,06,,-4.833333,-40.2
br,felipe guerra,Felipe Guerra,22,,-5.6,-37.683333
br,felipe schmidt,Felipe Schmidt,26,,-26.2,-50.7
br,felisberto caldeira,Felisberto Caldeira,15,,-18.016667,-43.316667
br,felisberto caldeiro,Felisberto Caldeiro,15,,-18.016667,-43.316667
br,felisberto,Felisberto,13,,-3.514167,-42.720556
br,felisburgo,Felisburgo,15,,-16.65,-40.766667
br,felix,Félix,15,,-18.55,-48.533333
br,felix,Felix,27,,-23.1042,-47.9896
br,felixlandia,Felixlândia,15,,-18.783333,-44.916667
br,felizardo,Felizardo,06,,-6.85,-38.75
br,felizburgo,Felizburgo,15,,-16.65,-40.766667
br,feliz deserto,Feliz Deserto,02,,-10.283333,-36.3
br,feliz do deserto,Feliz do Deserto,02,,-10.283333,-36.3
br,feliz,Feliz,15,,-20.616667,-44.85
br,feliz,Feliz,23,,-29.45,-51.3
br,feliz vitoria,Feliz Vitória,04,,-5.653056,-61.197778
br,fellipe dos santos,Fellipe dos Santos,15,,-20.516667,-43.8
br,fenix,Fênix,18,,-23.9,-51.95
br,ferias,Férias,13,,-3.242778,-42.208889
br,fermao dias,Fermão Dias,27,,-22.35,-49.516667
br,fernanda,Fernanda,05,,-13.683333,-41.583333
br,fernandes belo,Fernandes Belo,16,,-1.116667,-46.316667
br,fernandes,Fernandes,05,,-11.883333,-41.533333
br,fernandes,Fernandes,06,,-4.883333,-39.85
br,fernandes,Fernandes,13,,-3.529167,-43.399444
br,fernandes,Fernandes,15,,-19.333333,-42.716667
br,fernandes,Fernandes,22,,-5.066667,-37.333333
br,fernandes figueira,Fernandes Figueira,21,,-22.116667,-43.866667
br,fernandes pinheiro,Fernandes Pinheiro,18,,-25.416,-50.5498
br,fernandes pinheiro,Fernandes Pinheiro,21,,-22.066667,-43.216667
br,fernandes ribeiro,Fernandes Ribeiro,21,,-22.066667,-43.216667
br,fernando bueno,Fernando Bueno,15,,-20.8,-46.166667
br,fernando,Fernando,20,,-3.865278,-42.710278
br,fernando pedrosa,Fernando Pedrosa,22,,-5.697222,-36.530556
br,fernando pedroza,Fernando Pedroza,22,,-5.697222,-36.530556
br,fernandopolis,Fernandópolis,27,61932,-20.266667,-50.233333
br,fernando prestes,Fernando Prestes,27,,-21.266667,-48.716667
br,fernao dias,Fernão Dias,15,,-16.378889,-44.443333
br,fernao dias,Fernão Dias,18,,-23.1,-51.733333
br,fernao dias,Fernão Dias,27,,-22.35,-49.516667
br,fernao,Fernão,27,,-22.35,-49.516667
br,fernao velho,Fernão Velho,02,,-9.583333,-35.766667
br,ferquim,Ferquim,15,,-20.366667,-43.216667
br,ferradas,Ferradas,05,,-14.85,-39.35
br,ferrao,Ferrão,06,,-5.9,-40.35
br,ferrao,Ferrão,27,,-23.462474,-46.74787
br,ferrao,Ferrão,30,,-8.75,-37.066667
br,ferraria,Ferraria,18,,-25.45,-49.4
br,ferraz de vasconcelos,Ferraz de Vasconcelos,27,167904,-23.533333,-46.366667
br,ferraz,Ferraz,27,,-23.640301,-47.46586
br,ferraz,Ferraz,30,,-7.816667,-36.016667
br,ferreira,Ferreira,04,,-3.457222,-62.620278
br,ferreira,Ferreira,05,,-12.7,-40.983333
br,ferreira,Ferreira,15,,-20.9,-46.616667
br,ferreira,Ferreira,23,,-29.983333,-52.983333
br,ferreira gomes,Ferreira Gomes,03,,.8,-51.133333
br,ferreiro,Ferreiro,30,,-7.716667,-39.966667
br,ferreiropolis,Ferreirópolis,15,,-15.983333,-42.216667
br,ferreiros,Ferreiros,15,,-19.133333,-43
br,ferreiros,Ferreiros,21,,-22.416667,-43.566667
br,ferreiros,Ferreiros,30,,-7.4,-35.266667
br,ferreiro torto,Ferreiro Torto,22,,-5.85,-35.316667
br,ferrete,Ferrete,05,,-8.833333,-39.75
br,ferro novo,Ferro Novo,04,,-3.666667,-68.75
br,ferros,Ferros,15,,-19.233333,-43.033333
br,ferro velho,Ferro Velho,04,,-3.783333,-68.766667
br,ferrugem,Ferrugem,05,,-12.05,-40.766667
br,ferrugem,Ferrugem,13,,-9.883333,-46.466667
br,ferrugem,Ferrugem,23,,-29.9166,-50.7932
br,ferrugen,Ferrugen,13,,-9.883333,-46.466667
br,ferruginha,Ferruginha,15,,-18.9,-41.233333
br,fervedouro,Fervedouro,05,,-12.133333,-41.35
br,fervedouro,Fervedouro,15,,-20.733333,-42.283333
br,fetoria,Fetoria,16,,-9.233333,-57.05
br,fiacao,Fiação,02,,-9.866667,-37.05
br,fibuzanto sousa,Fibuzanto Sousa,15,,-17.116667,-41.416667
br,fidalga,Fidalga,06,,-5.483333,-40.183333
br,fidalgo,Fidalgo,15,,-19.516667,-43.966667
br,fidalgo,Fidalgo,22,,-6.316667,-38.066667
br,fidelandia,Fidelândia,15,,-18.2,-41.25
br,fidelis,Fidelis,04,,-5.574167,-59.569167
br,fidelo,Fidelo,22,,-5.124167,-36.061389
br,fidie,Fidié,13,,-4.283333,-43.316667
br,figueira branca,Figueira Branca,27,,-21.75,-47.766667
br,figueira da bandeira,Figueira da Bandeira,14,,-16.983333,-58.333333
br,figueira de braco,Figueira de Braço,18,,-25.422064,-48.817991
br,figueira de santa joanna,Figueira de Santa Joanna,08,,-19.85,-40.866667
br,figueira,Figueira,08,,-19.85,-40.866667
br,figueira,Figueira,11,,-17.666667,-56.85
br,figueira,Figueira,14,,-16.066667,-56.833333
br,figueira,Figueira,15,,-18.85,-41.933333
br,figueira,Figueira,17,,-7.666667,-38.283333
br,figueira,Figueira,18,,-23.334954,-50.234613
br,figueira,Figueira,23,,-28.416667,-53.266667
br,figueira,Figueira,26,,-28.466667,-49.366667
br,figueira,Figueira,27,,-20.833333,-48.75
br,figueiras,Figueiras,21,,-22.88896,-43.571589
br,figueiras,Figueiras,23,,-28.416667,-53.266667
br,figueiredo,Figueiredo,05,,-13.366667,-39.2
br,figueiredo,Figueiredo,06,,-6.333333,-40.066667
br,figueiredo,Figueiredo,22,,-6.266667,-37.833333
br,figueiredo,Figueiredo,30,,-7.916667,-39.266667
br,figueirinha,Figueirinha,11,,-19.083333,-57.2
br,figueropolis,Figuerópolis,31,,-12.141389,-49.114444
br,filadelfia,Filadélfia,24,,-9.1,-61.666667
br,filadelfia,Filadélfia,31,,-7.327222,-47.366111
br,filadeli,Filadéli,05,,-10.733333,-40.133333
br,filho d'anta,Filho d'Anta,05,,-11.5,-40.433333
br,filho dantas,Filho Dantas,05,,-11.5,-40.433333
br,filipe camarao,Filipe Camarão,13,,-2.85,-46.6
br,filipe camarao,Filipe Camarão,22,,-5.766667,-35.333333
br,filipe,Filipe,05,,-13.35,-40.15
br,filipe,Filipe,11,,-20.2,-55.383333
br,filipe,Filipe,15,,-14.516667,-44.633333
br,filipe turco,Filipe Turco,15,,-20.633333,-46.616667
br,filipson,Filipson,23,,-29.533333,-53.766667
br,filomena,Filomena,06,,-5.2,-40.8
br,fim do campo,Fim do Campo,27,,-23.120556,-46.715
br,fim do pasto,Fim do Pasto,13,,-3.555,-42.991944
br,final feliz,Final Feliz,21,,-22.825584,-43.387766
br,fineza,Fineza,20,,-6.6,-41.266667
br,finlandia,Finlândia,06,,-5.6,-40.05
br,fino,Finô,15,,-16.266667,-40.033333
br,fiocruz,Fiocruz,21,,-22.941072,-43.404278
br,fioduardo,Fioduardo,23,,-30.25,-55.116667
br,fioropolis,Fiorópolis,18,,-22.7,-52.15
br,firmamento,Firmamento,22,,-5.5175,-36.194444
br,firme,Firme,11,,-19.266667,-57.016667
br,firmiano,Firmiano,15,,-16.216667,-40.833333
br,firmino alves,Firmino Alves,05,,-14.983333,-39.933333
br,firmino candido,Firmino Cândido,15,,-20.35,-46.7
br,firmino ferraz,Firmino Ferraz,15,,-16.266667,-40.466667
br,firmino,Firmino,05,,-12.133333,-41.05
br,firmino,Firmino,06,,-5.2,-38.25
br,firmino,Firmino,15,,-16.066667,-40.366667
br,firmino grifo,Firmino Grifo,08,,-20.2,-41.3
br,firmino grilo,Firmino Grilo,08,,-20.2,-41.3
br,firminopolis,Firminópolis,29,9084,-16.666667,-50.316667
br,firmo,Firmo,15,,-14.65,-44.55
br,fiuza,Fiúza,06,,-4.316667,-38.516667
br,flambuaia,Flambuaiã,27,,-23.155818,-46.530213
br,flamenga,Flamenga,06,,-2.953889,-40.886667
br,flamengo,Flamengo,05,,-12.933333,-38.333333
br,flamengo,Flamengo,06,,-5.983333,-39.633333
br,flamengo,Flamengo,20,,-3.538889,-42.150833
br,flamengo,Flamengo,21,,-22.929422,-43.171882
br,flamenguinho,Flamenguinho,18,,-23.8248,-50.195
br,flarania,Flarânia,22,,-5.143889,-37.369444
br,flecha,Flecha,17,,-6.916667,-38.1
br,flechal,Flechal,16,,-2.083333,-46.483333
br,flechas,Flechas,05,,-12.383333,-38.566667
br,flechas,Flechas,11,,-19.25,-56.583333
br,flechas,Flechas,14,,-16.033333,-57.25
br,flechas,Flechas,22,,-6.316667,-38.233333
br,flecheira,Flecheira,06,,-7.25,-38.75
br,flecheira,Flecheira,13,,-3.530556,-42.72
br,flecheira,Flecheira,17,,-7.416667,-38.4
br,flecheira,Flecheira,21,,-22.935833,-43.908333
br,flecheiras,Flecheiras,02,,-9.266667,-35.716667
br,flecheiras,Flecheiras,28,,-10.716667,-36.9
br,flexal,Flexal,16,,-1.933333,-55.283333
br,flexal,Flexal,25,,3.416667,-60.3
br,flexas,Flexas,11,,-21.05,-56.083333
br,flexas,Flexas,14,,-16.033333,-57.25
br,flexeiras,Flexeiras,02,7783,-9.266667,-35.716667
br,floduardo,Floduardo,23,,-30.25,-55.116667
br,flora,Flora,01,,-8.633333,-72.866667
br,flora,Flora,04,,-3.45,-62.65
br,flora,Flora,16,,-.666667,-47.35
br,florai,Floraí,18,,-23.283333,-52.316667
br,floralia,Florália,15,,-19.95,-43.3
br,floralio,Floralio,15,,-19.95,-43.3
br,florania,Florânia,22,,-6.133333,-36.816667
br,flora rica,Flora Rica,27,,-21.666667,-51.383333
br,flor branca,Flor Branca,06,,-5.266667,-40.216667
br,flor da mata,Flor da Mata,08,,-20.233333,-41.7
br,flor da serra,Flor da Serra,20,,-6.283333,-41.35
br,flor de cipo,Flor de Cipó,05,,-13.033333,-40.55
br,flor de maio,Flor de Maio,11,,-22.883333,-55.266667
br,flor de maio,Flor de Maio,23,,-27.8,-54.2
br,flor do gaucho,Flor do Gaúcho,16,,-4.016667,-51.866667
br,flor do tempo,Flor do Tempo,13,,-5.7,-43.2
br,floreal,Floreal,27,,-20.683333,-50.116667
br,florencio ferreira,Florêncio Ferreira,15,,-20.766667,-45.45
br,florencio,Florêncio,15,,-17.266667,-41.05
br,florencio,Florêncio,25,,1.85,-61.083333
br,florescencia,Florescência,01,,-9.716667,-68.75
br,florescente,Florescente,30,,-8.733333,-35.5
br,flores da aparecida,Flores da Aparecida,08,,-20.633333,-41.533333
br,flores da cunha,Flores da Cunha,23,20522,-29.0287,-51.1822
br,flores da ribeira de pajeu,Flôres da Ribeira de Pajeú,30,,-7.85,-37.983333
br,flores do piaui,Flores do Piauí,20,,-7.833333,-42.933333
br,flores,Flores,04,,-3.9,-61.866667
br,flores,Flores,05,,-11.433333,-40.983333
br,flores,Flores,06,,-4.733333,-38.45
br,flores,Flores,13,,-3.6,-44.866667
br,flores,Flores,14,,-9.716667,-60.566667
br,flores,Flores,15,,-20.666667,-45.166667
br,flores,Flôres,17,,-6.833333,-37.833333
br,flores,Flores,20,,-5.466667,-41.516667
br,flores,Flores,22,,-5.555833,-36.531667
br,flores,Flôres,23,,-28.9,-51.566667
br,flores,Flores,24,,-9.6,-62.333333
br,flores,Flores,26,,-26.333333,-53.4
br,flores,Flores,29,,-14.566667,-47.066667
br,flores,Flores,30,11694,-7.85,-37.983333
br,flores novas,Flores Novas,06,,-5.95,-39.066667
br,floresta azul,Floresta Azul,05,,-14.85,-39.683333
br,floresta da tijuca,Floresta da Tijuca,21,,-22.957572,-43.292843
br,floresta do sul,Floresta do Sul,27,,-21.983333,-51.283333
br,floresta,Floresta,01,,-8.116667,-72.783333
br,floresta,Floresta,04,,-1.75,-65.95
br,floresta,Floresta,05,,-12.55,-38.466667
br,floresta,Floresta,06,,-4.683333,-38.583333
br,floresta,Floresta,08,,-20.7,-41.333333
br,floresta,Floresta,11,,-23.816667,-54.2
br,floresta,Floresta,14,,-9.583333,-60.55
br,floresta,Floresta,15,,-15.466667,-45.8
br,floresta,Floresta,16,,-2.05,-46.45
br,floresta,Floresta,17,,-7.533333,-36.233333
br,floresta,Floresta,18,,-23.633333,-52.116667
br,floresta,Floresta,20,,-6.133333,-41.533333
br,floresta,Floresta,21,,-21.916667,-42.433333
br,floresta,Floresta,23,,-30.020833,-51.2
br,floresta,Floresta,27,,-20.433333,-47.766667
br,floresta,Floresta,28,,-9.766667,-37.433333
br,floresta,Floresta,30,18100,-8.6,-38.566667
br,floresta,Floresta,31,,-11.616667,-46.966667
br,florestal,Florestal,06,,-5.233333,-39.166667
br,florestal,Florestal,15,,-19.9,-44.45
br,florestal,Florestal,18,,-25.45,-50.583333
br,floresta nova,Floresta Nova,17,,-7.033333,-36.833333
br,floresta sao joao,Floresta São João,18,,-25.704789,-50.085443
br,florestina,Florestina,15,,-18.483333,-48.016667
br,florestopolis,Florestópolis,18,13250,-22.866667,-51.4
br,flor,Flor,22,,-6.316667,-35.066667
br,floriano,Floriano,02,,-9.416667,-35.833333
br,floriano,Floriano,06,,-5.083333,-39.033333
br,floriano,Floriano,18,,-23.516667,-52.05
br,floriano,Floriano,20,48588,-6.783333,-43.016667
br,floriano,Floriano,21,,-22.4509,-44.3024
br,floriano hesseman,Floriano Hesseman,08,,-20.3,-40.916667
br,floriano huve,Floriano Huve,08,,-20.316667,-40.9
br,floriano huver,Floriano Huver,08,,-20.316667,-40.9
br,floriano peixoto,Floriano Peixoto,02,,-9.533333,-35.6
br,floriano peixoto,Floriano Peixoto,04,,-9.05,-67.4
br,floriano peixoto,Floriano Peixoto,06,,-5.083333,-39.033333
br,floriano peixoto,Floriano Peixoto,23,,-27.866667,-52.083333
br,florianopolis,Florianópolis,01,,-7.7,-72.65
br,florianopolis,Florianópolis,04,,-2.516667,-67.333333
br,florianopolis,Florianópolis,26,412731,-27.583333,-48.566667
br,florianos,Florianos,18,,-25.464167,-50.360833
br,floriano simmer,Floriano Simmer,08,,-20.333333,-40.866667
br,florida,Florida,11,,-21.966667,-57.616667
br,florida,Flórida,18,,-23.066667,-51.95
br,florida,Flórida,21,,-21.383333,-41.7
br,florida,Flórida,23,,-29.25,-54.6
br,florinea,Florínea,27,,-22.933333,-50.716667
br,florinia,Florínia,27,,-22.933333,-50.716667
br,florsina,Florsina,15,,-17.05,-40.633333
br,fluviopolis,Fluviópolis,18,,-26.016667,-50.616667
br,f. nova,F. Nova,11,,-19.516667,-51.85
br,fojo,Fojo,05,,-13.3,-39.533333
br,fojos,Fojos,18,,-24.966667,-50.783333
br,folego do sergio,Fôlego do Sérgio,05,,-14.1,-44.4
br,folha branca,Fôlha Branca,05,,-11.65,-40.883333
br,folha,Fôlha,05,,-12.4,-44.55
br,folha larga,Fôlha Larga,05,,-12.4,-44.55
br,folha larga,Folha Larga,13,,-3.96,-43.216111
br,folha larga,Fôlha Larga,15,,-17.066667,-42.983333
br,folha miuda,Fôlha Miúda,02,,-9.716667,-36.816667
br,folheta,Folheta,05,,-13.516667,-41.966667
br,fomento,Fomento,20,,-6.983333,-42.066667
br,fonceca,Foncêca,11,,-21.883333,-53.466667
br,fonceca,Fonceca,15,,-20.166667,-43.3
br,fonseca,Fonseca,06,,-5.466667,-39.066667
br,fonseca,Fonseca,15,,-20.166667,-43.3
br,fonseca,Fonseca,21,,-22.85,-42.05
br,fontainha,Fontainha,06,,-4.616667,-37.6
br,fonte boa,Fonte Boa,04,16060,-2.533333,-66.016667
br,fonte boa,Fonte Boa,24,,-10.733333,-62.6
br,fonte da saudade,Fonte da Saudade,21,,-22.965234,-43.199947
br,fonte de fatima,Fonte de Fátima,20,,-7.7,-42.35
br,fonte do pau-d'agua,Fonte do Pau-d'Agua,14,,-14.516667,-58.583333
br,fontela,Fontela,21,,-22.994557,-43.444213
br,fonte limpa,Fonte Limpa,08,,-20.2,-40.3
br,fonte nova,Fonte Nova,05,,-14.4,-43.683333
br,fonte rica,Fonte Rica,13,,-5.966667,-43.35
br,fontes,Fontes,21,,-22.7,-43.883333
br,fontes,Fontes,22,,-6.1,-35.4
br,fonte termal agua quente,Fonte Termal Água Quente,14,,-13.833333,-58.8
br,fonte thermal agua quente,Fonte Thermal Agua Quente,14,,-13.833333,-58.8
br,fontinha,Fontinha,13,,-3.131944,-42.478056
br,fontoura,Fontoura,31,,-11.300833,-50.605556
br,fontoura xavier,Fontoura Xavier,23,,-28.983333,-52.35
br,forca,Fôrca,15,,-18.55,-47.3
br,fordlandia,Fordlândia,16,,-3.8,-55.483333
br,forges,Forges,15,,-14.85,-44.383333
br,formate,Formate,08,,-20.366667,-40.483333
br,formiga,Formiga,05,,-13.316667,-39.266667
br,formiga,Formiga,11,,-21.3,-54.433333
br,formiga,Formiga,13,,-2.316667,-45.383333
br,formiga,Formiga,14,,-16.083333,-56.866667
br,formiga,Formiga,15,56405,-20.45,-45.416667
br,formiga,Formiga,18,,-25.133333,-53.016667
br,formiga,Formiga,20,,-6.683333,-42.366667
br,formiga,Formiga,23,,-27.95,-52.116667
br,formiga,Formiga,27,,-22.383333,-51.3
br,formiga,Formiga,30,,-7.95,-39.116667
br,formigas,Formigas,18,,-25.133333,-53.016667
br,formigueiro,Formigueiro,17,,-6.75,-38.55
br,formigueiro,Formigueiro,20,,-5.116667,-41.366667
br,formigueiro,Formigueiro,23,,-30,-53.433333
br,formigueiro,Formigueiro,30,,-7.733333,-37.533333
br,formosa de cima,Formosa de Cima,05,,-9.533333,-42.133333
br,formosa do rio preto,Formosa do Rio Prêto,05,14365,-11.046389,-45.059722
br,formosa,Formosa,05,,-10.383333,-43.466667
br,formosa,Formosa,06,,-4.083333,-38.983333
br,formosa,Formosa,11,,-19.233333,-56.783333
br,formosa,Formosa,13,,-3.436667,-42.393333
br,formosa,Formosa,14,,-15.065,-59.875
br,formosa,Formosa,17,,-7.3,-37.833333
br,formosa,Formosa,20,,-3.683333,-42.533333
br,formosa,Formosa,21,,-21.633333,-41.633333
br,formosa,Formosa,22,,-6.366667,-35
br,formosa,Formosa,23,,-29.6,-52.616667
br,formosa,Formosa,27,,-23.783333,-45.35
br,formosa,Formosa,29,81233,-15.533333,-47.333333
br,formosa,Formosa,30,,-8.783333,-36.583333
br,formos,Formos,06,,-2.8,-40.4
br,formoso de cima,Formoso de Cima,05,,-13.866667,-41.3
br,formoso do araguaia,Formoso do Araguaia,31,14963,-11.796667,-49.466944
br,formoso,Formoso,15,,-14.95,-46.233333
br,formoso,Formoso,27,,-22.633333,-44.516667
br,formoso,Formoso,29,,-13.616667,-48.9
br,formoso,Formoso,31,,-11.796667,-49.466944
br,forninho,Forninho,13,,-3.768611,-42.791944
br,forno velho,Forno Velho,22,,-5.183333,-37.4
br,forqueta,Forqueta,23,,-29.183333,-51.25
br,forquilha de cima,Forquilha de Cima,17,,-7.5,-36.45
br,forquilha,Forquilha,05,,-10.2,-38.616667
br,forquilha,Forquilha,06,,-2.9,-40.533333
br,forquilha,Forquilha,11,,-20.733333,-56.016667
br,forquilha,Forquilha,13,,-3.621389,-42.821667
br,forquilha,Forquilha,14,,-14.95,-56.366667
br,forquilha,Forquilha,15,,-16.583333,-40.816667
br,forquilha,Forquilha,18,,-24.755902,-48.776489
br,forquilha,Forquilha,20,,-3.460556,-42.197778
br,forquilha,Forquilha,22,,-5.228611,-37.321389
br,forquilha,Forquilha,26,,-27.516667,-48.783333
br,forquilha,Forquilha,27,,-24.799734,-48.397958
br,forquilha,Forquilha,30,,-8.8,-37.716667
br,forquilhas,Forquilhas,26,,-27.516667,-48.783333
br,forquilhinha,Forquilhinha,26,23021,-28.75,-49.466667
br,forquilinho,Forquilinho,26,,-28.75,-49.466667
br,forquilna,Forquilna,06,,-5.033333,-38.466667
br,forrambamba,Forrambambá,04,,-7.083333,-69.683333
br,forromeco,Forromeco,23,,-29.45,-51.4
br,fortaleza de abuna,Fortaleza de Abunã,24,,-9.783333,-65.5
br,fortaleza de a nilo coutinho,Fortaleza de A Nilo Coutinho,06,,-5.7,-40.8
br,fortaleza de ituxi,Fortaleza de Ituxi,04,,-7.483333,-66.333333
br,fortaleza de nova braganca,Fortaleza de Nova Bragança,06,,-3.716667,-38.5
br,fortaleza do abuna,Fortaleza do Abunã,24,,-9.783333,-65.5
br,fortaleza do ituxi,Fortaleza do Ituxi,04,,-7.483333,-66.333333
br,fortaleza dos nogueira,Fortaleza dos Nogueira,13,,-6.9,-46.15
br,fortaleza dos nogueiras,Fortaleza dos Nogueiras,13,,-6.9,-46.15
br,fortaleza dos valos,Fortaleza dos Valos,23,,-28.8,-53.216667
br,fortaleza do tabocao,Fortaleza do Tabocão,31,,-9.012778,-48.431944
br,fortaleza,Fortaleza,01,,-10.083333,-69.083333
br,fortaleza,Fortaleza,03,,-.366667,-52.45
br,fortaleza,Fortaleza,04,,-1.816667,-65.616667
br,fortaleza,Fortaleza,05,,-10.55,-38.6
br,fortaleza,Fortaleza,06,2416920,-3.316667,-41.416667
br,fortaleza,Fortaleza,08,,-20.366667,-41.4
br,fortaleza,Fortaleza,11,,-18.55,-54.766667
br,fortaleza,Fortaleza,13,,-1.316667,-46.133333
br,fortaleza,Fortaleza,15,,-16.016667,-41.266667
br,fortaleza,Fortaleza,16,,-1.066667,-52.533333
br,fortaleza,Fortaleza,18,,-24.3,-50.3
br,fortaleza,Fortaleza,20,,-5.533333,-41.9
br,fortaleza,Fortaleza,23,,-27.483333,-53.4
br,fortaleza,Fortaleza,24,,-11.916667,-63.4
br,fortaleza,Fortaleza,26,,-26.8681,-49.0537
br,fortaleza,Fortaleza,31,,-5.983333,-48.133333
br,fortaleza nova de braganca,Fortaleza Nova de Bragança,06,,-3.716667,-38.5
br,forte ambe,Forte Ambé,16,,-3.183333,-52.166667
br,forte coimbra,Forte Coimbra,11,,-19.916667,-57.783333
br,forte colmbra,Forte Colmbra,11,,-19.916667,-57.783333
br,forte da graca,Forte da Graça,04,,-3.616667,-66.1
br,forte de coimbra,Forte de Coimbra,11,,-19.916667,-57.783333
br,forte do abuna,Forte do Abunã,24,,-9.783333,-65.5
br,forte do coimbra,Forte do Coimbra,11,,-19.916667,-57.783333
br,forte do mato,Forte do Mato,22,,-5.774444,-37.46
br,forte do principe da beira,Forte do Principe Da Beira,24,,-12.416667,-64.416667
br,forte,Forte,04,,-3.483333,-62.616667
br,forte,Forte,16,,-3.183333,-52.166667
br,forte,Forte,20,,-6.65,-41.866667
br,forte,Forte,29,,-14.266667,-47.283333
br,forteleza,Forteleza,15,,-16.016667,-41.266667
br,forte militao formiga,Forte Militão Formiga,20,,-8.116667,-45.583333
br,forte principe da beira,Forte Principe da Beira,24,,-12.416667,-64.416667
br,forte veneza,Forte Veneza,16,,-5.083333,-52.933333
br,fortim,Fortim,06,,-4.45,-37.783333
br,fortinho,Fortinho,06,,-4.45,-37.783333
br,forto nacional,Forto Nacional,31,,-10.708056,-48.308333
br,fortuna,Fortuna,06,,-6.9,-39.45
br,fortuna,Fortuna,13,9755,-5.683333,-44.066667
br,fortuna,Fortuna,15,,-19.116667,-43.816667
br,fortuna,Fortuna,18,,-24.216667,-53.066667
br,fortuna,Fortuna,22,,-5.723056,-37.054167
br,fortuna,Fortuna,27,,-22.3,-50.283333
br,foveiros,Foveiros,20,,-7.183333,-40.866667
br,foz de iguassu,Foz de Iguassu,18,,-25.55,-54.583333
br,foz do acre,Foz do Acre,04,,-8.75,-67.383333
br,foz do aripuana,Foz do Aripuanã,04,,-5.120278,-60.378889
br,foz do ati,Foz do Ati,04,,-7.4,-70.4
br,foz do aty,Foz do Aty,04,,-7.4,-70.4
br,foz do breu,Foz do Breu,01,,-9.4,-72.7
br,foz do cahy,Foz do Cahy,05,,-17,-39.183333
br,foz do copea,Foz do Copeá,04,,-3.866667,-63.316667
br,foz do embira,Foz do Embira,04,,-7.333333,-70.233333
br,foz do iguacu,Foz do Iguaçu,18,293526,-25.55,-54.583333
br,foz do iguassu,Foz do Iguassú,18,,-25.55,-54.583333
br,foz do itucuman,Foz do Itucuman,04,,-6.983333,-69.833333
br,foz do jamari,Foz do Jamari,24,,-8.45,-63.483333
br,foz do jordao,Foz do Jordão,01,,-9.383333,-71.933333
br,foz do jutahy,Foz do Jutahy,04,,-2.733333,-66.95
br,foz do jutai,Foz do Jutaí,04,,-2.733333,-66.95
br,foz do macacoari,Foz do Macacoari,03,,.316667,-50.7
br,foz do mamoria,Foz do Mamoriá,04,,-2.45,-66.533333
br,foz do muru,Foz do Muru,01,,-8.166667,-70.766667
br,foz do pauini,Foz do Pauini,04,,-7.783333,-67.083333
br,foz do rio jau,Foz do Rio Jaú,04,,-1.9025,-61.436667
br,foz do riozinho,Foz do Riozinho,04,,-7.181389,-71.817222
br,foz do tarauaca,Foz do Tarauacá,04,,-6.7,-69.783333
br,foz do tauari,Foz do Tauari,01,,-7.933333,-71.466667
br,foz macacoari,Foz Macacoari,03,,.316667,-50.7
br,foz pauini,Foz Pauini,04,,-7.783333,-67.083333
br,foz riosinho,Foz Riosinho,04,,-7.181389,-71.817222
br,foz riozinho,Foz Riozinho,04,,-7.181389,-71.817222
br,frade,Frade,06,,-5.616667,-38.766667
br,frade,Frade,08,,-20.9,-40.983333
br,frade,Frade,17,,-7.3,-38.266667
br,frade,Frade,20,,-5.7,-41.25
br,frade,Frade,21,,-22.95,-44.433333
br,frades de baixo,Frades de Baixo,27,,-22.596111,-47.268889
br,frades de cima,Frades de Cima,27,,-22.576389,-47.286389
br,frades,Frades,13,,-5.216667,-47.966667
br,frades,Frades,21,,-22.334069,-42.754247
br,frades,Frades,27,,-22.557778,-47.26
br,fraga,Fraga,20,,-7.433333,-41.016667
br,fragas,Fragas,27,,-23.324389,-47.895741
br,fragoso,Fragoso,05,,-12.4,-38.5
br,fragoso,Fragoso,21,,-22.588889,-43.183333
br,fragosos,Fragosos,26,,-26.16,-49.3839
br,franca,França,05,,-10.183333,-42.533333
br,franca,França,06,,-6.216667,-38.733333
br,franca,Franca,27,305047,-20.533333,-47.4
br,francelino,Francelino,23,,-29.9262,-50.8211
br,francesa,Francesa,15,,-16.033333,-39.95
br,frances dos carvalhos,Francês dos Carvalhos,15,,-22.083333,-44.483333
br,frances,Francês,02,,-9.733333,-35.816667
br,frances,Francês,16,,-4.8,-56.583333
br,francez dos carvalhos,Francez dos Carvalhos,15,,-22.083333,-44.483333
br,francez,Francez,02,,-9.733333,-35.816667
br,francez,Francez,16,,-4.8,-56.583333
br,francinopolis,Francinópolis,20,,-6.433333,-42.266667
br,francisco afonso,Francisco Afonso,15,,-20.583333,-45.216667
br,francisco aires,Francisco Aires,20,,-6.616667,-42.683333
br,francisco alves,Francisco Alves,18,,-24.066667,-53.833333
br,francisco araujo,Francisco Araújo,15,,-21.4,-45.616667
br,francisco badaro,Francisco Badaró,15,,-17.05,-42.316667
br,francisco beltrao,Francisco Beltrão,18,57618,-26.083333,-53.066667
br,francisco caetano,Francisco Caetano,15,,-20.516667,-46.633333
br,francisco d'abila,Francisco d'Abila,23,,-31.883333,-53.166667
br,francisco dantas,Francisco Dantas,22,,-6.066667,-38.166667
br,francisco da rocha,Francisco da Rocha,27,,-23.324821,-46.718475
br,francisco das chagas,Francisco das Chagas,29,,-15.916667,-49.266667
br,francisco de sales,Francisco de Sales,15,,-19.866667,-49.766667
br,francisco de salles,Francisco de Salles,15,,-19.866667,-49.766667
br,francisco dos reis,Francisco dos Reis,03,,.316667,-51.15
br,francisco esteves,Francisco Esteves,15,,-21.466667,-45.916667
br,francisco ferreira,Francisco Ferreira,15,,-17.55,-41.35
br,francisco,Francisco,04,,-5.667222,-60.269722
br,francisco,Francisco,15,,-15.8,-43.95
br,francisco,Francisco,16,,-5.633333,-57.05
br,francisco,Francisco,17,,-7.2,-38.333333
br,francisco gonzaga,Francisco Gonzaga,29,,-17.4,-48.7
br,francisco graciano,Francisco Graciano,15,,-21.866667,-46.2
br,francisco lourenco,Francisco Lourenço,15,,-17.066667,-41.45
br,francisco lucas,Francisco Lucas,14,,-13.116667,-55.933333
br,francisco luciano,Francisco Luciano,08,,-20.033333,-41.25
br,francisco miranda,Francisco Miranda,15,,-21.366667,-45.683333
br,francisco monteiro,Francisco Monteiro,15,,-15.25,-44.933333
br,francisco morato,Francisco Morato,27,171793,-23.279503,-46.746403
br,francisco narciso,Francisco Narciso,04,,1.566667,-67.183333
br,francisco pereira,Francisco Pereira,15,,-21.466667,-46.233333
br,francisco pinho,Francisco Pinho,15,,-20.8,-45.65
br,francisco quirino,Francisco Quirino,27,,-23.083333,-47.166667
br,francisco rodrigues,Francisco Rodrigues,15,,-20.35,-45.533333
br,francisco sa,Francisco Sá,15,13997,-16.466667,-43.5
br,francisco sales,Francisco Sales,15,,-21.7,-44.45
br,francisco santos,Francisco Santos,20,,-6.983333,-41.133333
br,francisco silva,Francisco Silva,15,,-21.283333,-45.8
br,francisco sousa,Francisco Sousa,05,,-13.85,-41.05
br,francisco tuta,Francisco Tuta,15,,-21.1,-47.1
br,francisco venancio,Francisco Venâncio,15,,-20.5,-45.116667
br,francisco vilela,Francisco Vilela,15,,-20.983333,-46.333333
br,francisco xavier,Francisco Xavier,15,,-17.616667,-41.4
br,francisco xavier,Francisco Xavier,29,,-17.133333,-48.6
br,franco da rocha,Franco da Rocha,27,108860,-23.324821,-46.718475
br,franco,Franco,06,,-3.133333,-39.45
br,frango,Frango,30,,-8.1,-36.616667
br,franklin,Franklin,04,,-5.4,-71.95
br,franquilino marques,Franquilino Marques,15,,-16.533333,-41.766667
br,franquinha,Franquinha,03,,.9,-50.083333
br,franquinho,Franquinho,03,,.9,-50.083333
br,frazao,Frazão,11,,-21.483333,-56.816667
br,frechal,Frechal,04,,-4.3,-59.5
br,frechal,Frechal,16,,-5.333333,-56.816667
br,frecheira,Frecheira,13,,-2.633333,-43.55
br,frecheira,Frecheira,17,,-6.383333,-38.55
br,frecheira,Frecheira,20,,-3.366667,-41.6
br,frecheira,Frecheira,30,,-8.983333,-36.566667
br,frecheiras,Frecheiras,02,,-9.266667,-35.716667
br,frecheiras,Frecheiras,05,,-12.55,-38.066667
br,frecheiras,Frecheiras,06,,-2.927222,-40.688611
br,frecheiras,Frecheiras,08,,-21.033333,-41.183333
br,frecheiras,Frecheiras,13,,-2.633333,-43.55
br,frecheiras,Frecheiras,20,,-3.366667,-41.6
br,frecheiras,Frecheiras,30,,-8.4,-35.316667
br,frecheirinha,Frecheirinha,06,,-3.766667,-40.8
br,frecheirinhas,Frecheirinhas,06,,-3.766667,-40.8
br,fredericia,Frederícia,17,,-7.116667,-34.866667
br,frederico westphalen,Frederico Westphalen,23,20896,-27.366667,-53.4
br,freguesia da lagoa,Freguesia da Lagoa,26,,-27.483333,-51.4
br,freguesia do andira,Freguesia do Andirá,04,,-2.85,-57
br,freguesia do o,Freguesia do O,27,,-23.498773,-46.699829
br,freguesia,Freguesia,18,,-25.176839,-48.992474
br,freguesia,Freguesia,21,,-22.789548,-43.172061
br,freguezia da lagoa,Freguezia da Lagoa,26,,-27.483333,-51.4
br,freguezia do andira,Freguezia do Andirá,04,,-2.85,-57
br,freguezia,Freguezia,04,,-2.85,-57
br,freguezia,Freguezia,21,,-22.789548,-43.172061
br,freicheiras,Freicheiras,13,,-2.85,-42.083333
br,freicheiras,Freicheiras,20,,-3.366667,-41.6
br,frei eustaquio,Frei Eustáquio,15,,-21.183333,-45.366667
br,frei gaspar,Frei Gaspar,15,,-18.083333,-41.433333
br,frei gonzaga,Frei Gonzaga,15,,-17.433333,-41.183333
br,frei inocencio,Frei Inocêncio,15,,-18.55,-41.9
br,frei jorge,Frei Jorge,06,,-2.95,-40.333333
br,frei manuel,Frei Manuel,14,,-15.766667,-56.666667
br,frei martinho,Frei Martinho,17,,-6.4,-36.45
br,frei matins,Frei Matins,17,,-7.133333,-37.716667
br,frei miguelinho,Frei Miguelinho,30,,-7.95,-35.95
br,frei orlando,Frei Orlando,15,,-18.833333,-45.266667
br,frei paulo,Frei Paulo,28,7047,-10.55,-37.533333
br,freire alemao,Freire Alemão,29,,-16.816667,-49.916667
br,freire,Freire,23,,-31.666667,-52.816667
br,frei rogerio,Frei Rogério,26,,-27.183333,-50.833333
br,frei serafim,Frei Serafim,15,,-18.15,-41.85
br,freitas,Freitas,05,,-9.283333,-38.266667
br,freitas,Freitas,18,,-23.6854,-49.7532
br,freitas,Freitas,23,,-29.9935,-50.9788
br,freitas,Freitas,30,,-7.816667,-35.566667
br,frei timoteo,Frei Timóteo,18,,-23.216667,-50.95
br,frei timotheo,Frei Timótheo,18,,-23.216667,-50.95
br,freixal,Freixal,16,,-1.183333,-51.133333
br,freixeira,Freixeira,13,,-2.633333,-43.55
br,freixeiras,Freixeiras,05,,-12.55,-38.066667
br,freixeiras,Freixeiras,13,,-2.85,-42.083333
br,frexeiras,Frexeiras,05,,-12.55,-38.066667
br,frexeiras,Frexeiras,06,,-3.233333,-39.266667
br,frexeiras,Frexeiras,30,,-8.4,-35.316667
br,frexeirinha,Frexeirinha,06,,-3.766667,-40.8
br,fria,Fria,05,,-12.433333,-40.683333
br,frial,Frial,15,,-19.783333,-47.666667
br,frias,Frias,26,,-26.233333,-48.716667
br,friburgo,Friburgo,04,,-7.783333,-70.983333
br,frigideira,Frigideira,13,,-3.977222,-43.214722
br,frigorifico,Frigorífico,27,,-20.583333,-48.533333
br,frio,Frio,05,,-12.4,-42.9
br,frio,Frio,30,,-8.866667,-35.633333
br,frois,Fróis,15,,-16.566667,-45.933333
br,fronteira,Fronteira,01,,-10.583333,-68.966667
br,fronteiras,Fronteiras,20,,-7.083333,-40.616667
br,fronteiro,Fronteiro,06,,-7.283333,-38.866667
br,frozinho,Frozinho,20,,-5.6,-41.216667
br,fructal,Fructal,15,,-20.033333,-48.916667
br,fructuoso,Fructuoso,24,,-13.533333,-60.95
br,fruta de leite,Fruta de Leite,15,,-16.133333,-42.483333
br,frutal do campo,Frutal do Campo,27,,-22.85,-50.516667
br,frutal,Frutal,15,40931,-20.033333,-48.916667
br,frutal,Frutal,27,,-20.583333,-47.316667
br,fruteira,Fruteira,20,,-5.5,-42.9
br,fruteiras,Fruteiras,21,,-22.416667,-41.866667
br,frutuoso,Frutuoso,24,,-13.533333,-60.95
br,fua,Fua,17,,-6.85,-38.466667
br,fuba,Fubá,21,,-22.889219,-43.333018
br,fugida,Fugida,13,,-3.35,-44.416667
br,fugido,Fugido,13,,-3.45,-46.083333
br,fulu,Fulu,15,,-19.1,-41.3
br,fumaca,Fumaça,04,,-5.488889,-59.651111
br,fumaca,Fumaça,05,,-13.283333,-40.566667
br,fumaca,Fumaça,13,,-2.733333,-46.65
br,fumaca,Fumaça,14,,-15.966667,-58.3
br,fumaca,Fumaça,21,,-22.298,-44.3099
br,fuma,Fuma,27,,-20.8,-47.283333
br,fumal,Fumal,20,,-6.45,-41.8
br,fumo,Fumo,06,,-5.8,-40.533333
br,funchal,Funchal,15,,-19.283333,-45.9
br,fundacao,Fundação,18,,-24.997619,-48.816866
br,fundao de zombaria,Fundão de Zombaria,30,,-8.266667,-36.65
br,fundao,Fundão,05,,-12.016667,-38.1
br,fundao,Fundão,06,,-5.966667,-39.55
br,fundao,Fundão,08,12715,-19.916667,-40.4
br,fundao,Fundão,15,,-20.333333,-45.966667
br,fundao,Fundão,17,,-6.35,-38.483333
br,fundao,Fundão,18,,-25.8,-51.983333
br,fundao,Fundão,27,,-23.5743,-47.9331
br,fundao,Fundão,30,,-8.333333,-36.6
br,fundinho,Fundinho,14,,-16.716667,-56.666667
br,fundinho,Fundinho,17,,-7.35,-37.516667
br,fundo do canoas,Fundo do Canoas,26,,-27.198345,-49.674522
br,fundoes,Fundoes,30,,-7.433333,-37.45
br,fundo,Fundo,05,,-11.883333,-43.133333
br,fundo,Fundo,11,,-20.983333,-53.316667
br,fundo,Fundo,13,,-6.1,-44.25
br,fundo leao,Fundo Leão,26,,-27.037,-49.6861
br,funilandia,Funilândia,15,,-19.35,-44.05
br,funil de baixo,Funil de Baixo,27,,-23.729811,-47.472912
br,funil,Funil,01,,-9.116667,-70.166667
br,funil,Funil,05,,-11.4,-44.316667
br,funil,Funil,13,,-3.448611,-42.866667
br,funil,Funil,15,,-19.35,-44.05
br,funil,Funil,21,,-21.616667,-42.083333
br,funil,Funil,27,,-23.724324,-47.454727
br,funil,Funil,31,,-9.683333,-48.383333
br,funis,Funis,05,,-12.95,-41.916667
br,furada,Furada,06,,-5.75,-40.866667
br,furada,Furada,08,,-19.983333,-40.333333
br,furado,Furado,05,,-11.883333,-43.133333
br,furado olhos d'agua,Furado Olhos d'Agua,15,,-16.4,-43.933333
br,furados,Furados,05,,-12.85,-41.7
br,furna da onca,Furna da Onça,20,,-6.866667,-40.966667
br,furna,Furna,05,,-13.466667,-41.766667
br,furna,Furna,15,,-22.183333,-45.816667
br,furnas,Furnas,05,,-13.466667,-41.766667
br,furnas,Furnas,06,,-4.55,-38.666667
br,furnas,Furnas,13,,-3.664444,-43.245278
br,furnas,Furnas,18,,-24.783333,-49.033333
br,furnas,Furnas,20,,-3.539722,-42.494722
br,furnas,Furnas,22,,-5.766667,-35.783333
br,furnas,Furnas,27,,-22.366667,-47.433333
br,furnas,Furnas,30,,-8.133333,-36.316667
br,furquim,Furquim,15,,-20.366667,-43.216667
br,furquim,Furquim,27,,-21.066667,-51.283333
br,furtado de campos,Furtado de Campos,15,,-21.45,-43.066667
br,furtados,Furtados,15,,-20.766667,-45.15
br,furtainha,Furtaínha,22,,-5.866667,-35.95
br,furta-lhe-a-vida,Furta-lhe-a-Vida,20,,-6.75,-41.85
br,furundum,Furundum,27,,-23.506556,-47.163849
br,futrica,Futrica,20,,-6.95,-41.083333
br,futuro,Futuro,02,,-9.716667,-37.433333
br,futuro,Futuro,20,,-7.116667,-41.533333
br,futuro,Futuro,22,,-5.468056,-36.98
br,fuzil,Fuzil,13,,-7.833333,-46.983333
br,gabiarra,Gabiarra,05,,-16.25,-39.683333
br,gabiroba,Gabiroba,26,,-28.15,-49.016667
br,gabriel emilio,Gabriel Emílio,15,,-18.783333,-40.983333
br,gabriel franco,Gabriel Franco,15,,-21.8,-46.233333
br,gabriel,Gabriel,05,,-11.233333,-41.883333
br,gabriel lobo,Gabriel Lôbo,15,,-17.033333,-40.816667
br,gabriel martins,Gabriel Martins,15,,-21.15,-46.583333
br,gabriel monteiro,Gabriel Monteiro,27,,-21.533333,-50.566667
br,gabriel piza,Gabriel Piza,27,,-23.561194,-47.123849
br,gadelha,Gadelha,06,,-6.416667,-39.283333
br,gado brabo,Gado Brabo,13,,-6.316667,-42.966667
br,gado bravo,Gado Bravo,05,,-10.733333,-40.566667
br,gado bravo,Gado Bravo,06,,-5.283333,-40.566667
br,gado bravo,Gado Bravo,17,,-6.75,-37.7
br,gado bravo,Gado Bravo,20,,-5.583333,-42.883333
br,gado bravo,Gado Bravo,22,,-4.868056,-37.244444
br,gado bravo,Gado Bravo,28,,-10.516667,-37.283333
br,gado bravo,Gado Bravo,30,,-8.5,-36.316667
br,gado,Gado,06,,-4.133333,-38.9
br,gado manso,Gado Manso,13,,-3.881389,-43.494444
br,gado velhaco,Gado Velhaco,20,,-6.516667,-42.033333
br,gafanhoto,Gafanhoto,06,,-4.616667,-38.083333
br,gafanhoto,Gafanhoto,15,,-20.083333,-44.883333
br,gaivota,Gaivota,03,,.4,-51.783333
br,gaivota,Gaivota,04,,-5.61,-63.439167
br,gaivotas,Gaivotas,04,,-5.61,-63.439167
br,gajueiro,Gajueiro,16,,-7.8,-49.933333
br,galante,Galante,17,,-7.116667,-38.433333
br,galao,Galão,31,,-10.616667,-46.25
br,galdino,Galdino,05,,-16.366667,-39.85
br,galdino,Galdino,06,,-4.85,-39.9
br,galdino,Galdino,15,,-16.416667,-41.483333
br,galeao,Galeão,05,,-13.4,-39.016667
br,galeao,Galeão,21,,-22.804054,-43.239784
br,galena,Galena,15,,-18.35,-46.116667
br,galeno,Galeno,05,,-13.4,-39.016667
br,galha,Galha,15,,-16.1,-40.133333
br,galhao,Galhão,31,,-10.616667,-46.25
br,galhardo,Galhardo,05,,-12.2,-38.2
br,galheiro,Galheiro,05,,-14.266667,-44.583333
br,galheiro,Galheiro,11,,-18.966667,-51.95
br,galheiro,Galheiro,13,,-9.45,-45.8
br,galheiro,Galheiro,29,,-13.3,-46.416667
br,galheiros,Galheiros,29,,-13.3,-46.416667
br,galia,Gália,27,,-22.3,-49.566667
br,galileia,Galiléia,04,,-7.35,-62.933333
br,galileia,Galiléia,06,,-5.9,-40.583333
br,galileia,Galiléia,13,,-9.983333,-46.366667
br,galileia,Galiléia,15,,-19,-41.55
br,galinha,Galinha,02,,-9.583333,-36.933333
br,galinha,Galinha,15,,-17.616667,-46.033333
br,galinhas,Galinhas,06,,-6.25,-38.566667
br,galinhos,Galinhos,05,,-18.016667,-39.983333
br,galinhos,Galinhos,22,,-5.090556,-36.273611
br,gallia,Gallia,27,,-22.3,-49.566667
br,gallinhos,Gallinhos,22,,-5.090556,-36.273611
br,galo de ouro,Galo de Ouro,27,,-23.170213,-47.725132
br,galopolis,Galópolis,23,,-29.2307,-51.1573
br,galos,Galos,22,,-5.0975,-36.242222
br,galuado,Galuado,17,,-6.9,-37.733333
br,galvao,Galvão,26,,-26.466667,-52.65
br,galvao,Galvão,27,,-22.8,-47.416667
br,gama,Gama,07,,-15.95,-48.083333
br,gama,Gama,15,,-19.133333,-42.383333
br,gama,Gama,20,,-5.316667,-41.7
br,gamaleira,Gamaleira,31,,-10.85,-47.7
br,gambas,Gambás,05,,-11.016667,-42.466667
br,gamboa,Gamboa,05,,-12.983333,-38.6
br,gamboa,Gamboa,06,,-2.978056,-40.8375
br,gamboa,Gamboa,21,,-22.897567,-43.192758
br,gamboa,Gamboa,26,,-26.334,-48.6311
br,gamboa grande,Gamboa Grande,05,,-13.05,-38.8
br,gamela,Gamela,02,,-9.016667,-35.216667
br,gamela,Gamela,13,,-3.974167,-42.927222
br,gamela,Gamela,30,,-8.666667,-35.083333
br,gamelao,Gamelão,14,,-15.483333,-57.833333
br,gameleina,Gameleina,16,,-8.666667,-49.583333
br,gameleira da lagoa do boi,Gameleira da Lagoa do Boi,05,,-11.916667,-41.716667
br,gameleira da lapa,Gameleira da Lapa,05,,-12.866667,-43.366667
br,gameleira de aurelio,Gameleira de Aurélio,05,,-14.3,-41.283333
br,gameleira de sao sebastiao,Gameleira de São Sebastião,06,,-7.25,-39.116667
br,gameleira do assurua,Gameleira do Assuruá,05,,-11.3,-42.666667
br,gameleira dos machados,Gameleira dos Machados,05,,-14.25,-41.45
br,gameleira,Gameleira,02,,-10.083333,-36.483333
br,gameleira,Gameleira,05,,-10.183333,-42.716667
br,gameleira,Gameleira,06,,-3.766667,-39.966667
br,gameleira,Gameleira,11,,-20.616667,-54.633333
br,gameleira,Gameleira,13,,-3.883333,-45.183333
br,gameleira,Gameleira,15,,-16.183333,-41.566667
br,gameleira,Gameleira,16,,-7.75,-49.9
br,gameleira,Gameleira,17,,-6.616667,-37.916667
br,gameleira,Gameleira,20,,-2.95,-41.7
br,gameleira,Gameleira,22,,-5.65,-35.566667
br,gameleira,Gameleira,28,,-10.416667,-37.683333
br,gameleira,Gameleira,30,19424,-8.583333,-35.4
br,gameleira,Gameleira,31,,-10.85,-47.7
br,gameleira i,Gameleira I,13,,-3.807222,-42.813333
br,gameleira ii,Gameleira II,13,,-3.886389,-42.805278
br,gameleiras,Gameleiras,05,,-13.6,-40.233333
br,gameleiras,Gameleiras,15,,-15.083333,-43.133333
br,gameleiras,Gameleiras,20,,-6.083333,-41.483333
br,gameleira velha,Gameleira Velha,20,,-3.536667,-42.429444
br,gameleiro,Gameleiro,05,,-11.683333,-40.833333
br,gamelera,Gameléra,16,,-7.75,-49.9
br,gamelleira do assurua,Gamelleira do Assuruá,05,,-11.3,-42.666667
br,gamelleira,Gamelleira,05,,-11.816667,-42.65
br,gamelleira,Gamelleira,06,,-4.016667,-41.2
br,gamelleira,Gamelleira,15,,-15.083333,-43.133333
br,gamelleira,Gamelleira,16,,-7.75,-49.9
br,gamelleira,Gamelleira,30,,-8.583333,-35.4
br,gamelleira,Gamelleira,31,,-10.85,-47.7
br,gamelleiras,Gamelleiras,15,,-15.083333,-43.133333
br,gancho,Gancho,13,,-3.516667,-44.766667
br,gancho,Gancho,31,,-11.668889,-48.935556
br,ganchos,Ganchos,26,,-27.316667,-48.583333
br,gandhi,Gandhi,18,,-22.95,-51.15
br,gandu da laje,Gandú da Laje,05,,-13.75,-39.566667
br,gandu do laje,Gandu do Laje,05,,-13.75,-39.566667
br,gandu,Gandu,05,21566,-13.75,-39.5
br,gangorra,Gangorra,06,,-3.683333,-40.166667
br,gangorra,Gangorra,15,,-16.9,-42.616667
br,gangorra,Gangorra,17,,-6.5,-37.833333
br,gangorra,Gangorra,20,,-5.383333,-41.8
br,gangorra,Gangorra,22,,-4.933889,-37.301389
br,gangorra,Gangorra,30,,-7.816667,-37.616667
br,gangorras,Gangorras,15,,-16.9,-42.616667
br,gangorrinha,Gangorrinha,15,,-17.166667,-41.7
br,gangua,Gangúa,17,,-7.8,-38.266667
br,gangu,Gangu,05,,-11.6,-38.1
br,ganupo cervo,Ganupo Cervo,14,,-17.083333,-54.016667
br,garacui,Garacuí,18,,-24.713033,-48.677725
br,garaiber,Garaiber,13,,-6.416667,-42.866667
br,garajuba,Garajuba,05,,-12.7,-38.1
br,garajuva,Garajuva,26,,-28.883333,-49.483333
br,garamparo,Garamparo,13,,-3.048611,-43.397222
br,garancia,Garancia,04,,-7.1,-64.683333
br,garanhane,Garanhane,18,,-23.6188,-49.7763
br,garanhuns,Garanhuns,30,110087,-8.9,-36.483333
br,garapa de cima,Garapa de Cima,06,,-4.216667,-38.633333
br,garapa,Garapa,05,,-11.233333,-41.35
br,garapa,Garapa,06,,-4.216667,-38.633333
br,garapa,Garapa,25,,4.216667,-60.816667
br,garapua,Garapuá,05,,-13.483333,-38.916667
br,garapuava,Garapuava,15,,-16.1,-46.55
br,gararu,Gararu,28,2977,-9.966667,-37.083333
br,garatuba,Garatuba,18,,-25.35,-49.15
br,garauna,Garauna,06,,-5.3,-39.433333
br,garca,Garça,03,,1.866667,-50.8
br,garca,Garça,06,,-5.283333,-40.683333
br,garca,Garça,27,41303,-22.233333,-49.616667
br,garces,Garcês,23,,-29.666667,-51.25
br,garcez,Garcez,23,,-29.666667,-51.25
br,garcia,Garcia,02,,-9.383333,-37.083333
br,garcia,Garcia,15,,-18.616667,-49
br,garcia,Garcia,26,,-27.483333,-48.983333
br,garcia,Garcia,27,,-23.057457,-47.741826
br,garcia,Garcia,30,,-8.983333,-37.016667
br,garcias,Garcias,11,,-20.566667,-52.216667
br,garcias,Garcias,15,,-20.8,-45.2
br,gardenia azul,Gardênia Azul,21,,-22.960505,-43.35033
br,gardenia,Gardenia,15,,-19.25,-48.683333
br,gardenia,Gardênia,27,,-22.616667,-50.9
br,garganta do leandro,Garganta do Leandro,18,,-24.866667,-49.05
br,garganta do lizandro,Garganta do Lizandró,18,,-24.866667,-49.05
br,garganta,Garganta,02,,-9.5,-37.016667
br,garganta,Garganta,05,,-14.733333,-39.55
br,garganta,Garganta,20,,-6.683333,-40.533333
br,garganta,Garganta,22,,-6.1,-36.9
br,gargau,Gargaú,17,,-7.05,-34.9
br,gargau,Gargaú,21,,-21.583333,-41.066667
br,gargorra,Gargorra,20,,-8.783333,-42.2
br,garhaubinha,Garhaubinha,06,,-6.466667,-38.783333
br,garibaldi,Garibaldi,23,30364,-29.25,-51.533333
br,garibaldi,Garibaldi,26,,-26.533333,-49.216667
br,garibe,Garibé,05,,-13.133333,-38.983333
br,garimpo cervo,Garimpo Cervo,14,,-17.083333,-54.016667
br,garimpo das canoas,Garimpo das Canoas,15,,-20.4,-47.283333
br,garimpo do jenipapo,Garimpo do Jenipapo,31,,-7.616667,-49.2
br,garimpo,Garimpo,15,,-18.816667,-47.666667
br,garimpo luciano,Garimpo Luciano,29,,-16.833333,-52.966667
br,garimpo novo,Garimpo Novo,14,,-15.9,-54.433333
br,garimpo rio claro,Garimpo Rio Claro,14,,-13.75,-56.683333
br,gariroba,Gariroba,18,,-23.839628,-50.856787
br,garopaba,Garopaba,26,,-28.066667,-48.666667
br,garopada,Garopada,26,,-28.066667,-48.666667
br,garrafa,Garrafa,11,,-19.733333,-56.383333
br,garrafao,Garrafão,08,,-20.15,-40.816667
br,garrafao,Garrafão,20,,-3.924722,-42.398889
br,garrafao,Garrafão,21,,-21.233333,-41.4
br,garra,Garra,17,,-7.316667,-37.616667
br,garrota morta,Garrota Morta,22,,-6.2,-37.966667
br,garrote,Garrote,02,,-9.416667,-37.15
br,garrote,Garrote,06,,-3.533333,-39.916667
br,garrote,Garrote,13,,-8.25,-46.083333
br,garrote,Garrote,17,,-7.083333,-38.033333
br,garrote,Garrote,30,,-8.866667,-36.2
br,garrotes,Garrotes,17,,-7.383333,-38
br,garruchos,Garruchos,23,,-28.183333,-55.65
br,garuba,Garuba,26,,-26.9477,-49.012
br,garuva acima,Garuva Acima,26,,-25.983324,-48.878435
br,garuva,Garuva,26,,-25.983324,-48.878435
br,gaspar alto,Gaspar Alto,26,,-26.9967,-49.0371
br,gaspar alves,Gaspar Alves,15,,-17.383333,-41.283333
br,gaspar do meio,Gaspar do Meio,26,,-26.9942,-49.0467
br,gaspar,Gaspar,26,33659,-26.933333,-48.966667
br,gaspar martins,Gaspar Martins,23,,-29.4,-51.95
br,gaspar simoes,Gaspar Simões,23,,-30.5081,-52.3265
br,gastao vidigal,Gastão Vidigal,27,,-20.8,-50.166667
br,gata branca,Gata Branca,15,,-20.2224,-43.8477
br,gate espeto,Gaté Espeto,16,,-1.333333,-50.416667
br,gatinho,Gatinho,14,,-14.5,-56.516667
br,gato,Gato,02,,-9.166667,-37.75
br,gato,Gato,05,,-9.116667,-38.4
br,gato,Gato,06,,-6.116667,-40.683333
br,gato,Gato,13,,-5.95,-46.416667
br,gato,Gato,20,,-8.966667,-42.2
br,gatos,Gatos,05,,-12.316667,-39.3
br,gatos,Gatos,17,,-7.383333,-38.416667
br,gaturamo,Gaturamo,27,,-21.266667,-47.816667
br,gauacu,Gauacu,22,,-5.55,-35.9
br,gaucha,Gaúcha,14,,-15.066667,-58.566667
br,gaucha,Gaúcha,18,,-25.35,-54.166667
br,gaucho,Gaúcho,15,,-20.566667,-45.1
br,gauer,Gauer,23,,-27.716667,-52.283333
br,gaujiru,Gaujiru,22,,-5.066667,-35.866667
br,gaupo,Gaupó,13,,-2.833333,-45.033333
br,gaurama,Gaurama,23,,-27.566667,-52.05
br,gavao peixoto,Gavão Peixoto,27,,-21.833333,-48.5
br,gavea,Gávea,21,,-22.975777,-43.234925
br,gavea pequena,Gávea Pequena,21,,-22.976366,-43.277772
br,gaviao,Gavião,02,,-9.466667,-36.7
br,gaviao,Gavião,04,,-4.839167,-66.854444
br,gaviao,Gavião,05,,-11.466667,-39.783333
br,gaviao,Gavião,06,,-6.083333,-40.666667
br,gaviao,Gavião,13,,-3.080833,-42.287222
br,gaviao,Gavião,17,,-7.6,-37.766667
br,gaviao,Gavião,20,,-9.316667,-43.316667
br,gaviao,Gavião,22,,-5.907778,-37.189722
br,gaviao,Gavião,30,,-7.7,-38.316667
br,gaviao peixoto,Gavião Peixoto,27,,-21.833333,-48.5
br,gaviaosinho,Gaviãosinho,04,,-6.516667,-68.833333
br,gaviaozinho,Gaviãozinho,04,,-6.516667,-68.833333
br,gavioes,Gaviões,21,,-22.566667,-42.55
br,gaza,Gaza,05,,-11.233333,-42.083333
br,gazea,Gázea,06,,-4.683333,-40.733333
br,geada,Geada,27,,-22.576944,-47.473333
br,gelo,Gêlo,16,,-9.233333,-57.05
br,gemilina,Gemilina,18,,-25.497431,-48.836272
br,general brito,General Brito,26,,-26.026784,-49.990317
br,general camara,General Câmara,23,,-29.9,-51.766667
br,general carneiro,General Carneiro,14,,-15.7,-52.75
br,general carneiro,General Carneiro,15,,-19.833333,-43.833333
br,general carneiro,General Carneiro,18,,-26.466667,-51.416667
br,general daltro filho,General Daltro Filho,23,,-29.333333,-51.766667
br,general daltro filho,General Daltro Filho,26,,-26.866667,-51.05
br,general dutra,General Dutra,26,,-26.5,-51.083333
br,general osorio,General Osório,18,,-24.716667,-53.9
br,general osorio,General Osório,21,,-22.203056,-43.724167
br,general rondon,General Rondon,14,,-16.5,-54.633333
br,general rondon,General Rondon,18,,-24.566667,-54.066667
br,general salgado,General Salgado,27,8084,-20.65,-50.366667
br,general sampaio,General Sampaio,06,,-4.033333,-39.483333
br,general tiburcio,General Tibúrcio,06,,-3.5,-41.116667
br,general vargas,General Vargas,23,,-29.7,-54.666667
br,generica,Genérica,25,,4.483333,-60
br,generoso,Generoso,18,,-26.116667,-52.183333
br,generoso gomes,Generoso Gomes,15,,-17.683333,-41.633333
br,generoso ponce,Generoso Ponce,24,,-9.25,-64.383333
br,genesio,Genêsio,15,,-17.166667,-41.433333
br,genesio molin,Genésio Molin,23,,-29.0575,-51.034
br,genipapeiro,Genipapeiro,06,,-3.966667,-38.4
br,genipapeiro,Genipapeiro,20,,-7.816667,-41.666667
br,genipapo,Genipapo,04,,-5.571944,-60.921111
br,genipapo,Genipapo,05,,-11.616667,-45.016667
br,genipapo,Genipapo,16,,-.7,-49.166667
br,genipapo,Genipapo,20,,-6.033333,-41.383333
br,genipapo,Genipapo,30,,-8.283333,-36.566667
br,gentileza,Gentileza,28,,-9.8,-37.433333
br,gentil,Gentil,06,,-7.8,-39.05
br,gentil,Gentil,16,,-2.033333,-49.25
br,gentil,Gentil,18,,-24.416667,-49.633333
br,gentil,Gentil,20,,-7.183333,-41.683333
br,gentio de ouro,Gentio de Ouro,05,,-11.416667,-42.5
br,gentio do meio,Gentio do Meio,05,,-12.983333,-39.616667
br,gentio do ouro,Gentio do Ouro,05,,-11.416667,-42.5
br,gentio,Gentio,05,,-12.866667,-41.733333
br,gentio,Gentio,15,,-15.7,-45.233333
br,gentio,Gentio,18,,-24.416667,-49.633333
br,genuino,Genuíno,04,,-4.016667,-59.083333
br,genuino sampaio,Genuino Sampaio,23,,-29.65,-51.183333
br,geolandia,Geolândia,05,,-12.55,-39.083333
br,geomelino garcia,Geomelino Garcia,15,,-21.15,-46.933333
br,gequi,Gequí,30,,-8.65,-39.65
br,gerais,Gerais,05,,-13.1,-41.866667
br,geraizinho,Geraizinho,15,,-15.833333,-41.383333
br,geraldino,Geraldino,15,,-21.833333,-45.816667
br,geraldo lemos,Geraldo Lemos,15,,-20.783333,-46.633333
br,geral,Geral,20,,-6.666667,-40.6
br,gercinopolis,Gercinópolis,29,,-17.1,-49.633333
br,gerdau cosigua,Gerdau Cosigua,21,,-22.901391,-43.747547
br,geremeira,Geremeira,05,,-12.183333,-39.35
br,geremoabo,Geremoabo,05,,-10.066667,-38.35
br,geremuniz,Geremuniz,27,,-23.342,-46.2221
br,gerencia,Gerência,05,,-13.283333,-40.333333
br,gererau,Gereraú,06,,-3.916667,-38.55
br,gergelim,Gergelim,30,,-7.8,-40.483333
br,geriba,Geribá,15,,-16.833333,-40.383333
br,geribues,Geribués,13,,-3.510278,-43.135
br,gericino,Gericinó,21,,-22.845527,-43.480843
br,gerimatalha,Gerimatalha,02,,-9.666667,-37
br,gerinaldo,Gerinaldo,04,,-3.783333,-58.383333
br,germania,Germânia,01,,-10.333333,-69.55
br,germano,Germano,14,,-15.566667,-54.466667
br,gerno,Gernó,30,,-7.883333,-39.9
br,geroki,Geroki,11,,-22.966667,-54.566667
br,geroky,Geroky,11,,-22.966667,-54.566667
br,geroma,Geroma,20,,-6.8,-42.25
br,gertrudes,Gertrudes,11,,-21.516667,-55.433333
br,gertrudes,Gertrudes,27,,-23.349688,-46.746322
br,geru,Gerú,28,,-11.383333,-37.85
br,gesteira,Gesteira,15,,-20.266667,-43.133333
br,geti,Getí,20,,-10.033333,-44.283333
br,getulandia,Getulândia,21,,-22.666667,-44.1
br,getulina,Getulina,27,,-21.75,-49.916667
br,getulio d. vargas,Getúlio D. Vargas,23,,-29.25,-55.966667
br,getulio vargas,Getúlio Vargas,16,,-.966667,-47.866667
br,getulio vargas,Getúlio Vargas,22,,-6.016667,-37.416667
br,getulio vargas,Getúlio Vargas,23,13695,-27.833333,-52.266667
br,getulio vargas,Getúlio Vargas,26,,-27.0448,-49.6224
br,giboia,Gibóia,05,,-9.25,-41.583333
br,gibraltar,Gibraltar,01,,-7.433333,-73.6
br,gicaras,Giçaras,15,,-15.783333,-41.216667
br,gigante,Gigante,15,,-16.216667,-41.216667
br,giguy,Giguy,06,,-4.766667,-37.766667
br,gijoca dos bento,Gijoca dos Bento,06,,-2.85,-40.95
br,gijoca dos lula,Gijoca dos Lula,06,,-2.833333,-40.433333
br,gilbert,Gilbert,27,,-22.65,-47.7
br,gilboes,Gilboés,20,,-9.838889,-45.353889
br,gilbues,Gilbués,20,4920,-9.838889,-45.353889
br,gil,Gil,20,,-5.583333,-42.616667
br,gil,Gil,23,,-29.8,-51.633333
br,gimirim,Gimirim,15,,-21.8,-45.966667
br,ginete,Ginete,15,,-16.083333,-41.466667
br,ginga,Ginga,20,,-3.671667,-42.211944
br,ginimbu,Ginimbu,02,,-9.916667,-36.133333
br,giovani,Giovani,15,,-19.066667,-48.016667
br,giqui de baixo,Giqui de Baixo,06,,-4.75,-37.766667
br,giqui,Giqui,05,,-13.45,-41.1
br,giqui,Giqui,06,,-4.766667,-37.766667
br,gira,Gira,05,,-12.783333,-41.2
br,giral do ponceano,Giral do Ponceano,02,,-9.916667,-36.833333
br,giramundo de baixo,Giramundo de Baixo,13,,-3.013611,-42.825
br,giramundo,Giramundo,13,,-3.013333,-42.861111
br,gira mundo,Gira Mundo,20,,-5.15,-42.45
br,girando,Girando,08,,-20.866667,-41.416667
br,girao de pedra,Girão de Pedra,05,,-13.683333,-40.283333
br,girao,Girão,06,,-5.8,-39.416667
br,girao,Girao,14,,-15.233333,-57.7
br,girao,Girão,24,,-9.433333,-64.683333
br,girau do ponciano,Girau do Ponciano,02,9606,-9.916667,-36.833333
br,girau,Giráu,05,,-10.216667,-43.466667
br,girau,Girau,06,,-5.8,-39.416667
br,girau,Girau,24,,-9.433333,-64.683333
br,girua,Giruá,23,12170,-28.033333,-54.35
br,giru,Giru,15,,-16.833333,-41.066667
br,gissaras,Gissaras,15,,-15.783333,-41.216667
br,gitirana,Gitirana,20,,-7.35,-40.65
br,glaucilandia,Glaucilândia,15,,-16.85,-43.716667
br,glaura,Glaura,15,,-20.3,-43.633333
br,gleba 4,Gleba 4,18,,-23.9549,-50.9311
br,gleba brauna,Gleba Braúna,14,,-14.666667,-56.95
br,gleba capem,Gleba Capem,14,,-13.5,-55.1
br,gleba finch,Gleba Finch,21,,-23.02691,-43.478501
br,gleba i,Gleba I,27,,-23.333729,-46.638687
br,gleba ii,Gleba II,27,,-23.333121,-46.62723
br,gleba primeiro,Gleba Primeiro,27,,-23.333729,-46.638687
br,gleba quatro,Gleba Quatro,18,,-23.9549,-50.9311
br,gleba rio ferro,Gleba Rio Ferro,14,,-12.466667,-54.8
br,gleba segunda,Gleba Segunda,27,,-23.333121,-46.62723
br,glibert,Glibert,27,,-22.65,-47.7
br,glicerio,Glicério,21,,-22.233333,-42.066667
br,glicerio,Glicério,27,,-21.4,-50.183333
br,glicerio,Glicério,30,,-8.933333,-36.1
br,gloria de goyta,Gloria de Goytá,30,,-8.016667,-35.283333
br,gloria do goita,Glória do Goitá,30,17374,-8.016667,-35.283333
br,gloria,Glória,01,,-9.739722,-67.617222
br,gloria,Glória,05,,-9.183333,-38.3
br,gloria,Glória,08,,-20.366667,-40.516667
br,gloria,Glória,11,,-22.35,-54.216667
br,gloria,Glória,13,,-1.683333,-46.216667
br,gloria,Gloria,15,,-18.466667,-44.2
br,gloria,Glória,18,,-23.3625,-50.0108
br,gloria,Glória,21,,-22.92104,-43.180498
br,gloria,Glória,23,,-30.075,-51.2
br,glorinha,Glorinha,23,,-29.88,-50.7957
br,glucinio,Glucínio,15,,-18.216667,-42.35
br,glyceria,Glyceria,27,,-21.4,-50.183333
br,glycerio,Glycerio,21,,-22.233333,-42.066667
br,glycerio,Glycerio,30,,-8.933333,-36.1
br,gnadental,Gnadental,26,,-26.9503,-49.887
br,goaiz,Goaiz,29,,-15.933333,-50.133333
br,godinho,Godinho,21,,-21.266667,-41.6
br,godinho,Godinho,23,,-31.783333,-52.966667
br,godinho,Godinho,27,,-23.72738,-47.372327
br,godofredo,Godofredo,11,,-22.066667,-56.15
br,godofredo goncalves,Godofredo Gonçalves,11,,-22.066667,-56.15
br,goes,Goes,15,,-22.55,-46.3
br,goes,Góes,22,,-5.416667,-37.783333
br,goiaba,Goiaba,27,,-22.3,-47.966667
br,goiabal,Goiabal,04,,-3.116667,-68.05
br,goiabal,Goiabal,15,,-19.933333,-42.7
br,goiabal,Goiabal,16,,-1.05,-49.6
br,goiabas,Goiabas,15,,-19.1,-43.166667
br,goiabeira,Goiabeira,02,,-8.966667,-36.116667
br,goiabeira,Goiabeira,05,,-14.866667,-39.35
br,goiabeira,Goiabeira,06,,-7.583333,-38.75
br,goiabeira,Goiabeira,15,,-18.983333,-41.2
br,goiabeira,Goiabeira,17,,-7.083333,-37.5
br,goiabeira,Goiabeira,20,,-4.483333,-41.466667
br,goiabeira,Goiabeira,26,,-27.633333,-50.85
br,goiabeiras,Goiabeiras,08,,-20.266667,-40.3
br,goiabeiras,Goiabeiras,15,,-18.983333,-41.2
br,goiaberira,Goiaberira,20,,-5.35,-41.866667
br,goialina,Goialina,29,,-16.1,-49.333333
br,goiana,Goianá,15,,-21.533333,-43.2
br,goiana,Goianã,27,,-23.567958,-47.190678
br,goiana,Goianá,29,,-16.666667,-49.266667
br,goiana,Goiana,30,43981,-7.55,-34.983333
br,goianapolis,Goianápolis,29,10114,-16.5,-49.016667
br,goianases,Goianases,15,,-20.7,-47.033333
br,goianas,Goianás,29,,-16.383333,-49.316667
br,goianazes,Goianazes,15,,-20.7,-47.033333
br,goiandira,Goiandira,29,,-18.133333,-48.1
br,goiandira,Goiandira,31,,-11.766667,-46.666667
br,goianesia,Goianésia,29,47884,-15.3,-49.116667
br,goiania,Goiânia,29,1171209,-16.666667,-49.266667
br,goianinha,Goianinha,06,,-7.4,-39.116667
br,goianinha,Goianinha,22,13434,-6.266667,-35.2
br,goianinha,Goianinha,30,,-7.583333,-35.1
br,goianira,Goianira,29,22823,-16.5,-49.433333
br,goianopolis,Goianópolis,29,,-16.5,-49.016667
br,goianorte,Goianorte,31,,-8.726389,-48.817778
br,goiapabo-acu,Goiapabo-Açu,08,,-19.9,-40.45
br,goias,Goiás,29,19098,-15.933333,-50.133333
br,goiatins,Goiatins,31,,-7.700833,-47.179444
br,goiatuba,Goiatuba,29,25925,-18.016667,-49.366667
br,goiaz,Goiaz,29,,-15.933333,-50.133333
br,goio en,Goio En,26,,-27.283333,-52.683333
br,goio-ere,Goio-Erê,18,,-24.2,-53.016667
br,goio-ere,Goio-Erè,26,,-27.283333,-52.683333
br,goioxim,Goioxim,18,,-25.233333,-52.016667
br,goioxin,Goioxin,18,,-25.233333,-52.016667
br,goipaba acu,Goipaba Açu,08,,-19.9,-40.45
br,goipabo,Goipabo,08,,-19.9,-40.45
br,gois artigas,Góis Artigas,18,,-25.45,-51.25
br,gois calmon,Góis Calmon,05,,-12.783333,-38.35
br,gois,Góis,15,,-22.55,-46.3
br,gois,Gois,30,,-7.783333,-37.75
br,goitacases,Goitacases,21,,-21.816667,-41.266667
br,goitacazes,Goitacazes,21,,-21.816667,-41.266667
br,goitacaz,Goitacaz,04,,-3.564722,-62.963056
br,goitizeiro,Goitizeiro,08,,-20.2,-40.366667
br,golabeira,Golabeira,26,,-27.633333,-50.85
br,golden green,Golden Green,21,,-23.007568,-43.3486
br,golfo,Golfo,05,,-13.65,-40.133333
br,golfos,Golfos,05,,-14.133333,-43.433333
br,golfos,Golfos,17,,-6.416667,-38.483333
br,gomalina,Gomalina,14,,-15.816667,-59.802778
br,gomaticum,Gomaticum,05,,-12.366667,-38.516667
br,gomes,Gomes,06,,-7.483333,-38.733333
br,gomes,Gomes,17,,-7.466667,-38.1
br,gomes,Gomes,18,,-23.2817,-50.2265
br,gomes,Gomes,23,,-29.7,-51.966667
br,goncalo alves,Gonçalo Alves,20,,-3.756944,-42.081111
br,goncalo,Gonçalo,05,,-11.183333,-40.266667
br,goncalo,Gonçalo,13,,-3.044167,-43.231667
br,goncalo,Goncalo,17,,-7.55,-36.1
br,goncalo,Gonçalo,24,,-9.75,-62.266667
br,goncalo,Gonçalo,30,,-9.1,-37.15
br,goncalo martins,Gonçalo Martins,05,,-14.166667,-42.666667
br,goncalves dias,Gonçalves Dias,13,,-3.666667,-45.783333
br,goncalves ferreira,Gonçalves Ferreira,30,,-8.266667,-35.883333
br,goncalves,Gonçalves,15,,-22.666667,-45.85
br,goncalves,Gonçalves,27,,-20.266667,-47.616667
br,goncalves junior,Gonçalves Júnior,18,,-25.483333,-50.783333
br,gongogi,Gongogi,05,,-14.316667,-39.483333
br,gongonhas,Gongonhas,15,,-20.5,-43.866667
br,gonzaga,Gonzaga,15,,-18.8,-42.5
br,gopouva,Gopoúva,27,,-23.466667,-46.533333
br,goqay,Goqay,30,,-8.65,-39.65
br,gordo,Gordo,02,,-9.983333,-37.033333
br,gordura,Gordura,15,,-20.035,-43.9433
br,gorgulho,Gorgulho,31,,-8.923056,-48.106667
br,gorino,Gorino,29,,-14.633333,-49.733333
br,gorita,Gorita,15,,-21.066667,-46.483333
br,gororos,Gororós,15,,-18.783333,-43.25
br,gorutuba,Gorutuba,15,,-15.833333,-43.2
br,gostoso,Gostoso,22,,-5.116667,-35.633333
br,gotas,Gotas,17,,-7.266667,-37.616667
br,gotovelo,Gotovelo,22,,-5.933333,-35.933333
br,goulart,Goulart,27,,-21.133333,-50.283333
br,gouvea,Gouvêa,15,,-18.45,-43.733333
br,gouveia,Gouveia,15,,-18.45,-43.733333
br,governador amaral peixoto,Governador Amaral Peixoto,21,,-22.633333,-43.566667
br,governador archer,Governador Archer,13,,-4.933333,-44.383333
br,governador dix-sept rosado,Governador Dix-Sept Rosado,22,6626,-5.466667,-37.516667
br,governador lindemberg,Governador Lindemberg,08,,-19.266667,-40.483333
br,governador lindenberg,Governador Lindenberg,08,,-19.266667,-40.483333
br,governador lupion,Governador Lupion,18,,-25.983333,-53.716667
br,governador portela,Governador Portela,21,,-22.471389,-43.4925
br,governador portella,Governador Portella,21,,-2.483333,-43.5
br,governador valadares,Governador Valadares,15,250882,-18.85,-41.933333
br,goyandira,Goyandira,29,,-18.133333,-48.1
br,goyania,Goyania,29,,-16.666667,-49.266667
br,goyaninha,Goyaninha,06,,-7.4,-39.116667
br,goyanna,Goyanna,30,,-7.55,-34.983333
br,goyanninha,Goyanninha,22,,-6.266667,-35.2
br,goyanninha,Goyanninha,30,,-7.583333,-35.1
br,goyaz,Goyaz,29,,-15.933333,-50.133333
br,goy en,Goy En,26,,-27.283333,-52.683333
br,goyo-en,Goyo-En,26,,-27.283333,-52.683333
br,goza,Goza,05,,-11.233333,-42.083333
br,graca aranha,Graça Aranha,08,,-19.25,-40.6
br,graca aranha,Graça Aranha,13,,-5.383333,-44.333333
br,graca de deus,Graça de Deus,11,,-22.433333,-55.416667
br,graca,Graça,05,,-12.996667,-38.525
br,graca,Graça,06,,-4.05,-40.75
br,gracas a deus,Graças a Deus,05,,-14.7,-39.7
br,gracas,Graças,06,,-3.15,-39.75
br,graca torta,Graça Torta,02,,-9.583333,-35.666667
br,gracho cardoso,Gracho Cardoso,28,,-10.233333,-37.2
br,gracianopolis,Gracianópolis,27,,-21.433333,-51.6
br,graciosa,Graciosa,05,,-13.266667,-40.016667
br,graciosa,Graciosa,20,,-6.783333,-41.266667
br,gracismoes,Gracismões,06,,-4.983333,-37.933333
br,gradaus,Gradaús,16,,-7.716667,-51.183333
br,gragoata,Gragoatá,21,,-22.89899,-43.129635
br,grajahu,Grajahú,13,,-5.816667,-46.133333
br,grajau,Grajaú,05,,-9.733333,-39.033333
br,grajau,Grajaú,13,30218,-5.816667,-46.133333
br,grajau,Grajaú,20,,-7.833333,-41.283333
br,grajau,Grajaú,21,,-22.920256,-43.264573
br,gralau,Gralau,13,,-5.816667,-46.133333
br,gralha,Gralha,27,,-22.45,-49.516667
br,gramacho,Gramacho,21,,-22.755929,-43.293393
br,gramacno,Gramacno,21,,-22.755929,-43.293393
br,gramadinho,Gramadinho,18,,-25.083333,-52.183333
br,gramadinho,Gramadinho,27,,-23.766667,-48.116667
br,gramado,Gramado,18,,-23.6593,-49.8287
br,gramado,Gramado,23,26365,-29.4,-50.9
br,gramado,Gramado,26,,-26.966667,-51.083333
br,gramado,Gramado,27,,-23.283333,-45.5
br,gramados,Gramados,18,,-26.066667,-52.5
br,gramado xavier,Gramado Xavier,23,,-29.25,-52.483333
br,grama,Grama,05,,-13.9,-40.033333
br,grama,Grama,15,,-16.85,-42.15
br,grama,Grama,20,,-6.016667,-42.3
br,grama,Grama,21,,-22.75,-43.266667
br,grama,Grama,23,,-29.4,-50.9
br,grama,Grama,27,,-21.716667,-46.816667
br,gramal,Gramal,21,,-21.816667,-42.166667
br,gramame,Gramame,17,,-7.216667,-34.883333
br,gramas,Gramas,26,,-26.683333,-52.166667
br,graminea,Gramínea,15,,-22.166667,-46.633333
br,granada,Granada,15,,-20.183333,-42.4
br,granada,Granada,18,,-23.216667,-51.733333
br,grand degrad,Grand Dégrad,03,,2.316667,-51.533333
br,grande,Grande,05,,-11.5,-43.766667
br,grande,Grande,23,,-28.966667,-53.9
br,grande,Grande,30,,-9.3,-38.25
br,grande nova,Grande Nova,05,,-12.416667,-39.283333
br,grande oriente,Grande Oriente,04,,-7.666667,-67.666667
br,grandes rios,Grandes Rios,18,,-24.133333,-51.516667
br,grande vista,Grande Vista,05,,-12.25,-40.75
br,grand pegrand,Grand Pégrand,03,,2.316667,-51.533333
br,granito,Granito,30,,-7.716667,-39.6
br,granja beira mar,Granja Beira Mar,22,,-5.966667,-35.15
br,granja comari,Granja Comari,21,,-22.447949,-42.977514
br,granja do silencio,Granja do Silêncio,23,,-29.833333,-57.1
br,granja,Granja,04,,-2.883333,-57.066667
br,granja,Granja,06,25880,-3.1,-40.833333
br,granja santa fe,Granja Santa Fé,20,,-5.066667,-42.633333
br,granjas,Granjas,15,,-17.3,-42.233333
br,granjas,Granjas,18,,-23.197107,-52.209457
br,granja silvia,Granja Silvia,23,,-32.416667,-53.416667
br,granja velha,Granja Velha,18,,-25.7764,-49.7589
br,granjeiro,Granjeiro,06,,-6.883333,-39.2
br,granzato,Granzato,23,,-27.883333,-51.783333
br,granzoto,Granzoto,23,,-27.883333,-51.783333
br,graolandia,Graolândia,31,,-8.106944,-47.012222
br,grao mogol,Grão Mogol,15,3278,-16.566667,-42.9
br,grao para,Grão Pará,26,,-28.166667,-49.216667
br,grato,Grato,04,,-7.483333,-63.033333
br,grauna,Grauna,17,,-6.2,-37.3
br,gravata de fora,Gravata de Fora,17,,-7.433333,-36.3
br,gravata de jaburu,Gravatá de Jaburu,30,,-7.866667,-36.1
br,gravata do ibiapina,Gravatá do Ibiapina,30,,-7.866667,-36.1
br,gravata,Gravatá,02,,-9.066667,-36.133333
br,gravata,Gravatá,05,,-13.35,-41.666667
br,gravata,Gravata,06,,-7.333333,-38.683333
br,gravata,Gravata,15,,-17.483333,-41.883333
br,gravata,Gravatá,17,,-6.983333,-35.483333
br,gravata,Gravata,20,,-10.55,-45.266667
br,gravata,Gravatá,26,,-28.333333,-49.033333
br,gravata,Gravatá,30,61250,-8.2,-35.566667
br,gravatahy,Gravatahy,23,,-29.9426,-50.9933
br,gravatai,Gravataí,23,238782,-29.9426,-50.9933
br,gravatal,Gravatal,26,,-28.333333,-49.033333
br,gravier,Gravier,06,,-4.796389,-37.347222
br,gravi,Gravi,11,,-20.283333,-56.35
br,greenwood park,Greenwood Park,21,,-22.983239,-43.307458
br,gref,Gref,11,,-22.5,-55.4
br,gregorio barbosa,Gregório Barbosa,15,,-18.166667,-41.5
br,gregorio,Gregório,05,,-11.4,-43.9
br,gregorio,Gregorio,06,,-3.5,-40.25
br,gregorio,Gregório,11,,-20.766667,-56.716667
br,gregorio,Gregorio,14,,-10.366667,-60.483333
br,gregorio jordes,Gregorio Jordes,14,,-14.116667,-56.683333
br,gregorio marinho,Gregório Marinho,14,,-10.366667,-60.483333
br,gremios,Grêmios,06,,-4.466667,-39.633333
br,grilo,Grilo,27,,-23.7737,-47.0319
br,grilos,Grilos,30,,-7.666667,-40.05
br,grimeia,Griméia,13,,-5.416667,-43.4
br,grimpas,Grimpas,29,,-16.966667,-49.233333
br,gritos,Gritos,30,,-7.666667,-40.05
br,groairas,Groaíras,06,,-3.883333,-40.383333
br,grossas,Grossas,22,,-4.986111,-37.151944
br,grosso,Grosso,02,,-9.616667,-37.483333
br,grosso,Grosso,05,,-12.95,-39.266667
br,grosso,Grosso,17,,-6.8,-38.25
br,grosso,Grosso,30,,-7.533333,-37.283333
br,grossos,Grossos,06,,-3.533333,-40.05
br,grossos,Grossos,13,,-3.065556,-42.168611
br,grossos,Grossos,20,,-3.512222,-42.055833
br,grossos,Grossos,22,,-4.986111,-37.151944
br,grota do tobi,Grota do Tobi,05,,-12.2,-40.933333
br,grota do tubi,Grota do Tubi,05,,-12.2,-40.933333
br,grota funda,Grota Funda,20,,-6.833333,-40.533333
br,grota funda,Grota Funda,21,,-23.008498,-43.5182
br,grota funda,Grota Funda,26,,-26.333333,-49.133333
br,grota funda,Grota Funda,27,,-23.37847,-47.813178
br,grota,Grota,05,,-10.85,-43.35
br,grota,Grota,06,,-5.233333,-40.733333
br,grota,Grota,15,,-20.4,-42.566667
br,grota,Grota,21,,-22.8593,-43.270526
br,grotao,Grotão,02,,-9.783333,-36.366667
br,grotao,Grotão,05,,-10.816667,-41.683333
br,grotao,Grotão,15,,-21.633333,-45.283333
br,grotao,Grotão,17,,-6.75,-37.9
br,grotao,Grotão,20,,-5.633333,-42.666667
br,grotao,Grotão,21,,-22.8472,-43.292041
br,grotao,Grotão,29,,-14.616667,-46.183333
br,grotao,Grotão,30,,-8.7,-36.683333
br,grotas,Grotas,14,,-14.9,-56.533333
br,grota verde,Grota Verde,06,,-4.866667,-40.116667
br,grumari,Grumari,21,,-23.042408,-43.536149
br,grumarim,Grumarim,21,,-21.6,-41.783333
br,gruna,Gruna,05,,-10.683333,-41.516667
br,grupiara,Grupiara,15,,-18.5,-47.733333
br,grupo escolar,Grupo Escolar,29,,-15.216667,-49.583333
br,grussai,Grussaí,21,,-21.7,-41.033333
br,gruta funda,Gruta Funda,13,,-6.183333,-46.933333
br,gruta funda,Gruta Funda,22,,-5.966667,-35.8
br,gruta,Gruta,23,,-29.2402,-51.0375
br,gruzeiro,Gruzeiro,23,,-27.866667,-54.433333
br,guabiju,Guabiju,23,,-28.533333,-51.7
br,guabiraba,Guabiraba,06,,-2.9,-39.933333
br,guabiraba,Guabiraba,13,,-3.530833,-43.233333
br,guabiraba,Guabiraba,20,,-3.265,-42.111389
br,guabiraba,Guabiraba,30,,-8.416667,-35.666667
br,guabirabas,Guabirabas,20,,-6.883333,-41.783333
br,guabiroba,Guabiroba,18,,-23.618,-49.786
br,guabiroba,Guabiroba,23,,-29.8868,-50.8158
br,guacho,Guacho,23,,-28.733333,-51.083333
br,guachos,Guachos,27,,-21.966667,-51.033333
br,guaci,Guaci,06,,-4.25,-38.833333
br,guacoce,Guaçocê,06,,-6.266667,-39.016667
br,guacoce,Guaçoce,17,,-7.55,-38.516667
br,guacu,Guaçu,11,,-22.183333,-54.516667
br,guacu,Guaçu,27,,-23.502765,-47.132564
br,guacui,Guaçuí,08,19787,-20.766667,-41.683333
br,guacupi,Guaçupi,23,,-29.266667,-53.666667
br,guadalupe,Guadalupe,13,,-3.545,-43.253889
br,guadalupe,Guadalupe,20,,-6.733333,-43.783333
br,guadalupe,Guadalupe,21,,-22.841158,-43.372279
br,guadalupe,Guadalupe,30,,-8.683333,-35.1
br,guadiana,Guadiana,18,,-23.316667,-52.116667
br,guadrapas,Guadrapas,06,,-3.366667,-39.283333
br,guagiru,Guagiru,06,,-3.633333,-38.733333
br,guagiru,Guagiru,17,,-7.533333,-34.833333
br,guahyba,Guahyba,23,,-3.1,-51.316667
br,guahyra,Guahyra,18,,-24.066667,-54.25
br,guahyra,Guahyra,27,,-20.316667,-48.3
br,guaiaca dos pretos,Guaiaca dos Pretos,18,,-25.634072,-50.187003
br,guaiaca,Guaiaca,18,,-25.619969,-50.20077
br,guaianases,Guaianases,27,,-23.55,-46.416667
br,guaianas,Guaianás,27,,-22.3,-48.883333
br,guaianazes,Guaianazes,27,,-23.55,-46.416667
br,guaianeses,Guaianeses,27,,-23.55,-46.416667
br,guaiba,Guaíba,23,101026,-30.111111,-51.316667
br,guaibal,Guaibal,04,,-3.116667,-68.05
br,guaibim,Guaibim,05,,-13.283333,-38.966667
br,guaibinha,Guaibinha,05,,-12.7,-38.9
br,guaicara,Guaiçara,27,,-21.633333,-49.783333
br,guaicuhy,Guaicuhy,15,,-17.2,-44.816667
br,guaicui,Guaicuí,15,,-17.2,-44.816667
br,guaicurus,Guaicurus,23,,-28.966667,-51.4
br,guai,Guaí,05,,-12.85,-38.95
br,guaimbe,Guaimbê,27,,-21.916667,-49.9
br,guaipava,Guaipava,15,,-21.666667,-45.716667
br,guaiquica,Guaiquica,27,,-22.416667,-47.233333
br,guairaca,Guairacá,18,,-22.783333,-51.7
br,guaira,Guaíra,18,27611,-24.066667,-54.25
br,guaira,Guaíra,27,34093,-20.316667,-48.3
br,guairas,Guaíras,05,,-12.65,-44.266667
br,guaiuba,Guaiuba,06,21822,-4.033333,-38.633333
br,guajara-acu,Guajará-Açu,16,,-1.633333,-48.116667
br,guajara acu,Guajará Açu,24,,-10.766667,-65.366667
br,guajara-assu,Guajará-Assu,24,,-10.766667,-65.366667
br,guajara,Guajará,04,9776,-2.966667,-57.666667
br,guajara,Guajará,16,,-.516667,-49.033333
br,guajara-miri,Guajará-Miri,16,,-1.483333,-48.283333
br,guajara-mirim,Guajará-Mirim,24,34123,-10.8,-65.366667
br,guajara sinha,Guajara Sinha,04,,-5.635556,-63.371111
br,guajaratuba,Guajaratuba,04,,-5.115833,-62.732222
br,guajaratubinha,Guajaratubinha,04,,-5.635556,-63.371111
br,guajarauna,Guajaraúna,16,,-1.766667,-48.7
br,guajarraa,Guajarraã,04,,-7.7,-66.883333
br,guajeru,Guajeru,05,,-14.566667,-41.933333
br,guajiru,Guajiru,06,,-4.786389,-37.296389
br,guajiru,Guajirú,17,,-7.533333,-34.833333
br,guajiru,Guajiru,22,,-5.116667,-35.633333
br,guajuru,Guajuru,08,,-20.301389,-40.291667
br,guajuvira de cima,Guajuvira de Cima,18,,-25.633333,-49.466667
br,guajuvira,Guajuvira,18,,-25.6,-49.533333
br,gualibade,Gualibade,21,,-22.215278,-43.710278
br,guama,Guamá,16,,-1.616667,-47.45
br,guamare,Guamaré,22,,-5.106389,-36.320278
br,guamiranga,Guamiranga,18,,-25.2,-50.783333
br,guamiranga,Guamiranga,26,,-26.516667,-48.9
br,guamirim,Guamirim,18,,-25.566667,-50.866667
br,guampara,Guampará,18,,-25.033333,-52.183333
br,guanabara,Guanabara,01,,-10.4,-69.583333
br,guanabara,Guanabara,04,,-7.666667,-67.333333
br,guanabara,Guanabara,06,,-4.866667,-38.4
br,guanabara,Guanabara,22,,-5.983333,-35.933333
br,guanabara,Guanabara,27,,-20.766667,-51.183333
br,guanaces,Guanacés,06,,-4.15,-38.333333
br,guanambi,Guanambi,05,58879,-14.216667,-42.783333
br,guanamby,Guanamby,05,,-14.216667,-42.783333
br,guananazes,Guananazes,23,,-29.516667,-50.066667
br,guanandi,Guanandi,11,,-18.866667,-56.266667
br,guando,Guandó,08,,-20.25,-41.083333
br,guandu do sena,Guandu do Sena,21,,-22.838658,-43.504509
br,guandu,Guandu,02,,-9.233333,-37.233333
br,guandu,Guandu,08,,-20.25,-41.083333
br,guandu,Guandu,21,,-21.55,-41.333333
br,guanhaes,Guanhães,15,23728,-18.783333,-42.95
br,guanipa-mirim,Guanipá-Mirim,05,,-15.7,-39.65
br,guanumbi,Guanumbi,30,,-8.65,-37.033333
br,guapaba,Guapaba,17,,-7.6,-35.583333
br,guape,Guapé,15,,-20.783333,-45.916667
br,guapiacu,Guapiaçu,27,14065,-20.833333,-49.216667
br,guapiara,Guapiara,27,,-24.166667,-48.533333
br,guapiassu,Guapiassú,27,,-20.833333,-49.216667
br,guapicu,Guapicu,18,,-25.37404,-48.316321
br,guapimirim,Guapimirim,21,31202,-22.533333,-42.983333
br,guapira,Guapira,05,,-12.8,-39.05
br,guapirama,Guapirama,18,,-23.516498,-50.042443
br,guapiranga,Guapiranga,27,,-21.516667,-49.633333
br,guapiuru,Guapiuru,27,,-24.166667,-48.533333
br,guapo,Guapó,29,10075,-16.816667,-49.533333
br,guaporanga,Guaporanga,26,,-27.45,-48.633333
br,guapore,Guaporé,23,20050,-28.85,-51.9
br,guapore,Guapore,24,,-11.9,-64.983333
br,guaporema,Guaporema,18,,-23.316667,-52.833333
br,guaporema,Guaporema,23,,-28.85,-51.9
br,guapua,Guapuã,27,,-20.4,-47.416667
br,guapy-mirim,Guapy-mirim,21,,-22.533333,-42.983333
br,guarabira,Guarabira,17,43750,-6.85,-35.483333
br,guarabira,Guarabira,20,,-6.266667,-41.766667
br,guarabu,Guarabu,21,,-22.807151,-43.193964
br,guaracai,Guaraçaí,27,,-21.033333,-51.133333
br,guaraciaba d'oeste,Guaraciaba d'Oeste,27,,-21.383333,-51.666667
br,guaraciaba do norte,Guaraciaba do Norte,06,18186,-4.166667,-40.766667
br,guaraciaba,Guaraciaba,15,,-20.566667,-43
br,guaraciaba,Guaraciaba,26,,-26.583333,-53.583333
br,guaraciama,Guaraciama,15,,-17.05,-43.683333
br,guaraci,Guaraci,05,,-14.633333,-39.533333
br,guaraci,Guaraci,18,,-22.95,-51.666667
br,guaraci,Guaraci,27,,-20.483333,-48.95
br,guaracy,Guaracy,27,,-20.483333,-48.95
br,guaragi,Guaragi,18,,-25.274167,-50.235556
br,guara,Guará,07,,-15.833333,-47.9
br,guara,Guará,18,,-25.383333,-51.283333
br,guara,Guará,27,18263,-20.433333,-47.833333
br,guara,Guará,31,,-8.811667,-48.391667
br,guarai,Guaraí,31,,-8.811667,-48.391667
br,guaraipo,Guaraipo,18,,-24.933333,-49.3
br,guaraipos,Guaraipos,18,,-24.933333,-49.3
br,guaraji,Guaraji,18,,-25.274167,-50.235556
br,guarajuba,Guarajúba,05,,-12.7,-38.1
br,guarakessaba,Guarakessaba,18,,-25.296382,-48.32361
br,guarama,Guarama,23,,-27.566667,-52.05
br,guaramano,Guaramano,23,,-28.133333,-54.566667
br,guaramiranga,Guaramiranga,06,,-4.25,-38.933333
br,guaramirim,Guaramirim,26,21422,-26.45,-49
br,guarana,Guaraná,08,,-19.666667,-40.25
br,guarana,Guaraná,16,,-4.366667,-56.433333
br,guarandi,Guarandi,14,,-16.9,-56.966667
br,guaranesia,Guaranésia,15,17437,-21.3,-46.8
br,guaraniacu,Guaraniaçu,18,7781,-25.1,-52.866667
br,guarani das missoes,Guarani das Missões,23,,-28.133333,-54.566667
br,guarani d'oeste,Guarani d'Oeste,27,,-20.083333,-50.333333
br,guarani,Guarani,01,,-10.116667,-67.8
br,guarani,Guarani,05,,-12.7,-41.833333
br,guarani,Guarani,06,,-3.483333,-39.533333
br,guarani,Guarani,08,,-20.3,-41.366667
br,guarani,Guarani,11,,-19.9,-55.8
br,guarani,Guarani,14,,-17.033333,-56.116667
br,guarani,Guarani,15,,-16.316667,-40.816667
br,guarani,Guarani,16,,-6.45,-57.966667
br,guarani,Guarani,18,,-23.087207,-52.115217
br,guarani,Guarani,20,,-6.866667,-41.766667
br,guarani,Guarani,21,,-22.444317,-42.986268
br,guarani,Guarani,23,,-28.133333,-54.566667
br,guarani,Guarani,27,,-21.666667,-50.883333
br,guarani,Guarani,30,,-7.483333,-39.7
br,guaraniuva,Guaraniúva,27,,-21.566667,-51.283333
br,guaranta,Guarantã,27,,-21.883333,-49.566667
br,guarantan,Guarantan,27,,-21.883333,-49.566667
br,guarany,Guarany,06,,-4.166667,-38.466667
br,guarany,Guarany,15,,-21.366667,-43.05
br,guarapara,Guarapará,27,,-21.5,-48.033333
br,guarapari,Guarapari,08,100927,-20.666667,-40.5
br,guarapary,Guarapary,08,,-20.666667,-40.5
br,guarapiranga,Guarapiranga,27,,-21.966667,-48.25
br,guarapo,Guarapó,27,,-23.272038,-47.891223
br,guarapua,Guarapuã,27,,-22.233333,-48.366667
br,guarapuava,Guarapuava,18,150851,-25.383333,-51.45
br,guarapuavinha,Guarapuavinha,18,,-25.516667,-51.133333
br,guaraquecaba,Guaraqueçaba,18,,-25.296382,-48.32361
br,guaraquicaba,Guaraquiçaba,18,,-25.296382,-48.32361
br,guarara,Guarará,15,,-21.716667,-43.033333
br,guararapes,Guararapes,23,,-28.966667,-51.4
br,guararapes,Guararapes,27,27558,-21.25,-50.633333
br,guararapes,Guararapes,30,,-8.15,-34.95
br,guarare,Guararé,23,,-28.466667,-52.35
br,guararema,Guararema,08,,-18.833333,-40.716667
br,guararema,Guararema,18,,-23.316667,-52.833333
br,guararema,Guararema,27,23572,-23.4132,-46.0377
br,guararu,Guararu,06,,-3.716667,-38.866667
br,guarataia,Guarataia,15,,-18.333333,-41.866667
br,guarataia,Guarataia,21,,-21.45,-41.4
br,guaratiba,Guaratiba,21,,-22.966667,-42.8
br,guaratinga,Guaratinga,05,9519,-16.566667,-39.566667
br,guaratingueta,Guaratinguetá,27,105882,-22.815156,-45.18923
br,guaratuba,Guaratuba,18,18906,-25.8804,-48.571
br,guarau,Guaraú,27,,-23.216667,-47.316667
br,guarau ii,Guaraú II,27,,-24.723498,-48.061022
br,guarauna,Guaraúna,18,,-25.324722,-50.360556
br,guarau segunda,Guaraú Segunda,27,,-24.723498,-48.061022
br,guaravera,Guaravera,18,,-23.533333,-51.183333
br,guaraxaim,Guaraxaim,23,,-31.05,-51.516667
br,guarda do embau,Guarda do Embaú,26,,-27.9025,-48.591111
br,guardado,Guardado,05,,-12.5,-38.85
br,guardado,Guardado,22,,-6.133333,-38.4
br,guarda dos ferreiros,Guarda dos Ferreiros,15,,-19.366667,-46.133333
br,guarda,Guarda,26,,-28.45,-49.083333
br,guarda mor,Guarda Mor,15,,-17.783333,-47.1
br,guarda mor,Guarda Mor,26,,-27.15,-50.7
br,guarda nova,Guarda Nova,23,,-32.016667,-53.45
br,guardinha,Guardinha,15,,-20.916667,-47.166667
br,guardinha,Guardinha,27,,-23.324629,-47.843784
br,guarehy,Guarehy,27,,-23.366667,-48.166667
br,guarei,Guareí,27,,-23.366667,-48.166667
br,guareta,Guaretá,18,,-24.066667,-51.75
br,guariba,Guariba,04,,-5.685556,-61.268611
br,guariba,Guariba,05,,-13.166667,-40.216667
br,guariba,Guariba,13,,-6.283333,-43.116667
br,guariba,Guariba,15,,-16.666667,-41.166667
br,guariba,Guariba,16,,-4.016667,-56.6
br,guariba,Guariba,27,30464,-21.35,-48.233333
br,guariba,Guariba,30,,-8.8,-36.216667
br,guaribas,Guaribas,02,,-9.4,-37.016667
br,guaribas,Guaribas,05,,-11.183333,-45.383333
br,guaribas,Guaribas,06,,-4.683333,-40.25
br,guaribas,Guaribas,13,,-5.216667,-45.916667
br,guaribas,Guaribas,15,,-16.75,-41.25
br,guaribas,Guaribas,17,,-7.033333,-38.3
br,guaribas,Guaribas,20,,-3.865833,-42.683333
br,guaribas,Guaribas,30,,-8.716667,-36.966667
br,guaribas i,Guaribas I,13,,-3.163333,-43.245
br,guaribas ii,Guaribas II,13,,-3.148889,-43.211944
br,guaribas iii,Guaribas III,13,,-3.115278,-43.191944
br,guaribas iv,Guaribas IV,13,,-3.083611,-43.146667
br,guaribas v,Guaribas V,13,,-3.440833,-43.370833
br,guaricanga,Guaricanga,27,,-21.516667,-49.633333
br,guariguari,Guariguari,13,,-3.316667,-45.833333
br,guarima grande,Guarimã Grande,13,,-3.1725,-42.850278
br,guarima,Guarimã,13,,-3.331111,-43.388611
br,guarimanzal,Guarimanzal,13,,-3.090278,-43.494167
br,guarimazinho,Guarimãzinho,13,,-3.149722,-42.795833
br,guarinos,Guarinos,29,,-14.633333,-49.733333
br,guarirama,Guariramã,13,,-2.366667,-45.5
br,guariroba,Guariroba,15,,-21.533333,-46.1
br,guariroba,Guariroba,27,,-21.45,-48.616667
br,guariroba,Guariroba,31,,-11.766667,-48.183333
br,guarita do sul,Guaritá do Sul,18,,-24.116667,-51.5
br,guarita,Guarita,17,,-7.333333,-35.383333
br,guarita,Guaritá,18,,-24.066667,-51.75
br,guarituba,Guarituba,18,,-23.430099,-52.532017
br,guariuba,Guariúba,04,,-5.217778,-60.390833
br,guarizinho,Guarizinho,27,,-23.7,-48.85
br,guarnesia,Guarnesia,15,,-21.3,-46.8
br,guartela,Guartela,18,,-24.633333,-50.3
br,guaruja,Guarujá,11,,-21.883333,-54.033333
br,guaruja,Guarujá,23,,-30.1625,-51.225
br,guaruja,Guarujá,26,,-26.433333,-53.566667
br,guaruja,Guarujá,27,310430,-24,-46.266667
br,guarulhas,Guarulhas,21,,-21.733333,-41.333333
br,guarulhos,Guarulhos,21,,-21.733333,-41.333333
br,guarulhos,Guarulhos,27,1169601,-23.45068,-46.526175
br,guarus,Guarus,21,,-21.733333,-41.333333
br,guary,Guary,27,,-23.7,-48.85
br,guassi,Guassi,06,,-4.25,-38.833333
br,guassosse,Guassossê,06,,-6.266667,-39.016667
br,guatacaba,Guataçaba,29,,-13.85,-46.95
br,guata,Guatá,26,,-28.383333,-49.5
br,guatambu,Guatambu,26,,-27.116667,-52.75
br,guatapara,Guatapará,27,,-21.483333,-47.983333
br,guatapora,Guataporá,27,,-21.483333,-47.983333
br,guataquara,Guataquara,16,,-5.45,-56.866667
br,guatuba,Guatuba,06,,-4.033333,-38.616667
br,guavira,Guavira,11,,-20.5,-56.583333
br,guaxi,Guaxi,11,,-19.266667,-55.5
br,guaxima,Guaxima,15,,-19.866667,-47.566667
br,guaxindiba,Guaxindiba,08,,-18.566667,-39.733333
br,guaxindiba,Guaxindiba,21,,-22.783333,-42.966667
br,guaxinduba,Guaxinduba,27,,-23.283333,-47.016667
br,guaxinduva,Guaxinduva,27,,-23.109722,-46.511944
br,guaxupe,Guaxupé,15,47890,-21.3,-46.7
br,guayanas,Guayanas,27,,-22.3,-48.883333
br,guayanazes,Guayanazes,15,,-20.7,-47.033333
br,guayaramerim,Guayaramerim,24,,-10.8,-65.366667
br,guaycara,Guaycára,27,,-21.633333,-49.783333
br,guayra,Guayrá,18,,-24.066667,-54.25
br,guayra,Guayra,27,,-20.316667,-48.3
br,guayuba,Guayuba,06,,-4.033333,-38.633333
br,gueda,Guedá,11,,-18.883333,-55.65
br,guedes,Guedes,08,,-18.433333,-39.95
br,guedes,Guedes,15,,-20.366667,-44.266667
br,guedes,Guedes,17,,-7.833333,-37.066667
br,guedeslandia,Guedeslândia,06,,-5.766667,-38.85
br,guerem,Guerém,05,,-13.283333,-39.233333
br,guerengue,Guerenguê,21,,-22.927805,-43.37915
br,gueriroba,Gueriroba,31,,-11.766667,-48.183333
br,guerreira,Guerreira,13,,-5.65,-43.35
br,gueto,Gueto,06,,-5.033333,-39.516667
br,guia de pacobaiba,Guia de Pacobaíba,21,,-22.7025,-43.131944
br,guia de pacopahyba,Guia de Pacopahyba,21,,-22.7025,-43.131944
br,guia,Guia,04,,.433333,-67.333333
br,guia,Guia,06,,-4.9,-39.8
br,guia,Guia,14,,-15.366667,-56.233333
br,guia lopes da laguna,Guia Lopes da Laguna,11,9681,-21.433333,-56.116667
br,guia lopes,Guia Lopes,11,,-21.433333,-56.116667
br,guia lopes,Guia Lopes,15,,-20.25,-46.366667
br,guianuba,Güianuba,23,,-29.833333,-51.15
br,guida,Guida,22,,-5.466667,-37.533333
br,guido,Guido,13,,-9.2,-46.566667
br,guidoval,Guidoval,15,,-21.15,-42.8
br,guigos,Guigós,05,,-11.466667,-42.2
br,guilherme da silveira,Guilherme da Silveira,21,,-22.872778,-43.457222
br,guilherme paster,Guilherme Paster,08,,-20.183333,-40.766667
br,guilherme plastes,Guilherme Plastes,08,,-20.183333,-40.766667
br,guilhermino,Guilhermino,15,,-20.233333,-46.883333
br,guimaraes carneiro,Guimarães Carneiro,18,,-23.258527,-50.013306
br,guimaraes,Guimarães,06,,-3.883333,-40.383333
br,guimaraes,Guimarães,13,,-2.133333,-44.6
br,guimarania,Guimarânia,15,,-18.85,-46.783333
br,guinda,Guinda,15,,-18.25,-43.683333
br,guine de baixo,Guiné de Baixo,05,,-12.733333,-41.533333
br,guine,Guiné,05,,-12.8,-41.5
br,guiomar,Guiomar,08,,-20.65,-40.933333
br,guira barreiro,Guirá Barreiro,11,,-23.7,-54.666667
br,guirapa,Guirapá,05,,-14.4,-42.616667
br,guiratinga,Guiratinga,14,10938,-16.35,-53.75
br,guiricema,Guiricema,15,,-21,-42.716667
br,guivotas,Guivotas,04,,-5.61,-63.439167
br,guloso,Guloso,05,,-14.033333,-39.683333
br,gundiana,Gundiana,18,,-23.316667,-52.116667
br,gunza,Gunza,21,,-22.947402,-43.476753
br,guraituba,Guraituba,18,,-25.35,-49.15
br,gurgel,Gurgel,06,,-4.933333,-37.683333
br,gurgel,Gurgel,16,,-7.883333,-49.866667
br,gurgueia,Gurguéia,06,,-6.366667,-40.55
br,gurgueia,Gurgueia,20,,-6.233333,-42.616667
br,gurihu,Gurihú,06,,-2.850556,-40.589167
br,gurijuba,Gurijuba,03,,.866667,-50.316667
br,gurim,Gurim,21,,-22.833333,-42
br,gurinhata,Gurinhatã,15,,-19.233333,-49.8
br,gurinhem,Gurinhém,17,5618,-7.133333,-35.45
br,guriri,Guriri,21,,-21.916667,-41.466667
br,guriu,Guriú,06,,-2.850556,-40.589167
br,gurjao,Gurjão,17,,-7.25,-36.483333
br,gurjao,Gurjão,30,,-7.516667,-35.316667
br,gurupa,Gurupá,16,6461,-1.416667,-51.65
br,gurupa,Gurupá,27,,-21.65,-50.016667
br,gurupai,Gurupai,11,,-23.183333,-54.4
br,gurupa mirim,Gurupá Mirim,05,,-15.7,-39.65
br,gurupay,Gurupay,11,,-23.183333,-54.4
br,gurupi,Gurupí,16,,-1.6,-46.216667
br,gurupi,Gurupi,31,64790,-11.7225,-49.012222
br,gurupy,Gurupy,16,,-1.6,-46.216667
br,gussolandia,Gussolândia,27,,-20.65,-50.683333
br,gustavo bento,Gustavo Bento,15,,-21.033333,-46.616667
br,gustavo berthier,Gustavo Berthier,23,,-27.866667,-51.55
br,gustavo bertier,Gustavo Bertier,23,,-27.866667,-51.55
br,gustavo,Gustavo,05,,-14.633333,-45.5
br,gustavo,Gustavo,14,,-10.1,-60.516667
br,gustavo prates,Gustavo Prates,15,,-16.183333,-40.633333
br,gustavo richard,Gustavo Richard,26,,-26.983333,-49.75
br,guveia,Guveia,15,,-18.45,-43.733333
br,guzolandia,Guzolândia,27,,-20.65,-50.683333
br,gymirim,Gymirim,15,,-21.8,-45.966667
br,ha-mais-tempo,Há-Mais-Tempo,13,,-4.333333,-44.933333
br,hamburgberg,Hamburgberg,23,,-29.666667,-51.1
br,hamburgo,Hamburgo,04,,-2.716667,-66.783333
br,hamburgo velho,Hamburgo Velho,23,,-29.666667,-51.1
br,hammonia,Hammonia,26,,-27.0546,-49.516
br,hamond,Hamond,27,,-21.416667,-48.25
br,hamonia,Hamônia,26,,-27.0546,-49.516
br,hansa,Hansa,26,,-26.433333,-49.233333
br,haras farroupilhas,Haras Farroupilhas,27,,-22.756681,-45.146013
br,haras mondesir,Haras Mondesir,27,,-22.764651,-45.111524
br,harmonia,Harmonia,08,,-21.1,-41.45
br,harmonia,Harmonia,15,,-19.183333,-48.233333
br,harmonia,Harmonia,18,,-24.3,-50.616667
br,harmonia,Harmonia,23,,-29.533333,-51.433333
br,hauer,Hauer,18,,-23.366667,-50.333333
br,havai,Havai,06,,-3.916667,-40.283333
br,havre,Havre,04,,-7.883333,-71.466667
br,hebron,Hebron,06,,-6.266667,-39.583333
br,heimat,Heimat,26,,-26.716667,-49.55
br,heimtal,Heimtal,18,,-23.25,-51.15
br,helena de goias,Helena de Goiás,29,,-17.716667,-50.583333
br,heliodora gomes,Heliodora Gomes,15,,-18.75,-48.5
br,heliodora,Heliodora,15,,-22.066667,-45.533333
br,heliopolis,Heliópolis,05,,-10.683333,-38.283333
br,helvecia,Helvécia,05,,-17.833333,-39.666667
br,helvetia,Helvetia,05,,-17.833333,-39.666667
br,hematita,Hematita,15,,-19.516667,-43.033333
br,henrique dias,Henrique Dias,30,,-8.283333,-37.183333
br,henrique escostegui,Henrique Escostegui,23,,-30.583333,-55.95
br,henrique lage,Henrique Lage,26,,-28.233333,-48.666667
br,henrique laje,Henrique Laje,26,,-28.233333,-48.666667
br,henrique rocha,Henrique Rocha,15,,-16.716667,-41.816667
br,henrique zambao,Henrique Zambão,08,,-20.25,-41.116667
br,heraclito,Heráclito,15,,-18.616667,-48.416667
br,hercilio luz,Hercílio Luz,26,,-28.75,-49.366667
br,herciliopolis,Herciliópolis,26,,-26.8,-51.5
br,herculandia,Herculândia,27,,-22.016667,-50.366667
br,herculanea,Herculânea,11,,-18.5,-54.75
br,herculania,Herculânia,11,,-18.5,-54.75
br,herculania,Herculânia,27,,-22.016667,-50.366667
br,herculano,Herculano,30,,-7.8,-38.35
br,herculanopolis,Herculanópolis,13,,-3.680556,-42.682778
br,hercules coradi,Hércules Coradi,23,,-29.0162,-51.1969
br,hermenegildo,Hermenegildo,14,,-10.283333,-60.516667
br,hermenegildo,Hermenegildo,23,,-33.65,-53.283333
br,hermes silva,Hermes Silva,15,,-18.333333,-41.766667
br,hermilo alves,Hermilo Alves,15,,-21.016667,-43.8
br,hermogenes,Hermógenes,15,,-18.433333,-48.283333
br,hersiliopolis,Hersiliópolis,26,,-26.8,-51.5
br,herva,Herva,15,,-18.466667,-45.45
br,herval,Herval,11,,-20.733333,-56.283333
br,herval,Herval,15,,-20.833333,-42.65
br,herval,Herval,18,,-24.933333,-51.2
br,herval,Herval,23,,-30.6537,-52.2658
br,herval,Herval,26,,-27.216667,-51.566667
br,herval seco,Herval Sêco,23,,-27.55,-53.5
br,herval velho,Herval Velho,26,,-27.283333,-51.433333
br,herveira,Herveira,18,,-25.25,-52.533333
br,herveiras,Herveiras,23,,-29.45,-52.65
br,hevelandia,Hevelândia,04,,-5.203889,-61.835833
br,hibiraiaras,Hibiraiaras,23,,-28.366667,-51.65
br,hibiraires,Hibiraires,23,,-28.366667,-51.65
br,hidrolandia,Hidrolândia,06,10299,-4.416667,-40.416667
br,hidrolandia,Hidrolândia,29,7082,-16.966667,-49.233333
br,hidrolina,Hidrolina,29,,-14.616667,-49.416667
br,higienopolis,Higienópolis,21,,-22.876087,-43.263984
br,higienopolis,Higienópolis,23,,-30.016667,-51.183333
br,hilario vieira,Hilário Vieira,15,,-21.45,-46.183333
br,himalaia,Himalaia,02,,-9.566667,-36.216667
br,hipolito baldina,Hipólito Baldina,15,,-20.883333,-46.133333
br,hipolito cardoso,Hipólito Cardoso,15,,-21.216667,-46.05
br,holanda,Holanda,06,,-4.733333,-40.333333
br,holofote,Holofote,21,,-22.1,-42.416667
br,honorato,Honorato,14,,-10.283333,-60.516667
br,honorio bicalho,Honório Bicalho,15,,-20.023,-43.8214
br,honorio da fonseca,Honório da Fonseca,15,,-20.866667,-46.583333
br,honorio gurgel,Honório Gurgel,21,,-22.843435,-43.354
br,honorio sa,Honório Sá,15,,-16.9,-41.766667
br,horacio alves,Horácio Alves,15,,-20.616667,-46.183333
br,horacio,Horácio,11,,-21.9,-55.35
br,horacio,Horácio,15,,-17.3,-40.816667
br,hora,Hora,13,,-3.15,-44.05
br,horizonte,Horizonte,01,,-8.9425,-72.579722
br,horizonte,Horizonte,05,,-13.7,-40.266667
br,horizonte,Horizonte,06,51181,-4.083333,-38.483333
br,horizonte,Horizonte,21,,-22.483333,-44.516667
br,horizonte,Horizonte,22,,-5.386667,-37.401389
br,horizonte,Horizonte,23,,-27.616667,-54.316667
br,horizonte,Horizonte,30,,-8.783333,-36.033333
br,horizonte novo,Horizonte Novo,05,,-10.35,-39.716667
br,horizontina,Horizontina,23,14416,-27.616667,-54.316667
br,horma,Horma,18,,-22.666667,-51.983333
br,horror,Horror,13,,-3.6,-45.016667
br,hortencias,Hortências,21,,-22.906322,-43.536554
br,hortencio dutra,Hortêncio Dutra,23,,-28.75,-50.233333
br,horto florestal,Horto Florestal,27,,-23.40948,-46.679794
br,horto,Horto,21,,-22.968216,-43.237217
br,hortolandia,Hortolândia,27,203537,-22.85,-47.25
br,hosana,Hosana,22,,-6.266667,-37.75
br,hospedaria,Hospedaria,21,,-22.351461,-42.94053
br,huitanaa,Huitanaã,04,,-7.666667,-65.766667
br,hulha negra,Hulha Negra,23,,-31.4,-53.883333
br,humaita,Humaitá,01,,-8.033333,-71.5
br,humaita,Humaitá,04,31207,-7.516389,-63.022222
br,humaita,Humaitá,05,,-12.35,-40.683333
br,humaita,Humaitá,06,,-3.733333,-40.266667
br,humaita,Humaitá,15,,-16.766667,-41.816667
br,humaita,Humaitá,16,,-2.05,-48.3
br,humaita,Humaitá,17,,-7.416667,-38.566667
br,humaita,Humaitá,21,,-22.957414,-43.199222
br,humaita,Humaitá,23,,-27.566667,-53.966667
br,humayta,Humaytá,01,,-8.261111,-72.738889
br,humayta,Humaytá,04,,-7.516389,-63.022222
br,humayta,Humaytá,05,,-9.116667,-39.716667
br,humayta,Humayta,15,,-21.769722,-43.490278
br,humberto de campos,Humberto de Campos,13,5208,-2.616667,-43.45
br,humberto,Humberto,15,,-20.4,-46.8
br,humberto monte,Humberto Monte,06,,-3.666667,-40.233333
br,humildes,Humildes,05,,-12.366667,-38.883333
br,humildes,Humildes,20,,-5.25,-42.2
br,hungria,Hungria,27,,-23.1923,-47.7318
br,hydrolandia,Hydrolandia,29,,-16.966667,-49.233333
br,hyutanaha,Hyutanahã,04,,-7.666667,-65.766667
br,iabara,Iabará,31,,-10.773611,-47.4075
br,iabete,Iabetê,31,,-10.773611,-47.4075
br,iacaia,Iacaiá,15,,-20.433333,-46.733333
br,iacanga,Iacanga,27,,-21.9,-49.016667
br,iacara,Iaçara,29,,-14.15,-46.666667
br,iaciara,Iaciara,29,9207,-14.15,-46.666667
br,iaci,Iaci,27,,-20.883333,-49.55
br,iacri,Iacri,27,,-21.85,-50.65
br,iacu,Iaçu,05,22665,-12.75,-40.216667
br,ianatama,Ianatama,16,,-1.35,-47.75
br,iandara,Iandara,27,,-21.45,-51.616667
br,iandrinopolis,Iandrinópolis,18,,-23.683333,-51.083333
br,iapi,Iapi,06,,-5.683333,-40.333333
br,iapu,Iapu,15,,-19.433333,-42.216667
br,iaquirana,Iaquirana,04,,1.066667,-67.566667
br,iara,Iara,06,,-7.05,-38.783333
br,iara maria,Iara Maria,23,,-29.4,-54.733333
br,iaramonta,Iaramonta,25,,4.6,-60.4
br,iaras,Iaras,27,,-22.883333,-49.183333
br,iaripo,Iaripo,16,,1.183333,-54.666667
br,iassiara,Iassiara,29,,-14.15,-46.666667
br,iassi,Iassí,05,,-12.75,-40.216667
br,iata,Iata,24,,-10.583333,-65.383333
br,iateca,Iatecá,30,,-8.983333,-36.7
br,iati,Iati,30,,-9.05,-36.85
br,iatoba,Iatobá,30,,-7.95,-37.883333
br,iauacana,Iauacaná,04,,.516667,-67.383333
br,iauare,Iauaré,16,,-7.883333,-57.183333
br,iauarete,Iauaretê,04,,.45,-67.366667
br,iaunari,Iaunari,04,,-.516667,-64.833333
br,iaurare,Iauraré,16,,-7.883333,-57.183333
br,iaurete,Iauretê,04,,.633333,-69.2
br,iavarete,Iavaretê,04,,.633333,-69.2
br,iavarite,Iavarite,04,,-4.383333,-57.266667
br,ibacatu,Ibacatú,23,,-29.416667,-53.133333
br,ibaete,Ibaeté,27,,-21.95,-48
br,ibaiti,Ibaiti,18,25797,-23.8469,-50.1886
br,ibarama,Ibarama,23,,-29.416667,-53.133333
br,ibare,Ibaré,23,,-30.816667,-54.266667
br,ibaretama,Ibaretama,06,,-4.866667,-38.883333
br,ibateguara,Ibateguara,02,8755,-8.983333,-35.866667
br,ibate,Ibaté,27,29550,-21.95,-48
br,ibatequara,Ibatequara,02,,-8.983333,-35.866667
br,ibatiba,Ibatiba,08,12265,-20.233333,-41.516667
br,ibatuba,Ibatuba,15,,-22.066667,-45.05
br,ibatui,Ibatuí,05,,-11.883333,-38.166667
br,ibera peteby,Ibera Peteby,11,,-23.15,-55.033333
br,ibera petehy,Ibera Petehy,11,,-23.15,-55.033333
br,ibera petei,Ibera Petei,11,,-23.15,-55.033333
br,ibera petel,Iberá Petel,11,,-23.15,-55.033333
br,ibertioga,Ibertioga,15,,-21.416667,-43.966667
br,ibiaca,Ibiaçá,23,,-28.05,-51.866667
br,ibiacema,Ibiacema,05,,-11.316667,-43.166667
br,ibiaci,Ibiaci,18,,-22.916667,-51.016667
br,ibiacuce,Ibiaçucê,05,,-14.283333,-42.283333
br,ibiacu,Ibiaçu,05,,-14.266667,-39.25
br,ibia'e,Ibia'e,23,,-28.5,-50.933333
br,ibiagui,Ibiagui,05,,-13.05,-44.2
br,ibiahy,Ibiahy,15,,-16.858889,-44.910556
br,ibia,Ibiá,15,18428,-19.483333,-46.533333
br,ibia,Ibiã,26,,-27.166667,-51.233333
br,ibiai,Ibiaí,15,,-16.858889,-44.910556
br,ibiajara,Ibiajara,05,,-13,-42.2
br,ibiam,Ibiam,26,,-27.166667,-51.233333
br,ibiapaba,Ibiapaba,06,,-5.05,-40.916667
br,ibiapaba,Ibiapaba,08,,-20.233333,-40.416667
br,ibiapina,Ibiapina,06,9205,-3.916667,-40.9
br,ibiapina,Ibiapina,17,,-7.533333,-37.816667
br,ibiapina,Ibiapina,30,,-7.833333,-35.883333
br,ibiapinopolis,Ibiapinópolis,17,,-7.05,-36.35
br,ibiapora,Ibiaporã,05,,-12.05,-40.816667
br,ibiaporan,Ibiaporan,05,,-12.05,-40.816667
br,ibiara,Ibiara,17,,-7.5,-38.416667
br,ibiassuce,Ibiassucê,05,,-14.283333,-42.283333
br,ibiatiara,Ibiatiara,06,,-7.1,-40
br,ibicaba,Ibicaba,08,,-19.966667,-41.216667
br,ibicaba,Ibicaba,27,,-21.5,-47.4
br,ibicacu,Ibicacú,23,,-29.533333,-50.8
br,ibicarai,Ibicaraí,05,19575,-14.85,-39.6
br,ibicare,Ibicaré,26,,-27.116667,-51.4
br,ibicatu,Ibicatu,06,,-6.9,-39.45
br,ibicoara,Ibicoara,05,,-13.4,-41.3
br,ibicua,Ibicuã,06,,-5.933333,-39.416667
br,ibicui,Ibicuí,05,10640,-14.85,-39.983333
br,ibicui,Ibicuí,21,,-22.9606,-44.0266
br,ibicuipeba,Ibicuipeba,06,,-5.25,-38.116667
br,ibicuitaba,Ibicuitaba,06,,-4.738889,-37.312222
br,ibicuitanga,Ibicuitanga,06,,-4.983333,-38.65
br,ibicuitinga,Ibicuitinga,06,,-4.983333,-38.65
br,ibicuituba,Ibicuituba,13,,-2.55,-43.233333
br,ibimirim,Ibimirim,30,12272,-8.533333,-37.7
br,ibiopaba,Ibiopaba,08,,-20.233333,-40.416667
br,ibipeba,Ibipeba,05,14444,-11.633333,-42.033333
br,ibipetuba,Ibipetuba,05,,-11,-44.533333
br,ibipetum,Ibipetum,05,,-11.816667,-42.65
br,ibipeuara,Ibipeuara,13,,-2.966667,-44.85
br,ibipira,Ibipira,13,,-6.516667,-44.633333
br,ibipitanga,Ibipitanga,05,,-12.9,-42.5
br,ibipora,Ibiporã,18,44791,-23.283333,-51.05
br,ibiporanga,Ibiporanga,05,,-14.583333,-40.016667
br,ibiporanga,Ibiporanga,27,,-20.416667,-49.6
br,ibiquara,Ibiquara,05,,-13.4,-41.3
br,ibiquera,Ibiquera,05,,-12.633333,-40.95
br,ibiquitaba,Ibiquitaba,06,,-4.738889,-37.312222
br,ibiraba biraba,Ibiraba Biraba,05,,-10.8,-42.833333
br,ibiracatu,Ibiracatu,15,,-15.65,-44.183333
br,ibiraci,Ibiraci,15,,-20.466667,-47.133333
br,ibiracu,Ibiraçu,08,8921,-19.833333,-40.366667
br,ibiracy,Ibiracy,15,,-20.466667,-47.133333
br,ibiraiaras,Ibiraiaras,23,,-28.366667,-51.65
br,ibira,Ibirá,27,,-21.1,-49.283333
br,ibiraja,Ibirajá,05,,-17.2,-40.15
br,ibirajuba,Ibirajuba,30,,-8.583333,-36.183333
br,ibirama,Ibirama,26,18360,-27.0546,-49.516
br,ibiranete,Ibiranete,11,,-23.15,-55.033333
br,ibiranga,Ibiranga,30,,-7.4,-35.233333
br,ibiranhem,Ibiranhém,05,,-17.833333,-40.166667
br,ibira peteym,Ibira Peteym,11,,-23.15,-55.033333
br,ibirapitanga,Ibirapitanga,05,7302,-14.15,-39.366667
br,ibirapitinga,Ibirapitinga,05,,-14.15,-39.366667
br,ibirapua,Ibirapuã,05,,-17.65,-40.116667
br,ibirapuera,Ibirapuera,27,,-21.75,-50.966667
br,ibirapuita,Ibirapuitã,23,,-28.566667,-52.55
br,ibirarema,Ibirarema,27,,-22.816667,-50.1
br,ibirataia,Ibirataia,05,19943,-14.066667,-39.633333
br,ibiratanha,Ibiratanha,06,,-5.3,-38.05
br,ibiratinga,Ibiratinga,30,,-8.533333,-35.266667
br,ibirite,Ibirité,15,141376,-20.033333,-44.066667
br,ibirituba,Ibirituba,05,,-12.416667,-38.116667
br,ibirocaim,Ibirocaim,05,,-13.733333,-41.766667
br,ibiruba,Ibirubá,23,14180,-28.633333,-53.1
br,ibirucucu,Ibirucuçu,11,,-20.6,-54.75
br,ibitiara,Ibitiara,05,,-12.65,-42.216667
br,ibitiara,Ibitiara,06,,-7.1,-40
br,ibitiguacu,Ibitiguaçu,21,,-21.5,-42.083333
br,ibitiguaia,Ibitiguaia,15,,-21.949722,-43.415833
br,ibitiguassu,Ibitiguassú,21,,-21.5,-42.083333
br,ibitiguira,Ibitiguira,05,,-13.2,-40.15
br,ibiti,Ibiti,27,,-22.666667,-46.683333
br,ibitinema,Ibitinema,21,,-21.55,-42.283333
br,ibitinga,Ibitinga,27,49075,-21.75,-48.816667
br,ibitioca,Ibitioca,21,,-21.816667,-41.466667
br,ibitipoca,Ibitipoca,15,,-21.55,-43.916667
br,ibitipora,Ibitiporã,21,,-21.466667,-42.033333
br,ibitiquira,Ibitiquira,05,,-13.2,-40.15
br,ibitira,Ibitira,05,,-14.116667,-42.083333
br,ibitira,Ibitira,15,,-19.45,-45.133333
br,ibitira,Ibitira,27,,-21.85,-47.633333
br,ibitira,Ibitira,30,,-7.4,-35.233333
br,ibitirama,Ibitirama,08,,-20.533333,-41.666667
br,ibitiranga,Ibitiranga,30,,-7.666667,-37.7
br,ibitirucu,Ibitiruçu,17,,-7.25,-38.316667
br,ibitiruna,Ibitiruna,15,,-21.15,-44.75
br,ibitiruna,Ibitiruna,27,,-22.774167,-47.962778
br,ibitita,Ibititá,05,,-11.566667,-41.966667
br,ibitiuna,Ibitiuna,27,,-22.774167,-47.962778
br,ibitiura,Ibitiúra,15,,-22.066667,-46.433333
br,ibitiuva,Ibitiúva,27,,-20.983333,-48.333333
br,ibituba,Ibituba,08,,-19.683333,-41.016667
br,ibitu,Ibitu,27,,-20.616667,-48.75
br,ibitunane,Ibitunane,05,,-11.55,-42.75
br,ibitupa,Ibitupã,05,,-14.516667,-39.866667
br,ibituporanga,Ibituporanga,21,,-22.764167,-43.791667
br,ibitura,Ibitura,27,,-20.983333,-48.333333
br,ibituruma,Ibituruma,15,,-21.15,-44.75
br,ibituruna,Ibituruna,15,,-21.15,-44.75
br,ibiuna,Ibiúna,27,22860,-23.654522,-47.218152
br,ibo,Ibó,05,,-12.283333,-37.933333
br,ibo,Ibó,30,,-8.616667,-39.733333
br,iborepi,Iborepi,06,,-6.833333,-38.983333
br,iboti,Iboti,27,,-20.816667,-49.633333
br,ibotim,Ibotim,29,,-16.283333,-52.116667
br,ibotirama,Ibotirama,05,17354,-12.183333,-43.216667
br,ibrahy,Ibrahy,15,,-16.858889,-44.910556
br,ibuaco,Ibuaço,06,,-4.75,-39.8
br,ibuacu,Ibuaçu,06,,-4.75,-39.8
br,ibuguacu,Ibuguaçu,06,,-3.366667,-41.266667
br,ibuira,Ibuira,05,,-14.166667,-40.25
br,ibura,Ibura,17,,-7.216667,-37.75
br,ibutinga,Ibutinga,26,,-26.922936,-49.905742
br,icacu,Icaçu,23,,-28.2,-53.483333
br,icaicara,Icaiçara,30,,-8.083333,-39.783333
br,icaicarinha,Icaiçarinha,30,,-8.116667,-38.133333
br,icaissara,Icaissara,30,,-8.083333,-39.783333
br,icaissarinha,Icaissarinha,30,,-8.116667,-38.133333
br,icana,Içana,04,,1.083333,-67.583333
br,icapui,Icapuí,06,,-4.7125,-37.353333
br,icara,Içara,15,,-20.816667,-44.483333
br,icara,Içara,18,,-23.166667,-51.616667
br,icara,Içara,26,51455,-28.7,-49.3
br,icarai,Icaraí,06,,-3.05,-39.633333
br,icarai,Icarai,15,,-16.217778,-44.906667
br,icarai,Icaraí,21,,-22.9,-43.099722
br,icaraima,Icaraíma,18,,-23.383333,-53.683333
br,icatuacu,Icatuaçu,27,,-23.733333,-46.4
br,icatu,Icatu,05,,-10.8,-42.833333
br,icatu,Icatu,13,3648,-2.766667,-44.066667
br,icaturama,Icaturama,27,,-21.466667,-47.35
br,icem,Icém,27,,-20.35,-49.2
br,ichu,Ichu,05,,-11.766667,-39.2
br,icoaraci,Icoaraci,16,,-1.3,-48.466667
br,ico da mundinha,Icó da Mundinha,30,,-9.1,-40.583333
br,ico de d. mundinha,Icó de D. Mundinha,30,,-9.1,-40.583333
br,ico,Icó,05,,-10,-42.5
br,ico,Icó,06,28323,-6.4,-38.85
br,ico,Icó,30,,-7.983333,-38.216667
br,iconha,Iconha,08,5051,-20.8,-40.8
br,icoraci,Icoraci,16,,-1.3,-48.466667
br,icozeira,Icòzeira,05,,-8.933333,-39.316667
br,icozinho,Icòzinho,06,,-6.516667,-38.666667
br,ida,Ida,11,,-20.95,-55.916667
br,idaiolanda,Idaiolanda,27,,-20.7,-49.866667
br,ideal,Ideal,06,,-4.433333,-38.683333
br,ideal,Ideal,27,,-20.8,-51.1
br,ideao,Ideão,16,,-5.716667,-54.216667
br,idiolanda,Idiolanda,27,,-20.7,-49.866667
br,idiolandia,Idiolândia,27,,-20.7,-49.866667
br,ielmo marinho,Ielmo Marinho,22,,-5.816667,-35.55
br,iepe,Iepê,27,,-22.666667,-51.083333
br,iequiri,Iequiri,30,,-8.666667,-36.45
br,igacaba,Igaçaba,27,,-20.133333,-47.45
br,igaci,Igaci,02,6480,-9.55,-36.633333
br,igapira,Igapira,27,,-20.316667,-49.9
br,igapo,Igapo,05,,-13.766667,-42.716667
br,igapo,Igapó,22,,-5.766667,-35.25
br,igapo,Igapó,30,,-9.2,-36.433333
br,igapora,Igaporã,05,,-13.766667,-42.716667
br,igaracu do tiete,Igaraçu do Tietê,27,22758,-22.516667,-48.566667
br,igaracu,Igaraçu,05,,-13.4,-41.3
br,igaracu,Igaraçu,30,,-7.833333,-34.9
br,igarahy,Igarahy,27,,-21.416667,-46.816667
br,igara,Igara,05,,-10.4,-40.116667
br,igarai,Igaraí,05,,-11.616667,-43.4
br,igarai,Igaraí,27,,-21.416667,-46.816667
br,igarapava,Igarapava,27,29058,-20.05,-47.783333
br,igarape-acu,Igarapé-açu,04,,-5.726944,-61.270833
br,igarape-acu,Igarapé-Açu,16,24136,-1.116667,-47.616667
br,igarape-acu,Igarapé-açú,30,,-8.683333,-35.916667
br,igarape-assu,Igarapé-Assú,16,,-1.116667,-47.616667
br,igarapeassu,Igarapeassu,30,,-8.683333,-35.916667
br,igarape azul,Igarapé Azul,25,,-2.216667,-60.966667
br,igarapeba,Igarapeba,30,,-8.816667,-35.883333
br,igarape do lago,Igarapé do Lago,03,,.083333,-51.466667
br,igarape grande,Igarapé Grande,03,,-.133333,-51.866667
br,igarape grande,Igarapé Grande,13,,-4.683333,-44.966667
br,igarape,Igarapé,15,21427,-20.066667,-44.3
br,igarape-miri,Igarapé-Miri,16,26838,-1.983333,-48.966667
br,igarape-mirim,Igarapé-Mirim,16,,-1.983333,-48.966667
br,igarape miry,Igarapé Miry,16,,-1.983333,-48.966667
br,igarape viroa,Igarapé Viroa,25,,.961111,-61.374444
br,igarapiuna,Igarapiuna,05,,-13.816667,-39.15
br,igarassu,Igarassú,05,,-13.4,-41.3
br,igarassu,Igarassú,27,,-22.516667,-48.566667
br,igarassu,Igarassu,30,86458,-7.833333,-34.9
br,igarata,Igaratá,27,,-23.2,-46.116667
br,igarate,Igaraté,27,,-23.2,-46.116667
br,igaratinga,Igaratinga,15,,-19.933333,-44.7
br,igarau,Igaraú,13,,-2.75,-44.316667
br,igarite,Igarité,05,,-11.616667,-43.4
br,igaroi,Igarói,06,,-6.366667,-39.05
br,igataua,Igatauá,30,,-9.133333,-36.466667
br,igatemi,Igatemí,11,,-23.666667,-54.566667
br,igatiquira,Igatiquira,05,,-13.35,-39.816667
br,igatu,Igatu,05,,-12.883333,-41.3
br,ignacio uchoa,Ignacio Uchoa,27,,-20.933333,-49.216667
br,igrapiuna,Igrapiúna,05,,-13.816667,-39.15
br,igreja,Igreja,05,,-13,-38.666667
br,igreja nova,Igreja Nova,02,4606,-10.116667,-36.65
br,igreja nova,Igreja Nova,05,,-12.183333,-38.5
br,igreja nova,Igreja Nova,15,,-18.25,-41.733333
br,igreja nova,Igreja Nova,22,,-5.816667,-35.45
br,igreja nova,Igreja Nova,28,,-10.933333,-38.066667
br,igrejinha,Igrejinha,23,28680,-29.566667,-50.8
br,iguaba grande,Iguaba Grande,21,11104,-22.833333,-42.216667
br,iguaba,Iguaba,05,,-10.283333,-37.933333
br,iguacu,Iguaçu,05,,-12.933333,-41.066667
br,iguacu,Iguaçu,15,,-19.716667,-42.35
br,iguacu,Iguaçu,18,,-25.416667,-52.416667
br,iguacu,Iguaçu,21,,-22.65,-43.416667
br,iguacu,Iguaçu,22,,-5.583333,-35.916667
br,iguacuzinho,Iguaçuzinho,18,,-24.583333,-53.283333
br,iguaiba,Iguaíba,13,,-2.466667,-44.1
br,igua,Iguá,05,,-14.95,-40.933333
br,iguai,Iguaí,05,14218,-14.75,-40.066667
br,igualdade,Igualdade,04,,-1.8,-68.5
br,iguape,Iguape,05,,-12.683333,-38.85
br,iguape,Iguape,06,,-3.933333,-38.266667
br,iguape,Iguape,08,,-20.583333,-40.483333
br,iguape,Iguape,27,23785,-24.716667,-47.55
br,iguaraci,Iguaraci,30,,-7.833333,-37.533333
br,iguaracu,Iguaraçu,18,,-23.183333,-51.833333
br,iguaracu,Iguaraçu,30,,-7.833333,-34.9
br,iguarassu,Iguarassú,30,,-7.833333,-34.9
br,iguaratinga,Iguaratinga,13,,-6.25,-42.866667
br,iguassu,Iguassu,06,,-4.616667,-39.383333
br,iguassu,Iguassú,18,,-25.416667,-52.416667
br,iguatama,Iguatama,15,,-20.166667,-45.7
br,iguatemi,Iguatemi,05,,-13.916667,-41.9
br,iguatemi,Iguatemi,11,9619,-23.666667,-54.566667
br,iguatemi,Iguatemi,18,,-23.35,-52.066667
br,iguatemi,Iguatemi,23,,-31.166667,-52.533333
br,iguati,Iguati,05,,-11.616667,-39.45
br,iguatu,Iguatu,06,70381,-6.366667,-39.3
br,iguatu,Iguatu,13,,-6.133333,-43.766667
br,iguira,Iguira,05,,-10.6,-42.65
br,iguita,Iguita,15,,-21.466667,-46.3
br,iguitu,Iguitu,05,,-11.466667,-42.2
br,ihum,Ihum,11,,-21.583333,-56.716667
br,ihun,Ihun,11,,-21.583333,-56.716667
br,ii-tapuia,Ii-Tapuia,04,,.3,-68.65
br,ijaci,Ijaci,15,,-21.166667,-44.933333
br,ijucapirama,Ijucapirama,23,,-29.4,-54.633333
br,ijuhy,Ijuhy,23,,-28.383333,-53.916667
br,ijui,Ijuí,23,71203,-28.383333,-53.916667
br,ildefonso,Ildefonso,14,,-14.716667,-57.65
br,ilerneiras,Ilerneiras,23,,-29.45,-52.65
br,ilhabela,Ilhabela,27,32903,-23.783333,-45.35
br,ilha brava,Ilha Brava,15,,-18.883333,-42.016667
br,ilha caratirimani,Ilha Caratirimani,25,,.45,-61.683333
br,ilha danta,Ilha Danta,20,,-3.266667,-42.062222
br,ilha das cotias,Ilha das Cotias,04,,-2.233333,-56.716667
br,ilha das cutias,Ilha das Cutias,04,,-2.233333,-56.716667
br,ilha das flores,Ilha das Flores,28,,-10.45,-36.55
br,ilha das pecas,Ilha das Peças,18,,-25.458578,-48.334891
br,ilha de itaoca,Ilha de Itaoca,21,,-22.783333,-43.066667
br,ilha de monte cristo,Ilha de Monte Cristo,04,,-5.587222,-61.124444
br,ilha dentro,Ilha Dentro,05,,-15.1,-41.683333
br,ilha do catrimani,Ilha do Catrimani,25,,.45,-61.683333
br,ilha do ferro,Ilha do Ferro,02,,-9.733333,-37.516667
br,ilha do ouro,Ilha do Ouro,28,,-9.9,-37.25
br,ilha do pao,Ilha do Pão,15,,-16.333333,-40.883333
br,ilha grande,Ilha Grande,02,,-9.133333,-37.95
br,ilha grande,Ilha Grande,04,,-.45,-65.033333
br,ilha grande,Ilha Grande,05,,-13.833333,-40.716667
br,ilha grande,Ilha Grande,06,,-5.5,-38.466667
br,ilha grande,Ilha Grande,18,,-25.066667,-48.75
br,ilha grande,Ilha Grande,26,,-27.55,-49.483333
br,ilha grande,Ilha Grande,28,,-11.066667,-37.2
br,ilha,Ilha,02,,-9.733333,-37.516667
br,ilha,Ilha,05,,-10.616667,-38.283333
br,ilha,Ilha,06,,-2.967222,-41.094444
br,ilha,Ilha,11,,-18.483333,-56.416667
br,ilha,Ilha,13,,-6.633333,-42.866667
br,ilha,Ilha,20,,-7.25,-41.9
br,ilha,Ilha,21,,-23.005133,-43.538387
br,ilha,Ilha,27,,-23.688257,-47.661139
br,ilha,Ilha,28,,-11.233333,-37.916667
br,ilha,Ilha,30,,-8.25,-37.216667
br,ilha luz,Ilha Luz,27,,-23.516667,-45.8
br,ilha rasa,Ilha Rasa,18,,-25.331405,-48.398951
br,ilha redonda,Ilha Redonda,03,,.1,-51.133333
br,ilha redonda,Ilha Redonda,05,,-8.633333,-39.55
br,ilha sao vicente,Ilha São Vicente,31,,-5.616667,-48.133333
br,ilhas,Ilhas,26,,-28.9,-49.333333
br,ilha solteira,Ilha Solteira,27,,-20.383333,-51.333333
br,ilha verde,Ilha Verde,11,,-18.516667,-57.416667
br,ilheos do prata,Ilhéos do Prata,15,,-20,-42.783333
br,ilheos,Ilhéos,05,,-14.816667,-39.033333
br,ilheos,Ilheos,15,,-20,-42.783333
br,ilheus do prata,Ilhéus do Prata,15,,-20,-42.783333
br,ilheus,Ilhéus,05,155503,-14.816667,-39.033333
br,ilhinha,Ilhinha,31,,-6.666667,-48.466667
br,ilho dos bois,Ilho dos Bois,28,,-10.45,-36.55
br,ilhota de cima,Ilhota de Cima,05,,-12.883333,-39.133333
br,ilhota,Ilhota,26,,-26.9,-48.866667
br,ilicinea,Ilicinea,15,,-20.933333,-45.833333
br,ilicinia,Ilicínia,15,,-20.933333,-45.833333
br,ilidio rocha,Ilídio Rocha,11,,-19.6,-55.033333
br,ilio-se,Iliô-Sê,14,,-14.45,-58.466667
br,illidio da rosa,Illidio da Rosa,11,,-19.6,-55.033333
br,illio-se,Illio-sé,14,,-14.45,-58.466667
br,ilopolis,Ilópolis,23,,-28.933333,-52.116667
br,imaculada,Imaculada,17,4014,-7.366667,-37.5
br,imaruhy,Imaruhy,26,,-28.35,-48.816667
br,imarui,Imaruí,26,,-28.35,-48.816667
br,imbahu,Imbahú,18,,-24.383333,-50.65
br,imbare,Imbaré,27,,-21.95,-47.933333
br,imbarie,Imbariê,21,,-22.627778,-43.199167
br,imbauba,Imbaúba,30,,-8.583333,-37.133333
br,imbaubas,Imbaúbas,15,,-17.616667,-42.8
br,imbau,Imbaú,18,,-24.383333,-50.65
br,imbau,Imbaú,21,,-22.6,-42.416667
br,imbauzinho,Imbaùzinho,18,,-24.266667,-50.666667
br,imbe,Imbé,05,,-12.05,-38.016667
br,imbe,Imbé,15,,-19.6,-41.966667
br,imbe,Imbé,21,,-21.983333,-41.883333
br,imbe,Imbé,30,,-7.966667,-37.366667
br,imbetiba,Imbetiba,21,,-22.383333,-41.783333
br,imbiacaba,Imbiaçaba,30,,-7.833333,-40.316667
br,imbiara,Imbiara,05,,-12.666667,-38.9
br,imbiara,Imbiara,21,,-22.8,-42.566667
br,imbiassaba,Imbiassaba,30,,-7.833333,-40.316667
br,imbiricu,Imbiriçu,15,,-19.383333,-44.316667
br,imbirituba,Imbirituba,05,,-12.416667,-38.116667
br,imbirucu,Imbiruçu,11,,-20.6,-54.75
br,imbirucu,Imbiruçu,15,,-19.383333,-44.316667
br,imbirucu,Imbiruçu,20,,-9.5,-42.8
br,imbituba,Imbituba,26,43450,-28.233333,-48.666667
br,imbituva,Imbituva,18,19671,-25.2,-50.583333
br,imblassaba,Imblassaba,30,,-7.833333,-40.316667
br,imboiara,Imboiara,05,,-9.233333,-41.95
br,imbozal,Imbòzal,16,,-1,-52.533333
br,imbu-guacu,Imbu-Guaçu,27,,-23.816667,-46.8
br,imbuia,Imbuia,18,,-24.866667,-51
br,imbuial,Imbuial,18,,-25.183333,-49.133333
br,imbui,Imbuí,08,,-20.616667,-41.683333
br,imbui,Imbuí,21,,-22.320594,-42.866862
br,imbu,Imbu,18,,-24.916667,-50.283333
br,imbu,Imbu,27,,-23.65,-46.85
br,imbuira,Imbuíra,05,,-14.166667,-40.25
br,imbura,Imbura,21,,-22.183333,-41.8
br,imbura,Imbura,30,,-8.6,-37.15
br,imburana,Imburana,06,,-2.867778,-40.785278
br,imburana,Imburana,20,,-3.711667,-42.485833
br,imburana,Imburana,31,,-12.883333,-46.683333
br,imburanas,Imburanas,06,,-4.85,-41.016667
br,imburi,Imburi,21,,-21.483333,-41.283333
br,imburo,Imburo,21,,-22.183333,-41.8
br,imbute,Imbute,21,,-21.383333,-41.65
br,immaculada,Immaculada,17,,-7.366667,-37.5
br,imoroti,Imoroti,17,,-7.516667,-37.666667
br,imperatriz,Imperatriz,04,,-5.3,-67.183333
br,imperatriz,Imperatriz,06,,-3.5,-39.583333
br,imperatriz,Imperatriz,13,218110,-5.533333,-47.483333
br,imperatriz,Imperatriz,15,,-21.233333,-47.066667
br,imperio,Império,08,,-19.533333,-39.816667
br,impertinencia,Impertinência,22,,-6.116667,-38.016667
br,imprensa,Imprensa,30,,-9.266667,-37.166667
br,inacio goncalves,Inácio Gonçalves,15,,-19.016667,-48.1
br,inacio,Inácio,15,,-15.416667,-44.866667
br,inacio,Inácio,17,,-7.666667,-36.05
br,inacio martins,Inácio Martins,18,,-25.516667,-51.133333
br,inacio pires,Inácio Pires,05,,-13.816667,-41.083333
br,inacios,Inácios,15,,-21.366667,-46.983333
br,inacio uchoa,Inácio Uchoa,27,,-20.933333,-49.216667
br,inaja,Inajá,04,,-4.448611,-58.114722
br,inaja,Inajá,18,,-22.733333,-52.233333
br,inaja,Inajá,29,,-17.583333,-48.2
br,inaja,Inajá,30,,-8.9,-37.816667
br,inajaroba,Inajaroba,28,,-11.333333,-37.5
br,inambu,Inambu,04,,-3.583333,-62.433333
br,incaibro,Incaibro,05,,-9.533333,-41.15
br,inchu,Inchu,05,,-11.766667,-39.2
br,inconfidencia,Inconfidência,21,,-22.238611,-43.204167
br,inconfidencia,Inconfidência,23,,-28.65,-54.133333
br,inconfidentes,Inconfidentes,15,,-22.333333,-46.333333
br,indaiabira,Indaiabira,15,,-15.483333,-42.216667
br,indaia do aguapei,Indaiá do Aguapeí,27,,-21.4,-51.133333
br,indaia,Indaiá,05,,-13.683333,-39.583333
br,indaia,Indaiá,11,,-20.033333,-55.033333
br,indaia,Indaiá,15,,-15.983333,-42.383333
br,indaia,Indaiá,20,,-8.816667,-43.016667
br,indaial de baixo,Indaial de Baixo,26,,-28.4,-49
br,indaial de cima,Indaial de Cima,26,,-28.35,-48.933333
br,indaial,Indaial,26,44360,-26.8922,-49.2239
br,indaiatuba,Indaiatuba,27,179914,-23.083333,-47.233333
br,indai,Indaí,05,,-12.016667,-40.566667
br,indaval,Indaval,26,,-26.8922,-49.2239
br,indaya,Indayá,15,,-19.45,-45.6
br,independencia,Independência,01,,-10.566667,-68.216667
br,independencia,Independência,04,,-7.269722,-70.973333
br,independencia,Independência,05,,-16.516667,-39.416667
br,independencia,Independência,06,11113,-5.383333,-40.316667
br,independencia,Independência,08,,-19.183333,-40.5
br,independencia,Independência,11,,-21.683333,-56.383333
br,independencia,Independência,13,,-4.35,-44.333333
br,independencia,Independência,14,,-13.566667,-53.95
br,independencia,Independência,15,,-19.166667,-41.25
br,independencia,Independência,16,,-2.866667,-52.016667
br,independencia,Independencia,22,,-5.263333,-36.723056
br,independencia,Independência,23,,-27.85,-54.2
br,inderere,Indererê,05,,-13.183333,-41.6
br,india,Índia,15,,-15.9,-41.55
br,indiana,Indiana,15,,-17.833333,-40.35
br,indiana,Indiana,27,,-22.183333,-51.233333
br,indianopolis,Indianópolis,15,,-19.033333,-47.916667
br,indianopolis,Indianópolis,18,,-23.479941,-52.697173
br,indiapora,Indiaporã,27,,-19.95,-50.283333
br,indiarana,Indiarana,11,,-19.4,-56.216667
br,indiaroba,Indiaroba,28,4989,-11.533333,-37.516667
br,indio brasil,Indio Brasil,04,,-6.783333,-62.383333
br,indio brazil,Indio Brazil,04,,-6.783333,-62.383333
br,indio do brasil,Índio do Brasil,04,,-6.783333,-62.383333
br,indio,Índio,18,,-25.5,-54.233333
br,indio,Índio,29,,-16.016667,-49.133333
br,indios guarani,Índios Guarani,18,,-25.783333,-51.333333
br,indios,Indios,18,,-25.5,-54.233333
br,indios,Índios,26,,-27.783333,-50.2
br,indubrasil,Indubrasil,11,,-20.466667,-54.733333
br,industrial,Industrial,08,,-18.733333,-40.266667
br,inema,Inema,05,,-14.5,-39.5
br,inema,Inema,21,,-22.194167,-43.311667
br,ines,Inês,13,,-3.65,-45.366667
br,ines,Inês,18,,-22.65,-51.916667
br,inesopolis,Inesópolis,17,,-7.616667,-38.55
br,infernao,Infernão,04,,-8.483333,-60.783333
br,inferninho,Inferninho,27,,-24.742598,-48.226301
br,infinito,Infinito,13,,-5.333333,-43.333333
br,ingahy,Ingahy,15,,-21.4,-44.916667
br,ingahy,Ingahy,27,,-20.416667,-49.366667
br,ingai,Ingaí,15,,-21.4,-44.916667
br,ingai,Ingaí,27,,-20.416667,-49.366667
br,inga,Ingá,05,,-17.333333,-39.3
br,inga,Ingá,06,,-3.916667,-40.183333
br,inga,Ingá,11,,-19.8,-56.566667
br,inga,Ingá,13,,-3.216667,-43.716667
br,inga,Ingá,17,8751,-7.283333,-35.6
br,inga,Ingá,18,,-23.0488,-50.2276
br,inga,Ingá,21,,-22.903473,-43.125181
br,inga,Ingá,22,,-5.533333,-35.583333
br,inga,Ingá,30,,-7.833333,-39.266667
br,ingaseiro,Ingaseiro,11,,-22.083333,-57.916667
br,ingas,Ingás,27,,-20.416667,-49.366667
br,ingazeira,Ingàzeira,05,,-11,-44.933333
br,ingazeira,Ingàzeira,06,,-6.333333,-38.7
br,ingazeira,Ingazeira,20,,-3.865,-42.078056
br,ingazeira,Ingàzeira,21,,-22.2,-41.733333
br,ingazeira,Ingàzeira,30,,-7.666667,-37.466667
br,ingazeiras,Ingàzeiras,06,,-7.1,-39
br,ingazeiras,Ingàzeiras,30,,-7.733333,-39.533333
br,ingazeiro,Ingàzeiro,11,,-22.083333,-57.916667
br,ingazeiro,Ingàzeiro,30,,-8.633333,-38.65
br,inglesa,Inglesa,21,,-22.470833,-43.2225
br,ingles de souza,Inglês de Souza,16,,-1.933333,-54.166667
br,ingleses do rio vermelho,Inglêses do Rio Vermelho,26,,-27.45,-48.366667
br,ingleses,Inglêses,26,,-27.45,-48.366667
br,ingrata,Ingrata,18,,-24.533333,-50.366667
br,inhacora,Inhacorá,23,,-27.883333,-54.033333
br,inhahy,Inhahy,15,,-17.933333,-43.616667
br,inhai,Inhaí,15,,-17.933333,-43.616667
br,inhambupe,Inhambupe,05,14735,-11.783333,-38.35
br,inhambupo,Inhambupo,05,,-11.783333,-38.35
br,inhame,Inhame,15,,-20.35,-45.883333
br,inhames,Inhames,15,,-20.35,-45.883333
br,inhamuns,Inhamuns,06,,-5.866667,-39.85
br,inhandava,Inhandava,23,,-29.616667,-51.933333
br,inhangapi,Inhangapi,16,,-1.416667,-47.883333
br,inhangapy,Inhangapy,16,,-1.416667,-47.883333
br,inhapi,Inhapi,02,7550,-9.233333,-37.75
br,inhapim,Inhapim,15,13594,-19.55,-42.116667
br,inhare,Inharé,06,,-5.416667,-40.55
br,inhare,Inharé,20,,-6.816667,-40.566667
br,inhata,Inhatá,05,,-12.416667,-38.683333
br,inhauma,Inhaúma,02,,-9.15,-36.116667
br,inhauma,Inhaúma,06,,-7.166667,-39.75
br,inhauma,Inhaúma,15,,-19.483333,-44.366667
br,inhauma,Inhaúma,21,,-22.871944,-43.280556
br,inhauma,Inhaúma,30,,-8.316667,-36.4
br,inhaumas,Inhaúmas,05,,-13.033333,-44.616667
br,inhema,Inhema,27,,-22.016667,-49.8
br,inhoaiba,Inhoaíba,21,,-22.905259,-43.603237
br,inhoan,Inhôan,21,,-22.916667,-42.95
br,inhobim,Inhobim,05,,-15.25,-40.95
br,inhomirim,Inhomirim,21,,-22.569167,-43.182778
br,inhucu,Inhuçu,06,,-4.116667,-40.866667
br,inhuma,Inhuma,05,,-12.216667,-38.5
br,inhuma,Inhuma,11,,-20.3,-55.916667
br,inhuma,Inhuma,20,7056,-6.666667,-41.7
br,inhumas,Inhumas,13,,-8.746667,-45.968889
br,inhumas,Inhumas,15,,-16.15,-41.4
br,inhumas,Inhumas,20,,-6.666667,-41.7
br,inhumas,Inhumas,29,44058,-16.366667,-49.5
br,inhuporanga,Inhuporanga,06,,-4.1,-39.05
br,inhussu,Inhussu,06,,-4.116667,-40.866667
br,inhuvera,Inhuverá,23,,-29.466667,-52.083333
br,inimutaba,Inimutaba,15,,-18.75,-44.366667
br,ininga,Ininga,20,,-3.646389,-42.618333
br,inoa,Inoá,04,,-3.981667,-62.837222
br,inoa,Inoã,21,,-22.916667,-42.95
br,inocencia,Inocência,11,,-19.783333,-51.8
br,inojosa,Inojosa,06,,-4.416667,-39.25
br,instituto do prata,Instituto do Prata,16,,-1.3,-47.6
br,insua,Insua,14,,-17.616667,-57.716667
br,insu,Insú,14,,-17.616667,-57.716667
br,inta,Intã,06,,-4.016667,-40.183333
br,inta,Intã,30,,-7.766667,-37.716667
br,intas,Intãs,05,,-9.65,-41.433333
br,intendencia,Intendência,05,,-9.85,-43.05
br,interlagos de itauna,Interlagos de Itaúna,21,,-22.996398,-43.412117
br,interlandia,Interlândia,29,,-16.2,-49.033333
br,inubia,Inúbia,05,,-13.116667,-41.983333
br,inubia,Inubia,27,,-21.75,-50.966667
br,inubia paulista,Inúbia Paulista,27,,-21.75,-50.966667
br,inveia,Inveia,22,,-5.983333,-37.65
br,invejada,Invejada,20,,-5.266667,-41.866667
br,inveja,Inveja,04,,-4.634444,-59.427222
br,inveja,Inveja,05,,-8.9,-38.833333
br,inveja,Inveja,15,,-20.816667,-45.55
br,invernada da cruz,Invernada da Cruz,18,,-25.872729,-50.2279
br,invernada do machado,Invernada do Machado,18,,-26.1,-52.283333
br,invernada grande,Invernada Grande,18,,-24.997851,-48.873815
br,invernada,Invernada,15,,-18.733333,-50.15
br,invernada,Invernada,18,,-25.152863,-48.913933
br,invernada,Invernada,27,,-22.816667,-47.483333
br,invernadinha,Invernadinha,11,,-22.15,-55.066667
br,invernadinha,Invernadinha,27,,-23.347622,-47.920527
br,iomere,Iomerê,26,,-27.016667,-51.25
br,ione,Ione,18,,-23.416667,-50.383333
br,ipaarana,Ipaarana,17,,-7.15,-35.85
br,ipaba,Ipaba,15,15971,-19.383333,-42.416667
br,ipaguacu,Ipaguaçu,06,,-3.5,-40.266667
br,ipameri,Ipameri,20,,-10.366667,-45.133333
br,ipameri,Ipameri,29,18607,-17.716667,-48.15
br,ipamery,Ipamery,29,,-17.716667,-48.15
br,ipanana,Ipanana,15,,-19.4,-42.683333
br,ipane,Ipané,13,,-9.55,-46.15
br,ipane,Ipane,15,,-19.4,-42.683333
br,ipanema de cima,Ipanema de Cima,27,,-23.510047,-47.540333
br,ipanema do meio,Ipanema do Meio,27,,-23.5032,-47.5489
br,ipanema do norte,Ipanema do Norte,18,,-25.204515,-48.330452
br,ipanema,Ipanema,05,,-11.383333,-41.6
br,ipanema,Ipanema,15,11705,-19.783333,-41.733333
br,ipanema,Ipanema,18,,-24.728399,-48.997064
br,ipanema,Ipanema,21,,-22.980968,-43.202864
br,ipanema,Ipanema,23,,-30.133333,-51.229167
br,ipanema,Ipanema,27,,-23.433333,-47.6
br,ipanema,Ipanema,30,,-8.4,-36.816667
br,ipanguacu,Ipanguaçu,22,4624,-5.497778,-36.853333
br,ipanore,Ipanoré,04,,.25,-68.466667
br,ipaobi,Ipaobi,27,,-21.9,-47.033333
br,ipaporanga,Ipaporanga,06,,-4.9,-40.766667
br,iparanga,Iparanga,27,,-23.6,-46.616667
br,ipatinga,Ipatinga,15,228750,-19.5,-42.533333
br,ipatinga,Ipatinga,27,,-23.5028,-47.5289
br,ipauanema,Ipauanema,04,,-4.359167,-62.1175
br,ipaua-pixuna,Ipauá-Pixuna,04,,-2.75,-65.783333
br,ipauarana,Ipauarana,17,,-7.15,-35.85
br,ipaucu,Ipauçu,27,,-23.05,-49.616667
br,ipauguacu,Ipauguaçu,22,,-5.497778,-36.853333
br,ipaumirim,Ipaumirim,06,,-6.783333,-38.716667
br,ipaussu,Ipaussú,27,10833,-23.05,-49.616667
br,ipecaeta,Ipecaetá,05,,-12.316667,-39.3
br,ipecu,Ipeçu,04,,-6.516667,-64.266667
br,ipeguari,Ipeguari,29,,-17.716667,-50.583333
br,ipegue,Ipegue,11,,-20.2,-56.05
br,ipe,Ipê,08,,-20.633333,-40.9
br,ipe,Ipé,11,,-21.016667,-55.816667
br,ipe,Ipê,21,,-22.695833,-43.870556
br,ipe,Ipé,23,,-28.833333,-51.283333
br,iperaba,Iperaba,26,,-26.216667,-48.583333
br,iperoba,Iperoba,26,,-26.216667,-48.583333
br,ipero,Iperó,27,17161,-23.35,-47.683333
br,ipes,Ipês,27,,-21.65,-50.016667
br,ipeuate,Ipeuate,05,,-13.166667,-40.1
br,ipeuna,Ipeúna,27,,-22.433333,-47.716667
br,ipiabanha,Ipiabanha,31,,-9.542222,-48.228056
br,ipiabas,Ipiabas,21,,-22.376944,-43.873056
br,ipiacu,Ipiaçu,15,,-18.7,-49.95
br,ipiau,Ipiaú,05,38763,-14.133333,-39.733333
br,ipigua,Ipiguá,27,,-20.65,-49.366667
br,ipiiba,Ipiíba,21,,-22.866667,-42.95
br,ipiraca,Ipiraca,18,,-24.633333,-53.9
br,ipira,Ipirá,05,27218,-12.166667,-39.733333
br,ipira,Ipira,26,,-27.433333,-51.816667
br,ipiranga do piaui,Ipiranga do Piauí,20,,-6.816667,-41.75
br,ipiranga,Ipiranga,04,,-2.931944,-69.695
br,ipiranga,Ipiranga,05,,-12.466667,-38.716667
br,ipiranga,Ipiranga,06,,-7.066667,-39.816667
br,ipiranga,Ipiranga,08,,-19.516667,-40.283333
br,ipiranga,Ipiranga,11,,-20.933333,-55.583333
br,ipiranga,Ipiranga,15,,-16.716667,-41
br,ipiranga,Ipiranga,18,,-25.016667,-50.583333
br,ipiranga,Ipiranga,20,,-5,-42.083333
br,ipiranga,Ipiranga,21,,-22.894254,-43.573518
br,ipiranga,Ipiranga,22,,-5.45,-35.683333
br,ipiranga,Ipiranga,23,,-27.933333,-52.416667
br,ipiranga,Ipiranga,24,,-10.016667,-62.866667
br,ipiranga,Ipiranga,26,,-26.485,-48.7336
br,ipiranga,Ipiranga,27,,-21.8,-47.7
br,ipiranguinha,Ipiranguinha,18,,-23.8869,-50.124
br,ipiranguinha,Ipiranguinha,27,,-25.0325,-48.1364
br,ipitanga,Ipitanga,05,,-12.9,-38.333333
br,ipitangas,Ipitangas,21,,-22.75,-42.75
br,ipiuna,Ipiúna,05,,-13.583333,-39.866667
br,ipixuna,Ipixuna,04,5814,-7.051667,-71.693056
br,ipixuna,Ipixuna,13,,-4.366667,-44.566667
br,ipixuna,Ipixuna,16,,-.75,-50.966667
br,ipoeira,Ipoeira,14,,-16.4,-56.983333
br,ipoeiras,Ipoeiras,30,,-7.816667,-39.483333
br,ipoema,Ipoema,15,,-19.6,-43.433333
br,ipojuca,Ipojuca,27,,-22.433333,-47.716667
br,ipojuca,Ipojuca,30,53365,-8.4,-35.066667
br,ipomeia,Ipoméia,26,,-26.95,-51.1
br,ipora,Iporã,18,10353,-23.983333,-53.616667
br,ipora,Iporã,26,,-26.983333,-53.583333
br,ipora,Iporá,29,28254,-16.466667,-51.116667
br,iporanga,Iporanga,27,,-24.584536,-48.592226
br,ipuacu,Ipuaçu,05,,-12.283333,-39.016667
br,ipuacu,Ipuaçu,26,,-26.566667,-52.45
br,ipua,Ipuã,27,12370,-20.45,-48.033333
br,ipuarana,Ipuarana,17,,-7.15,-35.85
br,ipuassu,Ipuassú,05,,-12.35,-39.083333
br,ipubi,Ipubi,30,16424,-7.65,-40.116667
br,ipucaba,Ipuçaba,05,,-12.116667,-42.966667
br,ipuca,Ipuca,21,,-21.633333,-41.733333
br,ipueira cercada,Ipueira Cercada,06,,-5.25,-40.266667
br,ipueira de ze manezinho,Ipueira de Zé Manezinho,06,,-7.183333,-38.916667
br,ipueira do macio,Ipueira do Macio,05,,-10.366667,-39.95
br,ipueira do peixe,Ipueíra do Peixe,17,,-6.816667,-37.6
br,ipueira do velho,Ipueira do Velho,06,,-3.533333,-40.083333
br,ipueira,Ipueira,02,,-9.666667,-37.366667
br,ipueira,Ipueira,05,,-12.383333,-39.55
br,ipueira,Ipueira,06,,-3.95,-38.9
br,ipueira,Ipueira,17,,-7.166667,-36.516667
br,ipueira,Ipueira,20,,-6.95,-40.616667
br,ipueira,Ipueira,22,,-5.366667,-37.5
br,ipueira,Ipueira,30,,-7.483333,-37.183333
br,ipueiras,Ipueiras,02,,-9.333333,-37.05
br,ipueiras,Ipueiras,06,17111,-7.033333,-40.45
br,ipueiras,Ipueiras,20,,-7.066667,-41.45
br,ipueiras,Ipueiras,30,,-7.833333,-39.45
br,ipueiras,Ipueiras,31,,-11.232778,-48.351944
br,ipueirinha,Ipueirinha,06,,-3.65,-40.133333
br,ipueirinha,Ipueirinha,17,,-7.65,-36.433333
br,ipueirinha,Ipueirinha,30,,-8.133333,-37.416667
br,ipuera,Ipuera,30,,-7.816667,-39.483333
br,ipu,Ipu,06,26679,-4.333333,-40.7
br,ipu,Ipu,13,,-5.783333,-45.983333
br,ipuiuna,Ipuiúna,15,,-22.1,-46.183333
br,ipu marzagao,Ipu Marzagão,06,,-3.533333,-39.516667
br,ipumirim,Ipumirim,26,,-27.083333,-52.133333
br,ipupiara,Ipupiara,05,,-11.816667,-42.616667
br,ipura,Ipurá,26,,-26.983333,-53.583333
br,ipuyuna,Ipuyuna,15,,-22.1,-46.183333
br,ipuzinho,Ipuzinho,06,,-5.116667,-40.15
br,ipyra,Ipyra,26,,-27.433333,-51.816667
br,iracema,Iracema,01,,-10.533333,-68.15
br,iracema,Iracema,04,,-4.435833,-59.800833
br,iracema,Iracema,05,,-13.283333,-40.966667
br,iracema,Iracema,06,,-3.983333,-40.083333
br,iracema,Iracema,24,,-11.25,-61.933333
br,iracema,Iracema,26,,-26.45,-50.016667
br,iracemapolis,Iracemápolis,27,16796,-22.583333,-47.533333
br,iraceminha,Iraceminha,26,,-26.833333,-53.25
br,iracemopolis,Iracemopolis,27,,-22.583333,-47.533333
br,iraci,Iraci,30,,-8.816667,-35.95
br,iraguacu,Iraguaçu,30,,-7.766667,-38.033333
br,irahy,Irahy,15,,-18.983333,-47.466667
br,irahy,Irahy,23,,-27.183333,-53.25
br,irai de minas,Iraí de Minas,15,,-18.983333,-47.466667
br,irai,Iraí,05,,-11.933333,-38.616667
br,irai,Iraí,15,,-18.983333,-47.466667
br,irai,Iraí,23,,-27.183333,-53.25
br,iraiti,Iraiti,04,,.216667,-69.45
br,iraiti,Iraití,23,,-29.616667,-53.35
br,irajai,Irajaí,30,,-7.933333,-37.45
br,iraja,Irajá,06,,-4.366667,-40.433333
br,iraja,Irajá,13,,-5.133333,-43.1
br,iraja,Irajá,21,,-22.836453,-43.320873
br,irajuba,Irajuba,05,,-13.266667,-40.083333
br,iramaia,Iramaia,05,,-12.366667,-41.366667
br,iranduba grande,Iranduba Grande,04,,-3.25,-60.1
br,iranduba,Iranduba,04,11181,-3.25,-60.1
br,irani,Irani,06,,-5.216667,-39
br,irani,Irani,26,,-27.016667,-51.9
br,iraobi,Iraobí,31,,-11.014167,-48.505
br,irape,Irapé,27,,-23.066667,-49.733333
br,irapicuru,Irapicuru,05,,-12.1,-39.116667
br,irapiranga,Irapiranga,28,,-10.983333,-37.3
br,irapoa,Irapoá,20,,-3.583333,-42.383333
br,iraporanga,Iraporanga,05,,-12.3,-41.55
br,irapua de baixo,Irapuá de Baixo,06,,-5.166667,-40.45
br,irapua de cima,Irapuá de Cima,06,,-5.15,-40.433333
br,irapua,Irapuá,06,,-4.716667,-40.45
br,irapua,Irapuá,20,,-3.583333,-42.383333
br,irapua,Irapuá,23,,-27.5,-53.7
br,irapua,Irapuã,27,,-21.3,-49.4
br,irapuan,Irapuan,27,,-21.3,-49.4
br,irapuazinho,Irapuãzinho,05,,-13.5,-41.75
br,irapuru,Irapuru,16,,-2.45,-50.933333
br,irapuru,Irapuru,27,,-21.566667,-51.35
br,iraputa,Iraputã,26,,-26.45,-50.016667
br,iraquara,Iraquara,05,5131,-12.25,-41.6
br,iraquara,Iraquara,16,,-.916667,-47.216667
br,irara,Irará,05,9099,-12.033333,-38.766667
br,irara,Irara,11,,-19.333333,-51.3
br,iratama,Iratama,30,,-9.033333,-36.416667
br,irateua,Irateua,16,,-1.833333,-52.283333
br,irati,Irati,18,45831,-25.4735,-50.6524
br,irati,Irati,27,,-24.672521,-48.024675
br,iratim,Iratim,18,,-26.466667,-51.416667
br,iratinga,Iratinga,06,,-3.733333,-39.533333
br,irati velho,Irati Velho,18,,-25.5,-50.666667
br,iraty,Iraty,18,,-25.4735,-50.6524
br,iratym,Iratym,18,,-26.466667,-51.416667
br,iraucuba,Irauçuba,06,13282,-3.75,-39.783333
br,irece,Irecê,05,63628,-11.3,-41.866667
br,irere,Irerê,18,,-23.516667,-51.083333
br,iretama,Iretama,18,,-24.283333,-52.033333
br,irgang,Irgang,23,,-28.25,-53.883333
br,iriri,Iriri,08,,-20.833333,-40.7
br,iriri,Iriri,21,,-22.333333,-41.95
br,iriritiba,Iriritiba,08,,-20.7,-40.75
br,irituia,Irituia,16,5602,-1.766667,-47.433333
br,irmaos valadares,Irmãos Valadares,11,,-18.283333,-55.416667
br,irmaos ziemel,Irmãos Ziemel,15,,-17.133333,-41.35
br,iroi,Iroí,18,,-23.25,-52.15
br,irundiara,Irundiara,05,,-14.283333,-42.283333
br,irundi,Irundi,08,,-19.916667,-40.433333
br,irupi,Irupi,08,3505,-20.35,-41.633333
br,isaac portilho,Isaac Portilho,29,,-16.783333,-51.7
br,isabel dos santos,Isabel dos Santos,29,,-16.1,-51.7
br,isabel,Isabel,08,,-20.383333,-40.633333
br,isaias coelho,Isaías Coelho,20,,-7.733333,-41.666667
br,isalino,Isalino,15,,-16.433333,-40.3
br,isidoro alves,Isidoro Alves,11,,-20.15,-55.2
br,isidoro,Isidoro,06,,-6.133333,-39.25
br,isidro alves,Isidro Alves,11,,-20.15,-55.2
br,isidro,Isidro,11,,-21.466667,-55.25
br,israelandia,Israelândia,29,,-16.35,-50.9
br,itaara,Itaara,23,,-29.583333,-53.783333
br,itabaiana,Itabaiana,04,,-6.05,-67.833333
br,itabaiana,Itabaiana,05,,-13.45,-39.45
br,itabaiana,Itabaiana,17,19101,-7.333333,-35.333333
br,itabaiana,Itabaiana,28,63889,-10.683333,-37.433333
br,itabaianinha,Itabaianinha,28,17149,-11.266667,-37.783333
br,itabai,Itabaí,05,,-15.416667,-40.45
br,itabapoana,Itabapoana,08,,-21.2,-41.466667
br,itabapoana,Itabapoana,21,,-21.3,-40.966667
br,itabayanna,Itabayanna,04,,-6.05,-67.833333
br,itabayanna,Itabayanna,17,,-7.333333,-35.333333
br,itabayanninha,Itabayanninha,28,,-11.266667,-37.783333
br,itaberaba,Itaberaba,05,47303,-12.533333,-40.3
br,itaberahy,Itaberahy,29,,-16.033333,-49.8
br,itaberai,Itaberaí,29,22130,-16.033333,-49.8
br,itabera,Itaberá,27,11098,-23.85,-49.15
br,itabi,Itabi,28,,-10.133333,-37.1
br,itabira de mato dentro,Itabira de Mato Dentro,15,,-19.616667,-43.216667
br,itabira de matto dentro,Itabira de Matto Dentro,15,,-19.616667,-43.216667
br,itabira,Itabira,05,,-11.55,-40.45
br,itabira,Itabira,15,99498,-19.616667,-43.216667
br,itabirinha de mantena,Itabirinha de Mantena,15,,-18.533333,-41.25
br,itabirinha,Itabirinha,15,,-18.533333,-41.25
br,itabirito,Itabirito,15,39453,-20.2484,-43.8063
br,itaboca grande,Itaboca Grande,16,,-4.483333,-49.55
br,itaboca,Itaboca,04,,-4.883611,-62.682778
br,itaboca,Itaboca,15,,-22.05,-44.083333
br,itaboca,Itaboca,16,,-4.271389,-52.662222
br,itaborahy,Itaborahy,21,,-22.75,-42.866667
br,itaborahy,Itaborahy,29,,-16.033333,-49.8
br,itaborai,Itaboraí,21,182500,-22.75,-42.866667
br,itabuna,Itabuna,05,205666,-14.8,-39.266667
br,itacaja,Itacajá,31,,-8.359444,-47.628333
br,itacamba,Itacambá,17,,-6.55,-37.8
br,itacambira,Itacambira,15,,-17.066667,-43.3
br,itacara,Itacara,05,,-12.183333,-38.816667
br,itacarambi,Itacarambi,15,13084,-15.016667,-44.05
br,itacaramby,Itacaramby,15,,-15.083333,-44.116667
br,itacare,Itacaré,05,12490,-14.3,-39
br,itacatu,Itacatu,30,,-8.8,-36.466667
br,itacava,Itacava,05,,-12.183333,-38.816667
br,itaccuce,Itaçcucê,05,,-14.233333,-44.3
br,itace,Itacê,29,,-14.683333,-49.45
br,itacema,Itacêma,23,,-29.933333,-51.9
br,itachama,Itachama,05,,-13.033333,-39.716667
br,itaci,Itaci,15,,-20.933333,-45.95
br,itacima,Itacima,06,,-4.133333,-38.716667
br,itacira,Itacira,05,,-12.266667,-41.183333
br,itacoara,Itacoára,21,,-21.683333,-42.066667
br,itacoatiara,Itacoatiara,04,45995,-3.05,-58.433333
br,itacoatiara,Itacoatiara,05,,-11.35,-43.216667
br,itacoatiara,Itacoatiara,21,,-22.969722,-43.031667
br,itacoatiara,Itacoatiara,30,,-8.916667,-36.65
br,itacolomi,Itacolomi,14,,-16.283333,-55.45
br,itacolomi,Itacolomi,15,,-19.016667,-43.566667
br,itacolomi,Itacolomi,21,,-22.811817,-43.232401
br,itacolomi,Itacolomí,23,,-28.7,-50.4
br,itacu,Itaçu,08,,-19.683333,-40.783333
br,itacuruba,Itacuruba,30,,-8.833333,-38.716667
br,itacurubi,Itacurubi,23,,-29.033333,-55.033333
br,itacuruca,Itacuruçá,05,,-12.233333,-39.216667
br,itacuruca,Itacuruçá,21,,-22.925833,-43.912222
br,itacuru,Itacuru,15,,-19.4,-43.316667
br,itacurussa,Itacurussá,05,,-12.233333,-39.216667
br,itacurussa,Itacurussá,21,,-22.925833,-43.912222
br,itacurussu,Itacurussú,21,,-22.925833,-43.912222
br,itacutiara,Itacutiara,05,,-8.966667,-38.516667
br,itacutiu,Itacutiú,16,,-1.416667,-46.166667
br,itacy,Itacy,15,,-21.016667,-46.016667
br,itaete,Itaetê,05,,-12.983333,-40.966667
br,itagiba,Itagibá,05,9843,-14.283333,-39.85
br,itagi,Itagi,05,10534,-14.166667,-40.016667
br,itaguacu,Itaguaçu,05,,-13.6,-41.9
br,itaguacu,Itaguaçu,08,8202,-19.8,-40.85
br,itaguai,Itaguaí,21,100756,-22.870755,-43.773821
br,itagua,Itaguá,06,,-6.95,-40.35
br,itaguaje,Itaguajé,18,,-22.616667,-51.983333
br,itaguan,Itaguan,18,,-22.816667,-52.683333
br,itaguara,Itaguará,13,,-5.183333,-42.916667
br,itaguara,Itaguara,15,,-20.383333,-44.483333
br,itaguaru,Itaguaru,29,,-15.733333,-49.616667
br,itaguassu,Itaguassú,08,,-19.8,-40.85
br,itaguassu,Itaguassú,30,,-8.483333,-36.166667
br,itaguatins,Itaguatins,31,,-5.728056,-47.33
br,itaguira,Itaguira,05,,-15.15,-39.733333
br,itahu,Itahú,22,,-5.833333,-37.983333
br,itahum,Itahum,11,,-22,-55.333333
br,itahy,Itahy,27,,-23.4,-49.1
br,itahype,Itahypé,15,,-17.416667,-41.683333
br,itaiacoca,Itaiacoca,18,,-25.133333,-49.916667
br,itaia,Itaiá,05,,-14.883333,-39.916667
br,itaiapaba,Itaiapaba,06,,-4.183333,-38.583333
br,itaiba,Itaíba,05,,-12.433333,-40.3
br,itaiba,Itaíba,30,13870,-8.95,-37.416667
br,itaibo,Itaibó,05,,-13.966667,-39.733333
br,itaicaba,Itaiçaba,06,,-4.666667,-37.85
br,itaici,Itaici,08,,-20.533333,-41.516667
br,itaici,Itaici,14,,-16.066667,-55.9
br,itai de fora,Itaí de Fora,05,,-12.133333,-43.333333
br,itai,Itaí,05,,-12.15,-43.283333
br,itai,Itaí,21,,-22.716667,-42.183333
br,itai,Itaí,23,,-28.333333,-53.966667
br,itai,Itaí,27,22305,-23.4,-49.1
br,itailubesinho,Itailubesinho,23,,-28.633333,-50.566667
br,itaimbe,Itaimbé,08,,-19.666667,-40.833333
br,itaimbesinho,Itaimbésinho,23,,-28.633333,-50.566667
br,itaimbezinho,Itaimbèzinho,23,,-28.633333,-50.566667
br,itaim,Itaim,15,,-22.4,-45.883333
br,itaina,Itaina,18,,-22.716667,-52.9
br,itainopolis,Itainópolis,20,2922,-7.4,-41.516667
br,itainzinho,Itainzinho,20,,-7.95,-41
br,itaiobaia,Itaiobaia,08,,-20.133333,-40.366667
br,itaio,Itaió,26,,-26.466667,-49.866667
br,itaiopolis,Itaiópolis,26,,-26.333333,-49.933333
br,itaipaba,Itaipaba,06,,-4.183333,-38.616667
br,itaipava,Itaipava,05,,-14.333333,-39.333333
br,itaipava,Itaipava,08,,-20.533333,-41.516667
br,itaipava,Itaipava,13,,-5.1,-45.816667
br,itaipava,Itaipava,16,,-6.766667,-48.966667
br,itaipava,Itaipava,21,,-22.375833,-43.131389
br,itaipavas,Itaipavas,05,,-17.466667,-40.066667
br,itaipe,Itaípe,05,,-14.75,-39.05
br,itaipe,Itaipé,15,,-17.416667,-41.683333
br,itaipuacu,Itaipuaçu,21,,-22.966667,-43.016667
br,itaipu,Itaipu,06,,-6.95,-40.35
br,itaipu,Itaipu,21,,-22.965556,-43.047778
br,itaipu,Itaipu,25,,3.6,-60.833333
br,itaipu,Itaipu,27,,-22.600278,-47.363056
br,ita,Itá,26,,-27.266667,-52.316667
br,itaitinga,Itaitinga,06,30939,-3.966667,-38.516667
br,itaituba,Itaituba,04,,-5.4,-60.75
br,itaituba,Itaituba,16,64758,-4.216667,-56.016667
br,itaitu,Itaitu,05,,-11.333333,-40.4
br,itaiuba,Itaiúba,27,,-20.733333,-49.883333
br,itaiu,Itaiú,29,,-15.966667,-50.05
br,itajahi,Itajahi,26,,-26.883333,-48.65
br,itajahy do sul,Itajahy do Sul,26,,-27.2181,-49.6436
br,itajahy,Itajahy,26,,-26.883333,-48.65
br,itajai,Itajai,05,,-13.766667,-39.15
br,itajai,Itajaí,26,155719,-26.883333,-48.65
br,itaja,Itajá,29,,-19.116667,-51.616667
br,itajara,Itajara,21,,-21.316667,-42.016667
br,itajiba,Itajibá,05,,-14.283333,-39.85
br,itaji,Itaji,05,,-14.166667,-40.016667
br,itajobi,Itajobi,04,,-5.194444,-60.351389
br,itajobi,Itajobi,27,12231,-21.316667,-49.066667
br,itajoby,Itajoby,27,,-21.316667,-49.066667
br,itajuba,Itajubá,15,81871,-22.433333,-45.45
br,itajuba,Itajubá,26,,-26.6998,-48.6826
br,itajuba,Itajubá,29,,-16.466667,-51.116667
br,itajubaquara,Itajubaquara,05,,-11.4,-42.683333
br,itajubatiba,Itajubatiba,17,,-7.016667,-37.666667
br,itajuby,Itajuby,27,,-21.316667,-49.066667
br,itajui,Itajuí,05,,-11.046389,-45.059722
br,itajuipe,Itajuípe,05,15517,-14.683333,-39.366667
br,itaju,Itaju,27,,-22,-48.8
br,itajuru,Itajuru,05,,-14.083333,-39.933333
br,itajutiba,Itajutiba,15,,-19.433333,-41.9
br,itajuva,Itajuva,26,,-26.840133,-49.588065
br,italia,Itália,20,,-7.25,-41.983333
br,italva,Italva,21,,-21.416667,-41.7
br,itamacari,Itamacari,16,,-2.166667,-46.316667
br,itamaraca,Itamaracá,01,,-9.716667,-72.016667
br,itamaraca,Itamaracá,02,,-9.35,-35.866667
br,itamaraca,Itamaracá,30,14969,-7.75,-34.833333
br,itamaraju,Itamaraju,05,47630,-17.066667,-39.533333
br,itamarandiba,Itamarandiba,15,18064,-17.85,-42.85
br,itamarandyba,Itamarandyba,15,,-17.85,-42.85
br,itamarati,Itamarati,04,,-6.4,-68.25
br,itamarati,Itamarati,05,,-15.933333,-39.533333
br,itamarati,Itamarati,15,,-15.616667,-41.4
br,itamarati,Itamarati,16,,-1.133333,-51.183333
br,itamaraty,Itamaraty,15,,-21.416667,-42.816667
br,itamaraty,Itamaraty,20,,-4.416667,-41.466667
br,itamari,Itamari,05,,-13.783333,-39.616667
br,itamatare,Itamataré,13,,-2.266667,-46.4
br,itamauari,Itamauari,16,,-2.166667,-46.316667
br,itambacuri,Itambacuri,15,14652,-18.016667,-41.7
br,itambacury,Itambacury,15,,-18.016667,-41.7
br,itambaraca,Itambaracá,18,,-23.016667,-50.433333
br,itambe do mato dentro,Itambé do Mato Dentro,15,,-19.4,-43.316667
br,itambe,Itambé,05,23559,-15.25,-40.616667
br,itambe,Itambé,15,,-18.5,-43.3
br,itambe,Itambe,17,,-7.333333,-35.333333
br,itambe,Itambé,18,,-23.466667,-51.416667
br,itambe,Itambé,27,,-20.616667,-48.75
br,itambe,Itambé,30,,-7.416667,-35.1
br,itambi,Itambi,21,,-22.733333,-42.966667
br,itamby,Itamby,21,,-22.733333,-42.966667
br,itamembe,Itamembé,15,,-20.366667,-44.683333
br,itamira,Itamira,05,,-11.716667,-38.233333
br,itamirim,Itamirim,05,,-14.983333,-39.933333
br,itamirim,Itamirim,15,,-14.766667,-42.883333
br,itamoabo,Itamoabo,05,,-12.8,-38.533333
br,itamoata,Itamoata,02,,-9.883333,-37.183333
br,itamogi,Itamogi,15,,-21.083333,-47.05
br,itamoji,Itamoji,15,,-21.083333,-47.05
br,itamonte,Itamonte,15,,-22.283333,-44.883333
br,itamorotinga,Itamorotinga,17,,-7.483333,-36.666667
br,itamotinga,Itamotinga,05,,-14.583333,-39.616667
br,itamuri,Itamuri,15,,-20.983333,-42.366667
br,itanage,Itanagé,05,,-13.716667,-42.033333
br,itanagra,Itanagra,05,,-12.266667,-38.05
br,itanaje,Itanajé,05,,-13.716667,-42.033333
br,itanara,Itanarã,11,,-23.783333,-55.45
br,itangua,Itangua,27,,-23.524667,-47.5049
br,itanhaem,Itanhaém,27,90387,-24.183333,-46.783333
br,itanhaen,Itanhaen,27,,-24.183333,-46.783333
br,itanhandu,Itanhandu,15,11274,-22.3,-44.95
br,itanhanga,Itanhangá,21,,-22.99431,-43.307353
br,itanhem,Itanhém,05,13517,-17.15,-40.333333
br,itanhenga,Itanhenga,08,,-20.266667,-40.383333
br,itanhi,Itanhi,05,,-11.533333,-37.566667
br,itanhomi,Itanhomi,15,,-19.166667,-41.866667
br,itanhomy,Itanhomy,15,,-19.166667,-41.866667
br,itanhum,Itanhum,11,,-22,-55.333333
br,itans,Itans,06,,-4.6,-38.866667
br,itans,Itans,20,,-7,-40.65
br,itaobi,Itaobí,31,,-11.014167,-48.505
br,itaobim,Itaobim,15,15938,-16.566667,-41.833333
br,itaoca,Itaoca,08,,-20.733333,-41.116667
br,itaoca,Itaoca,21,,-21.816667,-41.466667
br,itaoca,Itaoca,27,,-24.640643,-48.840119
br,itaocara,Itaocara,21,16763,-21.683333,-42.066667
br,itapaci,Itapaci,29,16118,-14.95,-49.566667
br,itapacura,Itapacurá,16,,-4.383333,-56.1
br,itapage,Itapagé,06,32043,-3.683333,-39.566667
br,itapagipe,Itapagipe,05,,-12.916667,-38.5
br,itapagipe,Itapagipe,15,,-19.9,-49.366667
br,itapai,Itapai,06,,-4.25,-38.716667
br,itapaje,Itapajé,06,,-3.683333,-39.566667
br,itapajipe,Itapajipe,15,,-19.9,-49.366667
br,itapanhoacanga,Itapanhoacanga,15,,-18.783333,-43.45
br,itapaoa,Itapaoa,26,,-28.95,-49.583333
br,itapara,Itapará,18,,-25.466667,-51.05
br,itapare,Itaparé,15,,-16.616667,-42.183333
br,itaparica,Itaparica,05,20101,-12.9,-38.7
br,itaparica,Itaparica,08,,-20.383333,-40.316667
br,itaparica,Itaparica,30,,-9.083333,-38.3
br,itapeacu,Itapeaçú,04,,-2.967778,-58.058056
br,itapeba,Itapeba,21,,-22.816667,-41.983333
br,itapebi,Itapebi,05,,-15.933333,-39.533333
br,itapebucu,Itapebuçu,06,,-4.016667,-38.916667
br,itapebussu,Itapebussu,06,,-4.016667,-38.916667
br,itapecerica da serra,Itapecerica da Serra,27,151608,-23.716667,-46.833333
br,itapecerica,Itapecerica,05,,-13.2,-38.9
br,itapecerica,Itapecerica,15,16684,-20.466667,-45.116667
br,itapecerica,Itapecerica,27,,-23.716667,-46.833333
br,itapechinga,Itapechinga,27,,-22.966667,-46.583333
br,itapecoa,Itapecoá,08,,-20.9,-40.983333
br,itapeco,Itapecô,30,,-8.416667,-35.666667
br,itapecuru-mirim,Itapecuru-Mirim,13,,-3.4,-44.333333
br,itapeim,Itapeim,06,,-4.333333,-38.116667
br,itapeipu,Itapeipu,05,,-11.316667,-40.35
br,itape,Itapé,05,,-14.9,-39.433333
br,itape,Itapé,23,,-30.6,-51.566667
br,itapejara,Itapejara,18,,-25.966667,-52.816667
br,itapema,Itapema,05,,-12.7,-38.75
br,itapema,Itapema,18,,-25.4539,-48.6867
br,itapema,Itapema,26,36766,-27.099167,-48.615
br,itapema,Itapema,27,,-23.229824,-47.754668
br,itapemirim,Itapemirim,08,17536,-21.016667,-40.833333
br,itapemirim,Itapemirim,30,,-7.683333,-39.366667
br,itapera,Itapera,13,,-2.533333,-43.783333
br,itaperapoan,Itaperapoan,29,,-15.866667,-50.6
br,itaperapua,Itaperapuã,29,,-15.866667,-50.6
br,itaperapuan,Itaperapuan,29,,-15.866667,-50.6
br,itaperarama,Itaperarama,08,,-20.733333,-40.75
br,itaperiu,Itaperiú,26,,-26.583333,-48.733333
br,itaperorama,Itaperorama,08,,-20.733333,-40.75
br,itaperucu,Itaperuçu,18,26552,-25.2,-49.366667
br,itaperu,Itaperu,20,,-5.466667,-43.016667
br,itaperuna,Itaperuna,21,84436,-21.2,-41.9
br,itapeteiu,Itapeteiú,21,,-22.9,-42.783333
br,itapeti do salto,Itapeti do Salto,27,,-23.405707,-46.115047
br,itapeti,Itapeti,27,,-23.389269,-46.168376
br,itapetim,Itapetim,30,,-7.366667,-37.183333
br,itapetinga,Itapetinga,05,59723,-15.25,-40.25
br,itapetinga,Itapetinga,27,,-23.204444,-46.546389
br,itapetingui,Itapetingui,05,,-12.45,-38.733333
br,itapetininga,Itapetininga,27,126245,-23.6,-48.05
br,itapetininga,Itapetininga,30,,-7.366667,-37.183333
br,itapeua,Itapeua,04,,-3.966667,-57.283333
br,itapeua,Itapeua,13,,-2.883333,-44.683333
br,itapeua,Itapeua,16,,-2.5,-48.666667
br,itapeuna,Itapeúna,13,,-2.883333,-44.683333
br,itapeuna,Itapeúna,27,,-24.596435,-48.217785
br,itapeva,Itapevá,04,,-3.966667,-57.283333
br,itapeva,Itapeva,15,,-18.3,-43.433333
br,itapeva,Itapeva,23,,-29.5,-50.1
br,itapeva,Itapeva,27,62958,-23.966667,-48.866667
br,itapevi,Itapevi,27,201752,-23.55,-46.933333
br,itapevy,Itapevy,27,,-23.55,-46.933333
br,itapiche,Itapiché,15,,-21.166667,-45.933333
br,itapiciru,Itapiciru,05,,-13.616667,-40.85
br,itapicuma,Itapiçuma,30,,-7.766667,-34.9
br,itapicuri,Itapicuri,05,,-12.1,-39.116667
br,itapicuru de baixo,Itapicuru de Baixo,05,,-11.816667,-37.616667
br,itapicuru,Itapicuru,02,,-9.533333,-36.783333
br,itapicuru,Itapicuru,05,4994,-11.316667,-38.25
br,itapicuru,Itapicuru,13,,-3.4,-44.333333
br,itapicuru,Itapicurú,16,,-1.716667,-48.383333
br,itapicuru-mirim,Itapicurú-Mirim,13,,-3.4,-44.333333
br,itapina,Itapina,08,,-19.533333,-40.833333
br,itapinima,Itapinima,04,,-5.410556,-60.727222
br,itapinimba,Itapinimba,04,,-5.410556,-60.727222
br,itapipoca,Itapipoca,06,55785,-3.5,-39.583333
br,itapira,Itapira,05,,-14.3,-39.333333
br,itapira,Itapira,27,61608,-22.433333,-46.833333
br,itapira,Itapira,30,,-7.65,-35.566667
br,itapirama,Itapirama,24,,-11.033333,-62.116667
br,itapiranga,Itapiranga,04,,-2.666667,-58.023889
br,itapiranga,Itapiranga,13,,-2.2,-44.633333
br,itapiranga,Itapiranga,26,,-27.133333,-53.716667
br,itapirapua,Itapirapuã,27,,-24.583333,-49.166667
br,itapirapua,Itapirapuã,29,7923,-15.866667,-50.6
br,itapirapuan,Itapirapuan,29,,-15.866667,-50.6
br,itapirarema,Itapirarema,06,,-3.766667,-40.9
br,itapiratins,Itapiratins,31,,-8.321111,-47.955278
br,itapirucu,Itapiruçu,15,,-21.466667,-42.366667
br,itapiru,Itapiru,05,,-11.483333,-39.016667
br,itapiru,Itapiru,15,,-16.5,-40.416667
br,itapiruna,Itapiruna,15,,-19.166667,-42.083333
br,itapirussu,Itapirussu,15,,-21.466667,-42.366667
br,itapissuma,Itapissuma,30,16674,-7.766667,-34.9
br,itapitacai,Itapitacai,23,,-29.883333,-57.133333
br,itapitanga,Itapitanga,05,,-13.116667,-38.883333
br,itapitanga,Itapitanga,08,,-20.85,-40.75
br,itapitocahy,Itapitocahy,23,,-29.883333,-57.133333
br,itapitocai,Itapitocaí,23,,-29.883333,-57.133333
br,itapiuna,Itapiúna,06,,-4.55,-38.95
br,itapival,Itapival,13,,-5.1,-45.816667
br,itapixe,Itapixé,15,,-21.166667,-45.933333
br,itapixuna,Itapixuna,16,,-1.166667,-46.333333
br,itapoa,Itapoã,05,,-12.95,-38.366667
br,itapoa,Itapoã,15,,-16.333333,-40.566667
br,itapoa,Itapoã,16,,-.75,-48.108333
br,itapoa,Itapoã,23,,-30.266667,-51.016667
br,itapoama,Itapoama,08,,-20.866667,-40.933333
br,itapoan,Itapoan,05,,-12.95,-38.366667
br,itapoca,Itapoca,08,,-20.316667,-40.416667
br,itapocu,Itapocu,08,,-20.066667,-40.433333
br,itapocu,Itapocu,26,,-26.5481,-48.7138
br,itapo,Itapó,06,,-4.033333,-38.4
br,itapolis,Itápolis,27,34553,-21.583333,-48.766667
br,itapopo,Itapopó,11,,-23.783333,-54.316667
br,itapora do tocantins,Itaporã do Tocantins,31,,-8.529722,-48.572222
br,itapora,Itaporã,05,,-12.616667,-39.166667
br,itapora,Itaporã,11,12327,-22.016667,-54.9
br,itapora,Itaporã,31,,-8.529722,-48.572222
br,itaporanga d'ajuda,Itaporanga d'Ajuda,28,,-10.983333,-37.3
br,itaporanga,Itaporanga,02,,-10.233333,-36.566667
br,itaporanga,Itaporanga,04,,-2.666667,-58.023889
br,itaporanga,Itaporanga,15,,-20.483333,-42.483333
br,itaporanga,Itaporanga,17,15890,-7.3,-38.166667
br,itaporanga,Itaporanga,21,,-22.033333,-41.483333
br,itaporanga,Itaporanga,27,10202,-23.7,-49.483333
br,itaporanga,Itaporanga,28,,-10.983333,-37.3
br,itapore,Itaporé,15,,-16.616667,-42.183333
br,itapore,Itaporé,31,,-10.579722,-49.189167
br,itapororoca,Itapororoca,17,,-6.85,-35.25
br,itapororocas,Itapororocas,05,,-12.133333,-39.033333
br,itapua,Itapuã,04,,-3.4,-66.05
br,itapua,Itapuã,05,,-12.95,-38.366667
br,itapua,Itapuã,18,,-22.816667,-52.683333
br,itapua,Itapua,21,,-22.066667,-41.933333
br,itapua,Itapuã,23,,-30.266667,-51.016667
br,itapuan,Itapuan,18,,-22.816667,-52.683333
br,itapuan,Itapuan,23,,-30.266667,-51.016667
br,itapuca,Itapuca,21,,-23.037545,-43.557548
br,itapuca,Itapuca,23,,-28.9,-52.05
br,itapucu,Itapucu,08,,-20.066667,-40.433333
br,itapui,Itapuí,05,,-15.116667,-40.1
br,itapui,Itapuí,26,,-27.116667,-51.4
br,itapui,Itapuí,27,10445,-22.233333,-48.683333
br,itapu,Itapu,05,,-13.4,-38.983333
br,itapura,Itapura,05,,-11.55,-40.45
br,itapura,Itapura,27,,-20.666667,-51.516667
br,itapuranga,Itapuranga,04,,-5.2525,-60.220278
br,itapuranga,Itapuranga,29,19709,-15.583333,-49.983333
br,itapuvucu,Itapuvuçu,27,,-24.700879,-48.04082
br,itaquadiba,Itaquadiba,08,,-19.983333,-40.333333
br,itaquahy,Itaquahy,21,,-22.870755,-43.773821
br,itaqua,Itaquá,26,,-27.3,-49.45
br,itaquandiba,Itaquandiba,08,,-19.983333,-40.333333
br,itaquaquecetuba,Itaquaquecetuba,27,336686,-23.483333,-46.35
br,itaquaquicetuba,Itaquaquicetuba,27,,-23.483333,-46.35
br,itaquarai,Itaquaraí,05,,-14.05,-41.733333
br,itaquara,Itaquara,05,,-13.45,-39.95
br,itaquarari,Itaquarari,05,,-14.05,-41.733333
br,itaquari,Itaquari,05,,-12.85,-39.533333
br,itaquari,Itaquari,08,,-20.333333,-40.366667
br,itaquatiara,Itaquatiara,04,,-3.05,-58.433333
br,itaquatiara,Itaquatiara,05,,-11.35,-43.216667
br,itaquatiara,Itaquatiara,21,,-22.969722,-43.031667
br,itaquatiara,Itaquatiara,30,,-8.916667,-36.65
br,itaquena,Itaquena,05,,-16.633333,-39.083333
br,itaquera,Itaquera,27,,-23.533333,-46.45
br,itaquere,Itaquere,27,,-21.666667,-48.25
br,itaqueri da serra,Itaqueri da Serra,27,,-22.35,-47.9
br,itaqueri velho,Itaqueri Velho,27,,-22.3,-47.85
br,itaquery da serra,Itaquery da Serra,27,,-22.35,-47.9
br,itaqui,Itaqui,04,,-7.428333,-63.011389
br,itaqui,Itaqui,13,,-2.6,-44.35
br,itaqui,Itaqui,18,,-25.3177,-48.5207
br,itaqui,Itaqui,23,34631,-29.133333,-56.55
br,itaquira,Itaquira,21,,-22.15,-41.65
br,itaquitinga,Itaquitinga,30,11128,-7.666667,-35.1
br,itaquy,Itaquy,04,,-7.428333,-63.011389
br,itaquy,Itaquy,23,,-29.133333,-56.55
br,itaracema,Itaracema,06,,-3.766667,-40.9
br,itaracu,Itaraçu,27,,-23.480849,-47.755322
br,itarana,Itarana,08,4060,-19.85,-40.866667
br,itarantim,Itarantim,05,12370,-15.65,-40.05
br,itarare,Itararé,13,,-9.2,-46.166667
br,itarare,Itararé,26,,-27.733333,-50.55
br,itarare,Itararé,27,44810,-24.116667,-49.333333
br,itarema,Itarema,06,10330,-2.9,-39.966667
br,itaretama,Itaretama,22,,-5.698889,-36.245278
br,itariri,Itariri,27,,-24.3,-47.166667
br,itariry,Itariry,27,,-24.3,-47.166667
br,itaroquem,Itaroquém,23,,-28.483333,-55.35
br,itaruma,Itarumã,29,,-18.7,-51.416667
br,itas,Itãs,06,,-4.616667,-38.883333
br,itassuce,Itassucê,05,,-14.233333,-44.3
br,itatapua,Itatapua,16,,-.616667,-51.2
br,itatiaia,Itatiaia,15,,-19.333333,-41.433333
br,itatiaia,Itatiaia,21,12571,-22.5,-44.566667
br,itatiaiucu,Itatiaiuçu,15,,-20.2,-44.416667
br,itatiaiussu,Itatiaiussu,15,,-20.2,-44.416667
br,itatiayassu,Itatiayassú,15,,-20.2,-44.416667
br,itatiba,Itatiba,23,,-27.366667,-52.45
br,itatiba,Itatiba,27,67935,-23,-46.85
br,itaticui,Itaticuí,23,,-30.3,-52.166667
br,itati,Itati,05,,-14.316667,-39.283333
br,itati,Itati,23,,-29.5,-50.1
br,itatinga,Itatinga,05,,-15.25,-40.25
br,itatinga,Itatinga,27,15696,-23.116667,-48.6
br,itatingui,Itatingui,05,,-15.2,-39.433333
br,itatira,Itatira,06,,-4.5,-39.616667
br,itatitu,Itatitu,27,,-23.566,-47.7758
br,itatuba,Itatuba,04,,-5.683333,-63.410556
br,itatuba,Itatuba,17,4951,-7.383333,-35.65
br,itatupa,Itatupã,16,,-.616667,-51.2
br,itauba,Itaúba,04,,-4.009444,-59.809722
br,itauba,Itaúba,20,,-7.1,-41.983333
br,itauba,Itaúba,23,,-29.2,-53.183333
br,itaubal,Itaúbal,03,,1.683333,-51
br,itaucu,Itauçu,29,,-16.216667,-49.616667
br,itau de minas,Itaú de Minas,15,14888,-20.716667,-46.75
br,itaueira,Itaueira,20,5146,-7.6,-43.033333
br,itau,Itaú,22,,-5.833333,-37.983333
br,itaum,Itaum,11,,-22,-55.333333
br,itauna do sul,Itaúna do Sul,18,,-22.666667,-52.816667
br,itauna,Itaúna,04,,-2.983333,-65.983333
br,itauna,Itaúna,05,,-13.05,-40.066667
br,itauna,Itauna,06,,-4.55,-38.95
br,itauna,Itauna,13,,-6.2,-43.266667
br,itauna,Itaúna,15,77402,-20.066667,-44.566667
br,itauna,Itaúna,18,,-22.666667,-52.816667
br,itauna,Itaúna,20,,-6.083333,-41.85
br,itauna,Itaúna,21,,-22.775556,-43.031944
br,itauna,Itaúna,27,,-24.596435,-48.217785
br,itauna,Itaúna,30,,-8.166667,-36.133333
br,itaunas,Itaúnas,08,,-18.416667,-39.7
br,itauninha,Itauninha,15,,-19.7,-43.033333
br,itauninhas,Itauninhas,08,,-18.5,-40.083333
br,itavera,Itaverá,21,,-22.716667,-44.15
br,itaverava,Itaverava,15,,-20.666667,-43.6
br,itaxama,Itaxama,05,,-13.033333,-39.716667
br,itayopolis,Itayopolis,26,,-26.333333,-49.933333
br,iterere,Itererê,13,,-1.566667,-45.1
br,itibira,Itibira,15,,-19.45,-45.133333
br,itinga da serra,Itinga da Serra,05,,-10.566667,-40.283333
br,itinga ii,Itinga II,26,,-26.652,-48.7377
br,itinga,Itinga,05,,-10.566667,-40.283333
br,itinga,Itinga,15,4917,-16.6,-41.783333
br,itinga,Itinga,18,,-25.427678,-48.51946
br,itinga,Itinga,27,,-23.5673,-47.5726
br,itiquira,Itiquira,14,,-17.083333,-54.933333
br,itira,Itira,15,,-16.766667,-42.033333
br,itirapina,Itirapina,27,13229,-22.25,-47.816667
br,itirapua,Itirapuã,27,,-20.633333,-47.233333
br,itirapuan,Itirapuan,27,,-20.633333,-47.233333
br,itirucu,Itiruçu,05,11499,-13.516667,-40.15
br,itirussu,Itirussu,05,,-13.516667,-40.15
br,itiuba,Itiúba,05,9410,-10.716667,-39.85
br,itiuca,Itiúca,05,,-13.583333,-39
br,itobi,Itobi,27,,-21.733333,-46.966667
br,itoby,Itoby,27,,-21.733333,-46.966667
br,itonia,Itônia,18,,-23.933333,-53.9
br,itororo do paranapanema,Itororó do Paranapanema,27,,-22.6,-51.716667
br,itororo,Itororó,05,17325,-15.116667,-40.1
br,itororo,Itororó,26,,-27.216667,-51.533333
br,itoupava alto,Itoupava Alto,26,,-26.7623,-49.0551
br,itoupava central,Itoupava Central,26,,-26.8191,-49.0797
br,itoupava,Itoupava,26,,-26.8191,-49.0797
br,itoupava rega,Itoupava Rega,26,,-26.75,-49.083333
br,itoupava regia,Itoupava Régia,26,,-26.75,-49.083333
br,itoupavazinha,Itoupavazinha,26,,-26.851,-49.1216
br,ituacu,Ituaçu,05,4891,-13.816667,-41.3
br,ituassu,Ituassú,05,,-13.816667,-41.3
br,itubera,Ituberá,05,19888,-13.733333,-39.15
br,itucuma,Itucumã,04,,-6.983333,-69.833333
br,itueta,Itueta,15,,-19.383333,-41.183333
br,ituguacu,Ituguaçu,30,,-8.483333,-36.166667
br,ituguassu,Ituguassú,30,,-8.483333,-36.166667
br,itui,Ituí,15,,-21.533333,-42.916667
br,ituim,Ituim,23,,-28.55,-51.35
br,itu,Itu,27,137589,-23.266667,-47.316667
br,ituiutaba,Ituiutaba,15,85346,-18.966667,-49.466667
br,itumbiara,Itumbiara,29,79583,-18.416667,-49.216667
br,itumirim,Itumirim,05,,-10.2,-40.216667
br,itumirim,Itumirim,15,,-21.316667,-44.883333
br,itupava,Itupava,18,,-25,-49.35
br,itupava,Itupava,26,,-26.8191,-49.0797
br,itupeva,Itupeva,05,25183,-17.416667,-40.483333
br,itupeva,Itupeva,15,,-18.3,-43.433333
br,itupeva,Itupeva,27,,-23.15,-47.066667
br,itupiranga,Itupiranga,16,21301,-5.15,-49.333333
br,ituporanga,Ituporanga,26,13038,-27.416667,-49.6
br,ituquara,Ituquara,16,,-1.016667,-51.05
br,ituqui,Ituqui,04,,-7.428333,-63.011389
br,iturama,Iturama,15,29805,-19.733333,-50.183333
br,itutinga,Itutinga,15,,-21.3,-44.666667
br,ituverava,Ituverava,27,36998,-20.333333,-47.783333
br,ituxi,Ituxi,04,,-6.962778,-71.282222
br,ituyutaba,Ituyutaba,15,,-18.966667,-49.466667
br,ityrapina,Ityrapina,27,,-22.25,-47.816667
br,iuarete,Iuaretê,04,,.633333,-69.2
br,iubatinga,Iubatinga,27,,-21.916667,-51.2
br,iucai,Iucaí,04,,-.216667,-66.816667
br,iuira,Iuira,04,,1.05,-67.533333
br,iuitepora,Iuiteporã,30,,-8.516667,-35.8
br,iuiu,Iuiú,05,,-14.4,-43.583333
br,ium,Ium,11,,-21.583333,-56.716667
br,iuna,Iúna,08,14290,-20.35,-41.533333
br,iupeba,Iupeba,27,,-23.683333,-46.366667
br,iu-rapecuma,Iú-Rapecuma,04,,.1,-67.716667
br,iuru,Iuru,08,,-21.15,-41.6
br,iuru,Iurú,23,,-28.8,-51.033333
br,ius,Ius,20,,-3.881667,-42.008056
br,iutica,Iutica,04,,1.078889,-69.476389
br,ivagaci,Ivagaci,23,,-27.633333,-54.166667
br,ivahy,Ivahy,18,,-25.016667,-50.866667
br,ivai,Ivaí,11,,-17.333333,-56.633333
br,ivai,Ivaí,18,,-25.016667,-50.866667
br,ivai,Ivaí,23,,-29.016667,-53.8
br,ivaipora,Ivaiporã,18,23316,-24.25,-51.75
br,ivaitinga,Ivaítinga,18,,-23.166667,-52.416667
br,ivanheima,Ivanheima,11,,-22.166667,-53.616667
br,ivape,Ivapé,29,,-17.333333,-53.2
br,ivaporunduvinha,Ivaporunduvinha,27,,-24.525056,-48.300158
br,ivatuba,Ivatuba,18,,-23.616667,-52.216667
br,ivatuva,Ivatuva,18,,-23.616667,-52.216667
br,iviti,Iviti,31,,-7.802222,-47.798611
br,ivo,Ivo,14,,-14.983333,-56.366667
br,ivolandia,Ivolândia,29,,-16.566667,-50.85
br,ivora,Ivorá,23,,-29.533333,-53.566667
br,ivoti,Ivoti,23,18172,-29.6,-51.166667
br,ixu,Ixu,05,,-11.766667,-39.2
br,ixu,Ixu,14,,-16.8,-56.533333
br,ixuzinho,Ixuzinho,14,,-16.9,-56.616667
br,izidoria,Izidoria,20,,-6.533333,-41.833333
br,izidoro,Izidoro,06,,-6.133333,-39.25
br,izidro alves,Izidro Alves,11,,-20.15,-55.2
br,jabaete,Jabaeté,08,,-20.383333,-40.5
br,jabaquara,Jabaquara,08,,-20.7,-40.666667
br,jabaquara,Jabaquara,27,,-23.03696,-47.751127
br,jabitaca,Jabitacá,30,,-7.833333,-37.383333
br,jaboatao,Jaboatão,28,,-10.333333,-36.8
br,jaboatao,Jaboatão,30,702632,-8.116667,-35.016667
br,jabora,Jaborá,26,,-27.183333,-51.733333
br,jaborandi,Jaborandi,18,,-23.016667,-50.433333
br,jaborandi,Jaborandi,27,,-20.666667,-48.416667
br,jaborandy,Jaborandy,27,,-20.666667,-48.416667
br,jabota ferrado,Jabotá Ferrado,13,,-6.516667,-42.966667
br,jabota,Jabotá,05,,-12.65,-41.8
br,jabota,Jabotá,11,,-17.516667,-54.05
br,jaboticaba,Jaboticaba,05,,-12.7,-41.283333
br,jaboticaba,Jaboticaba,15,,-16.2,-41.666667
br,jaboticaba,Jaboticaba,30,,-8.35,-36.15
br,jaboticabal,Jaboticabal,27,69396,-21.266667,-48.316667
br,jaboticabas,Jaboticabas,15,,-19.5,-43.75
br,jaboticabeira,Jaboticabeira,26,,-28.566667,-48.983333
br,jaboticatubas,Jaboticatubas,15,,-19.5,-43.75
br,jaboti,Jaboti,04,,-4.133333,-58.633333
br,jaboti,Jaboti,05,,-12.45,-40.583333
br,jaboti,Jaboti,08,,-20.65,-40.566667
br,jaboti,Jaboti,11,,-20.8,-56.383333
br,jaboti,Jaboti,13,,-3.227778,-42.584444
br,jaboti,Jaboti,18,,-23.742125,-50.073954
br,jaboti,Jaboti,20,,-2.972222,-41.62
br,jaboty,Jaboty,04,,-4.133333,-58.633333
br,jaboty,Jaboty,18,,-23.766667,-50.066667
br,jaburu,Jaburu,01,,-8,-72.75
br,jaburu,Jaburu,02,,-9.066667,-37.583333
br,jaburu,Jaburu,04,,-5.565833,-64.190833
br,jaburu,Jaburu,05,,-12.966667,-38.6
br,jaburu,Jaburú,06,,-3.383333,-40.2
br,jaburu,Jaburu,13,,-5.55,-46.2
br,jaburu,Jaburu,14,,-16.137222,-56.991944
br,jaburu,Jaburu,16,,-.966667,-47.2
br,jaburu,Jaburu,17,,-8.15,-36.933333
br,jaburu,Jaburu,20,,-3.398056,-42.130278
br,jaburuna,Jaburuna,06,,-3.866667,-40.983333
br,jaburuzinho,Jaburuzinho,16,,-1.4,-50.666667
br,jabuticaba,Jabuticaba,23,,-27.616667,-53.266667
br,jabuticabal,Jabuticabal,27,,-21.266667,-48.316667
br,jabuticabeira,Jabuticabeira,21,,-22.486667,-43.713611
br,jabuticabeira,Jabuticabeira,26,,-28.566667,-48.983333
br,jabuti,Jabuti,04,,-3.088889,-61.706111
br,jabuti,Jabuti,05,,-12.45,-40.583333
br,jabuti,Jabuti,08,,-20.65,-40.566667
br,jabuti,Jabuti,11,,-20.8,-56.383333
br,jabuti,Jabuti,13,,-3.030556,-42.114167
br,jabuti,Jabuti,18,,-23.766667,-50.066667
br,jabuti,Jabuti,20,,-2.972222,-41.62
br,jacama,Jacama,13,,-4.533333,-43.816667
br,jacampari,Jacampari,06,,-4.733333,-39.933333
br,jacana,Jaçanã,22,,-6.4,-36.233333
br,jacana velho,Jaçanã Velho,04,,-5.621389,-63.998611
br,jacaqua,Jacaquá,23,,-29.683333,-55.2
br,jacaracanga,Jacaracanga,05,,-12.733333,-38.483333
br,jacaraci,Jacaraci,05,,-14.85,-42.433333
br,jacaracy,Jacaracy,05,,-14.85,-42.433333
br,jacaraipe,Jacaraípe,08,,-20.15,-40.183333
br,jacaranda,Jacarandá,05,,-12.883333,-39.15
br,jacaranda,Jacarandá,06,,-2.989722,-40.9125
br,jacaranda,Jacarandá,08,,-21.05,-40.833333
br,jacaranda,Jacarandá,13,,-3.606667,-43.080278
br,jacaranda,Jacarandá,15,,-20.133333,-44.683333
br,jacarandira,Jacarandira,15,,-20.766667,-44.416667
br,jacarara,Jacarará,17,,-8.066667,-36.866667
br,jacarau,Jacaraú,17,7035,-6.666667,-35.3
br,jacareacanga,Jacareacanga,16,1402,-6.266667,-57.65
br,jacare catinga,Jacaré Catinga,27,,-20.883333,-50.833333
br,jacarecica,Jacarecica,02,,-9.616667,-35.7
br,jacareci,Jacareci,05,,-15.3,-39.583333
br,jacarecoara,Jacarécoara,06,,-4.116667,-38.2
br,jacare dos homens,Jacaré dos Homens,02,,-9.65,-37.2
br,jacare grande,Jacaré Grande,05,,-11.75,-44.033333
br,jacare grande,Jacaré Grande,15,,-15.433333,-43.3
br,jacarehy,Jacarehy,21,,-23.033333,-44.15
br,jacarehy,Jacarehy,27,,-23.316667,-45.966667
br,jacarehype,Jacarehype,08,,-20.15,-40.183333
br,jacarei,Jacareí,11,,-23.816667,-54.583333
br,jacarei,Jacareí,21,,-23.033333,-44.15
br,jacarei,Jacareí,27,213114,-23.316667,-45.966667
br,jacareipe,Jacareipe,08,,-20.15,-40.183333
br,jacare,Jacaré,02,,-9.316667,-37.583333
br,jacare,Jacaré,04,,-2.4,-66.116667
br,jacare,Jacaré,05,,-10.8,-41.65
br,jacare,Jacaré,08,,-18.883333,-40.083333
br,jacare,Jacaré,13,,-2.766667,-44.7
br,jacare,Jacaré,14,,-15.266667,-57.7
br,jacare,Jacare,15,,-15.083333,-44.116667
br,jacare,Jacaré,16,,-1.283333,-49.933333
br,jacare,Jacaré,20,,-3.617222,-42.072222
br,jacare,Jacaré,21,,-22.891724,-43.25476
br,jacare,Jacaré,22,,-6.35,-37.233333
br,jacare,Jacaré,23,,-29.216667,-51.883333
br,jacare,Jacare,24,,-10.216667,-64.183333
br,jacare,Jacaré,27,,-23.11907,-47.915394
br,jacare,Jacaré,30,,-8.083333,-40.216667
br,jacare mirim,Jacaré Mirim,22,,-5.783333,-35.35
br,jacarepagua,Jacarepaguá,21,,-22.959706,-43.369083
br,jacarequara,Jacarequará,06,,-4.116667,-38.2
br,jacarequara,Jacarèquara,13,,-2.016667,-44.583333
br,jacarequara,Jacarèquara,16,,-1.533333,-47.05
br,jacaresinho,Jacaresinho,18,,-23.171382,-49.991453
br,jacaretinga,Jacaretinga,04,,-5.400278,-60.425556
br,jacare velho,Jacaré Velho,15,,-21.333333,-42.85
br,jacarezinho,Jacarezinho,04,,-4.456111,-59.838056
br,jacarezinho,Jacarèzinho,16,,-5.983333,-48.333333
br,jacarezinho,Jacarezinho,18,35090,-23.171382,-49.991453
br,jacarezinho,Jacarèzinho,23,,-29.216667,-51.883333
br,jacarini,Jacarini,15,,-21.933333,-45.933333
br,jacata,Jacatã,16,,-6.466667,-54.05
br,jacauna,Jacaúna,06,,-3.933333,-38.266667
br,jaceaba,Jaceaba,15,,-20.533333,-43.983333
br,jaceguai,Jaceguai,06,,-3.133333,-40.466667
br,jaceruba,Jaceruba,21,,-22.590833,-43.551667
br,jacetuba,Jacetuba,21,,-22.590833,-43.551667
br,jaciaba,Jaciaba,18,,-24.933333,-51.2
br,jaciara,Jaciara,14,22739,-15.983333,-54.95
br,jacigua,Jaciguá,08,,-20.7,-41.016667
br,jaci,Jaci,27,,-20.883333,-49.55
br,jacinto,Jacinto,15,,-16.166667,-40.283333
br,jacinto,Jacinto,18,,-23.4865,-49.7532
br,jacinto machado,Jacinto Machado,26,,-29,-49.766667
br,jacioba,Jacioba,02,,-9.766667,-36.9
br,jaciparana,Jaciparaná,24,,-9.25,-64.383333
br,jacipora,Jaciporã,27,,-21.6,-51.583333
br,jacirema,Jacirema,27,,-20.2,-47.95
br,jacirendi,Jacirendi,27,,-21.75,-47.333333
br,jacitara,Jacitara,04,,-2.016667,-65.15
br,jacobina,Jacobina,02,,-9.9,-37.116667
br,jacobina,Jacobina,05,47639,-11.183333,-40.516667
br,jacobina,Jacobina,14,,-16.25,-57.566667
br,jacobina,Jacobina,15,,-15.916667,-40.1
br,jacobina,Jacobina,20,,-7.933333,-41.2
br,jacobina,Jacobina,22,,-5.816667,-35.366667
br,jacoca de beixo,Jacoca de Beixo,22,,-5.666667,-35.433333
br,jacoca,Jacoca,17,,-7.266667,-34.9
br,jacohy,Jacohy,23,,-29.916667,-53.133333
br,jacone,Jaconé,21,,-22.916667,-42.633333
br,jacri,Jacrí,27,,-21.85,-50.65
br,jacruaru,Jacruaru,04,,-.383333,-64.5
br,jacuarana,Jacuarana,04,,-4.691111,-59.431111
br,jacuba,Jacuba,15,,-20.266667,-44.6
br,jacuba,Jacuba,27,,-22.05,-49.016667
br,jacucuara,Jacucuara,16,,-5.566667,-56.883333
br,jacuda,Jacuda,31,,-7.116667,-48.2
br,jacuecanga,Jacuecanga,21,,-22.9967,-44.245
br,jacueira,Jacueira,30,,-8.733333,-35.816667
br,jacuhy,Jacuhy,15,,-21.033333,-46.75
br,jacuhype,Jacuhype,02,,-8.85,-35.466667
br,jacu iii,Jacu III,13,,-3.622778,-43.148611
br,jacu ii,Jacu II,13,,-3.632778,-43.1525
br,jacui,Jacuí,08,,-20.233333,-40.316667
br,jacu i,Jacu I,13,,-3.648333,-43.151667
br,jacui,Jacuí,15,,-21.033333,-46.75
br,jacui,Jacuí,23,,-29.916667,-53.133333
br,jacuipe,Jacuípe,01,,-9.2,-71.55
br,jacuipe,Jacuípe,02,,-8.85,-35.466667
br,jacuipe,Jacuípe,05,,-12.483333,-38.45
br,jacuisinho,Jacuisinho,23,,-29.033333,-53.066667
br,jacuitiba,Jacuitiba,27,,-23.927482,-47.069543
br,jacuitinga,Jacuitinga,02,,-8.85,-35.466667
br,jacu iv,Jacu IV,13,,-3.600833,-43.147778
br,jacuizinho,Jacuìzinho,23,,-29.033333,-53.066667
br,jacu,Jacu,05,,-11.9,-37.683333
br,jacu,Jacú,06,,-3.933333,-39.4
br,jacu,Jacu,08,,-20.433333,-40.333333
br,jacu,Jacu,13,,-3.914722,-43.098889
br,jacu,Jacu,15,,-16.113611,-44.586667
br,jacu,Jacu,17,,-6.616667,-36.15
br,jacu,Jacu,20,,-3.7475,-42.376667
br,jacu,Jacu,22,,-6.066667,-38.033333
br,jacu,Jacu,27,,-23.316667,-48.533333
br,jacu,Jacu,30,,-7.75,-39.833333
br,jacu,Jacu,31,,-11.75,-47.2
br,jacuma,Jacumã,17,,-7.266667,-34.8
br,jacuma,Jacumã,22,,-5.583333,-35.233333
br,jacuman,Jacuman,17,,-7.266667,-34.8
br,jacunda,Jacundá,14,,-15.666667,-56.65
br,jacunda,Jacundá,16,,-4.55,-49.466667
br,jacunda,Jacundá,24,,-9.1,-62.816667
br,jacundazinho,Jacundàzinho,16,,-4.45,-49.5
br,jacupema,Jacupema,27,,-24.666463,-48.34902
br,jacupemba,Jacupemba,08,,-19.583333,-40.2
br,jacupemba,Jacupemba,26,,-26.988026,-49.892625
br,jacupiranga,Jacupiranga,27,11149,-24.700034,-48.004445
br,jacupiranguinha,Jacupiranguinha,27,,-24.7788,-48.1942
br,jacuquara,Jacuquara,16,,-5.566667,-56.883333
br,jacurici,Jacurici,05,,-10.85,-39.716667
br,jacuricy,Jacuricy,05,,-10.85,-39.716667
br,jacuri,Jacuri,22,,-5.218611,-37.495278
br,jacuripe,Jacuripe,01,,-9.2,-71.55
br,jacuruna,Jacuruna,05,,-13.066667,-38.85
br,jacurutu,Jacurutu,05,,-12.216667,-42.95
br,jacurutu,Jacurutu,30,,-8.583333,-38.716667
br,jacus,Jacus,20,,-6.95,-41.816667
br,jacutinga dos binos,Jacutinga dos Binos,18,,-23.2221,-50.1086
br,jacutinga,Jacutinga,05,,-17.983333,-39.6
br,jacutinga,Jacutinga,11,,-20.333333,-56.566667
br,jacutinga,Jacutinga,14,,-16.166667,-58.166667
br,jacutinga,Jacutinga,15,18470,-22.283333,-46.616667
br,jacutinga,Jacutinga,18,,-25.066667,-51.95
br,jacutinga,Jacutinga,23,,-27.733333,-52.5
br,jacutinga,Jacutinga,26,,-26.3103,-48.6642
br,jacu vii,Jacu VII,13,,-3.049444,-43.245556
br,jacu vi,Jacu VI,13,,-3.573056,-43.148333
br,jacu v,Jacu V,13,,-3.588611,-43.144444
br,jacy parana,Jacy Paraná,24,,-9.25,-64.383333
br,jader pinto,Jáder Pinto,21,,-21.166667,-41.583333
br,jadibaru,Jadibaru,04,,-6.45,-64.25
br,jaeteua,Jaeteua,04,,-3.25,-60.816667
br,jaguapita,Jaguapitã,18,,-23.116667,-51.55
br,jaguaquara,Jaguaquara,05,41499,-13.533333,-39.966667
br,jaguaraci,Jaguaraci,05,,-10.9,-41.566667
br,jaguaracu,Jaguaraçu,15,,-19.666667,-42.75
br,jaguara,Jaguara,05,,-12.116667,-39.1
br,jaguara,Jaguará,15,,-19.733333,-44.666667
br,jaguarandi,Jaguarandi,27,,-21.85,-47.7
br,jaguarao,Jaguarão,06,,-4.466667,-38.75
br,jaguarao,Jaguarão,15,,-16.366667,-40.233333
br,jaguarao,Jaguarão,23,29613,-32.566667,-53.383333
br,jaguarari,Jaguarari,05,22617,-10.266667,-40.2
br,jaguarary,Jaguarary,05,,-10.266667,-40.2
br,jaguarasinho,Jaguarasinho,14,,-14.866667,-55.916667
br,jaguaras,Jaguaras,15,,-19.733333,-44.666667
br,jaguarembe,Jaguarembé,21,,-21.783333,-42.033333
br,jaguaretama,Jaguaretama,06,,-5.616667,-38.766667
br,jaguarete,Jaguaretê,11,,-22.75,-55.45
br,jaguariahyva,Jaguariahyva,18,,-24.25,-49.7
br,jaguariaiva,Jaguariaíva,18,30627,-24.25,-49.7
br,jaguaribara,Jaguaribara,06,,-5.666667,-38.616667
br,jaguaribe,Jaguaribe,05,,-13.116667,-38.9
br,jaguaribe,Jaguaribe,06,23066,-5.883333,-38.616667
br,jaguaribe,Jaguaribe,15,,-15.633333,-42.35
br,jaguaribe,Jaguaribe,17,,-7.133333,-34.883333
br,jaguaribe,Jaguaribe,30,,-7.733333,-34.816667
br,jaguaribe mirim,Jaguaribe Mirim,06,,-5.883333,-38.616667
br,jaguaricatu,Jaguaricatu,18,,-24.5,-49.516667
br,jaguari,Jaguari,23,,-29.5,-54.683333
br,jaguari,Jaguari,27,,-22.669444,-47.296667
br,jaguarinho,Jaguarinho,15,,-20.033333,-47.3
br,jaguaripe,Jaguaripe,05,,-12.916667,-39.166667
br,jaguarisinho,Jaguarisinho,23,,-29.483333,-54.783333
br,jaguarita,Jaguarita,23,,-27.466667,-52.25
br,jaguaritira,Jaguaritira,15,,-17.9,-42.233333
br,jaguariuna,Jaguariúna,27,31718,-22.683333,-46.983333
br,jaguarizinho,Jaguarizinho,23,,-29.483333,-54.783333
br,jaguaruana,Jaguaruana,06,21791,-4.833333,-37.783333
br,jaguaruna,Jaguaruna,15,,-19.716667,-44.8
br,jaguaruna,Jaguaruna,26,11650,-28.6,-49.033333
br,jaguary,Jaguary,15,,-22.766667,-46.15
br,jaguary,Jaguary,23,,-29.5,-54.683333
br,jaguary,Jaguary,27,,-22.683333,-46.983333
br,jaguatei,Jaguateí,27,,-21.1,-48.783333
br,jaguatirica,Jaguatirica,18,,-24.166667,-50.633333
br,jahu,Jahú,27,,-22.3,-48.55
br,jaiba,Jaíba,05,,-12.2,-38.883333
br,jaibaras,Jaibaras,06,,-3.766667,-40.483333
br,jaicos,Jaicós,20,7107,-7.35,-41.133333
br,jaime ferreira,Jaime Ferreira,15,,-20.333333,-45.2
br,jaime guimaraes,Jaime Guimarães,15,,-16.383333,-40.766667
br,jaiobazinho,Jaiobazinho,31,,-11.433333,-46.633333
br,jaiu,Jaiú,05,,-9.383333,-38.516667
br,jajuaryahiva,Jajuaryahiva,18,,-24.25,-49.7
br,jalbaras,Jalbaras,06,,-3.766667,-40.483333
br,jales,Jales,27,43832,-20.266667,-50.55
br,jamacaru,Jamacaru,06,,-7.4,-39.116667
br,jamaica,Jamaica,27,,-21.516667,-51.616667
br,jamanacari,Jamanacari,04,,-2.983333,-69.033333
br,jamandua,Jamanduá,04,,-6.383333,-64.283333
br,jamapara,Jamapará,21,,-21.916667,-42.716667
br,jamari,Jamari,04,,-4.374167,-62.062778
br,jamari,Jamari,05,,-12.516667,-40.466667
br,jamari,Jamari,24,,-8.75,-63.45
br,jamary,Jamary,24,,-8.45,-63.483333
br,jambeiro,Jambeiro,15,,-18.083333,-42.766667
br,jambeiro,Jambeiro,27,,-23.266667,-45.683333
br,jaminaua,Jaminauá,01,,-9.353056,-71.024722
br,jamitine,Jamitine,04,,-5.704722,-63.642778
br,jampruca,Jampruca,15,,-18.45,-41.8
br,janari,Janari,04,,-.333333,-64.216667
br,j. anastacio,J. Anastácio,15,,-21.05,-45.216667
br,janauba,Janaúba,15,56573,-15.8,-43.316667
br,jandaia do sul,Jandaia do Sul,18,17507,-23.6,-51.65
br,jandaia,Jandaia,18,,-23.6,-51.65
br,jandaia,Jandaia,29,,-17.1,-50.116667
br,jandaira,Jandaíra,05,,-11.566667,-37.7
br,jandaira,Jandaíra,22,,-5.356111,-36.126111
br,jandia,Jandiá,04,,-5.089167,-59.393333
br,jandira,Jandira,27,113607,-23.516667,-46.9
br,jandiritiua,Jandiritiua,13,,-2.1,-44.633333
br,jandoim,Jandoim,06,,-5.266667,-38.266667
br,jandui,Janduí,22,,-5.445556,-37.061944
br,janduis,Janduís,22,,-6.016667,-37.416667
br,jangada do sul,Jangada do Sul,18,,-26.366667,-51.25
br,jangada,Jangada,05,,-11.683333,-43.266667
br,jangada,Jangada,14,,-15.233333,-56.483333
br,jangada,Jangada,15,,-22.05,-45.966667
br,jangada,Jangada,18,,-23.316667,-50.85
br,jangada,Jangada,26,,-26.5,-51.233333
br,jangada,Jangada,27,,-21.416667,-50.683333
br,jangada nova,Jangada Nova,27,,-21.45,-50.733333
br,jangadinha,Jangadinha,26,,-26.5,-51.233333
br,jangadinha,Jangadinha,27,,-21.416667,-50.55
br,janga,Janga,30,,-7.933333,-34.816667
br,jango,Jango,11,,-20.45,-55.483333
br,jangraguera,Jangraguera,06,,-5.483333,-40.2
br,jangueta,Janguetá,08,,-20.016667,-40.266667
br,jansen,Jansen,23,,-29.133333,-51.383333
br,janua coeli,Jánua Coeli,16,,-1.966667,-49.383333
br,januaria de acaracu,Januária de Acaracu,06,,-3.7,-40.35
br,januaria,Januária,15,34812,-15.483333,-44.366667
br,januario cicco,Januário Cicco,22,,-6.15,-35.583333
br,januario cico,Januário Cico,22,,-6.15,-35.583333
br,januario,Januário,05,,-12.366667,-39.1
br,januario,Januário,13,,-1.833333,-46.2
br,jao,Jaó,27,,-21.166667,-47.283333
br,jaozeiro,Jaozeiro,06,,-7.2,-39.333333
br,japao,Japão,06,,-5.566667,-39.216667
br,japao,Japão,13,,-3.483333,-42.6
br,japao,Japão,14,,-14.983333,-57.333333
br,japao,Japão,15,,-20.55,-44.633333
br,japao,Japão,27,,-20.383333,-47.566667
br,japaraiba,Japaraíba,15,,-20.133333,-45.5
br,japaratinga,Japaratinga,02,,-9.083333,-35.25
br,japaratuba,Japaratuba,02,,-9.083333,-35.25
br,japaratuba,Japaratuba,28,8092,-10.583333,-36.95
br,japecanaa,Japecanaa,17,,-6.216667,-37.466667
br,japecanga,Japecanga,30,,-8.233333,-36.133333
br,japeco,Japeco,13,,-5.15,-42.933333
br,japerica,Japerica,16,,-.833333,-47.083333
br,japeri,Japeri,21,95102,-22.648889,-43.658611
br,japiim,Japiim,01,,-7.616667,-72.9
br,japi,Japi,22,,-6.45,-35.933333
br,japira,Japira,05,,-17.483333,-39.75
br,japira,Japira,18,,-23.8115,-50.139
br,japiuba,Japiúba,27,,-20.65,-50.5
br,japoata,Japoatã,28,4207,-10.333333,-36.8
br,japo,Japó,04,,-3.533333,-66.083333
br,japomirim,Japomirim,05,,-14.15,-39.733333
br,japuiba,Japuíba,21,,-22.583333,-42.7
br,japuim,Japuim,01,,-7.616667,-72.9
br,japu,Japu,05,,-14.916667,-39.2
br,japura,Japurá,04,1908,-1.395833,-69.422222
br,japura,Japurá,18,,-23.470661,-52.554346
br,japyra,Japyra,18,,-23.8115,-50.139
br,jaquari,Jaquari,27,,-24.183333,-48.966667
br,jaquaritinga do norte,Jaquaritinga do Norte,30,,-7.9,-36.05
br,jaquary,Jaquary,27,,-22.683333,-46.983333
br,jaqueira,Jaqueira,02,,-9.383333,-37.166667
br,jaqueira,Jaqueira,05,,-12.366667,-41.15
br,jaqueira,Jaqueira,13,,-3.326667,-43.120556
br,jaqueira,Jaqueira,30,,-8.733333,-35.816667
br,jaques,Jaques,17,,-7.75,-36.4
br,jaquhype,Jaquhype,05,,-12.483333,-38.633333
br,jaquipe,Jaquípe,05,,-12.483333,-38.633333
br,jaquirana,Jaquirana,23,,-28.9,-50.383333
br,jaraaua,Jaraauá,27,,-23.454785,-46.742034
br,jaracatia,Jaracatiá,08,,-20.783333,-40.783333
br,jaracatia,Jaracatiá,18,,-24.183333,-52.9
br,jaracatia,Jaracatiá,30,,-8.133333,-36.35
br,jaracatiara,Jaracatiara,08,,-20.783333,-40.783333
br,jaracutia,Jaracutiá,30,,-8.133333,-36.35
br,jaragua do sul,Jaraguá do Sul,26,130132,-26.483333,-49.066667
br,jaragua,Jaraguá,11,,-20.466667,-54.766667
br,jaragua,Jaraguá,14,,-17.15,-55.083333
br,jaragua,Jaraguá,15,,-21.15,-45.733333
br,jaragua,Jaraguá,26,,-26.483333,-49.066667
br,jaragua,Jaraguá,27,,-23.454785,-46.742034
br,jaragua,Jaraguá,29,30410,-15.75,-49.333333
br,jaraguari,Jaraguari,11,,-20.15,-54.416667
br,jaraguary,Jaraguary,11,,-20.15,-54.416667
br,jaramataia,Jaramatáia,02,,-9.666667,-37
br,jaramataia,Jaramataia,17,,-7.533333,-37.983333
br,jarametais,Jarametais,02,,-9.666667,-37
br,jarandragoeira,Jarandragoeira,06,,-3.8,-38.733333
br,jaraqui,Jaraqui,04,,-2.953611,-60.438889
br,jararaca,Jararaca,25,,2.933333,-60.533333
br,jararaca,Jararaca,26,,-26.2,-50.7
br,jararaca,Jararaca,27,,-21.95,-47.883333
br,jararaita,Jararaitá,13,,-2.416667,-44.683333
br,jardim 25 de agosto,Jardim 25 de Agosto,21,,-22.793058,-43.300357
br,jardim acacia,Jardim Acacia,21,,-22.802155,-43.63629
br,jardim acacio,Jardim Acácio,27,,-23.413867,-46.510778
br,jardim agua branca,Jardim Água Branca,21,,-22.85932,-43.441392
br,jardim aguas lindas,Jardim Águas Lindas,21,,-22.847854,-43.761216
br,jardim alecrim,Jardim Alecrim,21,,-22.892835,-43.486203
br,jardim alegre,Jardim Alegre,18,,-24.15,-51.716667
br,jardim alexandrino,Jardim Alexandrino,21,,-22.884949,-43.663487
br,jardim almeida,Jardim Almeida,27,,-23.267277,-46.568012
br,jardim alto da cantareira,Jardim Alto da Cantareira,27,,-23.386919,-46.606195
br,jardim america,Jardim América,21,,-22.736976,-43.41834
br,jardim america,Jardim América,27,,-23.302734,-46.552188
br,jardim arnaldo eugenio,Jardim Arnaldo Eugênio,21,,-22.913263,-43.536194
br,jardim aurea,Jardim Áurea,21,,-22.890932,-43.448857
br,jardim bangu,Jardim Bangu,21,,-22.849494,-43.466021
br,jardim barra da tijuca,Jardim Barra da Tijuca,21,,-22.99696,-43.341392
br,jardim bela vista,Jardim Bela Vista,21,,-22.883689,-43.59257
br,jardim bela vista,Jardim Bela Vista,27,,-23.433333,-46.516667
br,jardim boiuna,Jardim Boiuna,21,,-22.910025,-43.39452
br,jardim bom pastor,Jardim Bom Pastor,21,,-22.753943,-43.372396
br,jardim borba gato,Jardim Borba Gato,27,,-23.801,-46.6333
br,jardim botanico,Jardim Botãnico,21,,-22.962103,-43.223313
br,jardim botujuru,Jardim Botujuru,27,,-24.712285,-48.004843
br,jardim brasilia,Jardim Brasilia,27,,-23.441833,-46.708345
br,jardim brisa de atibaia,Jardim Brisa de Atibaia,27,,-23.227778,-46.590278
br,jardim brogota,Jardim Brogotá,27,,-23.093333,-46.540278
br,jardim campinas barro branco,Jardim Campinas Barro Branco,27,,-23.7705,-46.7064
br,jardim campinho,Jardim Campinho,21,,-22.89364,-43.587549
br,jardim campo belo,Jardim Campo Belo,21,,-22.871192,-43.584966
br,jardim capuacu,Jardim Capuaçu,21,,-22.772981,-43.524402
br,jardim carioca,Jardim Carioca,21,,-22.802916,-43.192492
br,jardim centenario,Jardim Centenário,27,,-23.173056,-46.573333
br,jardim central,Jardim Central,21,,-22.795564,-43.640988
br,jardim cidade pirituba,Jardim Cidade Pirituba,27,,-23.481371,-46.721903
br,jardim cinco lagos de santa maria,Jardim Cinco Lagos de Santa Maria,27,,-23.310842,-46.534106
br,jardim cincos marias,Jardim Cincos Marias,21,,-22.974416,-43.6413
br,jardim clarice,Jardim Clarice,21,,-22.868567,-43.496941
br,jardim cristina,Jardim Cristina,27,,-23.320984,-46.209231
br,jardim da barra,Jardim da Barra,21,,-22.993018,-43.30017
br,jardim da lagoa,Jardim da Lagoa,27,,-23.251846,-46.609341
br,jardim dalila,Jardim Dalila,27,,-23.5144,-47.6042
br,jardim da luz,Jardim da Luz,21,,-22.887524,-43.563792
br,jardim da luz,Jardim da Luz,29,,-17.866667,-49.133333
br,jardim damasceno,Jardim Damasceno,27,,-23.447669,-46.6977
br,jardim da posse,Jardim da Posse,21,,-22.732733,-43.453351
br,jardim da represa,Jardim da Represa,27,,-23.7597,-46.596
br,jardim das acacias,Jardim Das Acácias,21,,-22.728734,-43.424298
br,jardim das accias,Jardim das Accias,27,,-23.3148,-46.2042
br,jardim da saude,Jardim da Saude,27,,-23.6,-46.633333
br,jardim das bandeiras,Jardim das Bandeiras,27,,-23.63475,-47.576458
br,jardim da serra,Jardim da Serra,27,,-23.338096,-46.544179
br,jardim das flores,Jardim das Flores,27,,-23.252028,-46.545072
br,jardim das oliveiras,Jardim das Oliveiras,23,,-29.9035,-50.8793
br,jardim das pedrinhas,Jardim das Pedrinhas,21,,-22.919087,-43.673656
br,jardim de abril,Jardim de Abril,27,,-23.449478,-46.748266
br,jardim de alah,Jardim de Alah,21,,-22.983379,-43.212576
br,jardim de angicos,Jardim de Angicos,22,,-5.65,-35.983333
br,jardim de areias,Jardim de Areias,06,,-4.233333,-38.883333
br,jardim de mairipora gleba ii,Jardim de Mairiporã Gleba II,27,,-23.310899,-46.634021
br,jardim de mairipora gleba i,Jardim de Mairiporã Gleba I,27,,-23.320817,-46.632506
br,jardim de mairipora gleba segunda,Jardim de Mairiporã Gleba Segunda,27,,-23.310899,-46.634021
br,jardim de mairipora gleba um,Jardim de Mairiporã Gleba Um,27,,-23.320817,-46.632506
br,jardim de pirahanas,Jardim de Pirahanas,22,,-6.366667,-37.333333
br,jardim de piranhas,Jardim de Piranhas,22,10935,-6.366667,-37.333333
br,jardim do saco,Jardim do Saco,21,,-22.852778,-43.298386
br,jardim dos afonsos,Jardim dos Afonsos,27,,-23.426989,-46.529113
br,jardim do serido,Jardim do Seridó,22,9520,-6.583333,-36.766667
br,jardim dos jacarandas,Jardim dos Jacarandas,27,,-23.257667,-46.598586
br,jardim embaixador,Jardim Embaixador,27,,-22.7074,-45.5613
br,jardim espirito santo,Jardim Espírito Santo,21,,-22.942551,-43.691985
br,jardim estancia brasil,Jardim Estância Brasil,27,,-23.156667,-46.594722
br,jardim estrela d'alva,Jardim Estrela D'Alva,21,,-22.908183,-43.669201
br,jardim europa,Jardim Europa,27,,-22.70174,-45.5568
br,jardim fortaleza,Jardim Fortaleza,06,,-3.783333,-38.7
br,jardim frutuoso,Jardim Frutuoso,21,,-22.871039,-43.668243
br,jardim gaver,Jardim Gaver,21,,-22.991907,-43.258183
br,jardim gibeon,Jardim Gibeon,27,,-23.255711,-46.588286
br,jardim gramacho,Jardim Gramacho,21,,-22.757371,-43.280747
br,jardim guanabara,Jardim Guanabara,21,,-22.81559,-43.199759
br,jardim guanabara,Jardim Guanabara,27,,-22.725556,-47.338056
br,jardim guaratiba,Jardim Guaratiba,21,,-22.976087,-43.652047
br,jardim helena,Jardim Helena,27,,-22.733056,-47.306111
br,jardim heliana,Jardim Heliana,27,,-23.755804,-46.669761
br,jardim iaraqua,Jardim Iaraqua,21,,-22.921519,-43.560105
br,jardim imperial,Jardim Imperial,21,,-22.785931,-43.540761
br,jardim ipiranga,Jardim Ipiranga,27,,-22.7475,-47.358056
br,jardim ipora,Jardim Iporã,27,,-23.783141,-46.703551
br,jardimirim,Jardimirim,06,,-7.6,-39.183333
br,jardim ita,Jardim Ita,21,,-22.914253,-43.694581
br,jardim itapeva,Jardim Itapeva,27,,-23.479096,-46.744996
br,jardim iv centenario,Jardim IV Centenario,27,,-23.7986,-46.5866
br,jardim,Jardim,06,7189,-3.433333,-39.016667
br,jardim,Jardim,07,,-15.983333,-47.4
br,jardim,Jardim,08,,-21.116667,-41.666667
br,jardim,Jardim,11,23781,-21.466667,-56.15
br,jardim,Jardim,13,,-3.922222,-43.435833
br,jardim,Jardim,15,,-17.516667,-43.333333
br,jardim,Jardim,17,,-7.733333,-35.85
br,jardim,Jardim,20,,-5.266667,-42.283333
br,jardim,Jardim,22,,-5.55,-35.966667
br,jardim,Jardim,26,,-26.7,-52.116667
br,jardim,Jardim,27,,-20.7,-47.65
br,jardim,Jardim,30,,-7.666667,-39.966667
br,jardim,Jardim,31,,-11.815,-46.628056
br,jardim joana,Jardim Joana,27,,-23.441508,-46.54395
br,jardim joari,Jardim Joari,21,,-22.910144,-43.551035
br,jardim julia miguel,Jardim Júlia Miguel,21,,-22.917602,-43.629564
br,jardim lagoa mar,Jardim Lagoa Mar,21,,-22.997594,-43.333852
br,jardim laranjeiras,Jardim Laranjeiras,21,,-22.773809,-43.537012
br,jardim leal,Jardim Leal,21,,-22.760474,-43.322785
br,jardim luana,Jardim Luana,21,,-22.970551,-43.628557
br,jardim lucia,Jardim Lúcia,27,,-23.269879,-46.573036
br,jardim magarca,Jardim Magarça,21,,-22.936529,-43.58056
br,jardim marambaia,Jardim Marambaia,21,,-22.642778,-43.405278
br,jardim marapendi,Jardim Marapendi,21,,-23.007126,-43.354456
br,jardim maravilha,Jardim Maravilha,21,,-22.962417,-43.605376
br,jardim maria antonia,Jardim Maria Antônia,27,,-23.313123,-46.548285
br,jardim maria da gloria,Jardim Maria da Glória,27,,-23.511,-47.6194
br,jardim maria paula,Jardim Maria Paula,21,,-22.877222,-43.024722
br,jardim maric,Jardim Maric,27,,-23.4954,-46.1814
br,jardim master,Jardim Master,27,,-23.505,-47.603
br,jardim mendanha,Jardim Mendanha,21,,-22.853576,-43.540102
br,jardim miramar,Jardim Miramar,27,,-23.8113,-46.5793
br,jardim mirassol,Jardim Mirassol,21,,-22.768307,-43.526496
br,jardim monte alto,Jardim Monte Alto,27,,-23.400411,-46.535857
br,jardim monteiro,Jardim Monteiro,21,,-22.939236,-43.572136
br,jardim monte santo,Jardim Monte Santo,21,,-22.910958,-43.535833
br,jardim moreira,Jardim Moreira,27,,-23.438048,-46.544225
br,jardim morro azul,Jardim Morro Azul,27,,-22.5575,-47.428333
br,jardim natal,Jardim Natal,27,,-23.8634,-46.6693
br,jardim nautico da cantareira,Jardim Nautico Da Cantareira,27,,-23.321917,-46.565265
br,jardim nazare,Jardim Nazaré,21,,-22.858889,-43.017778
br,jardim nossa senhora das gracas,Jardim Nossa Senhora das Graças,21,,-22.851977,-43.530159
br,jardim nova europa,Jardim Nova Europa,27,,-22.581111,-47.417778
br,jardim nova guaratiba,Jardim Nova Guaratiba,21,,-22.924333,-43.564477
br,jardim nova italia,Jardim Nova Italia,27,,-22.556667,-47.415
br,jardim nova suica,Jardim Nova Suica,27,,-22.568889,-47.390833
br,jardim novo dem,Jardim Novo dem,27,,-23.3375,-46.2243
br,jardim novo mundo,Jardim Novo Mundo,21,,-22.945912,-43.366722
br,jardim novo murido,Jardim Novo Murido,27,,-23.5365,-47.511
br,jardim novo realengo,Jardim Novo Realengo,21,,-22.886456,-43.421007
br,jardim oceanico,Jardim Oceánico,21,,-23.008997,-43.31058
br,jardim okinaga,Jardim Okinaga,27,,-23.29516,-46.609842
br,jardim okinagua,Jardim Okinagua,27,,-23.288624,-46.59943
br,jardim olavo bilac,Jardim Olavo Bilac,21,,-22.775623,-43.338883
br,jardim olimpio,Jardim Olímpio,27,,-23.251484,-46.592467
br,jardim oriental,Jardim Oriental,21,,-22.890624,-43.520244
br,jardim palmares,Jardim Palmares,21,,-22.885328,-43.641309
br,jardim palmira,Jardim Palmira,27,,-23.347301,-47.82114
br,jardim paraiso,Jardim Paraíso,21,,-22.896417,-43.578894
br,jardim paraiso,Jardim Paraíso,27,,-23.414929,-46.503447
br,jardim paulista,Jardim Paulista,21,,-22.882618,-43.559894
br,jardim paulista,Jardim Paulista,27,,-23.4364,-46.550721
br,jardim pedregoso,Jardim Pedregoso,21,,-22.869189,-43.562994
br,jardim perlamar,Jardim Perlamar,27,,-23.5171,-47.612
br,jardim pernambuco,Jardim Pernambuco,21,,-22.981663,-43.230026
br,jardim piai,Jardim Piaí,21,,-22.97783,-43.664689
br,jardim pinheiro,Jardim Pinheiro,27,,-23.434013,-46.523018
br,jardim portugal,Jardim Portugal,27,,-23.3035,-46.2156
br,jardim praca seca,Jardim Praça Seca,21,,-22.89935,-43.360216
br,jardim presidente,Jardim Presidente,27,,-23.243889,-46.606111
br,jardim primavera,Jardim Primavera,27,,-23.1825,-46.5775
br,jardim prince,Jardim Prince,27,,-23.318843,-46.601489
br,jardim progresso,Jardim Progresso,27,,-23.8405,-46.7254
br,jardim quarto centenario,Jardim Quarto Centenario,21,,-22.950817,-43.377515
br,jardim recanto do sol,Jardim Recanto do Sol,27,,-23.807,-46.6466
br,jardim redentor,Jardim Redentor,21,,-22.752885,-43.352962
br,jardim regina,Jardim Regina,27,,-23.473582,-46.742598
br,jardim represa,Jardim Represa,27,,-23.773,-46.5875
br,jardim rincao,Jardim Rincão,27,,-23.433735,-46.719491
br,jardim roseiral,Jardim Roseiral,27,,-23.152222,-46.7075
br,jardim rossi,Jardim Rossi,27,,-23.442033,-46.52387
br,jardim salaco,Jardim Salaco,21,,-22.370508,-42.97434
br,jardim sandra,Jardim Sandra,27,,-23.299064,-46.567056
br,jardim santa cruz,Jardim Santa Cruz,21,,-22.901307,-43.677692
br,jardim santa cruz,Jardim Santa Cruz,27,,-23.5083,-47.5996
br,jardim santa emilia,Jardim Santa Emilia,27,,-23.421602,-46.511361
br,jardim santa helena,Jardim Santa Helena,21,,-22.726082,-43.344217
br,jardim santa lucrecia,Jardim Santa Lucrécia,27,,-23.441587,-46.747402
br,jardim santana,Jardim Santana,27,,-23.326457,-46.57574
br,jardim santa teresa,Jardim Santa Teresa,27,,-23.7969,-46.6358
br,jardim sao bernardo,Jardim São Bernardo,27,,-23.7641,-46.7029
br,jardim sao domingos,Jardim São Domingos,21,,-22.919562,-43.637839
br,jardim sao gabriel das jabuticabeiras,Jardim São Gabriel das Jabuticabeiras,27,,-23.320527,-46.612706
br,jardim sao geraldo,Jardim São Geraldo,21,,-22.866117,-43.557795
br,jardim sao jeronimo,Jardim São Jerônimo,21,,-22.914079,-43.527179
br,jardim sao luis,Jardim São Luis,27,,-22.574722,-47.381667
br,jardim sao manuel,Jardim São Manuel,27,,-22.582222,-47.405278
br,jardim sao nicolau,Jardim São Nicolau,27,,-23.125,-46.548889
br,jardim sao paulo,Jardim São Paulo,27,,-23.43682,-46.5263
br,jardim sao pedro,Jardim São Pedro,21,,-22.87455,-43.558657
br,jardim sao rafael,Jardim São Rafael,27,,-23.758239,-46.7157
br,jardim sao vicente,Jardim São Vicente,21,,-22.715505,-43.443721
br,jardim sete de abril,Jardim Sete de Abril,21,,-22.928877,-43.637188
br,jardim shangrila,Jardim Shangrilá,21,,-22.914801,-43.406639
br,jardim sulacap,Jardim Sulacap,21,,-22.889059,-43.386159
br,jardim sun valley,Jardim Sun Valley,27,,-23.246667,-46.563333
br,jardim terra nova,Jardim Terra Nova,21,,-22.941667,-43.059167
br,jardim toquio,Jardim Tóquio,27,,-23.325673,-47.824945
br,jardim tupa,Jardim Tupa,27,,-23.7949,-46.5458
br,jardim uberlandia,Jardim Uberlândia,21,,-22.884783,-43.416375
br,jardim valaria simone,Jardim Valaria Simone,27,,-23.30359,-46.53489
br,jardim vila mar de guaratiba,Jardim Vila Mar de Guaratiba,21,,-22.991224,-43.623368
br,jardim vinte cinco de agosto,Jardim Vinte Cinco de Agosto,21,,-22.793058,-43.300357
br,jardim vista alegre,Jardim Vista Alegre,26,,-26.248237,-49.539618
br,jardim vitoria,Jardim Vitoria,21,,-22.913385,-43.637687
br,jardim vitoria-regia,Jardim Vitória-Régia,27,,-23.188333,-46.613889
br,jardineira,Jardineira,05,,-13.9,-41.266667
br,jardineiro,Jardineiro,17,,-6.816667,-38.55
br,jardinesia,Jardinésia,15,,-19.25,-48.683333
br,jardin,Jardin,31,,-11.815,-46.628056
br,jardinocolis,Jardinocolis,05,,-12.183333,-43.216667
br,jardinopolis,Jardinópolis,05,,-12.183333,-43.216667
br,jardinopolis,Jardinópolis,15,,-17.666667,-41.416667
br,jardinopolis,Jardinópolis,27,34719,-21.033333,-47.766667
br,jari,Jari,04,,-4.75,-62.157778
br,jari,Jari,23,,-29.283333,-54.216667
br,jarina,Jarina,04,,-4.391389,-71.238889
br,jarinu,Jarinu,27,17905,-23.103333,-46.728056
br,jarquari,Jarquarí,11,,-20.15,-54.416667
br,j. artur,J. Artur,05,,-12.416667,-40.633333
br,jarudore,Jarudore,14,,-16.2,-54.3
br,jaru,Jaru,24,28018,-10.433333,-62.45
br,jary,Jary,23,,-29.283333,-54.216667
br,jataba,Jatabá,20,,-9.516667,-44.966667
br,jatahy,Jatahy,29,,-17.883333,-51.716667
br,jatahy,Jatahy,30,,-8.65,-40.233333
br,jatahy parana,Jatahy Paraná,18,,-23.216667,-50.966667
br,jatai,Jataí,14,,-13.391667,-59.8625
br,jatai,Jataí,15,,-18.883333,-44.166667
br,jatai,Jataí,18,,-23.216667,-50.966667
br,jatai,Jataí,27,,-23.5,-48.983333
br,jatai,Jataí,29,76548,-17.883333,-51.716667
br,jataizinho,Jataìzinho,18,10014,-23.216667,-50.966667
br,jatal,Jatal,18,,-23.216667,-50.966667
br,jatauba,Jataúba,30,,-7.966667,-36.483333
br,jatei,Jatei,11,,-22.383333,-54.316667
br,jati,Jati,06,,-7.683333,-39.016667
br,jatimana,Jatimana,05,,-13.7,-39.05
br,jatina de baixo,Jatinã de Baixo,30,,-8.783333,-38.783333
br,jatina,Jatinã,30,,-8.766667,-38.966667
br,jatiuca,Jatiúca,30,,-7.883333,-38.216667
br,jatoba,Jatobá,04,,-4.562778,-59.408056
br,jatoba,Jatobá,05,,-11.9,-38.5
br,jatoba,Jatobá,06,,-2.981667,-40.973333
br,jatoba,Jatobá,11,,-20.05,-55.966667
br,jatoba,Jatobá,13,,-3.133056,-42.191667
br,jatoba,Jatobá,14,,-16.733333,-57.616667
br,jatoba,Jatobá,15,,-15.3,-44.166667
br,jatoba,Jatobá,16,,-4.833611,-52.783889
br,jatoba,Jatobá,17,,-6.833333,-37.65
br,jatoba,Jatoba,20,,-6.433333,-42.366667
br,jatoba,Jatobá,22,,-5.934444,-36.971111
br,jatoba,Jatobá,27,,-21.633333,-50.233333
br,jatoba,Jatobá,30,,-7.55,-37.583333
br,jatoba,Jatobá,31,,-5.2,-48.333333
br,jatobal,Jatobal,16,,-4.5,-49.533333
br,jatobazal,Jatobazal,20,,-3.982778,-42.005556
br,jatobazinho,Jatobàzinho,06,,-5.266667,-40.366667
br,jatobazinho,Jatobàzinho,30,,-7.983333,-38.166667
br,jatobazinho,Jatobàzinho,31,,-11.433333,-46.633333
br,jatobe,Jatobe,30,,-9.083333,-38.3
br,jatuarama,Jatuarama,24,,-9.416667,-62.533333
br,jatuarana,Jatuarana,04,,-5.806389,-63.536944
br,jatuarana,Jatuarana,24,,-9.133333,-62.25
br,jatuaraninha,Jatuaraninha,04,,-5.268611,-60.383611
br,jaua,Jauá,05,,-12.766667,-38.166667
br,jauaraita,Jauaraitá,13,,-2.416667,-44.683333
br,jauaraua,Jauarauá,04,,-2.883333,-64.916667
br,jauarete,Jauareté,04,,.633333,-69.2
br,jauarete poco,Jauaretê Poço,04,,1.203611,-69.297778
br,jauari,Jauari,04,,-.333333,-64.216667
br,jauato,Jauató,04,,-2.733333,-65.383333
br,jaudilandia,Jaudilândia,14,,-13.6,-55.966667
br,jau do tocantins,Jaú do Tocantins,31,,-12.6525,-48.54
br,jau,Jaú,11,,-20.983333,-55.133333
br,jau,Jaú,14,,-16.1,-55.866667
br,jau,Jaú,27,119209,-22.3,-48.55
br,jaupaci,Jaupaci,29,,-16.3,-50.9
br,jauquara,Jauquara,14,,-15.183333,-57.083333
br,jauquarinha,Jauquarinha,14,,-15.2,-56.933333
br,jauru,Jauru,11,,-18.583333,-54.283333
br,jauzinho,Jaùzinho,31,,-10.033333,-48.333333
br,java,Javá,05,,-12.766667,-38.166667
br,javari,Javari,04,,-4.333333,-57.266667
br,javari quixaba,Javari Quixaba,22,,-5.351667,-37.251667
br,j. bernardes,J. Bernardes,29,,-16.5,-52.05
br,jeceaba,Jeceaba,15,,-20.533333,-43.983333
br,jeguy,Jeguy,30,,-8.65,-39.65
br,jeitosa,Jeitosa,13,,-5.95,-46.55
br,jejui,Jejuí,28,,-4.433333,-45.283333
br,jenesare,Jenesaré,06,,-6.9,-40.033333
br,jenipabu,Jenipabu,05,,-12.7,-38.116667
br,jenipabu,Jenipabu,22,,-5.7,-35.204167
br,jenipapeiro,Jenipapeiro,06,,-5.916667,-39.083333
br,jenipapeiro,Jenipapeiro,17,,-6.516667,-37.616667
br,jenipapeiro,Jenipapeiro,20,,-3.645556,-42.466389
br,jenipapeiro,Jenipapeiro,22,,-5.716667,-42.283333
br,jenipapo iii,Jenipapo III,13,,-3.101389,-42.328056
br,jenipapo ii,Jenipapo II,13,,-3.381111,-42.448611
br,jenipapo i,Jenipapo I,20,,-3.546111,-42.053333
br,jenipapo,Jenipapo,02,,-9.133333,-36.1
br,jenipapo,Jenipapo,03,,3.8,-51.183333
br,jenipapo,Jenipapo,04,,-5.571944,-60.921111
br,jenipapo,Jenipapo,05,,-11.5,-44.95
br,jenipapo,Jenipapo,06,,-3.55,-39.183333
br,jenipapo,Jenipapo,11,,-21.4,-55.233333
br,jenipapo,Jenipapo,13,,-3.8175,-43.299444
br,jenipapo,Jenipapo,15,,-16.633333,-41.866667
br,jenipapo,Jenipapo,16,,-5.35,-48.883333
br,jenipapo,Jenipapo,17,,-6.766667,-37.766667
br,jenipapo,Jenipapo,20,,-7.366667,-43.95
br,jenipapo,Jenipapo,28,,-10.466667,-36.583333
br,jenipapo,Jenipapo,30,,-8.283333,-36.566667
br,jenipapo,Jenipapo,31,,-7.516667,-49.3
br,jenipauba,Jenipaúba,13,,-2.066667,-44.566667
br,jequeri,Jequeri,15,,-20.45,-42.666667
br,jequery,Jequery,15,,-20.45,-42.666667
br,jequia do cabuta,Jequiá do Cabuta,02,,-9.616667,-36.433333
br,jequia,Jequia,27,,-22.416667,-51.666667
br,jequiazinho,Jequiàzinho,02,,-10.016667,-36.033333
br,jequie,Jequié,05,127479,-13.85,-40.083333
br,jequie,Jequié,27,,-22.416667,-51.666667
br,jequi,Jequi,05,,-13.05,-40.066667
br,jequi,Jequi,22,,-5.916667,-35.166667
br,jequi,Jequi,30,,-8.65,-39.65
br,jequirica,Jequirica,05,,-13.233333,-39.6
br,jequiri,Jequiri,13,,-3.406944,-42.562222
br,jequiri,Jequiri,30,,-8.666667,-36.45
br,jequitahy,Jequitahy,15,,-17.25,-44.466667
br,jequitaia,Jequitaia,05,,-17.25,-39.5
br,jequitaia,Jequitaia,27,,-21.1,-51.05
br,jequitai,Jequitaí,15,,-17.25,-44.466667
br,jequitiba,Jequitibá,05,,-12.933333,-39.266667
br,jequitiba,Jequitiba,08,,-20.05,-40.666667
br,jequitiba,Jequitibá,15,,-19.266667,-44.016667
br,jequitinhonha,Jequitinhonha,15,15463,-16.433333,-41
br,jereba,Jereba,02,,-9.45,-36.316667
br,jeremias,Jeremias,18,,-25,-51.35
br,jeremoabo,Jeremoabo,05,16642,-10.066667,-38.35
br,jeriba,Jeribá,15,,-16.833333,-40.383333
br,jeribatuba,Jeribatuba,05,,-13.066667,-38.783333
br,jericoacoara,Jericoacoara,06,,-2.793333,-40.515833
br,jericoaquara,Jericoaquara,06,,-2.8,-40.483333
br,jerico,Jericó,06,,-5.183333,-40.366667
br,jerico,Jericó,17,,-6.55,-37.8
br,jerico,Jericó,22,,-5.37,-36.096944
br,jerico,Jericó,30,,-7.766667,-38.033333
br,jerimatalho,Jerimatalho,02,,-9.666667,-37
br,jerimum,Jerimum,06,,-5.383333,-39.45
br,jerimum,Jerimum,17,,-6.566667,-38.216667
br,jeriquaquara,Jeriquaquara,06,,-2.8,-40.483333
br,jeriquara,Jeriquara,27,,-20.316667,-47.6
br,jeritaco,Jeritacó,30,,-8.4,-37.633333
br,jeriva,Jerivá,27,,-23.233918,-47.723666
br,jeroaquara,Jeroaquara,29,,-15.383333,-50.416667
br,jeromenha,Jeromenha,20,,-7.083333,-43.5
br,jeronimo barcelos,Jerônimo Barcelos,11,,-19.666667,-54.633333
br,jeronimo belmonte,Jerônimo Belmonte,11,,-23.366667,-55.016667
br,jeronimo,Jerônimo,04,,-4.320278,-59.247778
br,jeronimo,Jerônimo,05,,-12.616667,-41.666667
br,jeronimo,Jerônimo,11,,-18.016667,-54.65
br,jeronimo,Jerônimo,15,,-20.183333,-41.616667
br,jeronimo,Jerônimo,20,,-6.75,-42.25
br,jeronimo monteiro,Jerônimo Monteiro,08,6902,-20.783333,-41.4
br,jeronimo r. oliveira,Jerônimo R. Oliveira,15,,-17.633333,-41.65
br,jeru,Jeru,28,,-11.383333,-37.85
br,jerumenha,Jerumenha,20,,-7.083333,-43.5
br,jerumirim,Jerumirim,21,,-22.933333,-44.316667
br,jerusalem,Jerusalém,22,,-5.366667,-35.533333
br,jerusalem,Jerusalém,24,,-12.783333,-60.091667
br,jerusalem,Jerusalem,30,,-7.783333,-38.916667
br,jesenopolis,Jesenópolis,15,,-16.566667,-42.533333
br,jesuania,Jesuânia,15,,-22,-45.3
br,jesuino da costa,Jesuíno da Costa,15,,-16.666667,-40.433333
br,jesuino,Jesuíno,15,,-17.166667,-41.033333
br,jesuino pereira,Jesuíno Pereira,15,,-17.5,-41.7
br,jesuitas,Jesuítas,21,,-22.875485,-43.67888
br,jetiba,Jetibá,08,,-20.05,-40.666667
br,jiboia,Jibóia,04,,1.226667,-69.502778
br,jiboia,Jibóia,05,,-13.016667,-40.466667
br,jiboia,Jibóia,13,,-3.513611,-42.979722
br,jiboia,Jibóia,15,,-16.0925,-44.85
br,jiboia,Jibóia,17,,-7.033333,-38.066667
br,jiboia,Jibóia,27,,-22.825833,-47.8675
br,jiboia,Jibóia,28,,-9.966667,-37.183333
br,jiju,Jiju,04,,-4.986944,-59.336389
br,jiju,Jiju,25,,3.533333,-60.366667
br,jimirim,Jimirim,15,,-21.8,-45.966667
br,jinipabu,Jinipabú,05,,-12.7,-38.116667
br,ji-parana,Ji-Paraná,24,100128,-10.833333,-61.966667
br,jipuba,Jipuba,13,,-2.066667,-44.666667
br,jiquia do cabuta,Jiquiá do Cabutã,02,,-9.616667,-36.433333
br,jiquia do fogo,Jiquiá do Fogo,02,,-9.883333,-36.166667
br,jiquia do sal,Jiquiá do Sal,02,,-9.683333,-36.383333
br,jiquia do sul,Jiquiá do Sul,02,,-9.683333,-36.383333
br,jiquiazinho,Jiquiàzinho,02,,-9.716667,-36.366667
br,jiquie,Jiquié,05,,-13.85,-40.083333
br,jiqui,Jiqui,05,,-13.45,-41.1
br,jiqui,Jiqui,22,,-5.916667,-35.183333
br,jiquirica,Jiquiriçá,05,,-13.233333,-39.6
br,jiquirica,Jiquiricá,06,,-4.65,-38.9
br,jiquiri,Jiquiri,13,,-3.056111,-42.140556
br,jiquitaia,Jiquitaia,05,,-17.25,-39.5
br,jirau de capim,Jirau de Capim,17,,-7.283333,-37
br,jirau de pedra,Jirau de Pedra,05,,-13.683333,-40.283333
br,jirau do ponciano,Jirau do Ponciano,02,,-9.916667,-36.833333
br,jirau,Jirau,05,,-10.216667,-43.466667
br,jirau,Jirau,06,,-4.65,-37.95
br,jirau,Jirau,17,,-7.433333,-36.566667
br,jirau,Jirau,20,,-8.85,-42.266667
br,jirau,Jirau,24,,-9.433333,-64.683333
br,jirau,Jirau,30,,-8.85,-37.383333
br,jiribatuba,Jiribatuba,05,,-13.066667,-38.783333
br,jirua,Jiruá,23,,-28.033333,-54.35
br,jitauna,Jitaúna,05,11619,-14.016667,-39.95
br,jitirana,Jitirana,02,,-9.866667,-36.216667
br,jitirana,Jitirana,05,,-12.133333,-41.35
br,jitirana,Jitirana,06,,-6.666667,-39.9
br,jitirana,Jitirana,17,,-7.233333,-38.033333
br,jitirana,Jitirana,20,,-6.366667,-41.4
br,jitirana,Jitirana,30,,-8.916667,-36.2
br,j. m. peres,J. M. Péres,29,,-18.233333,-51.966667
br,joacaba,Joaçaba,26,23516,-27.166667,-51.5
br,joaci,Joaci,04,,-7.733333,-70.433333
br,joacuba,Joaçuba,08,,-18.4,-40.633333
br,joacy,Joacy,04,,-7.733333,-70.433333
br,joahyma,Joahyma,15,,-16.65,-41.033333
br,joaia,Joáia,26,,-27.266667,-48.7
br,joaima,Joaíma,15,9022,-16.65,-41.033333
br,joa,Joá,06,,-3.883333,-39.883333
br,joa,Joá,18,,-23.4107,-49.8662
br,joa,Joá,21,,-23.003951,-43.288897
br,joa,Joá,30,,-8.316667,-39.4
br,joana coeli,Joana Coeli,16,,-1.966667,-49.383333
br,joana fraga,Joana Fraga,11,,-23.75,-54.833333
br,joana,Joana,05,,-13.066667,-39.766667
br,joana m. fraga,Joana M. Fraga,11,,-23.75,-54.833333
br,joana peres,Joana Peres,16,,-3.3,-49.7
br,joanesia,Joanésia,15,,-19.2,-42.666667
br,joanes,Joanes,16,,-.85,-48.516667
br,joaneta,Joaneta,23,,-29.45,-51.116667
br,joanica,Joanica,05,,-17.5,-39.45
br,joanico,Joanico,04,,-3.866667,-66.383333
br,joanina,Joanina,05,,-14.7,-41.666667
br,joaninha,Joaninha,05,,-14.7,-41.666667
br,joaninha,Joaninha,06,,-5.816667,-40.433333
br,joaninha,Joaninha,13,,-3.136667,-43.341944
br,joanisdorf,Joanisdorf,18,,-25.738611,-49.765278
br,joannes,Joannes,16,,-.85,-48.516667
br,joannopolis,Joannopolis,27,,-22.933333,-46.283333
br,joanopolis,Joanópolis,05,,-14.6,-41.133333
br,joanopolis,Joanópolis,27,11772,-22.933333,-46.283333
br,joa nova,Joá Nova,05,,-11.966667,-43.366667
br,joa novo,Joá Novo,05,,-11.966667,-43.366667
br,joan ribeiro,Joãn Ribeiro,31,,-10.583333,-46.166667
br,joao alfredo,João Alfredo,27,,-22.666667,-47.75
br,joao alfredo,João Alfredo,30,11334,-7.866667,-35.583333
br,joao alves,João Alves,29,,-15.7,-48.35
br,joao amaro,João Amaro,05,,-12.766667,-40.366667
br,joao anacleto diniz,João Anacleto Diniz,15,,-18.55,-48.966667
br,joao arregui,João Arrégui,23,,-29.483333,-56.716667
br,joao arreguy,João Arreguy,23,,-29.483333,-56.716667
br,joao augusto,João Augusto,04,,-7.2,-72.166667
br,joao balbino,João Balbino,15,,-21.083333,-46.6
br,joao batista,João Batista,08,,-20.383333,-40.75
br,joao bento,João Bento,30,,-7.533333,-39.5
br,joao betti,João Betti,23,,-29.0506,-51.1519
br,joao borges,João Borges,23,,-30.016667,-50.966667
br,joao branco,João Branco,29,,-17.466667,-52.233333
br,joao camara,João Câmara,22,19886,-5.533333,-35.8
br,joao carmelo,João Carmelo,29,,-17.716667,-51.883333
br,joao carmo,João Carmo,15,,-20.75,-47.1
br,joao cavalcanti,João Cavalcânti,16,,-5.616667,-54.45
br,joao chaves,João Chaves,15,,-16.75,-41.016667
br,joao-coelho,João-Coelho,16,,-1.266667,-48.183333
br,joao correa,João Correa,23,,-29.6,-50.916667
br,joao correia,João Correia,02,,-8.966667,-37.716667
br,joao correia,João Correia,05,,-13.266667,-41.616667
br,joao correia,João Correia,23,,-29.6,-50.916667
br,joao cristal,João Cristal,15,,-16.033333,-40.166667
br,joao da costa,João da Costa,06,,-6.333333,-40.666667
br,joao de deus,João de Deus,20,,-3.457222,-42.124722
br,joao de melo,João de Melo,15,,-20.4,-46.233333
br,joao de morais,João de Morais,11,,-17.55,-55.35
br,joao de sousa,João de Sousa,13,,-3.942222,-42.996944
br,joao de souza,João de Souza,20,,-6.8,-41.366667
br,joao dias,João Dias,05,,-13.55,-41.8
br,joao dias,João Dias,22,,-6.266667,-37.8
br,joao diogo,João Diogo,18,,-25.233333,-53.083333
br,joao do couro,João do Couro,30,,-7.583333,-37.283333
br,joao domingos,João Domingos,29,,-16.216667,-51.766667
br,joao dorneles,João Dorneles,23,,-30.15,-56.35
br,joao dutra,João Dutra,29,,-16.3,-48.8
br,joao estevao,João Estêvão,13,,-5.583333,-43.333333
br,joao eugenio,João Eugênio,18,,-25.6,-49.616667
br,joao fabricio,João Fabrício,15,,-20.566667,-46.516667
br,joao fagundes,João Fagundes,23,,-30.066667,-57.333333
br,joao felipe,João Felipe,24,,-10.65,-63.65
br,joao felipe rodriguez,João Felipe Rodriguez,16,,-2.883333,-50.366667
br,joao fereira,João Fereira,17,,-7.516667,-37.666667
br,joao ferreira,João Ferreira,14,,-14.266667,-57.333333
br,joao filipe,João Filipe,24,,-10.65,-63.65
br,joao franca,João França,16,,-2.25,-53.583333
br,joao gama,João Gama,25,,4.116667,-60.716667
br,joao gil,João Gil,15,,-16.35,-41.5
br,joao gomes,João Gomes,11,,-19.9,-54.45
br,joao gomes,João Gomes,22,,-6.266667,-38.1
br,joao goncalo,João Gonçalo,20,,-5.666667,-41.133333
br,joao goncalves,João Goncalves,06,,-4.683333,-38.783333
br,joao grama,João Grama,25,,4.116667,-60.716667
br,joao gualberto,João Gualberto,15,,-17.233333,-40.733333
br,joao guaxo,João Guaxo,15,,-16.8,-40.733333
br,joao gurgel,João Gurgel,16,,-7.883333,-49.866667
br,joao honorio,João Honório,21,,-22.1525,-43.988333
br,joao,João,15,,-19.833333,-43.133333
br,joao,João,16,,-2.766667,-50.983333
br,joao-joao,João-João,17,,-7.316667,-37.35
br,joao jorge,João Jorge,02,,-9.333333,-37.266667
br,joao leite,João Leite,14,,-15.933333,-56.7
br,joao lisboa,João Lisboa,13,,-5.366667,-47.283333
br,joao lopes de baixo,João Lopes de Baixo,06,,-5.033333,-40.05
br,joao lopes de cima,João Lopes de Cima,06,,-5.016667,-40.083333
br,joao lopes,João Lopes,03,,-.4,-52.45
br,joao lopes,João Lopes,15,,-17.15,-41.216667
br,joao manuel,João Manuel,15,,-15.5,-43.683333
br,joao marques,João Marques,27,,-21.1,-47.483333
br,joao martins,João Martins,06,,-3.566667,-40.25
br,joao martins,João Martins,15,,-17.266667,-44.583333
br,joao martins,João Martins,20,,-7.15,-43.9
br,joao martins,João Martins,23,,-30.3,-55.583333
br,joao massape,João Massapê,06,,-5.866667,-40.5
br,joao matheus,João Matheus,16,,-5.65,-48.166667
br,joao matos,João Matos,15,,-16.766667,-41.183333
br,joao miguel,João Miguel,15,,-20.783333,-46.783333
br,joao monlevade,João Monlevade,15,72763,-19.833333,-43.133333
br,joao morais,João Morais,11,,-17.55,-55.35
br,joao nea,João Néa,18,,-23.218066,-49.86396
br,joao neiva,João Neiva,08,10383,-19.75,-40.4
br,joao pais,João Pais,11,,-18.483333,-56.483333
br,joao para,João Pará,05,,-13.733333,-41.766667
br,joao paulo,João Paulo,14,,-14.583333,-56.733333
br,joao paz,João Paz,20,,-3.893889,-42.120833
br,joao pedro,João Pedro,05,,-13.883333,-40.6
br,joao pedro,João Pedro,14,,-16.35,-55.95
br,joao pedro,João Pedro,15,,-21.066667,-46.95
br,joao pedro,João Pedro,22,,-5.516667,-37.833333
br,joao pereira,João Pereira,06,,-6.466667,-38.833333
br,joao peres,João Peres,13,,-2.929167,-41.910833
br,joao pessoa,João Pessôa,04,,-6.666667,-69.866667
br,joao pessoa,João Pessoa,05,,-12.25,-41.6
br,joao pessoa,João Pessoa,08,,-21.066667,-41.366667
br,joao pessoa,João Pessoa,16,,-1.116667,-47.616667
br,joao pessoa,João Pessoa,17,650896,-7.116667,-34.866667
br,joao pessoa,João Pessoa,20,,-3.9,-42.7
br,joao pessoa,João Pessoa,26,,-26.45,-48.933333
br,joao pinheiro,João Pinheiro,14,,-10.916667,-51.383333
br,joao pinheiro,João Pinheiro,15,28083,-17.75,-46.166667
br,joao pinto,João Pinto,15,,-19.266667,-41.516667
br,joao pires,João Pires,15,,-16.35,-40.6
br,joao queiroz,João Queiroz,11,,-20.5,-56.116667
br,joao queiroz,João Queiroz,15,,-18.566667,-49.283333
br,joao ramalho,João Ramalho,27,,-22.266667,-50.8
br,joao ramos,João Ramos,15,,-18.383333,-41.416667
br,joao rezende,João Rezende,11,,-19.75,-54.383333
br,joao ribeiro,João Ribeiro,05,,-11.116667,-45.466667
br,joao ribeiro,João Ribeiro,14,,-15.616667,-54.083333
br,joao ribeiro,João Ribeiro,15,,-20.683333,-44.066667
br,joao ribeiro,João Ribeiro,31,,-10.583333,-46.166667
br,joao rodigues,João Rodigues,23,,-29.933333,-52.2
br,joao rodrigues,João Rodrigues,05,,-12.4,-44.85
br,joao rodrigues,João Rodrigues,20,,-5.633333,-42.316667
br,joao rodrigues,João Rodrigues,23,,-29.933333,-52.2
br,joao roque,João Roque,15,,-17.433333,-41.25
br,joao silva,João Silva,31,,-10.516667,-49.166667
br,joao soares,João Soares,05,,-9.283333,-41.65
br,joao soares,João Soares,06,,-5.283333,-40.533333
br,joao surra,João Surrá,18,,-24.702208,-48.660124
br,joao s. vieira,João S. Vieira,23,,-31.116667,-55.116667
br,joao vaqueiro,João Vaqueiro,15,,-16.233333,-40.616667
br,joao vaz,João Vaz,05,,-13.7,-41.6
br,joao viana,João Viana,15,,-14.666667,-44.15
br,joao vieira de castro,João Vieira de Castro,15,,-19.066667,-48.7
br,joao vieira,João Vieira,02,,-9.866667,-36.516667
br,joao vieira,João Vieira,05,,-11.133333,-38.983333
br,joao vieira,João Vieira,06,,-7.65,-39.083333
br,joao vieira,João Vieira,11,,-19.766667,-54.733333
br,joaozinho,Joãozinho,06,,-7.65,-38.966667
br,joaquim adolfo,Joaquim Adolfo,15,,-20.933333,-46.066667
br,joaquim alves,Joaquim Alves,15,,-20.766667,-45.633333
br,joaquim antonio,Joaquim Antônio,14,,-10.433333,-60.45
br,joaquim antonio,Joaquim Antônio,15,,-20.683333,-45.55
br,joaquim cardoso,Joaquim Cardoso,25,,3.766667,-60.466667
br,joaquim coimbra,Joaquim Coimbra,15,,-17.266667,-41.316667
br,joaquim correia,Joaquim Correia,22,,-6.116667,-38.316667
br,joaquim davi,Joaquim Davi,15,,-19.483333,-49.866667
br,joaquim de jesus,Joaquim de Jesus,14,,-17.833333,-53.2
br,joaquim egidio,Joaquim Egídio,27,,-22.883333,-46.983333
br,joaquim felicio,Joaquim Felício,15,,-17.766667,-44.15
br,joaquim ferreira,Joaquim Ferreira,15,,-17.466667,-41.7
br,joaquim gomes,Joaquim Gomes,02,14808,-9.2,-35.716667
br,joaquim hilario,Joaquim Hilário,15,,-20.583333,-46.416667
br,joaquim i. de jesus,Joaquim I. de Jesus,14,,-17.833333,-53.2
br,joaquim,Joaquim,06,,-5.05,-39.55
br,joaquim j. riria,Joaquim J. Riria,14,,-17.85,-53.2
br,joaquim leite,Joaquim Leite,21,,-22.35,-44.25
br,joaquim luis,Joaquim Luís,15,,-19,-48.483333
br,joaquim messias,Joaquim Messias,15,,-20.65,-46.133333
br,joaquim murtinho,Joaquim Murtinho,18,,-24.4,-49.866667
br,joaquim nabuco,Joaquim Nabuco,30,9965,-8.616667,-35.533333
br,joaquim nogueira,Joaquim Nogueira,15,,-17.8,-40.8
br,joaquim norberto,Joaquim Norberto,15,,-20.25,-45.316667
br,joaquim nunes,Joaquim Nunes,08,,-20.3,-41.583333
br,joaquim pereira dos santos,Joaquim Pereira dos Santos,15,,-17.066667,-41.383333
br,joaquim pires,Joaquim Pires,20,,-3.509167,-42.195556
br,joaquim prata,Joaquim Prata,15,,-16.8,-40.616667
br,joaquim rocha,Joaquim Rocha,15,,-16.533333,-40.633333
br,joaquim rodrigues,Joaquim Rodrigues,15,,-20.2,-45.433333
br,joaquim soares,Joaquim Soares,15,,-21.133333,-46.9
br,joaquim tavora,Joaquim Távora,06,,-5.966667,-38.816667
br,joaquim tavora,Joaquim Távora,18,,-23.504,-49.9239
br,joaquim tavora,Joaquim Távora,20,,-3.466667,-42.366667
br,joaquim tropeiro,Joaquim Tropeiro,15,,-17.433333,-40.516667
br,joaquim wolff,Joaquim Wolff,26,,-26.433333,-49.066667
br,joaquim wolf,Joaquim Wolf,26,,-26.433333,-49.066667
br,joaquina,Joaquina,05,,-12.333333,-37.916667
br,joarizinho,Joarizinho,16,,-4.366667,-49.516667
br,joatinga,Joatinga,21,,-23.013009,-43.288439
br,joatuba,Joatuba,08,,-19.866667,-40.95
br,joazeirinho,Joàzeirinho,17,,-7.066667,-36.583333
br,joazeiro,Joazeiro,05,,-9.5,-40.5
br,joazeiro,Joázeiro,06,,-4.45,-38.416667
br,joazeiro,Joazeiro,17,,-7.066667,-36.583333
br,jocelin bitencourt,Jocelin Bitencourt,11,,-21.5,-54.266667
br,jococa,Jococa,16,,-7.25,-53.683333
br,joeirana,Joeirana,15,,-18.05,-41.1
br,joe,Joé,15,,-21.016667,-46.366667
br,joelho,Joelho,27,,-24.669352,-48.144771
br,joffily,Jóffily,17,,-7.066667,-36.05
br,joffre,Joffre,24,,-13.5,-60.55
br,jofre,Jofre,24,,-13.5,-60.55
br,jogo da bola,Jôgo da Bola,05,,-12.933333,-39.216667
br,johannisdorf,Johannisdorf,18,,-25.738611,-49.765278
br,joia,Jóia,23,,-28.65,-54.133333
br,joinvile,Joinvile,26,,-26.3,-48.833333
br,joinville,Joinville,26,461312,-26.3,-48.833333
br,jojoca,Jojoca,16,,-7.25,-53.683333
br,jonas carvalho,Jonas Carvalho,14,,-16.15,-54
br,jonatas,Jônatas,11,,-20.05,-54.75
br,jonia,Jônia,26,,-27.266667,-48.7
br,jordania,Jordânia,15,,-15.9,-40.183333
br,jordao,Jordão,05,,-11.816667,-42.616667
br,jordao,Jordão,06,,-3.666667,-40.483333
br,jordao,Jordão,16,,-1.483333,-47.35
br,jordao,Jordão,22,,-5.966667,-37.566667
br,jordao,Jordão,26,,-26.993,-49.0627
br,jordaozinho,Jordãozinho,18,,-25.483333,-51.45
br,jorge cury,Jorge Cury,14,,-16.283333,-54.95
br,jorge,Jorge,17,,-7.55,-37.766667
br,jorge,Jorge,20,,-7.8,-41
br,jorge lima,Jorge Lima,15,,-21.083333,-46.85
br,jorge mendes,Jorge Mendes,15,,-17.366667,-41.35
br,jorge teixeira,Jorge Teixeira,15,,-21.966667,-45.866667
br,jose alencar,José Alencar,06,,-6.4,-39.15
br,jose alexandre,José Alexandre,05,,-14.716667,-41.383333
br,jose alves da silva,José Alves da Silva,15,,-20.066667,-41.6
br,jose alves de cima,José Alves de Cima,05,,-14.233333,-41.25
br,jose alves,José Alves,15,,-16.05,-40.5
br,jose amaro,José Amaro,21,,-21.866667,-41.216667
br,jose antonio,José Antônio,15,,-16.25,-39.933333
br,jose augusto,José Augusto,15,,-20.9,-45.633333
br,jose baio,José Baio,05,,-12.2,-40.883333
br,jose barbosa,José Barbosa,15,,-20.233333,-46.366667
br,jose batista,José Batista,15,,-21.366667,-46.35
br,jose bento,José Bento,11,,-22.033333,-53.233333
br,jose bento,José Bento,30,,-8.483333,-36.4
br,jose boiteux,José Boiteux,26,,-26.959168,-49.627078
br,jose bonifacio,José Bonifacio,23,,-27.633333,-52.283333
br,jose bonifacio,José Bonifácio,24,,-12.166667,-60.083333
br,jose bonifacio,José Bonifácio,27,27828,-21.05,-49.683333
br,jose borba,José Borba,15,,-21.016667,-46.616667
br,jose borges,José Borges,15,,-16.333333,-40.566667
br,jose bravo,José Bravo,15,,-17.066667,-41.116667
br,jose calhau,José Calhau,15,,-17.666667,-41.95
br,jose candido,José Cândido,15,,-20.266667,-45.4
br,jose cardoso,José Cardoso,08,,-20.6,-41.6
br,jose cariango,José Cariango,15,,-16.483333,-40.716667
br,jose carmelitano,José Carmelitano,15,,-20.383333,-46.833333
br,jose carvalho,José Carvalho,14,,-17.183333,-54.116667
br,jose ceconelo,José Ceconelo,23,,-29.0916,-51.1846
br,jose coco,José Coco,31,,-7.516667,-48.383333
br,jose coimbra,José Coimbra,15,,-17.016667,-41.483333
br,jose coroado,José Coroado,14,,-14.3,-54.7
br,jose costa,José Costa,15,,-20.6,-45.85
br,jose couto,José Couto,05,,-16.4,-39.866667
br,jose da costa,José da Costa,30,,-8.766667,-35.316667
br,jose da cruz,José da Cruz,14,,-16.25,-58.583333
br,jose da lage,José da Lage,02,,-9,-36.033333
br,jose da penha,José da Penha,22,,-6.316667,-38.283333
br,jose da silva,José da Silva,17,,-7.316667,-36.483333
br,jose de alencar,José de Alencar,06,,-6.4,-39.15
br,jose de almeida,José de Almeida,15,,-20.0008,-43.8869
br,jose de cruz,José de Cruz,14,,-16.25,-58.583333
br,jose de delmiro,José de Delmiro,15,,-16.9,-40.733333
br,jose de freitas,José de Freitas,20,21433,-4.75,-42.583333
br,jose dias,José Dias,31,,-6.516667,-48.633333
br,jose eusebio,José Eusébio,15,,-20.816667,-46.883333
br,jose fernandes,José Fernandes,18,,-24.75,-48.983333
br,jose ferreira,José Ferreira,15,,-20.95,-46.8
br,jose figueiredo,José Figueiredo,15,,-15.616667,-46.633333
br,jose figueredo,José Figueredo,15,,-15.616667,-46.633333
br,jose filipe rodrigues,José Filipe Rodrigues,16,,-2.883333,-50.366667
br,josefina,Josefina,15,,-15.183333,-46.583333
br,jose franca,José França,11,,-18.866667,-54.433333
br,jose geraldo,José Geraldo,05,,-16.15,-39.233333
br,jose gomez,José Gomez,30,,-7.516667,-39.566667
br,jose goncalo,José Gonçalo,05,,-10.783333,-43.716667
br,jose goncalves,José Gonçalves,05,,-14.733333,-40.716667
br,jose goncalves,José Goncalves,15,,-16.016667,-40.416667
br,jose grande,José Grande,15,,-17.816667,-40.816667
br,jose gregorio,José Gregório,29,,-16.116667,-51.75
br,jose grosso,José Grosso,05,,-16.183333,-39.833333
br,jose hipolito,José Hipólito,15,,-21.166667,-46.933333
br,jose inacio,José Inácio,15,,-21.566667,-45.566667
br,jose jacinto,José Jacinto,15,,-21.9,-45.85
br,jose,José,04,,.816667,-66.883333
br,jose,José,29,,-17.583333,-52.85
br,jose,José,30,,-8.483333,-36.4
br,jose lacerda,José Lacerda,18,,-24.516667,-50.85
br,joselandia,Joselândia,14,,-16.533333,-56.2
br,joselandia,Joselândia,15,,-20.8,-43.583333
br,jose laurentino,José Laurentino,04,,-8.633333,-60.683333
br,jose laurindo,José Laurindo,04,,-8.633333,-60.683333
br,jose lopes,José Lopes,15,,-17.216667,-41.6
br,jose lourenco,José Lourenço,17,,-6.683333,-38.233333
br,jose luis,José Luís,20,,-9.3,-42.9
br,jose luiz,José Luiz,20,,-9.3,-42.9
br,jose marcelino,José Marcelino,05,,-13,-39.383333
br,jose maria de freitas,José Maria de Freitas,23,,-29.966667,-57.3
br,jose maria,José Maria,23,,-29.966667,-57.3
br,jose mariano,José Mariano,15,,-17.783333,-40.25
br,jose mariano,José Mariano,21,,-22.866667,-42.95
br,jose mariano,José Mariano,30,,-8.483333,-35.4
br,jose marques,José Marques,15,,-17.466667,-41.266667
br,jose martins,José Martins,15,,-16.95,-40.866667
br,jose meira,José Meira,15,,-16.583333,-40.416667
br,jose mendes,José Mendes,15,,-17.95,-41.7
br,jose menino,José Menino,11,,-19.2,-54.283333
br,jose miguel,José Miguel,15,,-21.483333,-46.466667
br,jose mineiro,José Mineiro,31,,-7.2,-48.333333
br,jose moco,José Mocó,05,,-16.383333,-39.85
br,jose moreira,José Moreira,06,,-5.883333,-39.15
br,jose moreira,José Moreira,15,,-17.516667,-41.316667
br,jose moronga,José Moronga,15,,-20.65,-45.366667
br,jose murtinho,José Murtinho,18,,-24.4,-49.866667
br,jose nino,José Nino,11,,-19.683333,-53.75
br,josenopolis,Josenópolis,15,,-16.566667,-42.533333
br,jose nunes,José Nunes,15,,-17.65,-41.966667
br,jose nunes,José Nunes,17,,-7.116667,-36.45
br,jose olimpio de castro,José Olímpio de Castro,15,,-20.6,-45.55
br,jose oliveira,José Oliveira,15,,-17.366667,-41.066667
br,jose otavio,José Otávio,23,,-31.283333,-54.116667
br,jose pacheco,José Pacheco,15,,-17.916667,-41.75
br,jose paulo,José Paulo,13,,-3.533333,-42.716667
br,jose pedro,José Pedro,15,,-21.583333,-46.383333
br,jose pedro,José Pedro,29,,-12.883333,-49.05
br,jose pereira,José Pereira,11,,-23.4,-55.25
br,jose pinheiro,José Pinheiro,27,,-20.216667,-47.633333
br,jose pinto,José Pinto,28,,-10.566667,-37.733333
br,jose pio,José Pio,15,,-21.35,-46.316667
br,jose preto,José Prêto,08,,-18,-40.8
br,jose primo,José Primo,15,,-15.05,-42.9
br,jose quito,José Quito,14,,-17.966667,-53.683333
br,jose raydam,José Raydam,15,,-18.2,-42.5
br,jose ribeiro,José Ribeiro,05,,-16.35,-39.166667
br,jose rocha,José Rocha,15,,-20.333333,-46.483333
br,jose rodrigues,José Rodrigues,06,,-4.416667,-37.816667
br,jose rodrigues,José Rodrigues,17,,-6.783333,-37.783333
br,jose roiz,Josê Roiz,05,,-17.366667,-40.333333
br,jose roque,José Roque,15,,-20.316667,-45.466667
br,jose rosa,José Rosa,15,,-20.7,-45.55
br,jose rosa,José Rosa,27,,-21.4,-47.133333
br,jose santos,José Santos,05,,-12.183333,-41.116667
br,jose santos,José Santos,16,,-5.583333,-56.033333
br,jose sebastiao,José Sebastião,15,,-20.266667,-46.933333
br,jose sebastiao leite,José Sebastião Leite,15,,-20.666667,-46.233333
br,jose segundo,José Segundo,15,,-20.75,-45.65
br,jose silva,José Silva,15,,-21.5,-45.983333
br,jose tartano,José Tartano,23,,-28.916667,-54.65
br,jose teixeira,José Teixeira,15,,-20.433333,-45.566667
br,jose teodoro,José Teodoro,27,,-22.183333,-51.2
br,jose theodoro,José Theodoro,27,,-22.183333,-51.2
br,jose tome,José Tomé,15,,-17.183333,-41.1
br,jose valerio,José Valério,15,,-20.5,-45.4
br,jose velho,José Velho,02,,-9.55,-36.516667
br,jose vermelho,José Vermelho,15,,-16.95,-40.883333
br,jose viana,José Viana,15,,-16.433333,-41.933333
br,jose vicente,José Vicente,15,,-20.583333,-45.116667
br,jose vieira,José Vieira,22,,-5.666667,-35.6
br,jose vilela,José Vilela,27,,-21.05,-47.216667
br,josezinho,Josèzinho,16,,-2.816667,-51.9
br,josias,Josias,15,,-18.35,-48.6
br,josina,Josina,03,,.166667,-51.216667
br,jos,Jós,15,,-21.016667,-46.366667
br,jouquarinha,Jouquarinha,14,,-15.2,-56.933333
br,joviania,Joviânia,29,,-17.816667,-49.5
br,joviniano santos,Joviniano Santos,15,,-15.3,-43.333333
br,jovino sales,Jovino Sales,15,,-21.4,-46.033333
br,j. quirino,J. Quirino,29,,-18.7,-51.816667
br,j.r. vilela,J.R. Vilela,14,,-15.616667,-54.083333
br,juaba,Juaba,16,,-2.383333,-49.55
br,juacaba,Juaçaba,26,,-27.166667,-51.5
br,juacema,Juacema,05,,-10.2,-40.216667
br,jua,Juá,05,,-11.166667,-43.166667
br,jua,Juá,06,,-3.883333,-39.883333
br,jua,Juá,17,,-7.116667,-37.016667
br,jua,Juá,18,,-23.4107,-49.8662
br,jua,Juá,20,,-6.683333,-41.45
br,jua,Juá,23,,-29.133333,-50.866667
br,jua,Juá,27,,-21.166667,-47.283333
br,jua,Juá,30,,-7.95,-39.216667
br,juan borges,Juan Borges,03,,-.383333,-52.233333
br,jua novo,Juá Novo,05,,-11.966667,-43.366667
br,juarana,Juarana,05,,-17.716667,-39.566667
br,juarez,Juarez,17,,-6.816667,-38.183333
br,juarez tavora,Juarez Távora,17,,-7.166667,-35.566667
br,juari,Juari,04,,-3.0475,-61.589444
br,juarina,Juarina,31,,-8.080556,-49.018333
br,juataba,Juataba,06,,-5.083333,-39.033333
br,juatama,Juatama,06,,-5.083333,-39.033333
br,juatuba,Juatuba,08,,-19.866667,-40.95
br,juatuba,Juatuba,15,24551,-19.95,-44.333333
br,juazeirinho,Juàzeirinho,17,8846,-6.816667,-38.05
br,juazeirinho,Juàzeirinho,22,,-5.192222,-37.368333
br,juazeiro de baixo,Juàzeiro de Baixo,06,,-5.133333,-38.566667
br,juazeiro do norte,Juazeiro do Norte,06,225234,-7.2,-39.333333
br,juazeiro grande,Juàzeiro Grande,20,,-8.05,-41.35
br,juazeiro grande,Juàzeiro Grande,30,,-7.65,-38.716667
br,juazeiro,Juàzeiro,05,137807,-9.5,-40.5
br,juazeiro,Juazeiro,06,,-2.95,-40.383333
br,juazeiro,Juàzeiro,15,,-19.75,-44.8
br,juazeiro,Juàzeiro,17,,-7.066667,-36.583333
br,juazeiro,Juazeiro,20,,-5.1,-41.083333
br,juazeiro,Juazeiro,22,,-5.478611,-36.520556
br,juazeiro,Juàzeiro,30,,-7.55,-37.416667
br,jubaia,Jubaia,06,,-4.05,-38.716667
br,jubai,Jubaí,15,,-19.9,-47.683333
br,jubim,Jubim,16,,-.85,-48.516667
br,jubiro,Jubiro,16,,-.8,-48.533333
br,juca azevedo,Juca Azevêdo,21,,-21.166667,-41.733333
br,juca batista,Juca Batista,18,,-23.2277,-50.2474
br,juca,Juca,04,,1.116667,-67.233333
br,juca,Jucá,06,,-4.066667,-40.4
br,juca,Jucá,13,,-3.566667,-44.583333
br,juca,Juca,17,,-7.133333,-37.616667
br,juca,Jucá,22,,-5.320278,-36.314167
br,juca,Jucá,30,,-7.75,-35.366667
br,juca leite,Juca Leite,27,,-23.049955,-47.635238
br,jucal,Jucal,22,,-5.209444,-37.398056
br,juca modesto,Juca Modesto,15,,-20.733333,-45.616667
br,juca neto,Juca Neto,21,,-21.35,-41.95
br,juca novo,Jucá Novo,05,,-11.966667,-43.366667
br,juca pedroso,Juca Pedroso,15,,-20.466667,-46.816667
br,juca pereira,Juca Pereira,15,,-17.566667,-41.7
br,juca polvora,Juca Pólvora,15,,-10.566667,-48.066667
br,jucara,Juçara,13,,-1.883333,-44.65
br,jucara,Juçara,18,,-23.6,-52.466667
br,jucara,Juçara,29,,-15.883333,-50.85
br,jucaral,Juçaral,13,,-3.040833,-43.053333
br,jucaral,Juçaral,21,,-22.95,-44.266667
br,jucaral,Juçaral,30,,-8.266667,-35.066667
br,jucari,Juçari,05,,-15.2,-39.533333
br,juca santana,Juca Santana,15,,-18.7,-48.116667
br,jucas,Jucás,06,14822,-6.533333,-39.533333
br,jucas,Jucás,13,,-9.966667,-46.1
br,jucatan,Jucatán,16,,-6.466667,-54.05
br,jucati,Jucati,30,,-8.7,-36.45
br,juca vaqueiro,Juca Vaqueiro,15,,-17.216667,-41.1
br,jucazinho,Jucàzinho,17,,-7.766667,-36
br,jucelandia,Jucelândia,29,,-15.333333,-51.316667
br,juciape,Juciape,05,,-13.516667,-41.6
br,jucuitiba,Jucuitiba,27,,-23.927482,-47.069543
br,jucu,Jucu,08,,-20.433333,-40.333333
br,jucuma,Jucumã,06,,-2.816667,-40.416667
br,jucuri,Jucuri,22,,-5.133333,-35.966667
br,jucurucu,Jucurucu,05,,-16.866667,-39.916667
br,jucurupava,Jucurupava,27,,-23.596273,-47.518138
br,jucururi,Jucururi,22,,-5.218611,-37.495278
br,jucururu,Jucururu,05,,-16.866667,-39.916667
br,jucurutu,Jucurutu,05,,-12.216667,-42.95
br,jucurutu,Jucurutu,22,11535,-6.033333,-37.016667
br,jucurutu,Jucurutu,30,,-8.583333,-38.716667
br,juerana,Juerana,05,,-12.95,-38.616667
br,juie,Juié,04,,-4.791111,-62.452222
br,juiracu,Juiraçu,15,,-19.916667,-42.8
br,juissara,Juissara,13,,-5.933333,-46.25
br,juiz de fora,Juiz de Fora,15,470201,-21.751667,-43.352778
br,juiz,Juiz,06,,-7.066667,-38.983333
br,julia,Júlia,04,,-1.616667,-67.983333
br,juliana,Juliana,06,,-3.016667,-40.116667
br,juliania,Juliânia,27,,-21.866667,-50.366667
br,juliao,Julião,05,,-17.35,-40.4
br,juliao,Julião,20,,-8.766667,-41.616667
br,juliao,Julião,30,,-7.95,-40.516667
br,juliapolis,Juliapolis,27,,-21.866667,-50.366667
br,julio costa,Júlio Costa,15,,-20.666667,-46.516667
br,julio de carvalho,Júlio de Carvalho,15,,-16.55,-40.133333
br,julio de castilhos,Júlio de Castilhos,23,16487,-29.233333,-53.683333
br,julio do castilhos,Julio do Castilhos,23,,-29.233333,-53.683333
br,julio ferreira,Júlio Ferreira,15,,-17.883333,-40.5
br,julio,Júlio,23,,-29.9564,-50.788
br,julio laender,Júlio Laender,15,,-17.883333,-41.383333
br,julio marques,Júlio Marques,23,,-29.1,-54.166667
br,julio mesquita,Júlio Mesquita,27,,-22.016667,-49.8
br,jumas,Jumas,04,,-6.887778,-62.679444
br,jumas quadros,Jumas Quadros,04,,-6.887778,-62.679444
br,jumirim,Jumirim,18,,-23.716667,-52.25
br,jumirim,Jumirim,27,,-23.084831,-47.78461
br,juncal,Juncal,15,,-22.75,-46.266667
br,juncal,Juncal,27,,-23.67952,-47.525306
br,juncao,Junção,23,,-32.066667,-52.15
br,junccao,Juncção,23,,-32.066667,-52.15
br,junco do serido,Junco do Seridó,17,,-7,-36.716667
br,junco grande,Junco Grande,05,,-13.85,-42.433333
br,junco,Junco,05,,-11.333333,-40.15
br,junco,Junco,06,,-2.983333,-40.033333
br,junco,Junco,17,,-7,-36.716667
br,junco,Junco,20,,-3.9325,-42.265
br,junco,Junco,22,,-6.066667,-37.5
br,junco,Junco,28,,-10.933333,-38.183333
br,junco,Junco,30,,-7.883333,-35.916667
br,jundiacanga,Jundiacanga,27,,-23.549963,-47.693806
br,jundiahy,Jundiahy,27,,-23.183333,-46.866667
br,jundiai do sul,Jundiaí do Sul,18,,-23.4363,-50.2474
br,jundiai,Jundiaí,18,,-23.45,-50.283333
br,jundiai,Jundiaí,22,,-5.883333,-35.366667
br,jundiai,Jundiaí,27,321595,-23.183333,-46.866667
br,jundiaizinho,Jundiaizinho,27,,-23.231111,-46.613611
br,jundia,Jundiá,02,2267,-8.933333,-35.566667
br,jundia,Jundiá,05,,-12.466667,-40.583333
br,jundia,Jundiá,06,,-5.433333,-39.3
br,jundia,Jundiá,08,,-18.416667,-40.216667
br,jundia,Jundiá,15,,-16.033333,-41.583333
br,jundia,Jundiá,25,,-.183333,-60.683333
br,jundia,Jundia,30,,-7.983333,-36.583333
br,jundiapeba,Jundiapeba,27,,-23.55,-46.25
br,jundiaquara,Jundiaquara,27,,-23.55075,-47.5788
br,junqueira,Junqueira,27,,-20.833333,-49.866667
br,junqueiro,Junqueiro,02,7740,-9.933333,-36.483333
br,junqueiropolis,Junqueirópolis,27,13965,-21.533333,-51.433333
br,jupagua,Jupaguá,05,,-11.816667,-44.333333
br,jupara,Jupará,11,,-23.516667,-55.033333
br,juparana,Juparana,21,,-22.343889,-43.682778
br,jupariteua,Jupariteua,16,,-1.716667,-48.383333
br,jupia,Jupiá,26,,-26.45,-52.666667
br,jupi,Jupi,30,,-8.716667,-36.416667
br,jupiranga,Jupiranga,17,,-7.366667,-35.233333
br,jupy,Jupy,30,,-8.716667,-36.416667
br,juqueri,Juqueri,27,,-23.322628,-46.586935
br,juqueri-mirim,Juqueri-Mirim,27,,-23.35,-46.616667
br,juquery,Juquery,27,,-23.322628,-46.586935
br,juquia-grande,Juquiá-Grande,27,,-23.9771,-47.2265
br,juquia-guacu,Juquia-Guaçu,27,,-23.948401,-47.193355
br,juquia,Juquiá,18,,-25.233333,-52.016667
br,juquia,Juquiá,27,13497,-24.316667,-47.633333
br,juquiquera,Juquiquera,04,,-.283333,-63
br,juquiratiba,Juquiratiba,27,,-22.95,-48.1
br,juquitiba,Juquitiba,27,13961,-23.927482,-47.069543
br,jurace,Juracê,27,,-21.066667,-47.75
br,juraci,Juraci,05,,-13.2,-40.883333
br,juracy,Juracy,05,,-13.2,-40.883333
br,juramento,Juramento,15,,-16.833333,-43.583333
br,juranda,Juranda,18,,-23.264674,-52.505798
br,juraraita,Juraraitá,13,,-2.416667,-44.683333
br,jurara,Jurará,04,,-6.616667,-62.366667
br,jurece,Jurecê,27,,-21.066667,-47.75
br,jureia,Juréia,15,,-21.283333,-46.366667
br,jurema do toco preto,Jurema do Toco Preto,20,,-7.016667,-42.683333
br,jurema,Jurema,02,,-9.466667,-37.916667
br,jurema,Jurema,05,,-11.533333,-38.416667
br,jurema,Jurema,06,,-2.983333,-39.983333
br,jurema,Jurema,15,,-18.616667,-42.783333
br,jurema,Jurema,16,,-6.166667,-49.4
br,jurema,Jurema,17,,-6.733333,-37.7
br,jurema,Jurema,18,,-23.033333,-52.833333
br,jurema,Jurema,20,,-7.066667,-40.966667
br,jurema,Jurema,22,,-5.033333,-37.25
br,jurema,Jurema,27,,-21.366667,-48.566667
br,jurema,Jurema,30,,-7.633333,-37.5
br,juremal,Juremal,05,,-9.733333,-40.366667
br,juremal,Juremal,06,,-5.4,-38.216667
br,juremal,Juremal,22,,-5.083333,-37.55
br,jurema seca,Jurema Sêca,22,,-5.116944,-37.242778
br,jurema torta,Jurema Torta,06,,-6.7,-38.783333
br,jureminha,Jureminha,17,,-7.55,-36.75
br,juriassu,Juriassu,04,,-5.083333,-62.85
br,juricia,Jurícia,04,,-7.8,-65.1
br,juricia labrea,Juricia Labrea,04,,-7.8,-65.1
br,juripiranga,Juripiranga,17,8320,-7.366667,-35.233333
br,juritianha,Juritianha,06,,-2.9,-40
br,juriti,Juriti,15,,-21.6,-45.383333
br,juritis,Juritis,27,,-21.166667,-50.166667
br,juriti velho,Jurití Velho,16,,-2.4,-56.3
br,jurity novo,Jurity Novo,16,,-2.166667,-56.066667
br,jurity velho,Jurity Velho,16,,-2.4,-56.3
br,juruaia,Juruaia,15,,-21.25,-46.583333
br,jurua,Juruá,01,,-7.633333,-72.6
br,jurua,Juruá,04,,-3.45,-66.05
br,jurua,Juruá,22,,-6.016667,-37.483333
br,jurua puca,Juruá Puca,04,,-2.833333,-65.916667
br,jurua-puka,Jurua-Puka,04,,-2.833333,-65.916667
br,jurubeba,Jurubeba,13,,-3.129722,-43.043611
br,jurubeba,Jurubeba,20,,-8.833333,-42.566667
br,jurubeba,Jurubeba,30,,-8.533333,-36.833333
br,juruce,Jurucê,27,,-21.066667,-47.75
br,juruena,Juruena,14,,-12.85,-58.933333
br,jurujuba,Jurujuba,21,,-22.933333,-43.116667
br,juru,Juru,17,3796,-7.533333,-37.816667
br,juru,Juru,24,,-10.433333,-62.45
br,juruma,Juruma,23,,-30.266667,-50.516667
br,jurumirim,Jurumirim,15,,-20.133333,-42.683333
br,jurumirim,Jurumirim,21,,-22.933333,-44.316667
br,jurumirim,Jurumirim,27,,-23.183333,-49.266667
br,jurupara do meio,Jurupará do Meio,27,,-23.647385,-47.446322
br,jurupara,Jurupará,27,,-23.690935,-47.36966
br,jurupari,Jurupari,04,,-2.583333,-57.6
br,jurupeba,Jurupeba,27,,-20.3,-49.333333
br,jurupema,Jurupema,27,,-21.366667,-48.566667
br,juruti,Juruti,16,13333,-2.166667,-56.066667
br,juruti velho,Juruti Velho,16,,-2.4,-56.3
br,juruty novo,Juruty Novo,16,,-2.166667,-56.066667
br,juruty velho,Juruty Velho,16,,-2.4,-56.3
br,juruvalho,Juruvalho,05,,-13.333333,-39.366667
br,jurvena,Jurvena,14,,-12.85,-58.933333
br,juscelandia,Juscelândia,29,,-15.333333,-51.316667
br,jussara,Jussara,13,,-6.683333,-44.283333
br,jussara,Jussara,18,16374,-23.6,-52.466667
br,jussara,Jussara,29,,-15.883333,-50.85
br,jussaral,Jussaral,13,,-3.515,-43.326667
br,jussaral,Jussaral,21,,-22.95,-44.266667
br,jussaral,Jussaral,30,,-8.266667,-35.066667
br,jussari,Jussari,05,,-15.2,-39.533333
br,jussiape,Jussiape,05,,-13.516667,-41.6
br,jussipe,Jussipe,05,,-13.516667,-41.6
br,justina,Justina,05,,-13.033333,-39.683333
br,justiniano de serpa,Justiniano de Serpa,06,,-4.016667,-38.483333
br,justiniano,Justiniano,15,,-16.016667,-40.333333
br,justiniano serpa,Justiniano Serpa,06,,-4.016667,-38.483333
br,justino hipolito,Justino Hipólito,15,,-21.016667,-46.75
br,justino,Justino,31,,-8.45,-49.416667
br,justinopolis,Justinópolis,15,,-19.8,-44.016667
br,justino polvora,Justino Pólvora,15,,-18.616667,-48.216667
br,jutahy,Jutahy,04,,-2.733333,-66.95
br,jutahy,Jutahy,16,,-5.6,-57
br,jutai,Jutaí,04,5863,-5.183333,-68.9
br,jutai,Jutaí,16,,-1.166667,-46.816667
br,jutai,Jutaí,30,,-8.65,-40.233333
br,jutica,Jutica,04,,-3.65,-64.266667
br,juti,Juti,11,,-22.866667,-54.616667
br,juturnaiba,Juturnaíba,21,,-22.633333,-42.3
br,juvenal correia,Juvenal Correia,15,,-17.1,-45.666667
br,juvencio,Juvêncio,11,,-21.766667,-53.433333
br,juvencio,Juvêncio,16,,-.966667,-46.616667
br,juventina,Juventina,25,,3.266667,-61.316667
br,juventino,Juventino,15,,-18.45,-48.25
br,juventino,Juventino,18,,-25.916667,-52.733333
br,juventino pinto,Juventino Pinto,15,,-20.433333,-45.483333
br,juventino rocha,Juventino Rocha,15,,-17.95,-40.383333
br,juvi,Juvi,11,,-20.383333,-56.466667
br,juye,Juyé,04,,-4.791111,-62.452222
br,kadan,Kadan,18,,-25.498848,-48.831351
br,kalore,Kaloré,18,,-23.783333,-51.65
br,kapiting,Kapiting,16,,2.183333,-55.316667
br,keteroco,Ketéroco,14,,-14.45,-58.116667
br,kilometer 11,Kilometer 11,27,,-20.8,-51.1
br,kilometer 170,Kilometer 170,23,,-29.05,-55.033333
br,kilometer 29,Kilometer 29,16,,-1.1,-46.516667
br,kilometer 41,Kilometer 41,05,,-14.85,-39.55
br,kilometer sete,Kilometer Sete,27,,-22.033333,-50.466667
br,korff,Korff,23,,-28.8,-51.033333
br,kraemer,Kraemer,23,,-29.3,-55.35
br,kramer,Kramer,23,,-29.3,-55.35
br,krauel central,Krauel Central,26,,-26.948072,-49.724089
br,kroeff,Kroeff,23,,-29.733333,-51.133333
br,krooberger,Krooberger,26,,-26.9738,-49.0765
br,kumparuyamon,Kumparuyamon,25,,4.316667,-60.133333
br,kumparuymou,Kumparuymou,25,,4.316667,-60.133333
br,labirinto,Labirinto,06,,-5.783333,-39.7
br,labrea,Lábrea,04,19624,-7.266667,-64.783333
br,l. abreu,L. Abreu,23,,-29.933333,-57.183333
br,lacerda,Lacerda,06,,-5.433333,-39.35
br,lacerda,Lacerda,27,,-21.966667,-47.833333
br,lacerdopolis,Lacerdópolis,26,,-27.25,-51.566667
br,lacio,Lácio,27,,-22.25,-49.883333
br,lacos,Laços,05,,-14.016667,-41.283333
br,lacos,Lacos,11,,-21.35,-57.45
br,lacre,Lacre,13,,-3.863611,-43.416111
br,ladainha,Ladainha,15,,-17.65,-41.733333
br,ladario,Ladário,11,15790,-19.016667,-57.583333
br,ladeira 1,Ladeira 1,18,,-25.69265,-50.30681
br,ladeira 2,Ladeira 2,18,,-25.70138,-50.30981
br,ladeira da esperanca,Ladeira da Esperanca,06,,-4.7,-39.316667
br,ladeira dois,Ladeira Dois,18,,-25.70138,-50.30981
br,ladeira grande,Ladeira Grande,02,,-9.8,-36.433333
br,ladeira grande,Ladeira Grande,06,,-3.966667,-38.7
br,ladeira grande,Ladeira Grande,22,,-5.833333,-35.466667
br,ladeira,Ladeira,05,,-12.116667,-38.283333
br,ladeira,Ladeira,13,,-2.3,-44.616667
br,ladeira,Ladeira,18,,-25.69633,-50.33388
br,ladeira,Ladeira,28,,-10.433333,-36.766667
br,ladeira,Ladeira,31,,-11.866667,-46.533333
br,ladeirao,Ladeirão,31,,-11.866667,-46.533333
br,ladeira um,Ladeira Um,18,,-25.69265,-50.30681
br,ladeira vermelha,Ladeira Vermelha,13,,-5.6,-47.166667
br,ladeira vermelha,Ladeira Vermelha,20,,-3.649167,-42.584167
br,laeti,Laeti,05,,-13.466667,-41
br,lafaiete,Lafaiete,15,,-20.666667,-43.8
br,lagama,Lagama,22,,-5.789444,-37.05
br,lagamar do caboclo,Lagamar do Cabôclo,22,,-4.921389,-37.178056
br,lagamar,Lagamar,06,,-4.2,-38.4
br,lagamar,Lagamar,15,,-18.216667,-46.8
br,lagamar,Lagamar,17,,-7.433333,-36.483333
br,lagamar,Lagamar,30,,-8.35,-38.516667
br,lagao,Lagão,27,,-23.733333,-47.983333
br,lagarta,Lagarta,05,,-10.616667,-40.133333
br,lagartixa,Lagartixa,06,,-7.1,-38.933333
br,lagartixa,Lagartixa,30,,-8.683333,-36.566667
br,lagarto,Lagarto,21,,-21.416667,-41.65
br,lagarto,Lagarto,28,45446,-10.9,-37.683333
br,lageadinho,Lageadinho,11,,-20.916667,-55.416667
br,lageado bonita,Lageado Bonita,18,,-24.166667,-50.783333
br,lageado bonito,Lageado Bonito,18,,-24.166667,-50.783333
br,lageado,Lageado,13,,-7.75,-46.883333
br,lageado,Lageado,14,,-16.35,-53.75
br,lageado,Lageado,23,,-29.45,-51.966667
br,lageado,Lageado,26,,-26.75,-50.35
br,lageado liso,Lageado Liso,18,,-23.945099,-50.564365
br,lagedinha,Lagedinha,05,,-12.333333,-40.85
br,lagedinho,Lagedinho,05,,-12.333333,-40.85
br,lagedo,Lagedo,06,,-4.016667,-38.916667
br,lagedo,Lagedo,30,,-8.666667,-36.316667
br,lage do muriahe,Lage do Muriahé,21,,-21.2,-42.116667
br,lage grande,Lage Grande,30,,-8.6,-35.716667
br,lage,Lage,05,,-10.183333,-40.966667
br,lage,Lage,08,,-19.533333,-40.833333
br,lage,Lage,14,,-15.833333,-55.6
br,lage,Lage,16,,-5.566667,-56.966667
br,lage,Lage,30,,-7.883333,-38.216667
br,lages,Lages,05,,-10.933333,-42.35
br,lages,Lages,06,,-6.1,-39.45
br,lages,Lages,15,,-16.566667,-45.933333
br,lages,Lages,22,,-5.698889,-36.245278
br,lages,Lages,24,,-10.416667,-65.383333
br,lages,Lages,26,164679,-27.8,-50.316667
br,lages,Lages,29,,-14.05,-48.133333
br,laginha,Laginha,13,,-7.783333,-47.033333
br,laginha,Laginha,15,,-20.15,-41.616667
br,laginha,Laginha,22,,-5.504722,-37.228611
br,laginhas,Laginhas,22,,-6.25,-37.05
br,lagoa amarela,Lagoa Amarela,13,,-3.562222,-43.429444
br,lagoa arcada,Lagoa Arcada,20,,-9.583333,-45.65
br,lagoa azul,Lagoa Azul,18,,-25.1398,-53.8972
br,lagoa azul,Lagoa Azul,27,,-21.7,-50.833333
br,lagoa boaventura,Lagoa Boaventura,05,,-13.916667,-41.1
br,lagoa bonita,Lagoa Bonita,05,,-12.433333,-40.866667
br,lagoa bonita,Lagoa Bonita,13,,-4.8,-44.883333
br,lagoa bonita,Lagoa Bonita,15,,-19.116667,-44.2
br,lagoa branca,Lagoa Branca,05,,-12.85,-41.983333
br,lagoa branca,Lagoa Branca,23,,-30.166667,-55.583333
br,lagoa branca,Lagoa Branca,27,,-21.9,-47.033333
br,lagoa brilhante,Lagoa Brilhante,14,,-14.451389,-59.6875
br,lagoa capim,Lagoa Capim,30,,-8.883333,-37.416667
br,lagoa cercada,Lagoa Cercada,06,,-7.033333,-40.233333
br,lagoa cercada,Lagoa Cercada,20,,-9.133333,-44.25
br,lagoa cercada,Lagoa Cercada,30,,-8.366667,-38.216667
br,lagoa cerrada,Lagoa Cerrada,06,,-6.416667,-40.666667
br,lagoa clara,Lagoa Clara,05,,-12.683333,-44.4
br,lagoa comprida,Lagoa Comprida,05,,-12.4,-40.55
br,lagoa comprida,Lagoa Comprida,13,,-4.366667,-45.916667
br,lagoa comprida,Lagoa Comprida,20,,-9.35,-42.6
br,lagoa comprida,Lagoa Comprida,28,,-9.85,-37.866667
br,lagoa da areia,Lagoa da Areia,02,,-9.616667,-36.75
br,lagoa da barra,Lagoa da Barra,05,,-12.283333,-39.8
br,lagoa da brauna,Lagoa da Braúna,30,,-8.633333,-36.366667
br,lagoa da caicara,Lagoa da Caiçara,06,,-6.733333,-39.666667
br,lagoa da cajazeira,Lagoa da Cajàzeira,02,,-9.516667,-36.883333
br,lagoa da canabrava,Lagoa da Canabrava,05,,-11.283333,-42
br,lagoa da canoa,Lagoa da Canoa,02,13428,-9.816667,-36.766667
br,lagoa da comprida,Lagoa da Comprida,20,,-3.86,-42.489167
br,lagoa da confusao,Lagoa da Confusão,31,,-10.789722,-49.553889
br,lagoa da cruz,Lagoa da Cruz,05,,-10.633333,-43.5
br,lagoa da cruz,Lagoa da Cruz,18,,-25.889657,-50.223641
br,lagoa da cruz,Lagoa da Cruz,20,,-3.673056,-42.227222
br,lagoa da cruz,Lagoa da Cruz,30,,-7.716667,-37.916667
br,lagoa da eugenia,Lagoa da Eugênia,05,,-10.683333,-39.65
br,lagoa d'agua,Lagoa d'Agua,13,,-3.598889,-43.063889
br,lagoa da iha,Lagoa da Iha,17,,-7.716667,-36.716667
br,lagoa da laje,Lagoa da Laje,30,,-8.433333,-36.233333
br,lagoa da lapinha,Lagoa da Lapinha,05,,-12.45,-40.966667
br,lagoa da laurencia,Lagoa da Laurência,05,,-13.8,-42.016667
br,lagoa da legua,Lagoa da Légua,17,,-8.133333,-37.066667
br,lagoa da manga,Lagoa da Manga,06,,-3.933333,-40.1
br,lagoa da mata,Lagoa da Mata,05,,-12.316667,-39.55
br,lagoa da mata,Lagoa da Mata,06,,-4.866667,-40.433333
br,lagoa da moita,Lagoa da Moita,06,,-5.866667,-39.65
br,lagoa da montanha,Lagôa da Montanha,22,,-6.483333,-35.3
br,lagoa danta,Lagoa Danta,05,,-12.4,-39.616667
br,lagoa d'anta,Lagoa d'Anta,06,,-6.483333,-39.333333
br,lagoa da onca,Lagoa da Onça,05,,-15.5,-40.833333
br,lagoa da onca,Lagoa da Onça,13,,-3.290278,-42.405833
br,lagoa da pedra,Lagoa da Pedra,02,,-9.4,-36.816667
br,lagoa da pedra,Lagoa da Pedra,05,,-10.616667,-39.4
br,lagoa da pedra,Lagoa da Pedra,06,,-6.466667,-38.966667
br,lagoa da pedra,Lagoa da Pedra,30,,-8.266667,-36.05
br,lagoa da porta,Lagoa da Porta,02,,-9.95,-36.383333
br,lagoa da porta,Lagoa da Porta,06,,-5.7,-39.566667
br,lagoa da porta,Lagoa da Porta,30,,-8.816667,-36.45
br,lagoa da prata,Lagoa da Prata,15,43119,-20.016667,-45.55
br,lagoa da queimada,Lagoa da Queimada,05,,-12.983333,-39.6
br,lagoa da redinha,Lagoa da Redinha,17,,-6.883333,-36.8
br,lagoa da roca,Lagôa da Róca,05,,-10.5,-40.4
br,lagoa das almas,Lagoa das Almas,20,,-5.2,-41.833333
br,lagoa da salsa,Lagoa da Salsa,06,,-4.95,-37.733333
br,lagoa das cabras,Lagoa das Cabras,05,,-13.033333,-40.066667
br,lagoa das carnaubas,Lagoa Das Carnaubas,06,,-5.066667,-38.583333
br,lagoa das chaves,Lagoa das Chaves,30,,-8.366667,-36.516667
br,lagoa das cobras,Lagoa das Cobras,05,,-13.033333,-40.066667
br,lagoa das covas,Lagoa das Covas,05,,-13.933333,-41.133333
br,lagoa das dores,Lagoa das Dôres,30,,-7.833333,-38.183333
br,lagoa da serra,Lagoa da Serra,20,,-3.955833,-42.166111
br,lagoa das mocas,Lagoa das Moças,30,,-8.4,-36.516667
br,lagoa das pedras,Lagoa das Pedras,02,,-9.35,-37.883333
br,lagoa das pedras,Lagoa das Pedras,06,,-2.974444,-41.021944
br,lagoa das pedras,Lagoa das Pedras,20,,-6.916667,-41.233333
br,lagoa das vacas,Lagoa das Vacas,05,,-13.45,-40.733333
br,lagoa das vacas,Lagoa das Vacas,20,,-9.183333,-42.616667
br,lagoa da vaca,Lagoa da Vaca,05,,-12.016667,-41.6
br,lagoa da velha,Lagoa da Velha,05,,-12.916667,-39.533333
br,lagoa da vila,Lagoa da Vila,04,,-.116667,-63.95
br,lagoa da volta,Lagoa da Volta,06,,-2.816667,-40.25
br,lagoa de arroz,Lagoa de Arroz,17,,-7.05,-38.533333
br,lagoa de baixo,Lagoa de Baixo,06,,-2.883333,-40.216667
br,lagoa de baixo,Lagoa de Baixo,20,,-9.75,-45.45
br,lagoa de barro,Lagoa de Barro,05,,-13.4,-40.466667
br,lagoa de boi,Lagoa de Boi,22,,-5.9,-35.383333
br,lagoa de canoa,Lagôa de Canôa,02,,-9.816667,-36.766667
br,lagoa de casca,Lagoa de Casca,06,,-5.116667,-37.916667
br,lagoa de cima,Lagoa de Cima,13,,-5.766667,-43.783333
br,lagoa de cima,Lagoa de Cima,17,,-7.6,-36.683333
br,lagoa de cima,Lagoa de Cima,22,,-5.0675,-37.331667
br,lagoa de cima,Lagoa de Cima,30,,-8.333333,-36.75
br,lagoa de dentro ii,Lagoa de Dentro II,20,,-3.33,-42.012778
br,lagoa de dentro i,Lagoa de Dentro I,20,,-3.478611,-42.072222
br,lagoa de dentro,Lagoa de Dentro,05,,-11.616667,-39.616667
br,lagoa de dentro,Lagoa de Dentro,06,,-3.25,-39.266667
br,lagoa de dentro,Lagoa de Dentro,13,,-5.616667,-43.283333
br,lagoa de dentro,Lagoa de Dentro,17,,-7.8,-38.1
br,lagoa de dentro,Lagoa de Dentro,20,,-3.67,-42.247778
br,lagoa de dentro,Lagoa de Dentro,22,,-6.133333,-38.433333
br,lagoa de dentro,Lagoa de Dentro,28,,-9.95,-37.2
br,lagoa de dentro,Lagoa de Dentro,30,,-7.666667,-40.516667
br,lagoa de fora,Lagoa de Fora,08,,-21.266667,-41
br,lagoa de jose alves,Lagoa de José Alves,05,,-9.133333,-39.333333
br,lagoa de junco,Lagoa de Junco,20,,-5.583333,-41.15
br,lagoa dentro,Lagoa Dentro,30,,-8.783333,-36.2
br,lagoa de onca,Lagoa de Onça,06,,-7.333333,-38.8
br,lagoa de ouro,Lagôa de Ouro,30,,-9.133333,-36.466667
br,lagoa de pedra,Lagoa de Pedra,02,,-9.783333,-36.716667
br,lagoa de pedra,Lagoa de Pedra,05,,-12.65,-40.583333
br,lagoa de pedra,Lagoa de Pedra,13,,-4.333333,-45.166667
br,lagoa de pedra,Lagoa de Pedra,17,,-7,-37.316667
br,lagoa de pedra,Lagoa de Pedra,22,,-6.166667,-35.433333
br,lagoa de pedra,Lagoa de Pedra,30,,-7.95,-36.166667
br,lagoa de pedras,Lagoa de Pedras,05,,-12.666667,-40.816667
br,lagoa de santana,Lagoa de Santana,06,,-3.016667,-39.916667
br,lagoa de sao goncalo,Lagoa de São Gonçalo,15,,-18.45,-45.7
br,lagoa de sao joao,Lagoa de São João,30,,-7.75,-37.95
br,lagoa de sao joaquim,Lagoa de São Joaquim,20,,-5.616667,-41.416667
br,lagoa de sao jose,Lagoa de São José,30,,-9.266667,-36.65
br,lagoa de todos-os-santos,Lagoa de Todos-os-Santos,20,,-5.75,-42.8
br,lagoa do alegre,Lagoa do Alegre,05,,-9.1,-41.666667
br,lagoa do alto,Lagoa do Alto,05,,-13.166667,-40.1
br,lagoa do anjo,Lagoa do Anjo,06,,-6.133333,-40.65
br,lagoa do arroz,Lagoa do Arroz,05,,-12.2,-40.733333
br,lagoa do arroz,Lagoa do Arroz,20,,-9.716667,-43.85
br,lagoa do arroz,Lagoa do Arroz,30,,-8.433333,-36.05
br,lagoa do atalho,Lagoa do Atalho,05,,-12.233333,-39.683333
br,lagoa do baixao,Lagoa do Baixão,20,,-9.416667,-43.783333
br,lagoa do banco,Lagoa do Banco,20,,-8.55,-41.516667
br,lagoa do barro,Lagoa do Barro,13,,-3.088889,-42.288611
br,lagoa do barro,Lagoa do Barro,20,,-3.918056,-42.186111
br,lagoa do barro,Lagoa do Barro,30,,-7.766667,-40.366667
br,lagoa do boia,Lagoa do Boia,17,,-7.833333,-36.85
br,lagoa do boi,Lagoa do Boi,05,,-11.916667,-41.716667
br,lagoa do boi,Lagoa do Boi,06,,-5.833333,-40.283333
br,lagoa do boi,Lagoa do Boi,17,,-7.233333,-36.8
br,lagoa do buraco,Lagoa do Buraco,05,,-12.4,-40.9
br,lagoa do burro,Lagoa do Burro,30,,-7.816667,-40.366667
br,lagoa do cabore,Lagoa do Caboré,20,,-9.2,-42.516667
br,lagoa do caminho,Lagoa do Caminho,02,,-9.333333,-36.866667
br,lagoa do canto,Lagoa do Canto,05,,-13.966667,-42.466667
br,lagoa do canto,Lagoa do Canto,20,,-6.966667,-41.316667
br,lagoa do canto,Lagoa do Canto,22,,-5.75,-35.483333
br,lagoa do capim,Lagoa do Capim,05,,-12.333333,-40.083333
br,lagoa do carneiro,Lagoa do Carneiro,06,,-3.033333,-40.05
br,lagoa do caroa,Lagoa do Caroá,30,,-7.883333,-37.733333
br,lagoa do carro,Lagoa do Carro,06,,-6.783333,-40.35
br,lagoa do carro,Lagoa do Carro,30,,-7.85,-35.333333
br,lagoa do carvao,Lagoa do Carvão,28,,-10.6,-37.283333
br,lagoa do casco,Lagoa do Casco,13,,-3.066667,-43.35
br,lagoa do chiquinho,Lagoa do Chiquinho,05,,-13.55,-40.2
br,lagoa do cigano,Lagoa do Cigano,13,,-3.482778,-43.080833
br,lagoa do cipo,Lagoa do Cipó,05,,-12.083333,-40.2
br,lagoa do coco,Lagoa do Côco,02,,-8.966667,-37.516667
br,lagoa do crasto,Lagoa do Crasto,06,,-2.816667,-40.2
br,lagoa do curral,Lagoa do Curral,02,,-9.666667,-37.633333
br,lagoa do curral,Lagoa do Curral,30,,-8.666667,-37.016667
br,lagoa do dionisio,Lagoa do Dionísio,05,,-12.466667,-42.233333
br,lagoa do emidio,Lagôa do Emídio,30,,-9.2,-36.433333
br,lagoa do emigdio,Lagôa do Emigdio,30,,-9.2,-36.433333
br,lagoa do enchu,Lagoa do Enchu,13,,-4.016667,-43.05
br,lagoa do engano,Lagoa do Engano,06,,-4.65,-38.1
br,lagoa do espinho,Lagoa do Espinho,22,,-5.233333,-35.95
br,lagoa do estevam,Lagoa do Estevam,05,,-14.6,-42.066667
br,lagoa do estevao,Lagoa do Estêvão,05,,-14.6,-42.066667
br,lagoa do exu,Lagoa do Exu,13,,-4.016667,-43.05
br,lagoa do fabio,Lagoa do Fábio,05,,-10.816667,-43.466667
br,lagoa do felix,Lagoa do Félix,30,,-8.216667,-36.6
br,lagoa do forno,Lagoa do Forno,17,,-6.8,-38.166667
br,lagoa do garrote,Lagoa do Garrote,02,,-9.35,-37.266667
br,lagoa do gato,Lagoa do Gato,20,,-7.55,-41.833333
br,lagoa do gaviao,Lagoa do Gavião,02,,-9.466667,-37.633333
br,lagoa do gouveia,Lagoa do Gouveia,15,,-18.816667,-45.833333
br,lagoa do itaenga,Lagoa do Itaenga,30,17719,-7.916667,-35.333333
br,lagoa do jacare,Lagoa do Jacaré,15,,-19.133333,-44.533333
br,lagoa do jacu,Lagoa do Jacu,30,,-9.15,-36.683333
br,lagoa do jatoba,Lagoa do Jatobá,05,,-9.85,-43.65
br,lagoa do junco,Lagoa do Junco,06,,-4.65,-37.9
br,lagoa do junco,Lagoa do Junco,17,,-7.15,-37.966667
br,lagoado,Lagoado,20,,-10.533333,-44.066667
br,lagoa do lajedo,Lagoa do Lajedo,05,,-12.916667,-40.2
br,lagoa do lajeiro,Lagoa do Lajeiro,02,,-9.45,-37.616667
br,lagoa do laje,Lagoa do Laje,30,,-8.433333,-36.233333
br,lagoa do laurencio,Lagoa do Laurêncio,05,,-13.8,-42.016667
br,lagoa do leite,Lagoa do Leite,05,,-12.483333,-42.5
br,lagoa do limoeiro,Lagoa do Limoeiro,17,,-7.233333,-38.6
br,lagoa do manuel,Lagoa do Manuel,05,,-13.533333,-40.983333
br,lagoa do maracaja,Lagoa do Maracajá,06,,-6.1,-38.966667
br,lagoa do marco,Lagoa do Marco,13,,-5.366667,-42.966667
br,lagoa do marizeiro,Lagoa do Marizeiro,22,,-5.413889,-37.326944
br,lagoa do martins,Lagoa do Martins,05,,-12.116667,-40.733333
br,lagoa do mata,Lagoa do Mata,28,,-10.2,-36.983333
br,lagoa do mato,Lagoa do Mato,05,,-12.35,-39.75
br,lagoa do mato,Lagoa do Mato,06,,-4.583333,-37.633333
br,lagoa do mato,Lagoa do Mato,13,,-2.466667,-44.7
br,lagoa do mato,Lagoa do Mato,20,,-3.858889,-42.516944
br,lagoa do mato,Lagoa do Mato,22,,-5.183333,-35.5
br,lagoa do mato,Lagoa do Mato,28,,-10.2,-36.983333
br,lagoa do meio,Lagoa do Meio,05,,-13.2,-42.533333
br,lagoa do meio,Lagoa do Meio,17,,-6.933333,-36.9
br,lagoa do meio,Lagoa do Meío,20,,-7.116667,-41.966667
br,lagoa do meio,Lagoa do Meio,22,,-5.833333,-35.583333
br,lagoa do mel,Lagoa do Mel,02,,-9.633333,-36.75
br,lagoa do mel,Lagoa do Mel,22,,-5.95,-35.6
br,lagoa do mocambo,Lagoa do Mocambo,20,,-6.066667,-42.233333
br,lagoa do morto,Lagoa do Morto,05,,-13.1,-39.966667
br,lagoa do mucambo,Lagoa do Mucambo,20,,-6.066667,-42.233333
br,lagoa do neco,Lagoa do Neco,20,,-8.816667,-42.916667
br,lagoa do ouro,Lagoa do Ouro,05,,-10.45,-38.566667
br,lagoa do ouro,Lagoa do Ouro,30,,-9.133333,-36.466667
br,lagoa do padre,Lagoa do Padre,30,,-8.716667,-36.15
br,lagoa do pai goncalo,Lagoa do Pai Gonçalo,02,,-9.616667,-36.833333
br,lagoa do peixe,Lagoa do Peixe,05,,-12.466667,-41.183333
br,lagoa do pendao,Lagoa do Pendão,22,,-5.483333,-35.716667
br,lagoa do poco,Lagoa do Poço,05,,-11.25,-43.933333
br,lagoa do pore,Lagoa do Poré,22,,-5.386111,-36.881111
br,lagoa do prata,Lagoa do Prata,22,,-5.333333,-35.5
br,lagoa do rancho,Lagoa do Rancho,02,,-9.416667,-37.383333
br,lagoa do rancho,Lagoa do Rancho,28,,-9.966667,-37.433333
br,lagoa do remigio,Lagôa do Remigio,17,,-6.933333,-35.783333
br,lagoa do riacho,Lagoa do Riacho,30,,-9.133333,-36.7
br,lagoa do rocha,Lagoa do Rocha,06,,-5.216667,-37.816667
br,lagoa do sabino,Lagoa do Sabino,06,,-5.05,-37.833333
br,lagoa do saco,Lagoa do Saco,20,,-6.183333,-41.883333
br,lagoa do sapo,Lagoa do Sapo,22,,-5.766667,-35.916667
br,lagoa dos bastos,Lagoa dos Bastos,05,,-12.833333,-41.95
br,lagoa dos bois,Lagoa dos Bois,06,,-4.616667,-38.833333
br,lagoa dos bois,Lagoa dos Bois,14,,-16.233333,-56.966667
br,lagoa dos caboclos,Lagoa dos Caboclos,02,,-9.483333,-36.783333
br,lagoa dos cavalos,Lagoa dos Cavalos,20,,-3.521667,-42.090278
br,lagoa dos claudios,Lagoa dos Cláudios,20,,-4.383333,-41.616667
br,lagoa dos cocos da edmundo,Lagoa dos Cocos da Edmundo,20,,-6.066667,-42.566667
br,lagoa dos couros,Lagoa dos Couros,30,,-8.266667,-36.316667
br,lagoa dos currais,Lagoa dos Currais,22,,-5.883333,-35.516667
br,lagoa do serrote,Lagoa do Serrote,05,,-12.366667,-39.35
br,lagoa do serrote,Lagoa do Serrote,06,,-3.5,-40.1
br,lagoa dos filos,Lagoa dos Filos,06,,-4.783333,-39.866667
br,lagoa dos gatos,Lagoa dos Gatos,30,,-8.65,-35.9
br,lagoa do silvestre,Lagoa do Silvestre,13,,-3.594167,-43.175
br,lagoa do sitio,Lagoa do Sítio,20,,-6.5,-41.566667
br,lagoa dos macacos,Lagoa dos Macacos,20,,-3.909444,-42.305556
br,lagoa dos marinheiros,Lagoa dos Marinheiros,06,,-6.15,-38.55
br,lagoa dos martins,Lagoa dos Martins,15,,-20.366667,-45.95
br,lagoa dos mil homens,Lagoa dos Mil Homens,06,,-6.266667,-38.6
br,lagoa dos negros,Lagoa dos Negros,05,,-10.316667,-43.516667
br,lagoa dos neris,Lagoa dos Neris,06,,-5.666667,-40.816667
br,lagoa do sousa,Lagoa do Sousa,30,,-8.7,-35.933333
br,lagoa do souza,Lagoa do Souza,30,,-8.7,-35.933333
br,lagoa dos patos,Lagoa dos Patos,11,,-22.9,-55.5
br,lagoa dos patos,Lagoa dos Patos,13,,-3.4075,-42.631111
br,lagoa dos patos,Lagoa dos Patos,15,,-16.977222,-44.576111
br,lagoa dos perreira,Lagoa dos Perreira,18,,-25.9373,-49.3262
br,lagoa dos pioes,Lagoa dos Piões,17,,-7.8,-36.9
br,lagoa dos porcos,Lagoa dos Porcos,05,,-12.016667,-40.966667
br,lagoa dos tocos,Lagoa dos Tocos,06,,-6.383333,-39.2
br,lagoa do sul,Lagoa do Sul,26,,-26.366667,-50.333333
br,lagoa dos veados,Lagoa dos Veados,05,,-10.316667,-43.75
br,lagoa do tabuleiro,Lagoa do Tabuleiro,20,,-8.466667,-42.15
br,lagoa do tamboata,Lagoa do Tamboata,06,,-3.383333,-40.083333
br,lagoa do tapuio,Lagoa do Tapuio,06,,-5.116667,-38.6
br,lagoa do timoteo,Lagoa do Timoteo,05,,-13.85,-42.183333
br,lagoa do tocantins,Lagoa do Tocantins,31,,-10.379722,-47.423611
br,lagoa do umbuzeiro,Lagoa do Umbuzeiro,20,,-6.95,-40.966667
br,lagoa dourada,Lagoa Dourada,15,,-20.916667,-44.083333
br,lagoa do vaqueiro,Lagoa do Vaqueiro,05,,-13.483333,-40.816667
br,lagoa do vau,Lagoa do Vau,05,,-11.133333,-45.366667
br,lagoa do velho,Lagoa do Velho,22,,-6,-35.866667
br,lagoa do vicente,Lagoa do Vicente,02,,-9.6,-37.483333
br,lagoa do vieira,Lagoa do Vieira,30,,-7.733333,-38.566667
br,lagoa encantada,Lagoa Encantada,05,,-12.6,-41.3
br,lagoa escondida,Lagoa Escondida,05,,-9.816667,-39.383333
br,lagoa estrema,Lagoa Estrema,30,,-7.833333,-38.816667
br,lagoa fechada,Lagoa Fechada,30,,-8.916667,-37.916667
br,lagoa feia,Lagoa Feia,21,,-23.040005,-43.520522
br,lagoa felix,Lagoa Félix,20,,-9.483333,-45.383333
br,lagoa formosa,Lagoa Formosa,05,,-14.983333,-41.05
br,lagoa formosa,Lagoa Formosa,15,11822,-18.783333,-46.4
br,lagoa formosa,Lagoa Formosa,27,,-21.916667,-46.933333
br,lagoa funda,Lagoa Funda,05,,-13.85,-41.95
br,lagoa funda,Lagoa Funda,06,,-7.333333,-38.633333
br,lagoa funda,Lagoa Funda,28,,-10.016667,-36.95
br,lagoa grande de cima,Lagoa Grande de Cima,17,,-7.95,-37.033333
br,lagoa grande,Lagoa Grande,02,,-10.333333,-36.7
br,lagoa grande,Lagoa Grande,05,,-12.366667,-41.033333
br,lagoa grande,Lagoa Grande,06,,-2.902222,-40.655556
br,lagoa grande,Lagoa Grande,13,,-2.916667,-43.466667
br,lagoa grande,Lagoa Grande,15,,-15.7,-41.816667
br,lagoa grande,Lagoa Grande,17,,-6.966667,-38.1
br,lagoa grande,Lagoa Grande,18,,-25.683333,-49.45
br,lagoa grande,Lagoa Grande,20,,-6.85,-41.3
br,lagoa grande,Lagoa Grande,22,,-5.85,-35.633333
br,lagoa grande,Lagoa Grande,30,,-9,-40.283333
br,lagoa jose luis,Lagoa José Luís,05,,-15.016667,-40.95
br,lagoa jurema,Lagoa Jurema,20,,-9.35,-43.3
br,lagoa,Lagoa,02,,-9.383333,-37.266667
br,lagoa,Lagoa,05,,-11.05,-42.316667
br,lagoa,Lagoa,06,,-3.166667,-39.733333
br,lagoa,Lagoa,08,,-19.166667,-40.183333
br,lagoa,Lagoa,11,,-20.55,-54.083333
br,lagoa,Lagoa,13,,-3.305833,-43.212778
br,lagoa,Lagoa,14,,-14.133333,-55.333333
br,lagoa,Lagoa,15,,-16.3,-42.45
br,lagoa,Lagoa,17,,-6.583333,-37.916667
br,lagoa,Lagoa,18,,-23.833333,-51.116667
br,lagoa,Lagoa,20,,-3.535278,-42.016944
br,lagoa,Lagoa,21,,-22.968276,-43.204229
br,lagoa,Lagoa,22,,-5.316667,-35.766667
br,lagoa,Lagoa,26,,-27.616667,-48.483333
br,lagoa,Lagôa,27,,-21.9,-47.033333
br,lagoa,Lagoa,30,,-7.9,-36.366667
br,lagoa limpa,Lagoa Limpa,30,,-8.366667,-36.15
br,lagoa nova,Lagoa Nova,05,,-12.75,-40.9
br,lagoa nova,Lagoa Nova,06,,-3.45,-39.35
br,lagoa nova,Lagoa Nova,13,,-5.616667,-44.416667
br,lagoa nova,Lagoa Nova,20,,-5.45,-42.866667
br,lagoa nova,Lagoa Nova,21,,-22.801885,-43.792225
br,lagoa nova,Lagoa Nova,22,5984,-6.1,-36.483333
br,lagoa nova,Lagoa Nova,27,,-23.4948,-46.0121
br,lagoa nova,Lagoa Nova,30,,-7.716667,-39.566667
br,lagoao,Lagoão,15,,-16.283333,-45.783333
br,lagoao,Lagoão,18,,-26.45,-52.016667
br,lagoao,Lagoão,23,,-28.55,-53.466667
br,lagoao,Lagoão,27,,-23.671336,-47.577358
br,lagoa pau da embira,Lagoa Pau da Embira,17,,-7.5,-36.033333
br,lagoa pedro borges,Lagoa Pedro Borges,30,,-8.333333,-36.733333
br,lagoa preta,Lagoa Preta,05,,-10.65,-37.9
br,lagoa preta,Lagoa Preta,06,,-7.783333,-39.066667
br,lagoa queimada,Lagoa Queimada,05,,-12.683333,-40.433333
br,lagoa queimada,Lagoa Queimada,17,,-7.233333,-36.85
br,lagoa rasa,Lagoa Rasa,22,,-5.716667,-37.75
br,lagoa real,Lagoa Real,05,,-14.033333,-42.133333
br,lagoa redonda,Lagoa Redonda,05,,-11.933333,-38.016667
br,lagoa redonda,Lagoa Redonda,20,,-5.416667,-41.75
br,lagoa redonda,Lagoa Redonda,22,,-5.966667,-35.65
br,lagoa salgada,Lagoa Salgada,22,,-6.116667,-35.483333
br,lagoa santa,Lagoa Santa,15,38487,-19.633333,-43.883333
br,lagoa santo antonio,Lagoa Santo Antonio,15,,-17.133333,-46.816667
br,lagoa seca,Lagoa Sêca,02,,-9.833333,-36.616667
br,lagoa seca,Lagoa Sêca,05,,-12.5,-41.333333
br,lagoa seca,Lagoa Sêca,13,,-5.783333,-46.1
br,lagoa seca,Lagoa Sêca,17,8103,-7.15,-35.85
br,lagoa seca,Lagoa Sêca,18,,-25.45,-51.866667
br,lagoa seca,Lagoa Seca,20,,-5.333333,-42.733333
br,lagoa seca,Lagoa Sêca,22,,-5.653333,-37.175
br,lagoa seca,Lagoa Sêca,27,,-20.966667,-49.9
br,lagoa seca,Lagoa Sêca,30,,-7.666667,-35.183333
br,lagoa secca,Lagôa Secca,30,,-7.666667,-35.183333
br,lagoas,Lagoas,05,,-10.633333,-40.866667
br,lagoas,Lagoas,11,,-20.8,-51.716667
br,lagoas,Lagoas,20,,-5.4,-41.916667
br,lagoas,Lagoas,30,,-7.5,-39.833333
br,lagoa solgada,Lagoa Solgada,06,,-5.016667,-38.15
br,lagoas queimadas,Lagoas Queimadas,06,,-5.483333,-40.566667
br,lagoa tapada,Lagoa Tapada,06,,-6.666667,-38.733333
br,lagoa torta,Lagoa Torta,05,,-14.6,-41.1
br,lagoa velha,Lagoa Velha,06,,-5.433333,-39.816667
br,lagoa velha,Lagoa Velha,15,,-16.166667,-41.6
br,lagoa velha,Lagoa Velha,20,,-6.55,-41.283333
br,lagoa velha,Lagoa Velha,30,,-8.983333,-38.216667
br,lagoa verde,Lagoa Verde,05,,-12.333333,-38.1
br,lagoa verde,Lagoa Verde,13,,-4.066667,-45.733333
br,lagoa verde,Lagoa Verde,14,,-16.283333,-58.466667
br,lagoa verde,Lagoa Verde,18,,-25.896686,-49.516236
br,lagoa vermelha,Lagoa Vermelha,02,,-8.966667,-36.066667
br,lagoa vermelha,Lagoa Vermelha,06,,-4.916667,-37.8
br,lagoa vermelha,Lagoa Vermelha,23,24446,-28.216667,-51.533333
br,lagoa vermelha,Lagoa Vermelha,27,,-23.609,-47.9189
br,lago da pedra,Lago da Pedra,13,25996,-4.333333,-45.166667
br,lago de cima,Lago de Cima,13,,-5.766667,-43.783333
br,lago de santo antonio,Lago de Santo Antônio,04,,-6.75,-62.35
br,lagoinas,Lagoinas,30,,-7.933333,-38.433333
br,lagoinha de baixo,Lagoinha de Baixo,14,,-15.35,-55.55
br,lagoinha de cima,Lagoinha de Cima,14,,-15.466667,-55.55
br,lagoinha,Lagoinha,02,,-10.166667,-36.383333
br,lagoinha,Lagoinha,04,,-7.516667,-73.5
br,lagoinha,Lagoinha,05,,-10.316667,-38.9
br,lagoinha,Lagoinha,06,,-2.966667,-40.433333
br,lagoinha,Lagoinha,07,,-15.816667,-47.4
br,lagoinha,Lagoinha,08,,-20.233333,-41.066667
br,lagoinha,Lagoinha,11,,-20.716667,-54.766667
br,lagoinha,Lagoinha,13,,-3.783333,-43.833333
br,lagoinha,Lagoinha,14,,-14.183333,-56.8
br,lagoinha,Lagoinha,15,,-16.1,-42.416667
br,lagoinha,Lagoinha,17,,-6.616667,-38.35
br,lagoinha,Lagoinha,20,,-10.15,-45.283333
br,lagoinha,Lagoinha,21,,-22.939317,-43.207387
br,lagoinha,Lagoinha,22,,-5.067222,-37.406389
br,lagoinha,Lagoinha,23,,-30.283333,-55.733333
br,lagoinha,Lagoinha,27,,-22.35,-47.45
br,lagoinha,Lagoinha,28,,-9.916667,-37.166667
br,lagoinha,Lagoinha,30,,-7.333333,-37.333333
br,lagoinhas,Lagoinhas,05,,-12.6,-41.016667
br,lagoinhas,Lagoinhas,22,,-6.25,-37.05
br,lagoinhas,Lagoinhas,30,,-7.933333,-38.433333
br,lago izidoro,Lago Izidoro,01,,-8.056944,-72.655278
br,lago,Lago,05,,-8.883333,-40.916667
br,lago,Lago,18,,-24.966667,-49.916667
br,lagolandia,Lagolândia,29,,-15.616667,-49.033333
br,lago novo,Lago Novo,03,,1.4,-50.633333
br,lago verde,Lago Verde,04,,-7.733333,-70.433333
br,lago verde,Lago Verde,24,,-8.483333,-62.55
br,lago vermelha,Lago Vermelha,17,,-6.75,-38.5
br,lagradouro,Lagradouro,30,,-8.733333,-37.333333
br,laguinho,Laguinho,13,,-4.283333,-44.5
br,laguna carapa,Laguna Carapã,11,,-22.45,-55.016667
br,laguna,Laguna,11,,-22.533333,-55.216667
br,laguna,Laguna,26,39712,-28.483333,-48.783333
br,laguna pora,Laguna Porã,11,,-23.2,-54.85
br,laguna vera,Laguna Verá,11,,-23.416667,-55.2
br,lagunita,Lagunita,11,,-22.6,-55.383333
br,lajao,Lajão,15,,-19.166667,-41.5
br,laje 146,Laje 146,24,,-10.416667,-65.383333
br,lajeadinha,Lajeadinha,27,,-23.37351,-47.881518
br,lajeadinho,Lajeadinho,11,,-20.916667,-55.416667
br,lajeadinho,Lajeadinho,18,,-25.166667,-50.916667
br,lajeadinho,Lajeadinho,23,,-28.6,-49.916667
br,lajeado bonita,Lajeado Bonita,18,,-24.166667,-50.783333
br,lajeado bonito,Lajeado Bonito,17,,-7.683333,-37.9
br,lajeado bonito,Lajeado Bonito,18,,-24.166667,-50.783333
br,lajeado bonito,Lajeado Bonito,23,,-27.35,-54.166667
br,lajeado branco,Lajeado Branco,06,,-5.683333,-41.016667
br,lajeado de baixo,Lajeado de Baixo,22,,-5.466667,-35.8
br,lajeado do cacador,Lajeado do Caçador,18,,-26.139104,-49.51109
br,lajeado do salto,Lajeado do Salto,27,,-23.75,-47.283333
br,lajeado dos pintos,Lajeado dos Pintos,26,,-27.183333,-51.983333
br,lajeado grande,Lajeado Grande,18,,-25.833333,-52.916667
br,lajeado grande,Lajeado Grande,23,,-27.416667,-53.95
br,lajeado grande,Lajeado Grande,26,,-26.95,-52.6
br,lajeado,Lajeado,05,,-12.466667,-41.666667
br,lajeado,Lajeado,11,,-20.233333,-55.466667
br,lajeado,Lajeado,13,,-7.75,-46.883333
br,lajeado,Lajeado,14,,-16.35,-53.75
br,lajeado,Lajeado,15,,-19.166667,-48.7
br,lajeado,Lajeado,16,,-4.947778,-53.698333
br,lajeado,Lajeado,18,,-23.316667,-50.3
br,lajeado,Lajeado,20,,-4.283333,-41.983333
br,lajeado,Lajeado,22,,-5.45,-35.783333
br,lajeado,Lajeado,23,65408,-29.45,-51.966667
br,lajeado,Lajeado,26,,-26.658663,-49.635506
br,lajeado,Lajeado,27,,-21.916667,-47.466667
br,lajeado,Lajeado,29,,-17.1,-51.766667
br,lajeado,Lajeado,31,,-9.725833,-48.218056
br,lajeado liso,Lajeado Liso,18,,-23.945099,-50.564365
br,lajeados,Lajeados,27,,-20.683333,-47.15
br,laje cento e quarenta e seis,Laje Cento e Quarenta e Seis,24,,-10.416667,-65.383333
br,laje da oiticica,Laje da Oiticica,06,,-5.433333,-37.933333
br,lajedao,Lajedão,05,,-17.583333,-40.366667
br,laje da onca,Laje da Onça,17,,-7.566667,-37.8
br,laje d' aqua,Laje d' Aqua,17,,-7.516667,-37.7
br,laje de muriae,Laje de Muriaé,21,,-21.2,-42.116667
br,lajedinho,Lajedinho,05,,-11.383333,-40.633333
br,lajedinho,Lajedinho,15,,-14.933333,-43.7
br,lajedo alto,Lajedo Alto,05,,-12.083333,-40.4
br,laje do banco,Laje do Banco,05,,-14.35,-39.416667
br,laje do capia,Laje do Capiá,02,,-9.283333,-36.566667
br,laje do carrapato,Laje do Carrapato,30,,-7.883333,-38.216667
br,lajedo de baixo,Lajedo de Baixo,05,,-12.483333,-40.416667
br,lajedo de cima,Lajedo de Cima,05,,-12.516667,-40.45
br,lajedo de mel,Lajedo de Mel,06,,-5.083333,-37.733333
br,lajedo do batista,Lajedo do Batista,05,,-12.933333,-39.55
br,lajedo do carrapicho,Lajedo do Carrapicho,30,,-8.466667,-36.716667
br,lajedo do cedro,Lajedo do Cedro,30,,-8.3,-35.966667
br,lajedo do souza,Lajedo do Souza,06,,-5.383333,-37.933333
br,lajedo do tabocal,Lajedo do Tabocal,05,,-13.466667,-40.216667
br,lajedo do trapia,Lajedo do Trapiá,02,,-9.283333,-36.566667
br,lajedo grande,Lajedo Grande,15,,-16.316667,-41.566667
br,lajedo grande,Lajedo Grande,23,,-27.483333,-53.983333
br,lajedo,Lajedo,05,,-12.583333,-39.2
br,lajedo,Lajedo,17,,-6.816667,-36.133333
br,lajedo,Lajedo,22,,-5.041944,-37.423333
br,lajedo,Lajedo,30,25262,-8.383333,-36.55
br,laje do meio,Laje do Meio,22,,-5.5,-37.9
br,lajedo novo,Lajedo Novo,05,,-12.183333,-40.583333
br,laje do rio preto,Laje do Rio Prêto,05,,-13.6,-39.5
br,lajedo seco,Lajedo Sêco,05,,-12.866667,-40.4
br,laje do tabocal,Laje do Tabocal,05,,-13.466667,-40.216667
br,laje funda,Laje Funda,05,,-12.233333,-40.983333
br,laje grande,Laje Grande,13,,-3.8,-45.233333
br,laje grande,Laje Grande,30,,-8.6,-35.716667
br,lajeiro alto,Lajeiro Alto,30,,-8.95,-36.933333
br,lajeiro,Lajeiro,02,,-9.333333,-36.766667
br,lajeiro,Lajeiro,20,,-3.591944,-42.092222
br,lajeiro,Lajeiro,22,,-4.983333,-37.65
br,laje,Laje,02,,-9.433333,-37.666667
br,laje,Laje,05,4708,-10.183333,-40.966667
br,laje,Laje,08,,-19.533333,-40.833333
br,laje,Laje,13,,-3.016667,-46.65
br,laje,Laje,14,,-15.833333,-55.6
br,laje,Laje,15,,-21.05,-45.25
br,laje,Laje,16,,-5.566667,-56.966667
br,laje,Laje,20,,-9.2,-42.166667
br,laje,Laje,21,,-21.2,-42.116667
br,laje,Laje,24,,-9.8,-62.433333
br,laje,Laje,27,,-20.466667,-47.833333
br,laje,Laje,30,,-8.083333,-36.05
br,lajes dos lopes,Lajes dos Lopes,06,,-4.766667,-39.783333
br,lajes,Lajes,02,,-9.533333,-36.2
br,lajes,Lajes,05,,-10.933333,-42.35
br,lajes,Lajes,06,,-4.016667,-38.7
br,lajes,Lajes,13,,-6.466667,-42.983333
br,lajes,Lajes,14,,-15.833333,-55.6
br,lajes,Lajes,15,,-16.35,-46.183333
br,lajes,Lajes,17,,-7.3,-36.2
br,lajes,Lajes,20,,-5.266667,-41.766667
br,lajes,Lajes,22,,-5.283889,-37.289722
br,lajes,Lajes,26,,-27.8,-50.316667
br,lajes,Lajes,29,,-14.05,-48.133333
br,lajes,Lajes,30,,-7.45,-37.216667
br,lajes pintadas,Lajes Pintadas,22,,-6.15,-36.116667
br,laje velha,Laje Velha,30,,-7.833333,-37.833333
br,lajinha do mutum,Lajinha do Mutum,15,,-19.716667,-41.416667
br,lajinha do sebastiao inacio,Lajinha do Sebastiao Inácio,22,,-5.421667,-36.421944
br,lajinha,Lajinha,02,,-9.183333,-36.05
br,lajinha,Lajinha,05,,-12.183333,-40.6
br,lajinha,Lajinha,07,,-15.816667,-47.4
br,lajinha,Lajinha,08,,-19.166667,-40.766667
br,lajinha,Lajinha,13,,-7.783333,-47.033333
br,lajinha,Lajinha,15,,-19.716667,-41.416667
br,lajinha,Lajinha,18,,-25.655779,-50.127056
br,lajinha,Lajinha,20,,-5.583333,-42.816667
br,lajinha,Lajinha,22,,-6.15,-37.733333
br,lajinha,Lajinha,30,,-7.85,-38.433333
br,lajinha,Lajinha,31,,-7.683333,-48.083333
br,lalima,Lâlima,11,,-20.566667,-56.233333
br,lamacre,Lamacré,15,,-17.466667,-42.066667
br,lama,Lama,05,,-16.466667,-39.933333
br,lamarao do passe,Lamarão do Passé,05,,-12.6,-38.4
br,lamarao,Lamarão,05,,-10.65,-43.616667
br,lamarao,Lamarão,06,,-7.266667,-39.45
br,lamarao,Lamarão,08,,-20.95,-40.95
br,lamarao,Lamarão,17,,-6.666667,-36.266667
br,lambari de baixo,Lambari de Baixo,27,,-22.783333,-47.483333
br,lambari do meio,Lambari do Meio,27,,-22.8,-47.483333
br,lambari,Lambari,08,,-20.6,-41.466667
br,lambari,Lambari,11,,-21.716667,-54.083333
br,lambari,Lambari,15,14516,-21.966667,-45.35
br,lambari,Lambari,18,,-23.854763,-50.661714
br,lambari,Lambari,27,,-23.32767,-46.109887
br,lambary,Lambary,15,,-21.966667,-45.35
br,lambedor,Lambedor,06,,-5.75,-39.866667
br,lambedor,Lambedor,18,,-26.066667,-52.583333
br,lambedor,Lambedor,30,,-7.683333,-38.65
br,lambedouro,Lambedouro,06,,-3.583333,-41.016667
br,lamberio,Lamberio,15,,-16.333333,-40.35
br,lameirao,Lameirão,05,,-10.65,-43.616667
br,lameirao,Lameirão,08,,-20.683333,-40.533333
br,lameiro,Lameiro,05,,-13.55,-41.116667
br,lameiro,Lameiro,06,,-7.266667,-39.45
br,lameiro,Lameiro,13,,-3.6325,-42.684722
br,lameiro,Lameiro,20,,-3.745833,-42.646944
br,lamim,Lamim,15,,-20.783333,-43.466667
br,lamina,Lâmina,11,,-20.566667,-56.233333
br,lamin,Lamin,15,,-20.783333,-43.466667
br,lamins,Lamins,15,,-22.383333,-44.916667
br,lamounier,Lamounier,15,,-20.466667,-45.033333
br,lanacre,Lanacrê,15,,-17.466667,-42.066667
br,lanca,Lança,18,,-25.116667,-49.233333
br,lanca,Lança,26,,-26.3,-51
br,lancante,Lançante,05,,-12.283333,-40.55
br,lanceiro,Lanceiro,11,,-20.983333,-53.716667
br,lanchinha,Lanchinha,22,,-5.9925,-37.491111
br,landi,Landi,15,,-16.15,-41.683333
br,landim,Landim,05,,-12.6,-45.3
br,landin,Landin,05,,-12.6,-45.3
br,landri sales,Landri Sales,20,,-7.266667,-43.916667
br,landulfo,Landulfo,08,,-20.566667,-41.7
br,languiru,Languiru,23,,-29.466667,-51.8
br,lanza velha,Lanza Velha,06,,-2.85,-40.1
br,lapa de fogo,Lapa de Fogo,15,,-16.083333,-41.266667
br,lapa,Lapa,05,,-12.4,-38.733333
br,lapa,Lapa,18,25621,-25.765833,-49.717778
br,lapa,Lapa,20,,-4.35,-41.133333
br,lapa,Lapa,21,,-22.913993,-43.182011
br,lapa,Lapa,27,,-23.533333,-46.7
br,lapa,Lapa,30,,-7.5,-35.166667
br,lapao,Lapão,05,11253,-11.4,-41.833333
br,la paz,La Paz,24,,-9.75,-65.866667
br,lapeira dantas,Lapeira Dantas,30,,-7.366667,-37.316667
br,lapela,Lapela,13,,-3.733333,-44.75
br,lapinha,Lapinha,05,,-12.1,-41.283333
br,lapinha,Lapinha,15,,-19.566667,-43.966667
br,la preta,La Preta,05,,-11.766667,-41.033333
br,larangeiras,Larangeiras,06,,-5.283333,-38.866667
br,larangeiras,Larangeiras,17,,-7.066667,-35.766667
br,larangeiras,Larangeiras,21,,-21.766667,-42.166667
br,larangeiras,Larangeiras,27,,-20.283333,-48.716667
br,larangeiras,Larangeiras,28,,-10.8,-37.166667
br,laranginha,Laranginha,18,,-25.416667,-52.416667
br,larania da terra,Larania da Terra,08,,-20.216667,-41.683333
br,laranja azeda,Laranja Azeda,18,,-25.128934,-48.346437
br,laranja-azeda,Laranja-Azeda,27,,-23.128889,-46.505
br,laranja azeda,Laranja Azeda,27,,-23.2008,-47.9369
br,laranja-azeda,Laranja-Azeda,27,,-23.216325,-47.829697
br,laranja da terra,Laranja da Terra,08,3016,-19.9,-41.066667
br,laranjais,Laranjais,21,,-21.766667,-42.166667
br,laranja,Laranja,04,,-3.9,-63.416667
br,laranja,Laranja,05,,-13.883333,-41.833333
br,laranja,Laranja,20,,-5.05,-42.683333
br,laranjal,Laranjal,04,,-3.483333,-68.266667
br,laranjal,Laranjal,14,,-14.5,-55.133333
br,laranjal,Laranjal,15,,-21.366667,-42.466667
br,laranjal,Laranjal,18,,-24.73586,-48.978322
br,laranjal,Laranjal,23,,-28.5,-51.55
br,laranjal,Laranjal,26,,-28.65,-48.983333
br,laranjal,Laranjal,27,,-21.683333,-47.85
br,laranjal paulista,Laranjal Paulista,27,21264,-23.048726,-47.835968
br,laranjeira,Laranjeira,06,,-5.283333,-38.866667
br,laranjeira,Laranjeira,08,,-19.966667,-40.25
br,laranjeira,Laranjeira,14,,-15.9,-56.683333
br,laranjeira,Laranjeira,17,,-6.9,-37.283333
br,laranjeira,Laranjeira,18,,-24.7,-51.066667
br,laranjeira,Laranjeira,23,,-28.05,-54.683333
br,laranjeira,Laranjeira,26,,-27.583333,-50.883333
br,laranjeiras do sul,Laranjeiras do Sul,18,18425,-25.416667,-52.416667
br,laranjeiras ii,Laranjeiras II,13,,-3.493889,-43.418889
br,laranjeiras i,Laranjeiras I,13,,-3.496111,-43.383056
br,laranjeiras,Laranjeiras,05,,-12.566667,-38.533333
br,laranjeiras,Laranjeiras,06,,-5.283333,-38.866667
br,laranjeiras,Laranjeiras,08,,-19.966667,-40.25
br,laranjeiras,Laranjeiras,11,,-18.566667,-57.45
br,laranjeiras,Laranjeiras,13,,-3.506389,-43.390556
br,laranjeiras,Laranjeiras,14,,-15.15,-56.316667
br,laranjeiras,Laranjeiras,15,,-21.2,-45.433333
br,laranjeiras,Laranjeiras,16,,-5.7,-54.216667
br,laranjeiras,Laranjeiras,17,,-7.066667,-35.766667
br,laranjeiras,Laranjeiras,18,,-24.366667,-52.333333
br,laranjeiras,Laranjeiras,21,,-21.633333,-41.683333
br,laranjeiras,Laranjeiras,23,,-28.05,-54.683333
br,laranjeiras,Laranjeiras,26,,-26.2922,-48.6806
br,laranjeiras,Laranjeiras,27,,-20.283333,-48.716667
br,laranjeiras,Laranjeiras,28,23251,-10.8,-37.166667
br,laranjeiras,Laranjeiras,31,,-7.116667,-48.3
br,laranjeirinha,Laranjeirinha,24,,-10.866667,-65.3
br,laranjinha,Laranjinha,18,,-23.4,-50.3
br,laranjo,Laranjo,20,,-3.646944,-42.6475
br,laras,Laras,27,,-22.925,-47.896111
br,lar das meninas,Lar das Meninas,26,,-27.217377,-49.612074
br,larga,Larga,14,,-16.616667,-57.616667
br,larga,Larga,29,,-14.55,-46.216667
br,largao,Largão,11,,-20.266667,-56.85
br,largo da freguesia,Largo da Freguesia,21,,-22.942258,-43.342881
br,largo da taquara,Largo da Taquara,21,,-22.922289,-43.369654
br,largo do aarao,Largo do Aarão,21,,-22.949733,-43.678987
br,largo do bicao,Largo do Bicão,21,,-22.838337,-43.309894
br,largo do forno,Largo do Forno,13,,-5.3,-43.233333
br,largo do mariano,Largo do Mariano,13,,-5.3,-43.45
br,largo do queimado,Largo do Queimado,27,,-24.8027,-48.2595
br,largo do tanque,Largo do Tanque,21,,-22.916805,-43.356529
br,largo,Largo,05,,-11.8,-40.783333
br,largo,Largo,06,,-7.083333,-38.85
br,largo,Largo,14,,-16.616667,-57.616667
br,largo,Largo,20,,-10.016667,-44
br,largo,Largo,22,,-5.699167,-37.453333
br,lascadinha,Lascadinha,26,,-26.666667,-50.266667
br,las palmas,Las Palmas,03,,1.233333,-50.916667
br,lassance,Lassance,15,,-17.9,-44.566667
br,lastro,Lastro,22,,-6.516667,-38.166667
br,lau alves,Laú Alves,15,,-16.216667,-40.083333
br,laudja,Laudjá,11,,-21.083333,-56.7
br,laura,Laura,21,,-21.3,-41.566667
br,laurentino,Laurentino,26,,-27.218,-49.7323
br,laurindo antonio de jesus,Laurindo Antônio de Jesus,23,,-28.966667,-54.55
br,laurindo,Laurindo,16,,-7.933333,-57.516667
br,laurindo matos,Laurindo Matos,15,,-17.25,-41.833333
br,laurinha,Laurinha,15,,-19.516667,-41.383333
br,laurinha,Laurinha,18,,-24.716667,-50.133333
br,lauro,Lauro,21,,-21.3,-41.566667
br,lauro muller,Lauro Müller,26,10036,-28.4,-49.383333
br,lauro penteado,Lauro Penteado,27,,-21.5,-50.466667
br,lauro sodre,Lauro Sodré,04,,-3.858056,-62.584444
br,lauro sodre,Lauro Sodré,16,,-.75,-47.266667
br,lauzane paulista,Lauzane Paulista,27,,-23.478607,-46.64304
br,lava cara,Lava Cara,14,,-16.266667,-56.066667
br,lavadeira de baixo,Lavadeira de Baixo,05,,-14.016667,-40.666667
br,lavadeira,Lavadeira,13,,-3.183333,-45.016667
br,lavadeira,Lavadeira,17,,-7.25,-37.766667
br,lavador,Lavador,05,,-15.1,-41.766667
br,lavador,Lavador,18,,-25.98115,-50.063117
br,lavagem dos patos,Lavagem dos Patos,13,,-3.035278,-42.132222
br,lavagem,Lavagem,06,,-3.233333,-39.366667
br,lavagem,Lavagem,15,,-14.85,-43.95
br,lavaginha,Lavaginha,06,,-3.2,-39.383333
br,lavajinha,Lavajinha,13,,-3.027222,-42.081111
br,lava-pes,Lava-Pés,05,,-13.466667,-40.4
br,lava-pes,Lava-Pés,15,,-17.2,-41.816667
br,laviai,Laviaí,11,,-20.55,-55.983333
br,lavinia,Lavínia,27,,-21.15,-51.033333
br,lavoura,Lavoura,14,,-14.983333,-56.783333
br,lavouras,Lavouras,14,,-14.983333,-56.783333
br,lavrador,Lavrador,05,,-15.1,-41.766667
br,lavra,Lavra,27,,-24.532194,-48.985463
br,lavras da mangabeira,Lavras da Mangabeira,06,17221,-6.75,-38.95
br,lavras do batovi,Lavras do Batoví,23,,-30.816667,-53.916667
br,lavras do sul,Lavras do Sul,23,,-30.816667,-53.916667
br,lavras,Lavras,06,,-6.75,-38.95
br,lavras,Lavras,13,,-5.166667,-43.433333
br,lavras,Lavras,14,,-15.3,-59.233333
br,lavras,Lavras,15,81474,-21.233333,-45
br,lavras,Lavras,18,,-24.483333,-50.483333
br,lavras,Lavras,23,,-30.816667,-53.916667
br,lavras,Lavras,27,,-22.925,-47.896111
br,lavras novas,Lavras Novas,15,,-20.483333,-43.516667
br,lavrinha,Lavrinha,14,,-15.95,-56.966667
br,lavrinha,Lavrinha,18,,-23.89279,-50.0665
br,lavrinha,Lavrinha,27,,-20.166667,-47.633333
br,lavrinhas,Lavrinhas,14,,-15.95,-56.966667
br,lavrinhas,Lavrinhas,27,,-22.583333,-44.9
br,lavrinhas,Lavrinhas,29,,-14.966667,-49.3
br,lazarino vieira,Lazarino Vieira,15,,-21.066667,-46.833333
br,leandro ferreira,Leandro Ferreira,15,,-19.7,-45.033333
br,leandro,Leandro,13,,-3.8425,-43.487778
br,leao,Leão,23,,-30.116667,-52.05
br,leao,Leão,26,,-27.3,-51.566667
br,leblon,Leblon,11,,-19.983333,-56.016667
br,leblon,Leblon,21,,-22.98094,-43.220489
br,lebon regis,Lebon Régis,26,,-26.933333,-50.7
br,leda,Leda,11,,-19.333333,-56.95
br,ledo,Lêdo,17,,-7.25,-36.233333
br,leitao da cunha,Leitão da Cunha,21,,-22.083333,-42.016667
br,leite de sousa,Leite de Sousa,21,,-22.216667,-44.05
br,leite,Leite,27,,-23.697607,-47.496278
br,leites,Leites,27,,-23.6936,-47.5011
br,leiu,Leiú,20,,-7.216667,-43.15
br,lejeado,Lejeado,20,,-7.833333,-41.6
br,lembranca,Lembrança,08,,-20.55,-41.366667
br,lembranca,Lembrança,20,,-4.183333,-42.716667
br,leme do prado,Leme do Prado,15,,-17.083333,-42.666667
br,leme,Leme,21,,-22.961147,-43.165816
br,leme,Leme,27,81211,-22.2,-47.4
br,lemes,Lemes,15,,-22.5593,-45.5549
br,lemos do prado,Lemos do Prado,15,,-17.083333,-42.666667
br,lemos,Lemos,03,,.216667,-51.166667
br,lemos,Lemos,15,,-20.533333,-46.8
br,lemos,Lemos,27,,-23.983333,-48.5
br,lencoes,Lençóes,05,,-12.566667,-41.383333
br,lencoes,Lenções,15,,-20.816667,-45.083333
br,lencoes,Lençoes,27,,-22.6,-48.783333
br,lencois,Lençóis,05,,-12.566667,-41.383333
br,lencois,Lençóis,15,,-20.816667,-45.083333
br,lencois,Lençóis,27,,-22.6,-48.783333
br,lencois paulista,Lençóis Paulista,27,57376,-22.6,-48.783333
br,lencol,Lençol,27,,-24.624127,-48.030623
br,leocadia,Leocádia,05,,-16.55,-39.916667
br,leocadio boa vista,Leocadio Bôa Vista,14,,-17.116667,-56.583333
br,leodorio,Leodório,05,,-12.15,-38.083333
br,leoes,Leões,23,,-30.983333,-54.466667
br,leonardo,Leonardo,15,,-17.083333,-41.716667
br,leonardo,Leonardo,22,,-5.388333,-36.568611
br,leoncio clemente ferreira,Leôncio Clemente Ferreira,15,,-17.266667,-40.85
br,leoncio,Leoncio,18,,-23.317013,-52.579009
br,leonel barbosa,Leonel Barbosa,11,,-21.633333,-55.533333
br,leonel,Leonel,08,,-21.083333,-41.083333
br,leoni,Leoni,18,,-22.783333,-53.2
br,leopoldina,Leopoldina,02,,-8.95,-35.65
br,leopoldina,Leopoldina,15,46743,-21.533333,-42.633333
br,leopoldina,Leopoldina,29,,-14.9,-51.083333
br,leopoldina,Leopoldina,30,,-8.083333,-39.566667
br,leopoldo bulhoes,Leopoldo Bulhões,29,,-16.616667,-48.766667
br,leopoldo de bulhoes,Leopoldo de Bulhões,29,,-16.616667,-48.766667
br,leopoldo goulart,Leopoldo Goulart,15,,-18.583333,-48.233333
br,leopolis,Leópolis,18,,-23.066667,-50.75
br,leque,Leque,13,,-2.516667,-45.183333
br,leria,Leria,04,,-2.516667,-67.333333
br,lesbando goncalves,Lesbando Gonçalves,15,,-17.133333,-41.233333
br,lessa,Lessa,05,,-12.216667,-41.133333
br,letonia,Letônia,27,,-22.116667,-50.616667
br,letras,Letras,30,,-7.833333,-39.9
br,letreiro de cima,Letreiro de Cima,20,,-5.933333,-41.016667
br,letreiro,Letreiro,06,,-7.4,-38.666667
br,letreiro,Letreiro,22,,-6.35,-38.316667
br,letreiro,Letreiro,30,,-8.55,-36.083333
br,leucadia,Leucádia,29,,-18.05,-51.85
br,levergeria,Levergéria,11,,-21.133333,-55.8
br,leverger,Leverger,14,,-15.866667,-56.083333
br,levinopolis,Levinópolis,15,,-15.266667,-44.283333
br,libanesa,Libanesa,04,,-3.783333,-62.15
br,liberata,Liberata,26,,-27.033333,-50.933333
br,liberato gomes,Liberato Gomes,15,,-14.8,-42.883333
br,liberato,Liberato,13,,-4.75,-44.533333
br,liberato,Liberato,24,,-12.633333,-60.966667
br,liberato salzano,Liberato Salzano,23,,-27.583333,-53.066667
br,liberdade,Liberdade,01,,-9.383333,-71.116667
br,liberdade,Liberdade,04,,-2.566667,-67.383333
br,liberdade,Liberdade,05,,-11.966667,-45.016667
br,liberdade,Liberdade,06,,-6.133333,-38.583333
br,liberdade,Liberdade,08,,-20.583333,-41.55
br,liberdade,Liberdade,15,,-22.016667,-44.316667
br,liberdade,Liberdade,17,,-7.133333,-37.216667
br,liberdade,Liberdade,20,,-4.383333,-42.933333
br,liberdade,Liberdade,21,,-21.216667,-41.583333
br,liberdade,Liberdade,23,,-28.2,-53.483333
br,liberdade,Liberdade,27,,-23.55,-46.633333
br,liberdade,Liberdade,30,,-7.616667,-37.35
br,liberia,Libéria,29,,-14.2,-49.15
br,liberlandi,Liberlândi,22,,-5.157778,-37.35
br,licania,Licania,06,,-3.45,-40.2
br,licinio de almeida,Licínio de Almeida,05,,-14.683333,-42.5
br,licuri,Licuri,05,,-12.083333,-41.6
br,lidia rezende,Lidia Rezende,11,,-19.883333,-54.633333
br,lidice,Lídice,21,,-22.833,-44.1921
br,lidio lima,Lídio Lima,11,,-23.25,-54.983333
br,lido,Lido,21,,-22.965431,-43.177858
br,ligeiro alto,Ligeiro Alto,30,,-8.95,-36.933333
br,ligeiro de cima,Ligeiro de Cima,17,,-7.533333,-36.65
br,ligeiro,Ligeiro,18,,-25.753704,-50.144944
br,ligeiro,Ligeiro,20,,-7.8,-41.9
br,light,Light,27,,-23.594078,-47.358195
br,lima campos,Lima Campos,06,,-6.416667,-38.95
br,lima duarte,Lima Duarte,15,13480,-21.85,-43.8
br,lima,Lima,04,,-4.393611,-63.51
br,lima,Lima,06,,-5.25,-38.216667
br,lima,Lima,18,,-25.437586,-48.743244
br,lima,Lima,25,,2.616667,-60.666667
br,limao do curua,Limão do Curuá,03,,.75,-50.15
br,limao,Limão,03,,.75,-50.15
br,limao,Limão,04,,-4.248333,-59.939722
br,limao,Limão,06,,-4.466667,-39.05
br,limao,Limão,08,,-20.95,-40.95
br,limao,Limão,16,,-1.033333,-49.55
br,limao,Limão,17,,-7.483333,-37.7
br,limao,Limão,22,,-5.3,-35.866667
br,limao,Limão,25,,3.933333,-60.5
br,limao,Limão,27,,-23.492827,-46.669158
br,limboso,Limboso,14,,-15.183333,-57
br,limeira,Limeira,05,,-10.85,-40.233333
br,limeira,Limeira,11,,-18.566667,-56.7
br,limeira,Limeira,15,,-18.583333,-41.166667
br,limeira,Limeira,18,,-24.7,-51.65
br,limeira,Limeira,21,,-21.216667,-41.366667
br,limeira,Limeira,23,,-29.35,-53.35
br,limeira,Limeira,26,,-27.05,-48.866667
br,limeira,Limeira,27,289671,-22.561667,-47.402778
br,limeirinha,Limeirinha,27,,-21.416667,-46.683333
br,limeiro,Limeiro,26,,-27.05,-48.866667
br,limirio,Limírio,15,,-18.416667,-48.383333
br,limitao,Limitão,30,,-8.9,-36.8
br,limoeira,Limoeira,02,,-9.733333,-36.516667
br,limoeira,Limoeira,04,,-7.25,-71.05
br,limoeira,Limoeira,11,,-18.566667,-56.7
br,limoeiro de anadia,Limoeiro de Anadia,02,2770,-9.733333,-36.516667
br,limoeiro do ajuru,Limoeiro do Ajuru,16,4109,-1.916667,-49.383333
br,limoeiro do norte,Limoeiro do Norte,06,29450,-5.133333,-38.083333
br,limoeiro,Limoeiro,02,,-9.733333,-36.516667
br,limoeiro,Limoeiro,04,,-6.881944,-71.144444
br,limoeiro,Limoeiro,05,,-10.583333,-39.116667
br,limoeiro,Limoeiro,06,,-5.133333,-38.083333
br,limoeiro,Limoeiro,11,,-21.666667,-54.15
br,limoeiro,Limoeiro,13,,-3.070278,-42.186667
br,limoeiro,Limoeiro,14,,-14.266667,-55.283333
br,limoeiro,Limoeiro,15,,-16.033333,-40.833333
br,limoeiro,Limoeiro,16,,-1.916667,-49.383333
br,limoeiro,Limoeiro,18,,-24.783544,-48.930205
br,limoeiro,Limoeiro,20,,-3.862778,-42.253611
br,limoeiro,Limoeiro,21,,-21.3,-41.966667
br,limoeiro,Limoeiro,22,,-5.475278,-36.052778
br,limoeiro,Limoeiro,24,,-12.333333,-63.316667
br,limoeiro,Limoeiro,27,,-21.566667,-47.7
br,limoeiro,Limoeiro,30,42329,-7.866667,-35.45
br,limoeirro,Limoeirro,27,,-22.583333,-49.35
br,limondeua,Limondeua,16,,-1.166667,-46.233333
br,limo verde,Limo Verde,08,,-20.55,-41.716667
br,limpeza,Limpeza,13,,-6.7,-43.666667
br,limpeza,Limpeza,20,,-3.863889,-42.322778
br,limpo branco,Limpo Branco,17,,-7.966667,-37.05
br,limpo dos mocos,Limpo dos Mocós,28,,-9.833333,-37.65
br,limpo grande,Limpo Grande,14,,-15.733333,-56.166667
br,limpo grande,Limpo Grande,20,,-5.816667,-42.05
br,linda flor,Linda Flor,22,,-5.493056,-36.903333
br,linda,Linda,22,,-5.189167,-36.0975
br,linda rosa,Linda Rosa,05,,-13.383333,-39.75
br,linda vista,Linda Vista,04,,-3.182778,-62.827778
br,linda vista,Linda Vista,29,,-17.05,-49.783333
br,lindeza,Lindeza,06,,-5.483333,-40.3
br,lindeza,Lindeza,20,,-5.3,-42.466667
br,lindoia,Lindóia,11,,-20.883333,-55.166667
br,lindoia,Lindoia,20,,-6.116667,-41.916667
br,lindoia,Lindóia,27,,-22.516667,-46.65
br,lindolfo almeida,Lindolfo Almeida,15,,-20.433333,-46.55
br,lindolfo,Lindolfo,15,,-18.466667,-48.416667
br,lindo,Lindo,06,,-6.166667,-39.733333
br,lingua de vaca,Lingua de Vaca,22,,-5.471667,-36.813333
br,linha 3,Linha 3,23,,-28.4,-53.95
br,linha 40,Linha 40,23,,-29.1084,-51.2175
br,linha 5,Linha 5,18,,-25.4325,-50.7463
br,linha 60,Linha 60,23,,-29.0816,-51.2169
br,linha 7,Linha 7,23,,-29.466667,-53.4
br,linha 8,Linha 8,23,,-28.366667,-53.8
br,linha binda,Linha Binda,26,,-27.25,-51.833333
br,linha blinda,Linha Blinda,26,,-27.25,-51.833333
br,linha cerqueira,Linha Cerqueira,26,,-26.523195,-49.9514
br,linha cinco,Linha Cinco,18,,-25.4325,-50.7463
br,linha c,Linha C,18,,-25.440562,-50.74636
br,linha de austin,Linha de Austin,21,,-22.890501,-43.63236
br,linha floresta,Linha Floresta,18,,-25.1131,-53.8626
br,linha formosa,Linha Formosa,18,,-26.162222,-53.656111
br,linha gaucha,Linha Gaúcha,18,,-26.125278,-53.512778
br,linha goncalves,Linha Gonçalves,18,,-25.971492,-50.19098
br,linha jansen,Linha Jansen,23,,-29.133333,-51.383333
br,linha munhoz,Linha Munhoz,18,,-25.996136,-50.19694
br,linha oitenta,Linha Oitenta,23,,-29.0548,-51.2182
br,linha oito leste,Linha Oito Leste,23,,-28.366667,-53.8
br,linha oito,Linha Oito,23,,-28.366667,-53.8
br,linha ouro verde,Linha Ouro Verde,18,,-25.1107,-53.8867
br,linha panison,Linha Panison,18,,-25.2347,-53.9122
br,linha quarenta,Linha Quarenta,23,,-29.1084,-51.2175
br,linhares,Linhares,08,105084,-19.416667,-40.066667
br,linha santo andrade,Linha Santo Andrade,18,,-25.994955,-50.164396
br,linha sao roque,Linha São Roque,26,,-27.3,-52.016667
br,linha sarandi,Linha Sarandi,18,,-26.037222,-53.512778
br,linha sertaneja,Linha Sertaneja,18,,-26.198333,-53.6125
br,linha sessenta,Linha Sessenta,23,,-29.0816,-51.2169
br,linha sete,Linha Sete,23,,-29.466667,-53.4
br,linha torrens,Linha Torrens,26,,-28.633333,-49.266667
br,linha tres ceste,Linha Três Ceste,23,,-28.4,-53.95
br,linha tres,Linha Três,23,,-28.4,-53.95
br,linha tres oeste,Linha Três Oeste,23,,-28.4,-53.95
br,linha treze,Linha Treze,18,,-25.152,-53.8688
br,linha vacaria,Linha Vacaria,18,,-25.1731,-53.9839
br,lins do vasconcelos,Lins do Vasconcelos,21,,-22.913977,-43.277668
br,lins,Lins,27,69452,-21.666667,-49.75
br,lipo,Lipo,26,,-27.583333,-50.816667
br,lira,Lira,06,,-6.616667,-40.616667
br,lisbao,Lisbão,04,,-.316667,-63.016667
br,lisieh,Lisieh,06,,-4,-40.183333
br,liso,Liso,13,,-6.6,-44.566667
br,literlade,Literlade,20,,-4.383333,-42.933333
br,liveramento do brumado,Liveramento do Brumado,05,,-13.65,-41.833333
br,liverpool,Liverpool,03,,-.333333,-52.366667
br,livramento de tiuma,Livramento de Tiúma,30,,-7.466667,-35.4
br,livramento do brumado,Livramento do Brumado,05,,-13.65,-41.833333
br,livramento do tiuma,Livramento do Tiúma,30,,-7.466667,-35.4
br,livramento,Livramento,02,,-9.25,-36.483333
br,livramento,Livramento,03,,1.066667,-50.766667
br,livramento,Livramento,04,,-7.420833,-58.623889
br,livramento,Livramento,05,19914,-13.65,-41.833333
br,livramento,Livramento,06,,-3.7,-38.966667
br,livramento,Livramento,11,,-19.25,-55.95
br,livramento,Livramento,13,,-1.266667,-45.866667
br,livramento,Livramento,14,,-15.8,-56.366667
br,livramento,Livramento,15,,-21.083333,-44.05
br,livramento,Livramento,16,,-5.233333,-56.183333
br,livramento,Livramento,17,,-7.05,-34.9
br,livramento,Livramento,20,,-4.75,-42.583333
br,livramento,Livramento,22,,-5.616667,-37.55
br,livramento,Livramento,23,,-30.883333,-55.516667
br,livramento,Livramento,25,,3.333333,-61.316667
br,lizarda,Lizarda,31,,-9.630833,-46.533889
br,loanda,Loanda,18,18233,-22.9,-53.166667
br,lobao,Lobão,20,,-5.366667,-42.683333
br,lobato,Lobato,05,,-12.916667,-38.483333
br,lobato,Lobato,18,,-22.983333,-51.95
br,lobo leite,Lôbo Leite,15,,-20.516667,-43.8
br,lobo,Lôbo,11,,-17.9,-54.033333
br,lobo,Lôbo,13,,-1.716667,-45.233333
br,lobo,Lôbo,14,,-14.683333,-54.783333
br,lobo,Lôbo,15,,-15.883333,-46.766667
br,lobo,Lôbo,16,,-8.583333,-49.666667
br,lobo,Lôbo,27,,-22.283333,-47.916667
br,local da antiga colonia sao lourenco,Local da Antiga Colônia São Lourenço,14,,-16.666667,-55.25
br,locos,Locos,11,,-21.35,-57.45
br,lodo,Lôdo,05,,-12.533333,-38.1
br,logoa branca,Logoa Branca,06,,-5.583333,-40.683333
br,logoa da pedra,Logoa da Pedra,30,,-7.783333,-37.8
br,logrador,Logrador,15,,-19.3,-45.1
br,logrador,Logrador,17,,-6.466667,-37.5
br,logradoura,Logradoura,06,,-6.033333,-39.7
br,logradouro de cima,Logradouro de Cima,05,,-9.916667,-39.616667
br,logradouro,Logradouro,06,,-4.166667,-40.1
br,logradouro,Logradouro,15,,-19.3,-45.1
br,logradouro,Logradouro,17,,-6.783333,-38.183333
br,logradouro,Logradouro,22,,-5.333333,-37.5
br,logradouro,Logradouro,28,,-10.266667,-37.316667
br,logradouro,Logradouro,30,,-8.366667,-38.1
br,loiro paco,Loiro Paço,04,,1.366667,-68.683333
br,loiro poco,Loiro Poço,04,,1.366667,-68.683333
br,loisiania,Loisiânia,21,,-22.033333,-41.516667
br,lomba grande,Lomba Grande,23,,-29.75,-51.016667
br,lombardia,Lombardia,05,,-15.883333,-39.533333
br,lombas,Lombas,23,,-29.916667,-50.5
br,lombo,Lombo,27,,-23.102463,-47.844494
br,lona,Lona,11,,-21.25,-56.65
br,londrina,Londrina,18,471836,-23.3,-51.15
br,longos,Longos,20,,-7.483333,-41.65
br,lontra,Lontra,05,,-12.25,-38
br,lontra,Lontra,11,,-20.8,-54.016667
br,lontra,Lontra,15,,-15.9,-44.3
br,lontra,Lontra,16,,-4.383333,-51.916667
br,lontra,Lontra,31,,-7.16,-48.0575
br,lontrao,Lontrão,18,,-25.3271,-50.6609
br,lontras,Lontras,06,,-4.566667,-40.966667
br,lontras,Lontras,26,,-27.1697,-49.5411
br,lopei,Lopeí,18,,-24.8,-53.6
br,lopes,Lopes,05,,-12.083333,-41.1
br,lopes,Lopes,11,,-21.833333,-53.6
br,lopes,Lopes,15,,-20.166667,-41.883333
br,lopes,Lopes,23,,-32.091667,-52.166667
br,lopes,Lopes,27,,-22.383333,-47.483333
br,loredo,Loredo,06,,-6.466667,-38.933333
br,lorena,Lorena,04,,-7.683333,-71.45
br,lorena,Lorena,15,,-16.666667,-41
br,lorena,Lorena,16,,-4.733333,-56.35
br,lorena,Lorena,22,,-5.521944,-37.476944
br,lorena,Lorena,24,,-9.6,-62.116667
br,lorena,Lorena,27,76507,-22.733333,-45.133333
br,lorenz,Lorenz,03,,2.5,-51.666667
br,loreto,Loreto,04,,-.316667,-65.9
br,loreto,Loreto,05,,-12.766667,-38.616667
br,loreto,Loreto,13,,-7.083333,-45.15
br,loreto,Loreto,22,,-6.783333,-37.116667
br,loreto,Loreto,23,,-29.716667,-54.966667
br,loteamento chcaras cruzeiro do sul,Loteamento Chcaras Cruzeiro do Sul,27,,-23.4623,-46.1309
br,loteamento chcaras mont clair,Loteamento Chcaras Mont Clair,27,,-23.2547,-46.2306
br,loteamento colina ii de mainpora,Loteamento Colina II de Mainporã,27,,-23.271237,-46.590608
br,loteamento colina segunda de maripora,Loteamento Colina Segunda de Mariporã,27,,-23.271237,-46.590608
br,loteamento ijal,Loteamento Ijal,27,,-23.2915,-46.0456
br,loteamento jardim ana maria,Loteamento Jardim Ana Maria,27,,-24.736787,-48.118844
br,loteamento jardim barigui,Loteamento Jardim Barigui,18,,-25.432,-48.7461
br,loteamento joao wesley,Loteamento João Wesley,21,,-22.908085,-43.588621
br,loteamento mapua,Loteamento Mapua,21,,-22.926003,-43.387179
br,loteamento miguel cruz,Loteamento Miguel Cruz,27,,-23.2746,-46.2304
br,loteamento parque leao,Loteamento Parque Leão,18,,-25.431538,-48.728292
br,loteamento pontal da saxonia,Loteamento Pontal da Saxônia,26,,-26.9079,-49.062
br,loteamento sao miguel,Loteamento São Miguel,21,,-22.931636,-43.70299
br,loteamento vila imperial,Loteamento Vila Imperial,23,,-29.9081,-50.9042
br,loteamento vila incomager,Loteamento Vila Incomager,27,,-24.515823,-48.111101
br,lote ideal,Lote Ideal,11,,-23.5,-54.566667
br,loucas,Louças,20,,-10.1,-43.9
br,lourdes,Lourdes,11,,-18.65,-56.616667
br,lourdes,Lourdes,26,,-27.083333,-51
br,lourdes,Lourdes,27,,-20.966667,-50.216667
br,lourenco cue,Lourenço Cuê,11,,-23.216667,-55.533333
br,lourenco,Lourenço,02,,-9.366667,-36.366667
br,lourenco,Lourenço,03,,2.5,-51.666667
br,lourenco,Lourenço,15,,-16.016667,-41.65
br,lourenco,Lourenço,18,,-25.829902,-50.1887
br,lourenco preo,Lourenço Prêo,15,,-14.933333,-42.95
br,lourenco velho,Lourenço Velho,15,,-22.366667,-45.316667
br,lourival nunes,Lourival Nunes,08,,-20.216667,-40.333333
br,louro muller,Louro Müller,26,,-28.4,-49.383333
br,louro poco,Louro Poço,04,,.45,-69.05
br,louveira,Louveira,27,31098,-23.066667,-46.966667
br,lovat,Lovat,18,,-23.533333,-51.7
br,loyola,Loyola,08,,-20.783333,-40.6
br,lua cheia,Lua Cheia,01,,-10.566667,-68.816667
br,lua cheia,Lua Cheia,15,,-16.15,-40.25
br,luanda,Luanda,15,,-21.733333,-45.216667
br,luanda,Luanda,18,,-22.9,-53.166667
br,luanda,Luanda,30,,-7.7,-38.383333
br,lua nova,Lua Nova,05,,-14.3,-39.716667
br,lua nova,Lua Nova,16,,-5.116667,-56.633333
br,lucaia,Lucaia,05,,-14.75,-40.533333
br,lucania,Lucânia,01,,-8.116667,-72.816667
br,lucas borges,Lucas Borges,16,,-.883333,-56.083333
br,lucas costa,Lucas Costa,15,,-17.566667,-41.466667
br,lucaslandia,Lucaslândia,14,,-13.254167,-59.8625
br,lucas,Lucas,14,,-13.116667,-55.933333
br,lucas,Lucas,21,,-22.2895,-42.778508
br,lucas,Lucas,23,,-31.783333,-53.366667
br,lucelia,Lucélia,27,14807,-21.733333,-51.016667
br,lucena,Lucena,13,,-9.283333,-45.916667
br,lucena,Lucena,17,,-6.9,-34.866667
br,luciano dos chicotes,Luciano dos Chicotes,06,,-7.433333,-38.85
br,luciano,Luciano,02,,-9.333333,-38.033333
br,luciano,Luciano,15,,-20.683333,-46.583333
br,lucianopolis,Lucianópolis,27,,-22.45,-49.516667
br,lucianos,Lucianos,15,,-19.8,-50.15
br,lucianos,Lucianos,27,,-24.033333,-47.983333
br,luciano veras,Luciano Veras,22,,-5.656667,-37.484722
br,luciara,Luciára,14,,-10.75,-50.566667
br,lucio da luz,Lúcio da Luz,14,,-10.6,-51.35
br,lucios,Lúcios,15,,-22.6002,-45.6345
br,lucios,Lúcios,21,,-22.279682,-42.785642
br,lucrecia,Lucrécia,22,,-6.116667,-37.816667
br,lucrecia,Lucrécia,23,,-30.633333,-53.15
br,lucrecio,Lucrecio,23,,-30.633333,-53.15
br,lucuri,Lucuri,05,,-12.233333,-40.783333
br,ludgero,Ludgéro,30,,-7.483333,-39.8
br,ludovico,Ludovico,21,,-22.116667,-41.316667
br,lufa,Lufa,15,,-17.25,-41.916667
br,lugar combate,Lugar Combate,24,,-10.266667,-62.968056
br,lugar grande,Lugar Grande,20,,-5.883333,-41.133333
br,lugar tira serveja,Lugar Tira Serveja,24,,-10.333333,-62.933333
br,luisa,Luisa,22,,-6.216667,-36.683333
br,luis alves,Luís Alves,26,,-26.733333,-48.95
br,luisana,Luisana,18,,-24.3,-52.283333
br,luis antonio,Luís Antônio,27,,-21.5,-47.683333
br,luis antonio,Luís Antônio,30,,-8.933333,-38.166667
br,luisburgo,Luisburgo,15,,-20.433333,-42.1
br,luis candido,Luis Cândido,15,,-20.583333,-45.383333
br,luis carlos,Luis Carlos,27,,-23.4573,-46.0584
br,luis carlos manso,Luís Carlos Manso,15,,-21.45,-46.066667
br,luis correia,Luís Correia,20,11480,-2.883611,-41.666111
br,luis domingues,Luís Domingues,13,,-1.3,-45.866667
br,luis eugenio,Luís Eugênio,15,,-16.05,-40.233333
br,luis flores,Luís Flores,24,,-11.283333,-65.366667
br,luis gomes,Luís Gomes,22,,-6.416667,-38.383333
br,luis goncalves,Luís Gonçalves,16,,-5.616667,-50.416667
br,luis gonzaga,Luís Gonzaga,15,,-20.233333,-46
br,luisiana,Luisiana,18,,-24.3,-52.283333
br,luisiania,Luisiânia,21,,-22.033333,-41.516667
br,luisiania,Luisiânia,27,,-21.683333,-50.283333
br,luislandia,Luislândia,15,,-16.071667,-44.659167
br,luis,Luís,15,,-14.633333,-44.733333
br,luis,Luís,30,,-8.8,-36.233333
br,luis paulino,Luís Paulino,15,,-21.483333,-45.966667
br,luis pereira,Luís Pereira,30,,-7.95,-38.683333
br,luis pires de minas,Luís Pires de Minas,15,,-16.491667,-44.267778
br,luis prado,Luís Prado,15,,-21.483333,-45.7
br,luis tanare,Luís Tanare,15,,-16.2,-41.516667
br,luis tristao,Luís Tristão,15,,-21.45,-46.516667
br,luis viana,Luís Viana,05,,-8.75,-41.233333
br,luiza de brito,Luíza de Brito,05,,-12.85,-42.016667
br,luiz alves,Luiz Alves,26,,-26.733333,-48.95
br,luiz antonio,Luiz Antonio,27,,-21.55,-47.716667
br,luiz antonio,Luiz Antonio,30,,-8.933333,-38.166667
br,luizburgo,Luizburgo,15,,-20.433333,-42.1
br,luiz correia,Luiz Correia,20,,-2.883611,-41.666111
br,luiz duranto,Luiz Duranto,23,,-29.0339,-51.0466
br,luiz flores,Luiz Flõres,24,,-11.283333,-65.366667
br,luiz gomes,Luiz Gomes,22,,-6.416667,-38.383333
br,luiziania,Luiziânia,27,,-21.683333,-50.283333
br,luiz menegon,Luiz Menegon,23,,-29.0486,-51.1372
br,luiz pereira,Luiz Pereira,15,,-18.95,-44.116667
br,luiz viana,Luiz Viana,05,,-8.75,-41.233333
br,lumiar,Lumiar,21,,-22.366667,-42.2
br,luminarias,Luminárias,15,,-21.5,-44.9
br,luminosa,Luminosa,15,,-22.5814,-45.6351
br,luna,Luna,06,,-5.95,-39.366667
br,lunardelli,Lunardelli,18,,-23,-51.2
br,lunburgo,Lunburgo,15,,-20.433333,-42.1
br,lundiacanga,Lundiacanga,27,,-23.5716,-47.6827
br,lundiara,Lundiara,05,,-14.283333,-42.283333
br,lupercio,Lupércio,27,,-22.416667,-49.8
br,lupionopolis,Lupionópolis,18,,-22.733333,-51.666667
br,lupuna,Lupuna,01,,-9.65,-72.033333
br,lurdes,Lurdes,15,,-21.763889,-43.328889
br,lusitania,Lusitânia,11,,-18.416667,-55.783333
br,lusitania,Lusitânia,24,,-9.133333,-64.183333
br,lusitania,Lusitânia,27,,-21.133333,-48.266667
br,lustosa,Lustosa,05,,-12.2,-38.6
br,lustosa,Lustosa,20,,-4.333333,-42.55
br,lutecia,Lutécia,27,,-22.333333,-50.383333
br,luzeia,Luzéia,04,,-3.316667,-57.666667
br,luzeiro,Luzeiro,01,,-7.833333,-72.683333
br,luzelia,Luzélia,04,,-3.316667,-57.666667
br,luzerna,Luzerna,26,,-27.116667,-51.466667
br,luzia,Luzia,06,,-5.066667,-40.133333
br,luzia,Luzia,20,,-7.416667,-40.8
br,luzia,Lúzia,30,,-7.983333,-36.533333
br,luziania,Luziânia,29,143601,-16.25,-47.933333
br,luzilandia,Luzilândia,08,,-18.7,-40.533333
br,luzilandia,Luzilândia,20,12999,-3.466667,-42.366667
br,luzilandia,Luzilândia,29,,-16.25,-47.933333
br,luzio,Luzio,15,,-18.7,-48.283333
br,luzitana,Luzitana,21,,-21.866667,-41.466667
br,luzitania,Luzitania,11,,-18.416667,-55.783333
br,luzitania,Luzitânia,24,,-9.133333,-64.183333
br,luzitania,Luzitânia,27,,-20.866667,-50.25
br,luz,Luz,15,14396,-19.8,-45.666667
br,luz,Luz,16,,-8.7,-49.616667
br,luz,Luz,23,,-28.633333,-50.85
br,lyndoya,Lyndoya,27,,-22.516667,-46.65
br,mabederi,Mabederi,04,,-7.266667,-65.116667
br,mabedery,Mabedery,04,,-7.266667,-65.116667
br,mabe,Mabé,04,,.75,-67.216667
br,mabideri,Mabideri,04,,-7.266667,-65.116667
br,macabu,Macabu,21,,-22.066667,-41.866667
br,macabuzinho,Macabuzinho,21,,-22.083333,-41.733333
br,macacaria,Macacaria,20,,-3.5675,-42.142222
br,macacas,Macacas,18,,-24.633333,-52.333333
br,macaco branco,Macaco Branco,27,,-24.686856,-48.223039
br,macacoeira,Macacoeira,13,,-1.216667,-46.1
br,macaco,Macaco,05,,-12.466667,-38.833333
br,macaco,Macaco,06,,-3.433333,-39.233333
br,macaco,Macaco,11,,-19.116667,-54.25
br,macaco,Macaco,13,,-10.05,-45.95
br,macaco,Macaco,14,,-14.8,-56.666667
br,macaco,Macaco,15,,-16.183333,-40.8
br,macaco,Macaco,17,,-7.2,-38.166667
br,macaco,Macaco,18,,-25.135212,-48.356261
br,macaco,Macaco,20,,-5.116667,-42.316667
br,macaco,Macaco,21,,-21.983333,-42.266667
br,macaco,Macaco,22,,-6.5,-38.1
br,macaco,Macaco,23,,-32.125,-52.108333
br,macaco-prego,Macaco-Prego,04,,-4.168056,-60.841944
br,macacos,Macacos,02,,-9.666667,-36.683333
br,macacos,Macacos,05,,-12.6,-39.783333
br,macacos,Macacos,06,,-5.316667,-39.883333
br,macacos,Macacos,14,,-14.8,-56.666667
br,macacos,Macacos,15,,-16.316667,-41.9
br,macacos,Macacos,17,,-7.033333,-36.9
br,macacos,Macacos,18,,-24.633333,-52.333333
br,macacos,Macacos,20,,-3.888056,-42.526667
br,macacos,Macacos,22,,-6.35,-37.933333
br,macacos,Macacos,29,,-15.75,-48.316667
br,macacos,Macacos,30,,-7.833333,-37.533333
br,macacu,Macacu,08,,-19.3,-40.133333
br,macado,Macado,25,,1.066667,-60.916667
br,macae,Macaé,21,143031,-22.383333,-41.783333
br,macahe,Macahé,21,,-22.383333,-41.783333
br,macahubas,Macahubas,05,,-13.033333,-42.7
br,macahubas,Macahubas,27,,-20.8,-49.95
br,macahyba,Macahyba,22,,-5.85,-35.35
br,macaia,Macaia,15,,-21.133333,-44.916667
br,macaiba,Macaíba,22,40016,-5.716667,-35.55
br,macajatuba,Macajatuba,13,,-2.483333,-44.15
br,macajuba,Macajuba,05,,-12.15,-40.366667
br,macajuba,Macajuba,13,,-3.97,-43.154444
br,macambara,Macambará,21,,-22.325,-43.526389
br,macambara,Maçambará,23,,-29.133333,-56.05
br,macambira,Macambira,05,,-11.583333,-44.15
br,macambira,Macambira,06,,-3.8,-39.983333
br,macambira,Macambira,13,,-3.074722,-43.415278
br,macambira,Macambira,17,,-7.216667,-38.083333
br,macambira,Macambira,20,,-4.1,-41.95
br,macambira,Macambira,22,,-6.283333,-37.983333
br,macambira,Macambira,28,,-10.666667,-37.533333
br,macambira,Macambira,30,,-8.6,-36.433333
br,macambira velha,Macambira Velha,06,,-4.55,-41.116667
br,macanare,Macanaré,04,,.416667,-67.3
br,macaoca,Macaoca,06,,-4.666667,-39.433333
br,macao,Macao,04,,-7.45,-70.55
br,macao,Macáo,22,,-5.116667,-36.633333
br,macapa,Macapá,03,338937,.033333,-51.05
br,macapa,Macapá,04,,-9.483333,-67.5
br,macapa,Macapá,06,,-7.683333,-39.016667
br,macapa,Macapá,13,,-2.633333,-44.9
br,macapa,Macapá,16,,-1.366667,-47.883333
br,macapa,Macapá,17,,-6.933333,-37.5
br,macapa,Macapá,20,,-2.908889,-41.442222
br,macapa,Macapá,30,,-7.566667,-35.45
br,macaparana,Macaparana,06,,-7.683333,-39.016667
br,macaparana,Macaparana,30,14363,-7.566667,-35.45
br,macapuana,Macapuana,04,,-3.6,-69.366667
br,macarandiba,Maçarandiba,17,,-7.183333,-35.766667
br,macaranduba,Maçaranduba,05,,-13.766667,-39.35
br,macaranduba,Maçaranduba,06,,-7.716667,-38.883333
br,macaranduba,Maçaranduba,17,,-7.183333,-35.766667
br,macaranduba,Maçaranduba,20,,-2.961111,-41.426389
br,macaranduba,Macaranduba,22,,-5.733333,-35.366667
br,macaranduba,Maçaranduba,26,,-26.6,-49.016667
br,macaranduba,Maçaranduba,30,,-8.483333,-36.466667
br,macarani,Macarani,05,,-15.55,-40.4
br,macarau,Macaraú,06,,-4.2,-40.433333
br,macario,Macário,03,,.066667,-51.233333
br,macaroca,Maçaroca,05,,-9.883333,-40.283333
br,macaroca,Maçaroca,25,,-.678889,-61.955833
br,macata,Macatá,26,,-26.366667,-50.983333
br,macatuba,Macatuba,27,16180,-22.516667,-48.683333
br,macauari,Macauari,04,,-4.133333,-57.583333
br,macauary,Macauary,04,,-4.133333,-57.583333
br,macaubal,Macaubal,27,,-20.8,-49.95
br,macauba,Macaúba,05,,-12.65,-40.4
br,macauba,Macauba,11,,-22.183333,-54.516667
br,macauba,Macaúba,13,,-6.65,-44.016667
br,macauba,Macaúba,16,,-5.566667,-49.933333
br,macauba,Macaúba,27,,-20.583333,-49.5
br,macauba,Macaúba,31,,-10.516667,-50.5
br,macaubas,Macaúbas,05,14598,-13.033333,-42.7
br,macaubas,Macaúbas,15,,-20.816667,-46.25
br,macaubas,Macaúbas,27,,-20.583333,-49.5
br,macau,Macau,04,,-7.45,-70.55
br,macau,Macau,22,18070,-5.116667,-36.633333
br,macauzinho,Macáuzinho,22,,-5.148611,-36.605278
br,macava,Macava,06,,-5.166667,-37.916667
br,macavari,Macavari,04,,-4.133333,-57.583333
br,macayo,Maçayó,02,,-9.666667,-35.716667
br,macazeira,Macazeira,05,,-12.333333,-41.033333
br,macedina,Macedina,14,,-16.066667,-52.4
br,macedonia,Macedônia,27,,-20.116667,-50.216667
br,maceio,Maceió,01,,-8.333333,-70.916667
br,maceio,Maceió,02,955010,-9.666667,-35.716667
br,maceio,Maceió,06,,-2.8825,-40.956944
br,maceio,Maceió,21,,-22.91,-43.064167
br,macena,Macena,02,,-9.35,-36.266667
br,macenas,Macenas,13,,-3.869722,-42.803056
br,machacalis,Machacalis,15,,-17.083333,-40.75
br,machadinha,Machadinha,21,,-22.033333,-41.5
br,machadinho,Machadinho,23,,-27.566667,-51.666667
br,machado,Machado,04,,-4.923611,-62.3625
br,machado,Machado,05,,-13.366667,-39.7
br,machado,Machado,06,,-7.516667,-38.683333
br,machado,Machado,08,,-20.1,-41.333333
br,machado,Machado,13,,-6.35,-44.4
br,machado,Machado,15,33003,-21.683333,-45.933333
br,machado,Machado,25,,1.066667,-60.916667
br,machado,Machado,30,,-8.35,-36.583333
br,machado mineiro,Machado Mineiro,15,,-15.616667,-41.4
br,machado portela,Machado Portela,05,,-13.15,-40.75
br,machados,Machados,15,,-21.033333,-47.066667
br,machados,Machados,27,,-21.883333,-51.366667
br,machados,Machados,30,,-7.7,-35.516667
br,machorra,Machorra,11,,-21.983333,-56.483333
br,macieira,Macieira,26,,-26.85,-51.383333
br,maciel,Maciel,04,,-7.4825,-71.154722
br,maciel,Maciel,05,,-12.45,-39.1
br,maciel,Maciel,16,,-4.666667,-56.3
br,maciel,Maciel,18,,-25.561111,-48.405
br,macinha,Macinha,05,,-12.316667,-39
br,macios,Macios,17,,-7.266667,-38.016667
br,macoapani,Macoapani,04,,-2.533333,-65.5
br,maconha,Maconha,17,,-8.166667,-37.133333
br,macoto,Macotó,21,,-21.85,-41.683333
br,macuari,Macuari,04,,-4.133333,-57.583333
br,macuco,Macuco,05,,-14.95,-39.316667
br,macuco,Macuco,15,,-19.633333,-43.5
br,macuco,Macuco,21,,-21.983333,-42.266667
br,macuco,Macuco,27,,-21.716667,-50.133333
br,macucos,Macucos,27,,-21.716667,-50.133333
br,macucu,Macucu,08,,-19.3,-40.133333
br,macuge,Macugê,30,,-7.5,-35.166667
br,macuim,Maçuim,05,,-12.616667,-38.483333
br,macuje,Macujê,30,,-7.5,-35.166667
br,macujo,Macujó,05,,-13.033333,-38.866667
br,macu,Macu,04,,.416667,-69.25
br,macuna,Macunã,13,,-3.632778,-43.093056
br,macunam,Macunam,06,,-3.833333,-38.633333
br,macupim,Macupim,16,,-1.133333,-46.2
br,macuripari,Macuripari,04,,-5.569444,-63.978333
br,macuripary,Macuripary,04,,-5.569444,-63.978333
br,macuripe,Macuripe,04,,-7.083333,-64.6
br,macurure,Macururé,05,,-9.166667,-39.066667
br,macuxiri,Macuxiri,04,,1.766667,-67.283333
br,macuxixiri,Macuxixiri,04,,1.766667,-67.283333
br,madail,Madail,13,,-4.933333,-45.616667
br,madalena,Madalena,02,,-9.716667,-35.9
br,madalena,Madalena,06,,-4.533333,-40.2
br,madalena,Madalena,13,,-4.15,-44.883333
br,madalena,Madalena,27,,-21.066667,-50.933333
br,madeira cortada iii,Madeira Cortada III,13,,-3.293889,-42.320833
br,madeira cortada i,Madeira Cortada I,13,,-3.271667,-42.26
br,madeira cortada,Madeira Cortada,13,,-3.819444,-43.305556
br,madeira,Madeira,13,,-4.3,-42.983333
br,madeira,Madeira,17,,-7.6,-36
br,madeira,Madeira,20,,-3.486389,-42.5075
br,madeira,Madeira,24,,-10.333333,-65.333333
br,madeira,Madeira,30,,-7.583333,-37.55
br,madeira ricota,Madeira Ricota,27,,-22.616,-45.5756
br,madeireira dal'pai,Madeireira Dal'Pai,18,,-25.5186,-48.9995
br,madeiro,Madeiro,06,,-3.483333,-40.266667
br,maderia nova,Maderia Nova,30,,-7.666667,-39.583333
br,madia,Madia,04,,.916667,-67.05
br,madiberi,Madiberi,04,,-7.266667,-65.116667
br,madragoa,Madragoa,13,,-1.783333,-45.05
br,madre de deus de minas,Madre de Deus de Minas,15,,-21.483333,-44.333333
br,madre de deus,Madre de Deus,05,14887,-12.733333,-38.616667
br,madre-de-deus,Madre-de-Deus,13,,-6.566667,-43.45
br,madre de deus,Madre de Deus,15,,-21.483333,-44.333333
br,madre de deus,Madre de Deus,30,,-8.15,-36.366667
br,madre deus,Madre Deus,13,,-6.566667,-43.45
br,madre,Madre,13,,-6.383333,-43.383333
br,madre,Madre,26,,-28.533333,-48.933333
br,madresilva,Madresilva,21,,-22.233333,-41.95
br,madressilva,Madressilva,21,,-22.233333,-41.95
br,madrugao,Madrugão,05,,-14.25,-43.75
br,madureira,Madureira,21,,-22.881023,-43.339976
br,mae d'agua,Mae d'Agua,17,,-7.25,-37.433333
br,mae d'agua,Mae d'Agua,30,,-8.566667,-38.5
br,mae de deus,Mãe de Deus,06,,-5.55,-40.8
br,mae dos homens,Mãe dos Homens,15,,-18.116667,-42.616667
br,mae luzia,Mãe Luzia,26,,-28.7,-49.466667
br,mae maria,Mãe Maria,16,,-5.25,-48.916667
br,maetinga,Maetinga,05,,-14.666667,-41.5
br,mafra,Mafra,26,40081,-26.1181,-49.8023
br,mafrense,Mafrense,20,,-8.35,-41.066667
br,magalhaes bastos,Magalhães Bastos,21,,-22.876001,-43.410665
br,magalhaes de almeida,Magalhães de Almeida,13,,-3.4,-42.2
br,magalhaes,Magalhães,05,,-12.35,-38.966667
br,magalhaes,Magalhães,11,,-18.233333,-55.35
br,magarai,Magaraí,08,,-20.166667,-40.466667
br,magarca,Magarça,21,,-22.944358,-43.599244
br,magdalena,Magdalena,06,,-4.533333,-40.2
br,magda,Magda,27,,-20.616667,-50.233333
br,mage,Magé,21,216342,-22.655556,-43.015278
br,magno,Magno,21,,-22.872778,-43.34
br,magro,Magro,20,,-6.6,-41.8
br,maguari,Maguari,04,,-5.666389,-63.847778
br,maguari,Maguari,16,,-6.633333,-51.883333
br,maguari,Maguari,17,,-7.133333,-35.1
br,magu,Magu,13,,-2.929167,-41.910833
br,maia,Maia,06,,-6.516667,-38.7
br,maia,Maia,17,,-6.8,-35.566667
br,maia,Maia,27,,-22,-52.066667
br,maiauata,Maiauatá,16,,-1.85,-49.033333
br,mailasqui,Mailasqui,27,,-23.552919,-47.086823
br,mainart,Mainart,15,,-20.466667,-43.333333
br,maioba,Maioba,06,,-2.5,-44.15
br,maiquinique,Maiquinique,05,,-15.616667,-40.25
br,mairi,Mairi,05,13475,-11.716667,-40.133333
br,mairinque,Mairinque,15,,-17.783333,-40.483333
br,mairinque,Mairinque,27,44457,-23.544368,-47.183467
br,mairipora,Mairiporã,27,54417,-23.322628,-46.586935
br,mairipotaba,Mairipotaba,29,,-17.3,-49.466667
br,majaratuba,Majaratuba,04,,.183333,-63.966667
br,maje,Majé,21,,-22.655556,-43.015278
br,maje,Majé,30,,-8.533333,-36.733333
br,major ezequiel,Major Ezequiel,15,,-20.016667,-42.983333
br,major isidoro,Major Isidoro,02,8507,-9.533333,-37
br,major izidoro,Major Izidoro,02,,-9.533333,-37
br,majorlandia,Majorlândia,06,,-4.55,-37.666667
br,major,Major,26,,-27.416667,-48.95
br,major moreno,Major Moreno,14,,-15.533333,-54.8
br,major oscar,Major Oscar,18,,-24.616667,-53.283333
br,major prado,Major Prado,27,,-20.883333,-50.5
br,major sales,Major Sales,22,,-6.4,-38.316667
br,major simplicio,Major Simplício,06,,-4.566667,-40.4
br,major vieira,Major Vieira,26,,-26.316667,-50.333333
br,majuria,Majuriã,04,,-7.5,-64.916667
br,malacacheta,Malacacheta,15,8820,-17.833333,-42.083333
br,malacacheta,Malacacheta,25,,2.7,-60.383333
br,malaquias,Malaquias,22,,-5.333333,-37.533333
br,malaquias,Malaquias,25,,3.333333,-61.1
br,malaripo,Malaripo,16,,.766667,-54.25
br,mal assombrado,Mal Assombrado,22,,-5.9175,-36.114167
br,mal da areia,Mal da Areia,05,,-14.65,-43.333333
br,male,Malé,18,,-25.916667,-50.833333
br,maleta,Maleta,05,,-9.35,-41.9
br,maleta,Maleta,11,,-19.433333,-57.6
br,malet,Malét,18,,-25.916667,-50.833333
br,malhada alta,Malhada Alta,20,,-7.233333,-40.75
br,malhada bonita,Malhada Bonita,05,,-12.016667,-39.683333
br,malhada bonita,Malhada Bonita,30,,-7.783333,-39.633333
br,malhada branca,Malhada Branca,30,,-8.516667,-37.1
br,malhada cortada,Malhada Cortada,30,,-7.983333,-38.3
br,malhada da areia,Malhada da Areia,05,,-13.216667,-41.783333
br,malhada da areia,Malhada da Areia,06,,-7.633333,-38.816667
br,malhada da areia,Malhada da Areia,20,,-3.828889,-42.603611
br,malhada da aroeira,Malhada da Aroeira,06,,-6.533333,-38.766667
br,malhada da aroeira,Malhada da Aroeira,17,,-7.483333,-38.6
br,malhada da barra,Malhada da Barra,20,,-10.416667,-45.216667
br,malhada da cruz,Malhada da Cruz,22,,-6.15,-36.383333
br,malhada da espera,Malhada da Espera,17,,-7.2,-37.583333
br,malhada da jurema,Malhada da Jurema,05,,-10.3,-38.583333
br,malhada da laje,Malhada da Laje,02,,-9.066667,-37.383333
br,malhada da onca,Malhada da Onça,05,,-13.816667,-44.433333
br,malhada d'areia,Malhada d'Areia,06,,-5.383333,-39.15
br,malhada da roca,Malhada da Roca,17,,-7.3,-36.383333
br,malhada das pedras,Malhada das Pedras,13,,-3.558056,-42.587222
br,malhada de areia,Malhada de Areia,22,,-6.65,-37.483333
br,malhada de baixo,Malhada de Baixo,20,,-3.623611,-42.231944
br,malhada de boi,Malhada de Boi,06,,-6.166667,-38.616667
br,malhada de cima,Malhada de Cima,20,,-7.433333,-40.816667
br,malhada de fora,Malhada de Fora,20,,-6.55,-42.7
br,malhada de padre,Malhada de Padre,05,,-14.383333,-41.9
br,malhada de pedra,Malhada de Pedra,05,,-14.383333,-41.9
br,malhada de pedra,Malhada de Pedra,20,,-3.988889,-42.381944
br,malhada de pedra,Malhada de Pedra,30,,-8.6,-38.483333
br,malhada do angico,Malhada do Angico,22,,-6.7,-36.75
br,malhada do bezerro,Malhada do Bezerro,17,,-6.633333,-38.25
br,malhada do boi,Malhada do Boi,30,,-8.25,-38.016667
br,malhada do cordeiro,Malhada do Cordeiro,22,,-6.383333,-36.616667
br,malhada do cosme,Malhada do Cosme,30,,-8.833333,-36.733333
br,malhada do ferreira,Malhada do Ferreira,20,,-6.9,-41.45
br,malhada do juazeiro,Malhada do Juàzeiro,22,,-5.568889,-36.707778
br,malhada do meio,Malhada do Meio,20,,-3.8,-42.05
br,malhada do rio,Malhada do Rio,22,,-5.974444,-36.009167
br,malhada do saco,Malhada do Saco,30,,-9.05,-37.966667
br,malhada do sal,Malhada do Sal,05,,-8.966667,-38.533333
br,malhada dos bois,Malhada dos Bois,28,,-10.333333,-36.933333
br,malhada dos cavalos,Malhada dos Cavalos,13,,-3.434444,-42.571111
br,malhada funda,Malhada Funda,06,,-6.933333,-38.866667
br,malhada grande,Malhada Grande,05,,-12.85,-41.85
br,malhada grande,Malhada Grande,06,,-4.083333,-40.316667
br,malhada grande,Malhada Grande,17,,-7.316667,-38.15
br,malhada grande,Malhada Grande,20,,-3.8525,-42.653333
br,malhada grande,Malhada Grande,30,,-7.716667,-38.85
br,malhada,Malhada,02,,-9.483333,-37.966667
br,malhada,Malhada,05,,-12.083333,-38.783333
br,malhada,Malhada,06,,-3.833333,-38.833333
br,malhada,Malhada,13,,-3.470833,-42.471389
br,malhada,Malhada,17,,-6.633333,-38.416667
br,malhada,Malhada,20,,-3.672222,-42.395278
br,malhada,Malhada,29,,-13.3,-46.583333
br,malhada,Malhada,30,,-7.583333,-39.633333
br,malhada,Malhada,31,,-11.933333,-47.066667
br,malhada nova,Malhada Nova,05,,-10.083333,-38.066667
br,malhada real,Malhada Real,20,,-7.083333,-41.983333
br,malhada redonda,Malhada Redonda,17,,-7.083333,-38.433333
br,malhada redonda,Malhada Redonda,22,,-5.943889,-37.256389
br,malhadas,Malhadas,05,,-12.516667,-38.016667
br,malhada vermelha,Malhada Vermelha,05,,-10.683333,-37.866667
br,malhada vermelha,Malhada Vermelha,06,,-5.566667,-38.533333
br,malhada vermelha,Malhada Vermelha,20,,-6.416667,-42.866667
br,malhada vermelha,Malhada Vermelha,30,,-7.933333,-38.1
br,malhada vermerha,Malhada Vermerha,17,,-7.55,-38.133333
br,malhadinha,Malhadinha,05,,-13.983333,-41.766667
br,malhadinha,Malhadinha,06,,-5.283333,-39.533333
br,malhadinha,Malhadinha,13,,-3.246111,-42.08
br,malhadinha,Malhadinha,17,,-7.866667,-37.033333
br,malhadinha,Malhadinha,20,,-6.533333,-42.116667
br,malhadinha,Malhadinha,22,,-5.611944,-36.044722
br,malhadinha,Malhadinha,30,,-8.133333,-37.35
br,malhadinho,Malhadinho,15,,-15.35,-44.15
br,malhado,Malhado,20,,-3.394722,-42.104167
br,malhador,Malhador,28,5574,-10.65,-37.3
br,malha fria,Malha Fria,30,,-7.716667,-38.633333
br,malheiro,Malheiro,22,,-5.435278,-36.845278
br,malibu,Malibu,21,,-23.00296,-43.396932
br,malica,Maliça,20,,-7.983333,-45.233333
br,malicia,Malícia,13,,-4.466667,-43.283333
br,malicia,Malícia,15,,-15.9,-40.933333
br,malicia,Malícia,20,,-3.736944,-42.485
br,malicia,Malicia,30,,-7.916667,-39.083333
br,mallet,Mallet,18,,-25.4,-52.233333
br,maloca acai,Maloca Acaí,04,,1.115556,-69.777778
br,maloca apuii,Maloca Apuií,04,,-.1,-65.083333
br,maloca arara,Maloca Arara,04,,1.065,-69.301667
br,maloca araripira,Maloca Araripirá,04,,1.184444,-69.086944
br,maloca barrigudo,Maloca Barrigudo,04,,-4.126111,-61.127778
br,maloca caiabi,Maloca Caiabi,14,,-11.366667,-55.533333
br,maloca capi ponta,Maloca Capi Ponta,04,,1.216667,-69.133333
br,maloca caruru,Maloca Caruru,04,,1.089167,-69.313056
br,maloca cipo poco,Maloca Cipó Poço,04,,1.215,-69.384444
br,maloca de barro,Maloca de Barro,25,,4.216667,-60.8
br,maloca de indios,Maloca de Índios,14,,-11.883333,-58.2
br,maloca de indios,Maloca de Índios,24,,-9.683333,-64.983333
br,maloca de indius,Maloca de Indius,24,,-9.683333,-64.983333
br,maloca do baruema,Maloca do Baruema,16,,-8.083333,-54.616667
br,maloca do barurema,Maloca do Barurema,16,,-8.083333,-54.616667
br,maloca do borurema,Maloca do Borurema,16,,-8.083333,-54.616667
br,maloca do capieri,Maloca do Capieri,16,,-7.366667,-57.4
br,maloca do chico,Maloca do Chico,04,,.15,-69
br,maloca do goncalo,Maloca do Gonçalo,16,,-7.766667,-57.433333
br,maloca do joao ferreira,Maloca do João Ferreira,14,,-14.266667,-57.333333
br,maloca dos indios,Maloca dos Índios,24,,-9.683333,-64.983333
br,maloca dos urucuianas,Maloca dos Urucuianas,03,,1.45,-53.916667
br,maloca foz do querari,Maloca Foz do Querari,04,,1.090278,-69.833889
br,maloca iauarete ponta,Maloca Iauaretê Ponta,04,,1.122778,-69.73
br,maloca jacare,Maloca Jacaré,04,,1.042778,-69.4125
br,maloca jandu,Maloca Jandu,04,,1.079444,-69.306667
br,maloca japu,Maloca Japu,04,,1.0575,-69.279444
br,maloca jauarete poco,Maloca Jauaretê Poço,04,,1.203611,-69.297778
br,maloca jiboia,Maloca Jibóia,04,,1.226667,-69.502778
br,maloca jibora,Maloca Jibóra,04,,1.226667,-69.502778
br,maloca ji ponta,Maloca Ji Ponta,04,,1.0425,-69.235278
br,maloca joao ferreira,Maloca João Ferreira,14,,-14.266667,-57.333333
br,maloca jutica,Maloca Jutica,04,,1.078889,-69.476389
br,maloca macu,Maloca Macu,25,,3.683333,-63.716667
br,maloca,Maloca,01,,-10.8,-70.133333
br,maloca,Maloca,04,,-3.35,-63.55
br,maloca,Maloca,16,,-3.783333,-51.783333
br,maloca,Maloca,24,,-9.683333,-64.983333
br,maloca mandurucu,Maloca Mandurucu,04,,-7.6,-58.15
br,maloca matapi,Maloca Matapi,04,,1.086111,-69.363056
br,maloca mundurucu,Maloca Mundurucu,14,,-8.15,-58.216667
br,maloca mundurucus,Maloca Mundurucus,14,,-8.15,-58.216667
br,maloca pacu,Maloca Pacu,04,,1.083889,-69.827222
br,maloca periquito,Maloca Periquito,04,,1.059444,-69.253611
br,maloca ponta de bacaba,Maloca Ponta de Bacaba,04,,1.085,-69.804167
br,maloca puraque ponta,Maloca Puraque Ponta,04,,1.083889,-69.307222
br,maloca repy,Maloca Repy,03,,1.766667,-54.266667
br,maloca salamaim,Maloca Salamaim,24,,-12.25,-61.066667
br,malocas caiabi,Malocas Caiabí,14,,-11.366667,-55.533333
br,maloca taina,Maloca Taina,04,,1.1025,-69.648333
br,maloca tapira geral,Maloca Tapira Geral,04,,1.085278,-69.372222
br,maloca taracua,Maloca Taracuá,04,,1.096389,-69.6625
br,maloca timbe,Maloca Timbé,16,,-3.033333,-47.75
br,maloca uacari,Maloca Uacari,04,,1.224444,-69.350556
br,maloca velha,Maloca Velha,16,,-3.783333,-51.783333
br,malta,Malta,17,,-6.9,-37.516667
br,maltide,Maltide,08,,-20.566667,-40.816667
br,malu,Malu,18,,-23.666667,-52.383333
br,ma luz,Má Luz,26,,-26.166667,-48.533333
br,malva do meio,Malva do Meio,13,,-3.739444,-43.257778
br,malva,Malva,13,,-3.723889,-43.270833
br,mamanguape,Mamanguape,17,27607,-6.833333,-35.116667
br,mamao,Mamão,20,,-7,-40.633333
br,mamata,Mamata,05,,-12.2,-39.65
br,mambai,Mambaí,29,,-14.466667,-46.116667
br,mambore,Mamborê,18,,-24.3,-52.533333
br,mambucaba,Mambucaba,21,,-23.016667,-44.516667
br,mambuquinha,Mambuquinha,15,,-20.85,-46.6
br,mambure,Mamburê,18,,-24.3,-52.533333
br,mamede,Mamede,13,,-3.135,-42.901944
br,mamede,Mamede,20,,-4.416667,-42.866667
br,mameluca,Mameluca,06,,-7.683333,-39.25
br,mameluco,Mameluco,30,,-7.666667,-38.7
br,mamia,Mamiá,04,,-4.016667,-62.866667
br,mamoeiro,Mamoeiro,06,,-6.6,-39.45
br,mamoeiro,Mamoeiro,20,,-4.433333,-41.5
br,mamoeiro,Mamoeiro,30,,-7.966667,-38.933333
br,mamoes,Mamões,20,,-7.066667,-40.566667
br,mamoi,Mamoí,13,,-5.55,-45.533333
br,mamona,Mamona,15,,-15.516667,-41.783333
br,mamonas,Mamonas,05,,-12.766667,-42.733333
br,mamonas,Mamonas,15,,-15.133333,-42.966667
br,mamonas,Mamonas,20,,-7.683333,-41.116667
br,mamoneiro,Mamoneiro,15,,-14.8,-44.483333
br,mamore,Mamoré,24,,-10.816667,-65.333333
br,mamoria,Mamoriá,04,,-7.516667,-66.3
br,mamoria petropolis,Mamoriá Petropolis,04,,-7.516667,-66.3
br,mamori,Mamori,04,,-1.633333,-67.666667
br,mamory,Mamory,04,,-1.633333,-67.666667
br,mamparra,Mamparra,27,,-24.25,-47.916667
br,mamui,Mamuí,13,,-3.023889,-42.347222
br,manaca,Manacá,06,,-6.333333,-40.533333
br,manaca,Manacá,30,,-7.833333,-40.316667
br,manacanau,Manacanaú,22,,-5.372222,-37.1475
br,manacapuru,Manacapuru,04,52460,-3.3,-60.616667
br,manairama,Manairama,22,,-6.7,-36.95
br,manaira,Manaíra,17,4913,-7.7,-38.166667
br,mana,Mana,02,,-9.416667,-36.633333
br,manaos,Manáos,04,,-3.113333,-60.025278
br,manaparu,Manaparu,20,,-6.883333,-40.983333
br,manaquery,Manaquery,04,,-3.316667,-60.35
br,manaquiri,Manaquiri,04,9986,-3.316667,-60.35
br,manari,Manari,30,,-8.816667,-37.583333
br,manauara,Manauara,03,,.283333,-51.166667
br,manaus,Manaus,04,1598227,-3.113333,-60.025278
br,manaus,Manaus,13,,-1.5,-46.183333
br,mancio lima,Mâncio Lima,01,7086,-7.616667,-72.9
br,mandacaia,Mandaçaia,18,,-24.333333,-50.666667
br,mandacaia,Mandaçaia,30,,-8.1,-36.266667
br,mandacaio,Mandaçaio,18,,-24.333333,-50.666667
br,mandacaru,Mandacaru,02,,-9.483333,-36.733333
br,mandacaru,Mandacaru,05,,-12.55,-39.683333
br,mandacaru,Mandacaru,06,,-6.266667,-38.8
br,mandacaru,Mandacaru,13,,-2.6,-42.7
br,mandacaru,Mandacaru,17,,-7.466667,-38.333333
br,mandacaru,Mandacarú,20,,-6.35,-41.4
br,mandacaru,Mandacaru,22,,-6.366667,-38.15
br,mandacaru,Mandacaru,30,,-8.333333,-38.016667
br,mandaguacu,Mandaguaçu,18,14866,-23.333333,-52.083333
br,mandaguari,Mandaguari,15,,-21.516667,-45.716667
br,mandaguari,Mandaguari,18,38239,-23.533333,-51.7
br,mandai,Mandai,13,,-4.933333,-45.616667
br,mandala,Mandala,21,,-23.003497,-43.375252
br,mandani,Mandani,11,,-23.233333,-55.45
br,mandante,Mandante,30,,-7.916667,-38.566667
br,mandassaia,Mandassáia,30,,-8.1,-36.266667
br,mandembo,Mandembo,15,,-20.666667,-45.883333
br,mandicununga,Mandiçununga,27,,-23.102881,-47.69301
br,mandihy,Mandihy,04,,-4.4625,-59.796111
br,mandii,Mandii,04,,-4.4625,-59.796111
br,mandim,Mandim,30,,-9.166667,-38.083333
br,mandiocal,Mandiocal,05,,-13.25,-41.616667
br,mandioca,Mandioca,04,,-4.029722,-60.613056
br,mandioca,Mandioca,13,,-3.905,-43.468889
br,mandiqueira,Mandiqueira,21,,-22.083333,-41.566667
br,mandiquera,Mandiquera,21,,-22.083333,-41.566667
br,mandiqui,Mandiqui,04,,-4.4625,-59.796111
br,mandira,Mandira,27,,-24.993569,-48.038232
br,mandirituba,Mandirituba,18,,-25.7792,-49.3258
br,mandiroba,Mandiroba,05,,-14.483333,-43.05
br,mandiu,Mandiú,27,,-20.65,-47.55
br,manduca,Manduca,25,,2.099914,-59.75621
br,manducas,Manducas,18,,-25.55186,-50.555967
br,manduira,Manduira,18,,-25.462032,-48.798487
br,mandu,Mandu,05,,-12.033333,-38.583333
br,mandu,Mandu,17,,-7.083333,-38.233333
br,mandu,Mandu,27,,-22.9,-45.516667
br,manduri,Manduri,27,,-23.016667,-49.316667
br,mandury,Mandury,27,,-23.016667,-49.316667
br,maneco,Maneco,11,,-22.1,-55.983333
br,maneco rondon,Maneco Rondon,14,,-13.65,-58.3
br,mangaba,Mangaba,11,,-20.216667,-56.116667
br,mangaba,Mangaba,13,,-3.861667,-43.272222
br,mangaba,Mangaba,20,,-3.812778,-42.525833
br,mangabeira,Mangabeira,05,,-12.05,-41.9
br,mangabeira,Mangabeira,06,,-3.666667,-38.75
br,mangabeira,Mangabeira,13,,-3.818611,-43.412778
br,mangabeira,Mangabeira,16,,-2.55,-49.583333
br,mangabeira,Mangabeira,20,,-5.7,-42.683333
br,mangabeira,Mangabeira,22,,-5.833333,-35.3
br,mangabeira,Mangabeira,29,,-13.2,-46.566667
br,mangabeira,Mangabeira,31,,-11.9,-47.233333
br,mangabeira velha,Mangabeira Velha,13,,-3.194167,-43.147778
br,mangabeirinha,Mangabeirinha,13,,-3.299167,-43.228333
br,mangai,Mangaí,11,,-23.233333,-55.45
br,mangalatiba,Mangalatiba,21,,-22.9609,-44.0402
br,mangalo,Mangalô,05,,-12.15,-38.466667
br,manga,Manga,03,,3.733333,-51.716667
br,manga,Manga,05,,-11.466667,-44
br,manga,Manga,06,,-4.416667,-38.883333
br,manga,Manga,11,,-19.233333,-57.216667
br,manga,Manga,13,,-3.516667,-43.95
br,manga,Manga,14,,-15.233333,-59.966667
br,manga,Manga,15,11733,-14.766667,-43.933333
br,manga,Manga,20,,-6.783333,-43.016667
br,manga nova,Manga Nova,30,,-7.033333,-37.716667
br,mangarahy,Mangarahy,08,,-20.166667,-40.466667
br,mangarai,Mangaraí,08,,-20.166667,-40.466667
br,mangarataia,Mangarataia,04,,1.086389,-66.841111
br,mangarate,Mangarate,27,,-20.4,-49.316667
br,mangaratiba,Mangaratiba,21,27023,-22.9609,-44.0402
br,mangaratu,Mangaratu,27,,-20.4,-49.316667
br,mangola,Mangolã,05,,-12.15,-38.466667
br,manguaba,Manguaba,02,,-9.6,-35.933333
br,manguairinha,Manguairinha,18,,-25.95,-52.15
br,manguari,Manguari,04,,-1.605556,-69.268889
br,manguba,Manguba,06,,-3.916667,-38.616667
br,mangueira da pedra,Mangueira da Pedra,23,,-30.216667,-51.8
br,mangueira de pedra,Mangueira de Pedra,23,,-30.516667,-55.616667
br,mangueira ii,Mangueira II,13,,-3.158056,-43.122222
br,mangueira i,Mangueira I,13,,-3.226111,-43.417778
br,mangueiral,Mangueiral,21,,-22.86437,-43.480205
br,mangueira,Mangueira,05,,-12.05,-38.3
br,mangueira,Mangueira,11,,-21.716667,-53.5
br,mangueira,Mangueira,13,,-3.033333,-43.033333
br,mangueira,Mangueira,15,,-15.2,-41.75
br,mangueira,Mangueira,16,,-2.883333,-46.65
br,mangueira,Mangueira,20,,-5.35,-42.316667
br,mangueira,Mangueira,21,,-21.316667,-41.416667
br,mangueira,Mangueira,23,,-32.183333,-52.166667
br,mangueira,Mangueira,25,,3.733333,-60.466667
br,mangueiras,Mangueiras,16,,-5.333333,-49.133333
br,mangueiras,Mangueiras,21,,-22.549167,-43.578611
br,mangueirinha,Mangueirinha,18,,-25.95,-52.15
br,mangue,Mangue,13,,-1.15,-45.716667
br,mangue,Mangue,30,,-9.1,-36.266667
br,manguenza caboclo,Manguenza Cabôclo,17,,-7.483333,-37.983333
br,manguenza,Manguenza,17,,-7.366667,-37.733333
br,mangue secco,Mangue Secco,05,,-11.466667,-37.366667
br,mangue seco,Mangue Sêco,05,,-11.466667,-37.366667
br,mangue seco,Mangue Seco,06,,-2.841944,-40.553611
br,manguinho,Manguinho,05,,-11.316667,-41.1
br,manguinhos,Manguinhos,05,,-12.9,-38.616667
br,manguinhos,Manguinhos,08,,-20.183333,-40.2
br,manguinhos,Manguinhos,21,,-21.4,-41
br,mangunca,Mangunça,13,,-1.616667,-44.666667
br,manha,Manhã,31,,-12.716667,-46.4
br,manhuacu,Manhuaçu,15,54608,-20.25,-42.033333
br,manhuassu,Manhuassú,15,,-20.1,-41.933333
br,manhumirim,Manhumirim,15,15544,-20.366667,-41.95
br,maniacu,Maniaçu,05,,-13.85,-42.433333
br,maniassu,Maniassu,05,,-13.85,-42.433333
br,manibu,Manibu,06,,-4.8,-37.266667
br,manica,Manica,05,,-11.416667,-38.45
br,manicobal,Maniçobal,30,,-7.866667,-38.766667
br,manicoba,Maniçoba,05,,-9.25,-40.3
br,manicoba,Maniçoba,06,,-6.1,-38.55
br,manicoba,Maniçoba,17,,-6.65,-37.816667
br,manicoba,Manicoba,22,,-5.659444,-36.063333
br,manicoba,Maniçoba,30,,-8.25,-36.1
br,manicore,Manicoré,04,14058,-5.812222,-61.2975
br,manimbu,Manimbu,02,,-10.166667,-36.366667
br,manino,Manino,20,,-7.2,-40.633333
br,manissobal,Manissobal,30,,-7.866667,-38.766667
br,manituba,Manituba,06,,-5.216667,-39.566667
br,maniva,Maniva,21,,-21.4,-41.15
br,manjericao,Manjericão,22,,-5.941389,-36.329444
br,manoel alexandre,Manoel Alexandre,06,,-6.483333,-39.183333
br,manoel borba,Manoel Borba,30,,-7.583333,-35.5
br,manoel branco,Manoel Branco,14,,-8.266667,-58.1
br,manoel cardozo,Manoel Cardozo,16,,-7.666667,-57.583333
br,manoel da hora,Manoel da Hora,30,,-8.366667,-36.15
br,manoel de freitas,Manoel de Freitas,23,,-29.05,-55.033333
br,manoel de mato,Manoel de Mato,17,,-7.65,-37.916667
br,manoel dias,Manoel Dias,06,,-3.75,-40.016667
br,manoel dias,Manoel Dias,22,,-6.016667,-36.733333
br,manoel dos santos,Manoel dos Santos,16,,-1.183333,-47.016667
br,manoel ferreira,Manoel Ferreira,06,,-5.916667,-40.65
br,manoel lopes,Manoel Lopes,13,,-3.8675,-43.393056
br,manoel,Manoel,24,,-11.283333,-65.366667
br,manoel mororo,Manoel Mororó,06,,-7.35,-38.933333
br,manoel pereira,Manoel Pereira,05,,-12.316667,-40.533333
br,manoel raimundo,Manoel Raimundo,20,,-3.799167,-42.653333
br,manoelsinho,Manoelsinho,16,,-7.35,-54.85
br,manoel soares,Manoel Soares,30,,-7.633333,-37.683333
br,manoel thomaz,Manoel Thomaz,14,,-8.85,-60.7
br,manoel tomaz,Manoel Tomaz,14,,-8.85,-60.7
br,manoel urbano,Manoel Urbano,01,4066,-8.883333,-69.3
br,manoel viana,Manoel Viana,23,,-29.583333,-55.483333
br,manos,Manos,04,,-3.113333,-60.025278
br,mansao,Mansão,05,,-13.483333,-40.633333
br,mansidao,Mansidão,05,,-10.716667,-44.033333
br,mansinha,Mansinha,06,,-7.066667,-38.866667
br,mansinha,Mansinha,30,,-8.366667,-37.616667
br,mansinha,Mansinha,31,,-9.476667,-47.172778
br,mansinho,Mansinho,06,,-5.8,-38.133333
br,mansinho,Mansinho,13,,-3.716111,-42.778611
br,mansinho,Mansinho,20,,-5.133333,-41.683333
br,manso,Manso,13,,-5.55,-45.533333
br,mantena,Mantena,15,18715,-18.783333,-40.983333
br,manteninha,Manteninha,08,,-18.883333,-41.1
br,mantenopolis,Mantenópolis,08,8547,-18.883333,-41.1
br,mantiqueira,Mantiqueira,15,,-21.95,-44.183333
br,mantiqueira,Mantiqueira,21,,-22.083333,-41.566667
br,mantiqueira,Mantiqueira,27,,-23.371654,-46.573866
br,mantiqueira,Mantiqueira,30,,-7.75,-38.833333
br,manto,Manto,06,,-6.35,-40.016667
br,manuel andrade,Manuel Andrade,15,,-20.733333,-46.65
br,manuel barros,Manuel Barros,15,,-18.266667,-41.666667
br,manuel-borba,Manuel-Borba,30,,-7.583333,-35.5
br,manuel botelho,Manuel Botelho,31,,-10.733333,-48.95
br,manuel branco,Manuel Branco,14,,-8.266667,-58.1
br,manuel cabra,Manuel Cabra,05,,-13.566667,-41.85
br,manuel cantulina,Manuel Cantulina,15,,-16.483333,-41.816667
br,manuel cardoso,Manuel Cardoso,16,,-7.666667,-57.583333
br,manuel costa,Manuel Costa,23,,-30.85,-55.7
br,manuel da hora,Manuel da Hora,30,,-8.366667,-36.15
br,manuel da silva,Manuel da Silva,15,,-20.866667,-46.666667
br,manuel de morais,Manuel de Morais,21,,-22.033333,-42.15
br,manuel domingues,Manuel Domingues,15,,-21.25,-46.05
br,manuel duarte,Manuel Duarte,21,,-22.085,-43.558611
br,manuel dutra,Manuel Dutra,15,,-21.016667,-46.8
br,manuel emidio,Manuel Emídio,15,,-16.233333,-40.05
br,manuel emidio,Manuel Emídio,20,,-8.033333,-43.833333
br,manuel feliciano,Manuel Feliciano,05,,-16.266667,-39.85
br,manuel fialho,Manuel Fialho,23,,-31.066667,-55.983333
br,manuel freitas,Manuel Freitas,23,,-29.05,-55.033333
br,manuel gomes,Manuel Gomes,15,,-17.533333,-41.483333
br,manuel lopes,Manuel Lopes,15,,-20.116667,-45.5
br,manuel,Manuel,24,,-11.283333,-65.366667
br,manuel parreira,Manuel Parreira,15,,-17.983333,-41.7
br,manuel pereira,Manuel Pereira,05,,-11.4,-39.766667
br,manuel pereira,Manuel Pereira,15,,-20.483333,-45.583333
br,manuel ribas,Manuel Ribas,18,,-24.516667,-51.65
br,manuelsinho,Manuelsinho,16,,-7.35,-54.85
br,manuel tavares,Manuel Tavares,21,,-22.133333,-41.6
br,manuel tomas,Manuel Tomás,14,,-8.85,-60.7
br,manuel urbano,Manuel Urbano,01,,-8.883333,-69.3
br,manuel viana,Manuel Viana,23,,-29.583333,-55.483333
br,manuelzinho,Manuelzinho,04,,-4.947778,-62.371389
br,manuelzinho,Manuelzinho,16,,-7.35,-54.85
br,mao beijada,Mão Beijada,17,,-8.1,-37.016667
br,mao direita,Mão Direita,06,,-6.066667,-38.933333
br,mao,Mao,21,,-20.816667,-41.75
br,mapada,Mapada,04,,-2.375,-61.09
br,mapana,Mapana,04,,-2.933333,-67.883333
br,mapangapa,Mapangapa,04,,-8.7,-67.383333
br,mapaugapa,Mapaugapa,04,,-8.7,-67.383333
br,mapele,Mapele,05,,-12.783333,-38.433333
br,mapia,Mapiá,04,,-8.45,-67.45
br,mapireme,Mapireme,16,,.516667,-54.083333
br,mapirunga,Mapirunga,06,,-7.233333,-40.283333
br,mapixi,Mapixi,04,,-5.617222,-64.012778
br,mapixy,Mapixy,04,,-5.666667,-63.883333
br,mapua,Mapuá,06,,-5.983333,-38.666667
br,maquina,Máquina,21,,-21.283333,-41.066667
br,maquine,Maquiné,05,,-11.05,-42.35
br,maquine,Maquiné,20,,-5.966667,-41.383333
br,maquine,Maquiné,23,,-29.683333,-50.183333
br,maquinista maino,Maquinista Maino,23,,-28.166667,-52.35
br,maquinista severo,Maquinista Severo,23,,-28.25,-53.133333
br,maraa,Maraã,04,4387,-1.833333,-65.366667
br,maraba,Marabá,16,145865,-5.35,-49.116667
br,maraba paulista,Marabá Paulista,27,,-22.1,-51.933333
br,marabitana,Marabitana,16,,-.883333,-47.983333
br,marabitanas,Marabitanas,04,,.966667,-66.85
br,marabitanas,Marabitanas,16,,-.883333,-47.983333
br,maracachita,Maracachita,25,,2.533333,-60.6
br,maracacume,Maracaçumé,13,14164,-2.05,-45.933333
br,maracahy,Maracahy,27,,-22.6,-50.65
br,maracaibo,Maracaibo,24,,-12.404167,-60.604167
br,maracai,Maracaí,27,11960,-22.6,-50.65
br,maracaja,Maracajá,04,,.233333,-69.65
br,maracaja,Maracajá,06,,-4.516667,-41.066667
br,maracaja,Maracajá,13,,-3.916667,-44.2
br,maracaja,Maracajá,16,,-4.147778,-50.220278
br,maracaja,Maracajá,22,,-5.568889,-36.392778
br,maracaja,Maracajá,26,,-28.85,-49.466667
br,maracajatuba,Maracajatuba,16,,-3.416667,-56.45
br,maracajau,Maracajaú,22,,-5.416667,-35.316667
br,maracaju,Maracaju,11,22690,-21.633333,-55.15
br,maraca,Maracá,03,,2.133333,-50.5
br,maraca,Maracá,30,,-7.916667,-36.116667
br,maracana ll,Maracanã ll,23,,-29.7717,-50.7695
br,maracana,Maracanã,04,,-.366667,-66.466667
br,maracana,Maracanã,05,,-12.75,-38.533333
br,maracana,Maracanã,06,,-2.933333,-40.033333
br,maracana,Maracanã,16,12683,-.766667,-47.45
br,maracana,Maracanã,21,,-22.91453,-43.225466
br,maracana,Maracanã,23,,-29.7719,-50.778
br,maracana,Maracanã,30,,-7.733333,-38.85
br,maracanau,Maracanaú,06,193532,-3.866667,-38.633333
br,maracani,Maracaní,25,,3.183333,-61.183333
br,maracanu,Maracanu,25,,3.183333,-61.183333
br,maracas,Maracás,05,22050,-13.433333,-40.45
br,maracassume,Maracassumé,13,,-2.05,-45.933333
br,maracoeira,Maracoeira,13,,-1.233333,-46.1
br,maraconahu,Maraconahú,06,,-3.866667,-38.633333
br,maracuja,Maracujá,01,,-8.383333,-71
br,maracuja,Maracujá,05,,-11.516667,-40.216667
br,maracuja,Maracujá,06,,-3.516667,-40.05
br,maracuja,Maracujá,17,,-7.083333,-37.5
br,maracuja,Maracujá,20,,-3.691389,-42.420278
br,marada,Marada,16,,-5.35,-49.116667
br,marafi,Marafi,04,,-5.716667,-67.783333
br,maragao,Maragão,06,,-4.5,-38.783333
br,maragassume,Maragassume,13,,-2.05,-45.933333
br,maragipinho,Maragipinho,05,,-13.05,-38.95
br,maragogi,Maragogi,02,16066,-9.016667,-35.216667
br,maragogipe,Maragogipe,05,20921,-12.766667,-38.916667
br,maragogipinho,Maragogipinho,05,,-13.05,-38.95
br,maragogy,Maragogy,02,,-9.016667,-35.216667
br,maragoji,Maragoji,02,,-9.016667,-35.216667
br,maragojipe,Maragojipe,05,,-12.766667,-38.916667
br,maragojipinho,Maragojipinho,05,,-13.05,-38.95
br,maragua,Maraguá,06,,-7.3,-38.55
br,marahu,Marahú,05,,-14.1,-39
br,maraial,Maraial,30,14204,-8.783333,-35.833333
br,maraja,Marajá,04,,-4.983333,-60.233333
br,maraja,Marajá,13,,-3.046389,-43.436111
br,maraja,Marajá,20,,-3.793889,-42.421111
br,marajazinho,Marajazinho,04,,-5.014444,-60.265
br,marajoara,Marajoara,27,,-21.583333,-51.233333
br,marala,Marala,23,,-29.55,-51.566667
br,mar a mar,Mar A Mar,21,,-23.024172,-43.496663
br,marambaia,Marambaia,15,,-17.183333,-41.583333
br,marambaia,Marambaia,21,,-22.766667,-42.933333
br,marambainha,Marambainha,15,,-17.183333,-41.583333
br,maranduva,Maranduva,27,,-24.566513,-48.110699
br,maranga,Marangá,21,,-23.004287,-43.451551
br,marangatu,Marangatu,21,,-21.616667,-42.216667
br,marangua,Maranguá,21,,-22.866667,-42.6
br,maranguape,Maranguape,01,,-9.166667,-72.266667
br,maranguape,Maranguape,06,,-3.883333,-38.666667
br,maranhao,Maranhão,13,,-2.516667,-44.266667
br,maranhao,Maranhão,17,,-7.766667,-36.116667
br,marapanim,Marapanim,16,10236,-.7,-47.7
br,marape,Marapé,08,,-20.216667,-41.3
br,marape,Marape,14,,-12,-56.65
br,marapica,Marapica,21,,-22.804191,-43.58837
br,marapicu,Marapicu,21,,-22.804191,-43.58837
br,marapoama,Marapoama,27,,-21.25,-49.133333
br,marapuama,Marapuama,27,,-21.25,-49.133333
br,marari,Marari,04,,-5.716667,-67.783333
br,marari,Marari,26,,-27.216667,-51.083333
br,mararupa,Mararupá,06,,-7.25,-38.766667
br,marary,Marary,04,,-5.716667,-67.783333
br,marasco,Marasco,23,,-32.816667,-53.066667
br,marataizes,Marataízes,08,25397,-21.033333,-40.833333
br,marata,Maratá,23,,-29.55,-51.566667
br,marata,Maratá,26,,-26.366667,-50.983333
br,maraua,Marauá,04,,-2.9,-66.083333
br,marau,Maraú,05,2956,-14.1,-39
br,marau,Marau,16,,-4.05,-56.883333
br,marau,Marau,23,26860,-28.45,-52.2
br,maravilha,Maravilha,02,,-9.233333,-37.3
br,maravilha,Maravilha,04,,-2.512778,-60.786111
br,maravilha,Maravilha,05,,-10.866667,-40.016667
br,maravilha,Maravilha,14,,-15.816667,-56.066667
br,maravilha,Maravilha,15,,-17.583333,-41.116667
br,maravilha,Maravilha,20,,-8.133333,-42.133333
br,maravilha,Maravilha,25,,3.433333,-60.183333
br,maravilha,Maravilha,26,13865,-26.783333,-53.15
br,maravilha,Maravilha,30,,-8.55,-40.65
br,maravilha nova,Maravilha Nova,30,,-8.55,-40.65
br,maravilhas,Maravilhas,15,,-18.033333,-43.216667
br,maraxo paia,Maraxó Paiá,16,,1.433333,-56.533333
br,marayal,Marayal,30,,-8.783333,-35.833333
br,marazinho,Marazinho,04,,-4.997778,-60.253889
br,marcacac,Marcaçâc,22,,-5.749444,-36.921667
br,marcacao,Marcação,02,,-10,-36.95
br,marcacao,Marcação,17,,-6.566667,-36.366667
br,marcal ii,Marçal II,13,,-3.363611,-43.348333
br,marcal i,Marçal I,13,,-3.326667,-43.459722
br,marcal,Marçal,13,,-3,-45.083333
br,marcal,Marçal,20,,-6.916667,-40.533333
br,marcelina,Marcelina,17,,-6.233333,-37.683333
br,marcelino,Marcelino,04,,-1.75,-66.35
br,marcelino,Marcelino,05,,-17.666667,-40.266667
br,marcelino,Marcelino,15,,-16.166667,-40.9
br,marcelino,Marcelino,18,,-25.772401,-49.233989
br,marcelino ramos,Marcelino Ramos,23,,-27.466667,-51.9
br,marcelino vieira,Marcelino Vieira,22,,-6.3,-38.166667
br,marcellino,Marcellino,04,,.9,-67.2
br,marcellino ramos,Marcellino Ramos,23,,-27.466667,-51.9
br,marcelo guedes,Marcelo Guedes,15,,-18.15,-41.683333
br,marcelo,Marcelo,05,,-10.816667,-40.316667
br,marcelo,Marcelo,16,,-2.2,-51.45
br,marcelo,Marcelo,17,,-7.233333,-38.3
br,marcia b. serpa,Márcia B. Serpa,23,,-30.1,-56.2
br,marcianopolis,Marcianópolis,18,,-26.110278,-53.646667
br,marcilio dias,Marcílio Dias,26,,-26.133333,-50.383333
br,marco brasileiro,Marco Brasileiro,24,,-10.4,-65.366667
br,marco do riachao,Marco do Riachão,20,,-6.133333,-42.966667
br,marcolandia,Marcolândia,30,,-7.433333,-40.65
br,marcolino,Marcolino,05,,-12.15,-41
br,marcolino,Marcolino,15,,-17.25,-41.3
br,marcolino moco,Marcolino Moco,15,,-17.166667,-40.883333
br,marcolino moura,Marcolino Moura,05,,-13.583333,-41.716667
br,marco,Marco,06,14502,-3.133333,-40.15
br,marco,Marco,13,,-3.951944,-43.329167
br,marco,Marco,20,,-3.351389,-42.113333
br,marcondesia,Marcondésia,27,,-20.866667,-48.7
br,marcondes,Marcondes,15,,-18.55,-48.1
br,marco prete,Marco Prete,06,,-3.983333,-40.316667
br,marco rondon,Marco Rondon,24,,-12.016667,-60.866667
br,marcos-de-honorato,Marcos-de-Honorato,14,,-10.283333,-60.516667
br,marcos,Marcos,05,,-13.3,-40.383333
br,marcos,Marcos,13,,-3.734722,-42.792222
br,marcos,Marcos,17,,-6.516667,-35.133333
br,marcos parente,Marcos Parente,20,,-7.25,-43.7
br,marcos rocha,Marcos Rocha,15,,-15.033333,-46.8
br,marco zero,Marco Zero,18,,-22.95,-53.416667
br,mar de espanha,Mar de Espanha,15,9678,-21.865833,-43.009722
br,mar de hespanha,Mar de Hespanha,15,,-21.865833,-43.009722
br,mar d'hespanha,Mar d'Hespanha,15,,-21.865833,-43.009722
br,marecas,Marecas,04,,-4.820556,-62.603889
br,marechal al floriano,Marechal al Floriano,18,,-25.316667,-53.883333
br,marechal bormann,Marechal Bormann,26,,-27.233333,-52.6
br,marechal candido rondon,Marechal Cândido Rondon,18,43028,-24.566667,-54.066667
br,marechal deodoro,Marechal Deodoro,02,50579,-9.716667,-35.9
br,marechal floriano,Marechal Floriano,02,,-9.45,-37.766667
br,marechal floriano,Marechal Floriano,08,5869,-20.416667,-40.666667
br,marechal floriano,Marechal Floriano,29,,-15.95,-51.25
br,marechal hermes,Marechal Hermes,21,,-22.864928,-43.370145
br,marechal jardim,Marechal Jardim,21,,-22.483333,-44.516667
br,marechal luz,Marechal Luz,26,,-26.166667,-48.533333
br,marechal mallet,Marechal Mallet,18,,-25.916667,-50.833333
br,marechal taumaturgo,Marechal Taumaturgo,01,,-8.948333,-72.786944
br,marema,Marema,26,,-26.833333,-52.716667
br,mare,Maré,21,,-22.856039,-43.243481
br,marequeta,Marequetá,06,,-5.033333,-39.483333
br,maresias,Maresias,27,,-23.8,-45.55
br,mares,Marés,06,,-4.433333,-39.066667
br,marezinha,Marèzinha,06,,-5.766667,-39.183333
br,marfim,Marfim,06,,-4.683333,-40.433333
br,marfim,Marfim,13,,-4,-44.783333
br,marfim,Marfim,20,,-3.619722,-42.150556
br,marfim,Marfim,27,,-20.633333,-47.466667
br,marfinzeiro,Marfinzeiro,13,,-3.800833,-43.429444
br,margarida,Margarida,11,,-21.683333,-56.733333
br,margarida,Margarida,18,,-24.65,-54.116667
br,margarida,Margarida,21,,-21.45,-41.45
br,margaride,Margaride,22,,-6.283333,-36.833333
br,mar grande,Mar Grande,05,,-12.95,-38.616667
br,maria boneca,Maria Boneca,05,,-16.116667,-39.4
br,maria carlota,Maria Carlota,15,,-21.133333,-45.166667
br,maria cruger,Maria Cruger,08,,-20.2,-40.533333
br,maria cruz,Maria Cruz,05,,-16.483333,-39.966667
br,maria da fe,Maria da Fé,15,,-22.3,-45.383333
br,maria da graca,Maria da Graça,21,,-22.883498,-43.265481
br,maria farinha,Maria Farinha,30,,-7.85,-34.833333
br,maria gorda,Maria Gorda,18,,-24.816667,-49.016667
br,maria helena,Maria Helena,18,,-23.583333,-53.166667
br,maria isabel,Maria Isabel,05,,-10.033333,-41.366667
br,maria joana,Maria Joana,14,,-14.366667,-56.983333
br,marialva,Marialva,18,26001,-23.466667,-51.7
br,maria,Maria,23,,-28.533333,-52.15
br,maria melo,Maria Melo,17,,-7.416667,-35.416667
br,mariana,Mariana,05,,-9.5,-38.95
br,mariana,Mariana,08,,-20.35,-41.55
br,mariana,Mariana,15,45237,-20.383333,-43.416667
br,mariana,Mariana,18,,-25.356153,-48.425234
br,mariana,Mariana,30,,-8.983333,-37.616667
br,mariana pimentel,Mariana Pimentel,23,,-30.333333,-51.583333
br,mariana velha,Mariana Velha,16,,-1.7,-46.25
br,marianna,Marianna,15,,-20.383333,-43.416667
br,marianna,Marianna,30,,-8.983333,-37.616667
br,mariano flores,Mariano Flores,15,,-14.8,-44.133333
br,mariano guedes,Mariano Guedes,15,,-16.85,-41.266667
br,mariano,Mariano,05,,-12.333333,-39.233333
br,mariano,Mariano,08,,-20.35,-41.55
br,marianopolis do tocantins,Marianópolis do Tocantins,31,,-9.742778,-49.566944
br,marianopolis,Marianópolis,13,,-4.783333,-44.633333
br,marianopolis,Marianópolis,15,,-16.416667,-42.533333
br,mariano ramos,Mariano Ramos,14,,-15.95,-57.083333
br,mariante,Mariante,23,,-29.7,-51.966667
br,maria paes,Maria Paes,17,,-6.733333,-37.316667
br,maria pereira,Maria Pereira,20,,-5.75,-39.633333
br,mariapolis,Mariápolis,27,,-21.8,-51.183333
br,mariapopolis,Mariapópolis,15,,-16.416667,-42.533333
br,maria preta,Maria Preta,26,,-26.4,-53.583333
br,maria quiteria,Maria Quitéria,05,,-12.133333,-39.033333
br,maria rosa,Maria Rosa,05,,-16.216667,-39.433333
br,maria soares,Maria Soares,17,,-7.533333,-38.45
br,marias pretas,Marias Pretas,02,,-9.5,-36.816667
br,marias pretas,Marias Pretas,17,,-6.933333,-38.566667
br,marias pretas,Marias Pretas,30,,-7.85,-37.783333
br,maria viera,Maria Viera,29,,-16.35,-51.416667
br,maribondo,Maribondo,02,10475,-9.583333,-36.233333
br,maribondo,Maribondo,05,,-13.583333,-40.216667
br,maribondo,Maribondo,20,,-3.950278,-42.277222
br,maribondo,Maribondo,31,,-7.383333,-48.066667
br,maribu,Maribu,05,,-13.95,-39.75
br,marica,Maricá,21,79552,-22.916667,-42.816667
br,marica,Maricá,23,,-30.5,-53.833333
br,maricoabo,Maricoabo,05,,-13.416667,-39.066667
br,maricota,Maricota,30,,-7.9,-34.883333
br,mari da sombra,Mari da Sombra,22,,-5.645278,-36.006389
br,mariental,Mariental,18,,-25.733333,-49.65
br,marilac,Marilac,15,,-18.466667,-42.183333
br,marila,Marilá,18,,-23.483333,-52.116667
br,marilandia do sul,Marilândia do Sul,18,,-23.75,-51.316667
br,marilandia,Marilândia,08,3900,-19.416667,-40.516667
br,marilandia,Marilândia,15,,-18.616667,-49.116667
br,marilandia,Marilândia,18,,-23.75,-51.316667
br,marilandia,Marilândia,29,,-15.683333,-49.183333
br,marilena,Marilena,18,,-22.716667,-53.05
br,marilia,Marília,27,212222,-22.216667,-49.933333
br,mariluz,Mariluz,18,,-24.033333,-53.216667
br,mari,Mari,04,,-7.083333,-64.566667
br,mari,Mari,05,,-9.216667,-38.316667
br,mari,Mari,06,,-5.833333,-39.833333
br,mari,Mari,17,17535,-7.083333,-35.333333
br,mari,Mari,22,,-5.131389,-37.26
br,mari,Mari,30,,-9.266667,-38.25
br,marimba,Marimba,20,,-8.85,-44.383333
br,marimbas,Marimbas,17,,-7.016667,-38.666667
br,marimbas,Marimbas,20,,-8.85,-44.383333
br,marimbondo,Marimbondo,02,,-9.583333,-36.233333
br,marimbondo,Marimbondo,18,,-23.55,-49.7
br,marimbondo,Marimbondo,21,,-21.416667,-41.616667
br,marimbondo,Marimbondo,27,,-22.383333,-47.216667
br,marimbondo,Marimbondo,28,,-10.683333,-36.916667
br,marineiro,Marineiro,27,,-20.316667,-49.9
br,marineli,Marinéli,21,,-22.116667,-42.616667
br,maringa,Maringá,18,311727,-23.416667,-51.916667
br,marinheiro,Marinheiro,17,,-7.583333,-36.533333
br,marinheiro,Marinheiro,20,,-6.9,-41.366667
br,marinheiros,Marinheiros,06,,-3.183333,-39.466667
br,marinho,Marinho,17,,-7.583333,-36.166667
br,marinopolis,Marinopolis,13,,-4.783333,-44.633333
br,marinopolis,Marinópolis,27,,-20.45,-50.833333
br,marins,Marins,15,,-22.45,-45.133333
br,mario belo,Mário Belo,21,,-22.593611,-43.651944
br,mariola,Mariola,30,,-7.816667,-38.816667
br,mariom,Mariom,28,,-10.75,-37.083333
br,marionopolis,Marionopólis,13,,-4.783333,-44.633333
br,mario pinto,Mário Pinto,15,,-21.733333,-45.083333
br,mariopolis,Mariópolis,18,,-26.333333,-52.55
br,mario spinelli,Mário Spinelli,14,,-15.55,-54.283333
br,maripa,Maripá,15,,-21.7,-42.966667
br,maripeme,Maripeme,16,,.516667,-54.083333
br,mariquioca,Mariquioca,08,,-20.666667,-40.6
br,mariquita,Mariquita,05,,-12.4,-44.25
br,mariricu,Mariricu,08,,-18.716667,-39.766667
br,mariri,Mariri,30,,-7.883333,-38.133333
br,mariseira,Mariseira,22,,-5.516667,-35.616667
br,marisopolis,Marisópolis,17,,-6.833333,-38.35
br,maristela,Maristela,18,,-23.083333,-52.316667
br,maristela,Maristela,27,,-23.038725,-47.891797
br,maristella,Maristella,27,,-23.038725,-47.891797
br,marita,Maritá,15,,-21.8,-45.75
br,marituba,Marituba,02,,-10.283333,-36.4
br,marizeiro,Marizeiro,06,,-6.25,-38.816667
br,marizopolis,Marizópolis,17,,-6.833333,-38.35
br,marlenopolis,Marlenopolis,06,,-5.65,-39.016667
br,marlieria,Marliéria,15,,-19.716667,-42.75
br,marmelada,Marmelada,20,,-7.066667,-42.7
br,marmeleiro de baixo,Marmeleiro de Baixo,18,,-25.678696,-50.555848
br,marmeleiro de cima,Marmeleiro de Cima,18,,-25.647434,-50.533766
br,marmeleiro dos ingleses,Marmeleiro dos Ingleses,18,,-25.646313,-50.57495
br,marmeleiro dos rosas,Marmeleiro dos Rosas,18,,-25.665613,-50.535652
br,marmeleiro,Marmeleiro,18,,-26.133333,-53.033333
br,marmeleiro,Marmeleiro,23,,-29.45,-54.683333
br,marmeleiro,Marmeleiro,27,,-23.128333,-46.521944
br,marmelo,Marmelo,13,,-2.966667,-45.366667
br,marmelo,Marmelo,30,,-7.8,-39.916667
br,marmelos,Marmelos,27,,-22.6349,-45.5036
br,marmota,Marmota,15,,-20.566667,-41.983333
br,maroba,Marobá,05,,-17.883333,-39.366667
br,maroim,Maroim,28,,-10.75,-37.083333
br,maroins,Maroins,24,,-9.016667,-61.933333
br,maro isla,Maro Isla,11,,-23.366667,-54.65
br,marombas,Marombas,26,,-27.2,-50.633333
br,maropolis,Marópolis,18,,-26.333333,-52.55
br,maroto,Maroto,05,,-10.366667,-43.833333
br,marova,Marova,04,,-1.133333,-62.583333
br,marques de abrantes,Marquês de Abrantes,18,,-24.978733,-48.928895
br,marques de sousa,Marques de Sousa,23,,-29.333333,-52.1
br,marques de valenca,Marquês de Valença,21,,-22.241944,-43.701389
br,marques do erval,Marquês do Erval,23,,-29.566667,-50.266667
br,marques do herval,Marquês do Herval,23,,-29.566667,-50.266667
br,marques,Marques,13,,-3.872222,-43.117778
br,marques,Marques,15,,-22.4,-45.583333
br,marques,Marques,18,,-25.40536,-48.882041
br,marquez do herval,Marquez do Herval,23,,-29.566667,-50.266667
br,marquinho,Marquinho,18,,-25.116667,-52.283333
br,marrao,Marrão,05,,-11.816667,-42.183333
br,marreca,Marreca,13,,-3.324722,-42.365556
br,marreca,Marreca,18,,-24.68248,-48.614391
br,marreca,Marreca,20,,-7.7,-43.133333
br,marrecao,Marrecão,04,,-4.820556,-62.603889
br,marrecas,Marrecas,05,,-10.6,-42.65
br,marrecas,Marrecas,06,,-6.133333,-40.483333
br,marrecas,Marrecas,17,,-7.1,-37.666667
br,marrecas,Marrecas,18,,-25.116667,-51.4
br,marrecas,Marrecas,20,,-5.633333,-41.75
br,marrecas,Marrecas,21,,-21.933333,-41.066667
br,marrecas,Marrecas,27,,-21.35,-51.866667
br,marrecas,Marrecas,28,,-9.95,-37.533333
br,marrecas mulaco,Marrecas Mulaco,21,,-21.933333,-41.066667
br,marreco,Marreco,17,,-7.416667,-37.666667
br,marreiros,Marreiros,20,,-6.1,-42.216667
br,marreta,Marreta,22,,-6.166667,-38.266667
br,marretas,Marrêtas,06,,-5.85,-38.95
br,marrinho,Marrinho,06,,-3.233333,-40.116667
br,marrinhos,Marrinhos,05,,-11.033333,-45.05
br,marroa,Marroa,13,,-6.366667,-43.433333
br,marroas,Marroás,05,,-11.566667,-44.283333
br,marroas,Marroás,06,,-6.033333,-39.883333
br,marrocos,Marrocos,06,,-7.166667,-39.25
br,marrocos nova,Marrocos Nova,05,,-11.433333,-42.316667
br,marrua,Marruá,05,,-9.216667,-38.95
br,marruas,Marruás,05,,-11.566667,-44.283333
br,marruas,Marruás,06,,-6.033333,-39.883333
br,marruas,Marruás,20,,-3.166667,-41.683333
br,marruazinho,Marruazinho,20,,-3.776389,-42.471667
br,marsal,Marsal,30,,-7.416667,-39.8
br,martelandia,Martelândia,08,,-18.85,-39.983333
br,martele,Martelê,23,,-28.6,-53.516667
br,marteler,Marteler,23,,-28.6,-53.516667
br,martelet,Martelet,23,,-28.6,-53.516667
br,martelo,Martelô,23,,-28.6,-53.516667
br,martelo,Martelo,30,,-9.233333,-38.266667
br,martim francisco,Martim Francisco,27,,-22.516667,-46.95
br,martim,Martim,13,,-3.9325,-43.4025
br,martinesia,Martinésia,15,,-18.716667,-48.416667
br,martinho campos,Martinho Campos,15,9198,-19.333333,-45.216667
br,martinho,Martinho,16,,-6.083333,-57.516667
br,martinica,Martinica,06,,-3.833333,-40.233333
br,martinlandia nova,Martinlândia Nova,27,,-22.45,-52.066667
br,martinlandia velha,Martinlândia Velha,27,,-22.45,-52.15
br,martinopole,Martinópole,06,,-3.25,-40.683333
br,martinopolis,Martinópolis,06,,-3.25,-40.683333
br,martinopolis,Martinópolis,15,,-18.716667,-48.416667
br,martinopolis,Martinópolis,27,18488,-22.183333,-51.2
br,martins carneiro,Martins Carneiro,14,,-17.283333,-54.2
br,martins ferreira,Martins Ferreira,15,,-17.433333,-41.516667
br,martins lage,Martins Lage,21,,-21.766667,-41.25
br,martins laje,Martins Laje,21,,-21.766667,-41.25
br,martins,Martins,13,,-3.488889,-42.719444
br,martins,Martins,15,,-20.05,-46.4
br,martins,Martins,16,,-8.616667,-49.666667
br,martins,Martins,20,,-5.616667,-41.15
br,martins,Martins,22,,-5.417222,-37.215278
br,martins,Martins,27,,-24.656886,-48.283051
br,martins,Martins,29,,-17.85,-52.7
br,martins soares,Martins Soares,15,,-20.25,-41.883333
br,martirio,Martírio,04,,-2.966667,-65.866667
br,maruahy,Maruahy,25,,3.733333,-60.466667
br,maruai,Maruaí,25,,3.733333,-60.466667
br,maruanum,Maruanum,03,,.183333,-51.266667
br,maruas,Maruás,05,,-14.4,-42.35
br,marucupari,Marucupari,04,,-5.539722,-64.0775
br,maruda,Marudá,16,,-.866667,-47.666667
br,maruim,Maruim,28,12153,-10.75,-37.083333
br,marumbe,Marumbé,17,,-6.583333,-37.866667
br,marumbi,Marumbi,18,,-23.666667,-51.633333
br,marumby,Marumby,18,,-25.716667,-50.783333
br,marupiara,Marupiara,23,,-29.666667,-53.183333
br,marvai,Marvaí,25,,3.733333,-60.466667
br,marvao,Marvão,20,,-5.333333,-41.55
br,mar vermelho,Mar Vermelho,02,,-9.433333,-36.116667
br,marzagania,Marzagânia,15,,-19.883333,-43.866667
br,marzagao,Marzagão,14,,-14.583333,-55.733333
br,marzagao,Marzagão,15,,-19.883333,-43.866667
br,marzagao,Marzagão,29,,-17.983333,-48.65
br,mascarenhas,Mascarenhas,08,,-19.5,-40.9
br,mascote,Mascote,05,18899,-15.55,-39.283333
br,massacara do mato,Massacará do Mato,05,,-10.433333,-38.766667
br,massacara do matto,Massacara do Matto,05,,-10.433333,-38.766667
br,massacara,Massacará,05,,-10.433333,-38.766667
br,massambara,Massambará,23,,-29.133333,-56.05
br,massangana,Massangana,06,,-5.15,-40.033333
br,massape,Massapé,02,,-9.533333,-36.933333
br,massape,Massapê,06,22193,-3.516667,-40.316667
br,massape,Massapê,17,,-6.4,-37.516667
br,massape,Massapê,20,,-3.488889,-42.199444
br,massape,Massapê,22,,-5.135556,-36.332778
br,massape,Massapê,30,,-7.916667,-38.716667
br,massarandiba,Massarandiba,17,,-7.183333,-35.766667
br,massaranduba,Massaranduba,17,3153,-7.183333,-35.766667
br,massaranduba,Massaranduba,26,,-26.6,-49.016667
br,massaranduba,Massaranduba,30,,-9.1,-36.516667
br,massarapua,Massarapuã,18,,-25.359646,-48.432745
br,massaroca,Massaroca,05,,-9.883333,-40.283333
br,massena,Massena,13,,-3.856111,-43.430833
br,massiambu pequeno,Massiambu Pequeno,26,,-27.810833,-48.648333
br,massui,Massuí,05,,-12.616667,-38.483333
br,massuim,Massuim,05,,-12.616667,-38.483333
br,mata alta,Mata Alta,13,,-3.638611,-43.309167
br,mata boi,Mata Boi,30,,-7.85,-39.566667
br,mata burro,Mata Burro,06,,-7.3,-40.433333
br,mata burro,Mata Burro,17,,-7.083333,-37.966667
br,mata burro,Mata Burro,22,,-5.766667,-35.516667
br,mata cabra,Mata Cabra,22,,-5.666667,-35.816667
br,mata cabra,Mata Cabra,30,,-8.95,-38.2
br,mata catingada,Mata Catíngada,13,,-3.933889,-43.334444
br,mata cavalo,Mata Cavalo,02,,-9.666667,-37.283333
br,mata cavalo,Mata Cavalo,05,,-12.1,-41.866667
br,mata da alianca,Mata da Aliança,05,,-12.466667,-38.683333
br,mata da cachoeira,Mata da Cachoeira,15,,-21.15,-45.85
br,mata da chuva,Mata da Chuva,27,,-20.916667,-47.95
br,mata da serra,Mata da Serra,30,,-8.75,-36.616667
br,mata da varjota,Mata da Varjota,13,,-3.976944,-43.410278
br,mata de baixo,Mata de Baixo,22,,-6.366667,-38.116667
br,mata de cima,Mata de Cima,13,,-3.483889,-42.9225
br,mata dentro,Mata Dentro,13,,-9.316667,-46.583333
br,mata de sao joao,Mata de São João,05,26680,-12.516667,-38.283333
br,mata do boi,Mata do Boi,13,,-3.45,-45.2
br,mata do canudo,Mata do Canudo,05,,-12.45,-41.75
br,mata do irigadeiro,Mata do Irigadeiro,13,,-3.715278,-43.224167
br,mata do meio ii,Mata do Meio II,20,,-3.3025,-42.042222
br,matador,Matador,26,,-27.205775,-49.5898
br,mata dos cocos,Mata dos Côcos,20,,-8.75,-45.066667
br,mata do sino,Mata do Sino,15,,-21.183333,-46.516667
br,matadouro,Matadouro,21,,-22.926457,-43.693004
br,matadouro,Matadouro,27,,-22.797845,-45.207776
br,mata do velho,Mata do Velho,30,,-8.566667,-37.133333
br,mata escura,Mata Escura,02,,-9.2,-37.766667
br,mata escura,Mata Escura,13,,-3.604444,-42.811389
br,mata escura,Mata Escura,17,,-6.483333,-38.033333
br,mata escura,Mata Escura,20,,-5.733333,-41.333333
br,mata escura,Mata Escura,30,,-7.683333,-37.783333
br,mata fome,Mata Fome,05,,-11.316667,-43.166667
br,matafome,Matafome,11,,-20.4,-56.233333
br,mata fresca,Mata Fresca,06,,-4.716667,-40.483333
br,mata fresca,Mata Fresca,17,,-6.883333,-38.266667
br,mata fresca,Mata Fresca,20,,-3.713889,-42.526111
br,mata grande,Mata Grande,02,4654,-9.111667,-37.7
br,mata grande,Mata Grande,13,,-3.009167,-43.271667
br,mata grande,Mata Grande,17,,-7.383333,-38.466667
br,mata grande,Mata Grande,20,,-8.6,-45.416667
br,mata grande,Mata Grande,23,,-30.383333,-53.75
br,matai,Mataí,05,,-12.35,-39.3
br,mata leitao,Mata Leitão,23,,-29.533333,-52.133333
br,mata limpa,Mata Limpa,02,,-9.783333,-36.8
br,mata limpa,Mata Limpa,05,,-12.266667,-38.75
br,mata limpa,Mata Limpa,08,,-19.766667,-40.166667
br,mata limpa,Mata Limpa,17,,-7.35,-38.383333
br,mata,Mata,05,,-10.783333,-43.35
br,mata,Mata,08,,-20.75,-41.833333
br,mata,Mata,13,,-2.583333,-44.183333
br,mata,Mata,15,,-20.9,-46.55
br,mata,Mata,20,,-8.75,-45.383333
br,mata,Mata,22,,-5.6,-35.483333
br,mata,Mata,23,,-29.566667,-54.45
br,mata,Mata,27,,-20.666667,-47.133333
br,mata,Mata,30,,-7.533333,-37.483333
br,matamata,Matamatá,04,,-4.783333,-66.74
br,matanca,Matanca,20,,-7.9,-43.166667
br,matanca velha,Matança Velha,05,,-13.216667,-39.533333
br,mata nova,Mata Nova,11,,-21.683333,-54.533333
br,mata nova,Mata Nova,31,,-10.616667,-47.266667
br,matao,Matão,13,,-6.716667,-44.183333
br,matao,Matão,18,,-24.843348,-48.849377
br,matao,Matão,27,72469,-21.583333,-48.366667
br,matao,Matão,29,,-16.216667,-49.2
br,matao tomas,Matão Tomás,22,,-5.533333,-35.733333
br,mataozinho,Matãozinho,18,,-24.876795,-48.957397
br,matapagipe,Matapagipe,30,,-8.25,-35.1
br,mata pais,Mata Pais,27,,-22.216667,-46.783333
br,mata pasto,Mata Pasto,20,,-3.875,-42.7
br,mata pasto,Mata Pasto,22,,-6.316667,-37.916667
br,mata pastos,Mata Pastos,06,,-6.266667,-39.15
br,matapi,Matapi,03,,.25,-51.166667
br,matapiquara,Matapiquara,16,,-.933333,-47.65
br,matapyquara,Matapyquara,16,,-.933333,-47.65
br,mata quatro,Mata Quatro,08,,-19.316667,-40.766667
br,mataquiri,Mataquirí,06,,-4.116667,-38.266667
br,mataraca,Mataraca,17,,-6.6,-35.05
br,matarandiba,Matarandiba,05,,-13,-38.75
br,matarazzo,Matarazzo,23,,-32.033333,-52.9
br,mata redonda,Mata Redonda,17,,-7.35,-34.95
br,mataripe,Mataripe,05,,-12.683333,-38.583333
br,mataripua,Mataripuá,04,,-7.683333,-66.633333
br,matariz,Matariz,21,,-23.1,-44.25
br,mata roma,Mata Roma,13,,-3.623611,-43.111667
br,mataruca,Matarucá,25,,4.466667,-60.1
br,mataruna,Mataruna,27,,-21.1,-47.65
br,mata-sete,Mata-Sete,16,,-1.033333,-47.2
br,matas,Matas,20,,-9.2,-45.65
br,matauna,Mataúna,29,,-16.816667,-49.916667
br,mata-veado,Mata-Veado,05,,-14.6,-42.7
br,mata velha,Mata Velha,13,,-3.221111,-42.343611
br,mata verde,Mata Verde,02,,-9.483333,-36.35
br,mata verde,Mata Verde,05,,-11.433333,-41.983333
br,mata verde,Mata Verde,15,,-15.733333,-40.7
br,mata verde,Mata Verde,22,,-5.95,-35.516667
br,mata virgem,Mata Virgem,17,,-7.733333,-35.8
br,mateira,Mateira,29,,-18.9,-50.5
br,mateiro,Mateiro,14,,-15.966667,-54.783333
br,matela,Matela,11,,-19.433333,-57.6
br,matelandia,Matelândia,18,10816,-25.2413,-53.983
br,mate,Mate,03,,2.433333,-50.766667
br,materlandia,Materlândia,08,,-18.85,-39.983333
br,matetui,Matetuí,16,,-2.116667,-47.333333
br,mateus jose,Mateus José,15,,-18.083333,-45.333333
br,mateus leme,Mateus Leme,15,24890,-19.983333,-44.416667
br,mateus,Mateus,16,,-5.65,-48.166667
br,mateus,Mateus,17,,-6.816667,-38.466667
br,mateus,Mateus,28,,-10.05,-37.183333
br,matheus leme,Matheus Leme,15,,-19.983333,-44.416667
br,mathias barbosa,Mathias Barbosa,15,,-21.869722,-43.318611
br,mathias cardoso,Mathias Cardoso,15,,-14.866667,-43.933333
br,mathilde,Mathilde,08,,-20.566667,-40.816667
br,matias barbosa,Matias Barbosa,15,12072,-21.869722,-43.318611
br,matias borges,Matias Borges,05,,-16.483333,-39.916667
br,matias cardoso,Matias Cardoso,15,,-14.866667,-43.933333
br,matias,Matias,06,,-3.95,-39.083333
br,matias,Matias,15,,-21.266667,-46.516667
br,matias,Matias,30,,-8.55,-38.783333
br,matias olimpio,Matias Olímpio,20,4012,-3.716667,-42.55
br,matias vieira,Matias Vieira,30,,-7.933333,-36.066667
br,matilde,Matilde,08,,-20.566667,-40.816667
br,matilde velha,Matilde Velha,08,,-20.55,-40.816667
br,matinada,Matinada,21,,-20.95,-41.9
br,matina,Matina,05,,-13.916667,-42.85
br,matinha de baixo,Matinha de Baixo,20,,-6.183333,-41.283333
br,matinha de dentro,Matinha de Dentro,13,,-3.87,-43.1825
br,matinha,Matinha,05,,-12.25,-41.333333
br,matinha,Matinha,13,6851,-3.1,-45.033333
br,matinha,Matinha,15,,-20.816667,-46.45
br,matinha,Matinha,17,,-7.1,-35.766667
br,matinha,Matinha,20,,-10.333333,-43.95
br,matinha,Matinha,27,,-20.15,-47.733333
br,matinha,Matinha,30,,-8.233333,-38.4
br,matinha,Matinha,31,,-12.894167,-49.773056
br,matinhas,Matinhas,06,,-3.566667,-39.65
br,matinhas,Matinhas,17,,-7.1,-35.766667
br,matinhas,Matinhas,31,,-12.894167,-49.773056
br,matinho,Matinho,30,,-7.733333,-37.75
br,matinhos,Matinhos,18,32008,-25.816667,-48.533333
br,matintim,Matintim,04,,-2.883333,-68.483333
br,matipo,Matipó,15,12997,-20.283333,-42.35
br,mato aberto,Mato Aberto,13,,-3.31,-42.741667
br,mato alto,Mato Alto,20,,-3.958611,-42.214167
br,mato alto,Mato Alto,21,,-22.909408,-43.362279
br,mato alto,Mato Alto,26,,-28.533333,-48.95
br,mato alto,Mato Alto,27,,-22.816667,-47.683333
br,mato branco,Mato Branco,18,,-25.833333,-52.333333
br,mato-dentro,Mato-Dentro,18,,-25.751631,-49.405387
br,mato dentro,Mato Dentro,27,,-22.983333,-46.633333
br,mato-dentro,Mato-Dentro,27,,-23.0237,-46.7461
br,mato do gado,Mato do Gado,27,,-23.7,-47.116667
br,matoes dos caboclos,Matões dos Caboclos,13,,-4.716667,-44.383333
br,matoes,Matões,05,,-13.033333,-38.75
br,matoes,Matões,06,,-3.583333,-38.816667
br,matoes,Matões,13,,-4.716667,-44.383333
br,matoes,Matões,20,,-4.35,-42.683333
br,mato feio,Mato Feio,20,,-3.641667,-42.115278
br,mato fino,Mato Fino,23,,-29.7929,-50.8995
br,mato grande,Mato Grande,05,,-11.9,-40.866667
br,mato grande,Mato Grande,11,,-18.333333,-57.383333
br,mato grande,Mato Grande,20,,-4.066667,-42.516667
br,mato grosso,Mato Grosso,02,,-9.7,-37.4
br,mato grosso,Mato Grosso,05,,-14.433333,-42.666667
br,mato grosso,Mato Grosso,13,,-3.566667,-44.95
br,mato grosso,Mato Grosso,14,,-15.25,-56.733333
br,mato grosso,Mato Grosso,15,,-18.733333,-48.616667
br,mato grosso,Mato Grosso,17,,-6.566667,-38.316667
br,mato grosso,Mato Grosso,21,,-22.866667,-42.6
br,mato grosso,Mato Grosso,30,,-7.6,-37.8
br,matoim,Matoim,05,,-12.766667,-38.5
br,mato leitao,Mato Leitão,23,,-29.533333,-52.133333
br,mato limpo,Mato Limpo,18,,-24.8487,-48.735
br,mato novo,Mato Novo,14,,-15.066667,-55.983333
br,mato preto dos paiois,Mato Preto dos Paióis,18,,-25.902014,-50.010609
br,mato preto,Mato Prêto,05,,-12.283333,-41.566667
br,mato preto,Mato Preto,18,,-25.8793,-49.9882
br,mato preto paiol,Mato Preto Paiol,18,,-25.9204,-49.9894
br,mato preto povinho,Mato Preto Povinho,18,,-25.899991,-49.970846
br,mato quatro,Mato Quatro,08,,-19.316667,-40.766667
br,mato queimado,Mato Queimado,18,,-25.1,-52.95
br,matos costa,Matos Costa,26,,-26.45,-51.15
br,matos dentro,Matos Dentro,13,,-9.316667,-46.583333
br,mato seco do alto,Mato Seco do Alto,27,,-23.217236,-47.838553
br,mato seco,Mato Seco,13,,-3.911667,-43.0675
br,mato seco,Mato Seco,27,,-23.178562,-47.826111
br,matos,Matos,05,,-13.916667,-42.85
br,matos,Matos,20,,-5.3,-41.966667
br,matos,Matos,23,,-29.066667,-51.6
br,matoso,Matoso,11,,-22.9,-55.466667
br,matotui,Matotuí,16,,-1.9,-47.366667
br,mato verde,Mato Verde,05,,-11.55,-42.95
br,mato verde,Mato Verde,13,,-8.05,-45.6
br,mato verde,Mato Verde,14,,-11.216667,-50.666667
br,mato verde,Mato Verde,15,7783,-15.383333,-42.866667
br,matozinho,Matozinho,15,,-20.0239,-43.8315
br,matozinhos,Matozinhos,15,30844,-19.583333,-44.116667
br,matozinhos,Matozinhos,21,,-22.251389,-43.284444
br,matraca,Matraca,15,,-16.216667,-41.85
br,matriz de camaragibe,Matriz de Camaragibe,02,18705,-9.15,-35.516667
br,matriz de camarajibe,Matriz de Camarajibe,02,,-9.15,-35.516667
br,matriz de guaratiba,Matriz de Guaratiba,21,,-22.991385,-43.576367
br,matriz,Matriz,06,,-3.066667,-40.333333
br,matta de sao joao,Matta de São João,05,,-12.516667,-38.283333
br,matta do coco,Matta do Côco,20,,-8.75,-45.066667
br,matta fresca,Matta Fresca,06,,-4.833611,-37.415278
br,matta,Matta,23,,-29.566667,-54.45
br,mattao,Mattão,27,,-21.583333,-48.366667
br,matta virgem,Matta Virgem,17,,-7.733333,-35.8
br,mattinha,Mattinha,17,,-7.1,-35.766667
br,matto grosso,Matto Grosso,14,,-15,-59.95
br,matto grosso,Matto Grosso,15,,-18.733333,-48.616667
br,matto grosso,Matto Grosso,21,,-22.866667,-42.6
br,mattosinhos,Mattosinhos,15,,-19.583333,-44.116667
br,matto verde,Matto Verde,15,,-15.383333,-42.866667
br,matuapira,Matuapira,21,,-22.783333,-42.783333
br,matumse,Matumse,17,,-6.833333,-38.233333
br,maturaia de baixo,Maturaia de Baixo,22,,-5.533333,-35.316667
br,maturaia de cima,Maturaia de Cima,22,,-5.533333,-35.333333
br,matura,Maturá,04,,-3.483333,-68.1
br,mature,Maturé,17,,-7.266667,-37.333333
br,maturuca,Maturuca,25,,4.466667,-60.1
br,matutagem,Matutagem,30,,-7.85,-37.833333
br,matutina,Matutina,15,,-19.216667,-45.966667
br,maua,Mauá,11,,-21.9,-57.483333
br,maua,Mauá,15,,-22.316667,-44.566667
br,maua,Mauá,18,,-24.05,-50.716667
br,maua,Mauá,21,,-22.333333,-44.55
br,maua,Mauá,23,,-27.583333,-54.666667
br,maua,Mauá,26,,-27.166667,-52.116667
br,maua,Mauá,27,386077,-23.666667,-46.45
br,mau cabelo,Mau Cabelo,21,,-21.5,-41.55
br,maues,Maués,04,22476,-3.4,-57.7
br,mau,Maú,16,,-.866667,-47.8
br,mau,Maú,21,,-20.816667,-41.75
br,mauricea,Mauricéa,30,,-8.05,-34.9
br,mauricio cardoso,Maurício Cardoso,23,,-27.5,-54.366667
br,maurilandia do tocantins,Maurilândia do Tocantins,31,,-5.882778,-47.356667
br,mauriti,Mauriti,06,20064,-7.383333,-38.766667
br,maurity,Maurity,06,,-7.383333,-38.766667
br,mauruca,Mauruca,25,,4.466667,-60.1
br,mavedeve,Mavedevé,25,,2.916667,-60.966667
br,ma vida,Má Vida,05,,-12.7,-39.183333
br,maxaranguape,Maxaranguape,22,,-5.466667,-35.55
br,maximiliano d'almeida,Maximiliano d'Almeida,23,,-27.633333,-51.783333
br,maximiliano de almeida,Maximiliano de Almeida,23,,-27.633333,-51.783333
br,maximim,Maximim,08,,-20.266667,-40.966667
br,maximo,Máximo,23,,-28.883333,-50.183333
br,maxixeiro,Maxixeiro,20,,-7.966667,-42.416667
br,maxixeiro,Maxixeiro,30,,-7.983333,-38.533333
br,maxixe,Maxixe,06,,-5.15,-37.766667
br,maxixe,Maxixe,20,,-3.461667,-42.505278
br,maxixe,Maxixe,30,,-8.116667,-37.366667
br,maye,Maye,03,,2.433333,-50.766667
br,maynart,Maynart,15,,-20.466667,-43.333333
br,mayrink,Mayrink,27,,-23.544368,-47.183467
br,mazaganopolis,Mazaganopolis,03,,-.116667,-51.283333
br,mazagao,Mazagão,03,6500,-.116667,-51.283333
br,mazagao velho,Mazagão Velho,03,,-.216667,-51.416667
br,mazela,Mazela,15,,-16.066667,-41.666667
br,mazomba,Mazomba,21,,-22.859167,-43.896111
br,mazombinha,Mazombinha,21,,-22.857222,-43.868333
br,m'boy,M'Boy,27,,-23.65,-46.85
br,meahype,Meahype,08,,-20.733333,-40.55
br,meaipe,Meaípe,08,,-20.733333,-40.55
br,mearim,Mearim,06,,-4.3,-38.616667
br,mearim,Mearim,13,,-3.466667,-44.883333
br,mecalineta,Mecalineta,25,,4.383333,-61.133333
br,mecejana,Mecejana,06,,-3.833333,-38.483333
br,medeiros de baixo,Medeiros de Baixo,18,,-25.376361,-48.455037
br,medeiros de cima,Medeiros de Cima,18,,-25.408695,-48.458608
br,medeiros,Medeiros,06,,-2.85,-40.266667
br,medeiros,Medeiros,15,,-19.983333,-46.216667
br,medeiros,Medeiros,18,,-25.166667,-52.8
br,medeiros,Medeiros,26,,-26.7157,-48.7418
br,medeiros,Medeiros,27,,-23.5986,-47.9279
br,medeiros neto,Medeiros Neto,05,15255,-17.333333,-40.233333
br,medianeira,Medianeira,18,34069,-25.283333,-54.083333
br,medianeira,Medianeira,23,,-29.9955,-51.308
br,medina,Medina,02,,-9.25,-36.216667
br,medina,Medina,15,14686,-16.25,-41.483333
br,medique,Medique,23,,-32.083333,-52.2
br,meditacao,Meditação,04,,-6.4,-62.216667
br,medonho,Medonho,06,,-5.183333,-40.966667
br,meguerez,Meguerez,04,,1.05,-67.266667
br,meia lata,Meia Lata,04,,-5.117222,-59.293889
br,meia legua,Meia Légua,27,,-23.833333,-47.883333
br,meia-legua,Meia-Légua,27,,-23.904082,-47.116574
br,meia lua,Meia Lua,18,,-25.778482,-50.221561
br,meia ponte,Meia Ponte,29,,-15.85,-48.95
br,meia praia,Meia Praia,26,,-27.123056,-48.613611
br,meier,Méier,21,,-22.901336,-43.281475
br,meio do serra,Meio do Serra,21,,-22.551111,-43.185
br,meio,Meio,05,,-13.133333,-38.85
br,meio,Meio,30,,-8.633333,-37.6
br,meios,Meios,20,,-5.416667,-41.316667
br,meirim,Meirim,02,,-9.516667,-35.616667
br,meirus,Meirus,02,,-9.683333,-37.383333
br,meladinho,Meladinho,30,,-8.966667,-36.816667
br,melado,Melado,05,,-13.533333,-44.633333
br,melado,Melado,15,,-20.283333,-46.8
br,melado,Melado,21,,-22.943333,-43.490556
br,melado,Melado,27,,-20.783333,-47.816667
br,melancia,Melancia,05,,-12.2,-45.383333
br,melancia,Melancia,06,,-3.066667,-39.783333
br,melancia,Melancia,13,,-3.0375,-42.103611
br,melancia,Melancia,15,,-16.116667,-40.333333
br,melancia,Melancia,17,,-6.7,-38.566667
br,melancia,Melancia,20,,-3.703333,-42.672222
br,melancia,Melancia,22,,-5.133333,-37.266667
br,melancia,Melancia,30,,-8.4,-37.083333
br,melancias,Melancias,05,,-10.783333,-42.216667
br,melancias,Melancias,06,,-4.772222,-37.284444
br,melancias,Melancias,17,,-7.083333,-36.416667
br,melancias,Melancias,22,,-5.133333,-37.266667
br,melao,Melão,06,,-4.066667,-38.816667
br,melao,Melão,22,,-6.383333,-36.183333
br,meleiro,Meleiro,26,,-28.833333,-49.633333
br,meleiros,Meleiros,15,,-20.316667,-45.3
br,melgaco,Melgaço,14,,-16.216667,-55.966667
br,melgaco,Melgaço,16,,-1.783333,-50.733333
br,melissa,Melissa,18,,-24.833333,-53.416667
br,melissa velha,Melissa Velha,18,,-24.75,-53.333333
br,mello vianna,Mello Vianna,15,,-19.433333,-45.783333
br,mel,Mel,06,,-6.383333,-39.583333
br,mel,Mel,13,,-3.633333,-45.116667
br,mel,Mel,25,,3.016667,-61.066667
br,melo barreto,Melo Barreto,21,,-22.933333,-42.933333
br,melo,Melo,16,,-.783333,-47
br,melo,Melo,22,,-6.383333,-36.183333
br,melos,Melos,06,,-6.416667,-40.733333
br,melos,Melos,15,,-20.133333,-42.933333
br,melos,Melos,23,,-29.783333,-52.183333
br,melos,Melos,30,,-7.8,-39.35
br,meloso,Meloso,15,,-19.066667,-43.333333
br,melo-viana,Melo-Viana,15,,-19.433333,-45.783333
br,melo viana,Melo Viana,15,,-19.466667,-42.633333
br,melquiades,Melquíades,15,,-15.933333,-40.416667
br,melquiades,Melquíades,16,,-3.233333,-46.8
br,membeca,Membeca,21,,-22.292222,-43.275833
br,membeca,Membeca,27,,-22.35,-47.283333
br,memori,Memori,13,,-5.916667,-44.083333
br,mendanha,Mendanha,15,,-18.1,-43.5
br,mendanha,Mendanha,21,,-22.846258,-43.544267
br,mendes,Mendes,05,,-13.833333,-41.35
br,mendes,Mendes,13,,-3.070278,-43.281389
br,mendes,Mendes,15,,-20.333333,-43.5
br,mendes,Mendes,18,,-24.752884,-48.88641
br,mendes,Mendes,20,,-6.05,-41.383333
br,mendes,Mendes,21,17308,-22.526111,-43.724722
br,mendes,Mendes,22,,-5.983333,-35.3
br,mendes,Mendes,30,,-7.7,-37.866667
br,mendes pimentel,Mendes Pimentel,15,,-18.666667,-41.4
br,mendez,Mendez,18,,-24.5,-54.333333
br,mendonca,Mendonça,13,,-4.533333,-44.35
br,mendonca,Mendonça,15,,-17.483333,-42.783333
br,mendonca,Mendonca,17,,-7.066667,-36.616667
br,mendonca,Mendonça,25,,.661944,-61.672778
br,mendonca,Mendonça,27,,-21.2,-49.566667
br,mendubim,Mendubim,20,,-5.066667,-41.25
br,meneghetti,Meneghetti,23,,-28.083333,-52.283333
br,menezes,Menezes,23,,-30.1,-54.8
br,menino deus,Menino Deus,16,,-1.983333,-49.05
br,menino deus,Menino Deus,23,,-30.058333,-51.220833
br,menino,Menino,16,,-.75,-50.583333
br,mentirosos,Mentirosos,30,,-8.4,-36.016667
br,meoas,Meoas,13,,-3.316667,-44.983333
br,mercador,Mercador,20,,-7.1,-40.766667
br,mercedes,Mercedes,01,,-9.516667,-68.7
br,mercedes,Mercedes,11,,-19.266667,-57.066667
br,mercedes,Mercedes,18,,-24.45,-54.183333
br,merces de agua limpa,Mercês de Água Limpa,15,,-21.033333,-44.6
br,merces de diamantina,Mercês de Diamantina,15,,-17.95,-43.166667
br,merces,Mercês,01,,-9.516667,-68.7
br,merces,Mercês,05,,-12.433333,-38.866667
br,merces,Mercês,15,,-21.2,-43.35
br,merces,Mercês,30,,-8.316667,-35.1
br,merejo,Merêjo,06,,-6.166667,-40.683333
br,merejo,Merejo,17,,-6.733333,-38.133333
br,merenda,Merenda,27,,-23.4259,-46.0692
br,mergueira,Mergueira,20,,-6.133333,-41.983333
br,mergulhao,Mergulhão,04,,-6.183333,-62.083333
br,mergulhao,Mergulhão,18,,-25.3029,-48.7446
br,meridiano,Meridiano,27,,-20.366667,-50.183333
br,meriruma,Merirumã,16,,1.116667,-54.65
br,meriti,Meriti,21,,-22.798614,-43.360894
br,merity,Merity,21,,-22.798614,-43.360894
br,meruoca,Meruoca,06,,-3.466667,-40.466667
br,meruoca,Meruoca,20,,-4.816667,-42.75
br,merure,Meruré,14,,-15.55,-53.083333
br,merusca,Merusca,20,,-4.816667,-42.75
br,mervesta,Mervesta,06,,-5.35,-39.866667
br,mesa do imperador,Mesa do Imperador,21,,-22.971976,-43.257593
br,mesota,Mesota,30,,-7.833333,-37.516667
br,mesqueira,Mesqueira,13,,-3.117222,-43.47
br,mesquita,Mesquita,15,,-19.216667,-42.583333
br,mesquita,Mesquita,21,,-22.785815,-43.432642
br,mesquita,Mesquita,27,,-22.016667,-49.8
br,messejana,Messejana,06,,-3.833333,-38.483333
br,messianopolis,Messianópolis,29,,-16.433333,-50.7
br,messias,Messias,02,12376,-9.416667,-35.833333
br,messias,Messias,24,,-9.8,-65.65
br,mestre almeida,Mestre Almeida,21,,-22.25,-43.5
br,mestre caetano,Mestre Caetano,15,,-19.85,-43.733333
br,metalurgico,Metalúrgico,21,,-22.309254,-42.864076
br,metancia,Metancia,20,,-6.866667,-42.4
br,metaripua,Metaripuá,04,,-7.683333,-66.633333
br,metelandia,Metelândia,18,,-25.2413,-53.983
br,meudon,Meudon,21,,-22.428551,-42.958745
br,meu rancho,Meu Rancho,22,,-5.4,-35.616667
br,micui,Micui,04,,.483333,-69.05
br,migueis,Miguéis,17,,-7.516667,-38.25
br,miguel alves,Miguel Alves,20,10439,-4.166667,-42.9
br,miguel bento,Miguel Bento,03,,-.533333,-52.516667
br,miguel burnier,Miguel Burnier,15,,-20.433333,-43.783333
br,miguel calmon,Miguel Calmon,05,13748,-11.433333,-40.6
br,miguel calmon,Miguel Calmon,06,,-5.933333,-39.416667
br,miguel chalubi,Miguel Chalubi,15,,-16.7,-41.916667
br,miguel couto,Miguel Couto,21,,-22.7,-43.433333
br,miguel do peixe,Miguel do Peixe,05,,-12.1,-41.1
br,miguelino,Miguelino,11,,-23.716667,-55.4
br,miguelito,Miguelito,11,,-23.716667,-55.4
br,miguelito,Miguelito,21,,-22.296763,-42.781931
br,miguel jorge,Miguel Jorge,27,,-23.016667,-47.85
br,miguel leao,Miguel Leão,20,,-5.683333,-42.733333
br,miguel lobato,Miguel Lobato,23,,-30.516667,-53.316667
br,miguel longuinho,Miguel Longuinho,15,,-21.2,-46.55
br,miguel,Miguel,15,,-20.033333,-46.25
br,miguelopolis,Miguelópolis,27,18262,-20.2,-48.05
br,miguel pereira,Miguel Pereira,06,,-5.016667,-38.033333
br,miguel pereira,Miguel Pereira,21,23850,-22.452778,-43.476389
br,miguel teixeira,Miguel Teixeira,15,,-20.033333,-46.25
br,miguel xavier,Miguel Xavier,06,,-7.1,-39.2
br,milagre,Milagre,05,,-12.033333,-41.966667
br,milagre,Milagre,15,,-21.3,-47
br,milagre,Milagre,22,,-5.836944,-37.392222
br,milagres,Milagres,05,,-12.866667,-39.85
br,milagres,Milagres,06,12588,-7.283333,-38.95
br,milagres,Milagres,13,,-3.581111,-42.609444
br,milagres,Milagres,15,,-21.3,-47
br,milagres,Milagres,20,,-3.7875,-42.291111
br,milha dos birros,Milhã dos Birros,22,,-5.616667,-35.933333
br,milha,Milhã,06,,-5.666667,-39.183333
br,milha,Milhá,22,,-5.3,-37.616667
br,milha,Milhã,27,,-22.8475,-47.756667
br,milhans,Milhans,06,,-7.183333,-40.316667
br,milho branco,Milho Branco,14,,-15.566667,-56.916667
br,milhoes,Milhões,13,,-6.6,-43.85
br,milho,Milho,05,,-11.05,-39.7
br,milho,Milho,06,,-4.45,-39.7
br,milho,Milho,24,,-9.016667,-61.933333
br,milho verde,Milho Verde,15,,-18.45,-43.5
br,milona,Milona,22,,-5.9,-37.866667
br,mimosa,Mimosa,05,,-10.316667,-40.5
br,mimosa,Mimosa,20,,-5.066667,-42.133333
br,mimosa,Mimosa,31,,-12.266667,-46.75
br,mimoso do sul,Mimoso do Sul,08,14045,-21.066667,-41.366667
br,mimoso,Mimoso,05,,-10.266667,-41.416667
br,mimoso,Mimoso,08,,-21.066667,-41.366667
br,mimoso,Mimoso,11,,-19.683333,-55.1
br,mimoso,Mimoso,13,,-6.166667,-43.083333
br,mimoso,Mimoso,14,,-16.283333,-55.8
br,mimoso,Mimoso,17,,-6.7,-37.5
br,mimoso,Mimoso,20,,-3.553056,-42.02
br,mimoso,Mimoso,29,,-15.166667,-48.083333
br,mimoso,Mimoso,30,,-8.25,-35.833333
br,mimosos,Mimosos,20,,-4.116667,-42.466667
br,mimozo,Mimozo,14,,-16.283333,-55.8
br,mina brejui,Mina Brejuí,22,,-6.316667,-36.55
br,mina de chelita,Mina de Chelita,22,,-5.968611,-36.461944
br,mina do leao,Mina do Leão,23,,-30.116667,-52.05
br,mina do loao,Mina do Loão,23,,-30.116667,-52.05
br,minador de baixo,Minador de Baixo,20,,-3.296389,-42.008611
br,minador de cima,Minador de Cima,20,,-3.322222,-42.008889
br,minador do negrao,Minador do Negrão,02,1986,-9.333333,-36.866667
br,minador do negro,Minador do Negro,02,,-9.333333,-36.866667
br,minador,Minador,02,,-9.666667,-37.466667
br,minador,Minador,05,,-12.233333,-39.7
br,minador,Minador,06,,-4.5,-39.833333
br,minador,Minador,20,,-5.65,-42.483333
br,minador,Minador,30,,-7.4,-37.483333
br,minadouro,Minadouro,17,,-7.616667,-37.883333
br,minadouro,Minadouro,20,,-3.777222,-42.278889
br,mina,Mina,20,,-7.066667,-41.816667
br,minas do espirito santo,Minas do Espírito Santo,05,,-12.033333,-42.133333
br,minas do mimoso,Minas do Mimoso,05,,-10.266667,-41.416667
br,minas do rio de contas,Minas Do Rio De Contas,05,,-13.6,-41.8
br,mina seca,Mina Sêca,16,,-1.8,-46.616667
br,minas gerais,Minas Gerais,01,,-8.966667,-72.783333
br,minas,Minas,23,,-30.666667,-52.85
br,minas novas,Minas Novas,15,7365,-17.25,-42.6
br,mina velha,Mina Velha,26,,-25.9943,-48.7192
br,minduri,Minduri,15,,-21.683333,-44.616667
br,mineira,Mineira,05,,-12.35,-39.3
br,mineirolandia,Mineirolândia,06,,-5.5,-39.633333
br,mineiro,Mineiro,06,,-5.666667,-38.483333
br,mineiro,Mineiro,13,,-5.133333,-43.45
br,mineiro,Mineiro,22,,-5.823611,-36.749722
br,mineiro,Mineiro,30,,-7.966667,-36.383333
br,mineiros do tiete,Mineiros do Tietê,27,,-22.4,-48.433333
br,mineiros,Mineiros,21,,-22.733333,-42.466667
br,mineiros,Mineiros,27,,-22.4,-48.433333
br,mineiros,Mineiros,29,38951,-17.566667,-52.566667
br,mineracao pedra branca,Mineração Pedra Branca,18,,-25.9947,-49.3303
br,mineracao rondonia,Mineração Rondônia,24,,-9.333333,-62.833333
br,minerva,Minerva,03,,2.5,-50.883333
br,minervinho,Minervinho,15,,-15.133333,-42.716667
br,mingau de baixo,Mingau de Baixo,05,,-13.066667,-39.166667
br,mingau,Mingau,05,,-13.05,-39.2
br,mingote,Mingote,05,,-11.95,-37.85
br,minguante,Minguante,27,,-23.068569,-47.753158
br,minguinho,Minguinho,18,,-25.483333,-50.033333
br,mingu,Mingu,15,,-14.966667,-42.816667
br,minhas,Minhas,04,,-7.333056,-62.924444
br,minhoca,Minhoca,27,,-23.114587,-47.836727
br,minuim,Minuim,05,,-9.85,-38.083333
br,miquilina,Miquilina,17,,-6.55,-37.75
br,mira alem,Mira Além,27,,-20.916667,-50.033333
br,mirabela,Mirabela,15,8934,-16.258056,-44.159167
br,miracatu,Miracatu,27,11679,-24.283333,-47.466667
br,miracema do norte,Miracema do Norte,31,,-9.529167,-48.319722
br,miracema do tocantins,Miracema do Tocantins,31,29181,-9.529167,-48.319722
br,miracema,Miracema,21,26684,-21.416667,-42.183333
br,miracema,Miracema,31,,-9.529167,-48.319722
br,miracica,Miracica,30,,-9.05,-36.533333
br,mirador,Mirador,02,,-9.666667,-37.466667
br,mirador,Mirador,06,,-5.466667,-40.066667
br,mirador,Mirador,13,6955,-6.366667,-44.366667
br,mirador,Mirador,17,,-7.45,-38.083333
br,mirador,Mirador,18,,-23.2,-52.833333
br,mirador,Mirador,20,,-8.029722,-45.218889
br,mirador,Mirador,26,,-27.0663,-49.7086
br,mirador,Mirador,30,,-7.75,-38.416667
br,miradouro,Miradouro,15,,-20.883333,-42.35
br,miradouro,Miradouro,20,,-4.933333,-42.316667
br,mira estrela,Mira Estrêla,27,,-19.983333,-50.166667
br,mira-flores,Mira-Flores,01,,-8.45,-69.983333
br,miragaia,Miragaia,15,,-21.05,-43
br,miragem,Miragem,06,,-7.033333,-39.283333
br,miragem,Miragem,11,,-21.466667,-57.15
br,miraguaia,Miraguaia,23,,-29.85,-50.6
br,mirahy,Mirahy,15,,-21.2,-42.616667
br,miraima ii,Miraima II,20,,-5.116667,-41.4
br,miraima,Miraíma,06,,-3.583333,-39.983333
br,mirai,Miraí,15,8500,-21.2,-42.616667
br,miralta,Miralta,15,,-16.583333,-43.95
br,miraluz,Miraluz,27,,-20.933333,-49.7
br,miramar,Miramar,06,,-4.116667,-39.4
br,miramar,Miramar,16,,-1.402778,-48.491667
br,mirambe,Mirambé,06,,-3.816667,-38.683333
br,mira,Mira,04,,-4.755556,-62.1625
br,miranda,Miranda,04,,-3.076667,-61.535833
br,miranda,Miranda,05,,-11.683333,-41.766667
br,miranda,Miranda,06,,-3.333333,-39.283333
br,miranda,Miranda,11,13189,-20.233333,-56.366667
br,miranda,Miranda,13,,-3.55,-44.516667
br,miranda,Miranda,14,,-8.35,-57.95
br,miranda,Miranda,15,,-20.166667,-41.733333
br,miranda,Miranda,17,,-6.933333,-38.216667
br,miranda,Miranda,26,,-26.334,-48.6553
br,miranda,Miranda,28,,-10.6,-37.05
br,mirandas,Mirandas,27,,-23.379576,-47.762364
br,mirandela,Mirandela,05,,-10.666667,-38.616667
br,mirandella,Mirandella,05,,-10.666667,-38.616667
br,mirandiba,Mirandiba,30,,-8.1,-38.733333
br,mirandinha,Mirandinha,06,,-3.366667,-39.3
br,mirando,Mirando,17,,-7.183333,-37.766667
br,mirandopolis,Mirandópolis,15,,-18.366667,-41.2
br,mirandopolis,Mirandópolis,27,23379,-21.15,-51.1
br,mirangaba,Mirangaba,05,,-10.95,-40.583333
br,miranga,Miranga,05,,-12.366667,-38.25
br,miranorte,Miranorte,31,12446,-9.476667,-48.480278
br,mirantao,Mirantão,15,,-22.25,-44.5
br,mirante do paranapanema,Mirante do Paranapanema,27,9387,-22.283333,-51.9
br,mirante,Mirante,05,,-12.716667,-39.183333
br,mirante,Mirante,18,,-25.183037,-48.359821
br,mirante,Mirante,20,,-3.813889,-42.302222
br,mirante,Mirante,27,,-20.116667,-47.716667
br,mirapenima,Mirapenima,04,,-2.180278,-61.142778
br,mirapinima,Mirapinima,04,,-2.180278,-61.142778
br,miraporanga,Miraporanga,15,,-19.25,-48.45
br,mirari,Mirari,04,,-5.666944,-60.9225
br,mirary,Mirary,04,,-7.765,-62.941944
br,miraselva,Miraselva,22,,-5.55,-37.75
br,miraselvas,Miraselvas,16,,-1.083333,-46.983333
br,mira sol,Mira Sol,27,,-20.766667,-49.466667
br,mirasselvas,Mirasselvas,16,,-1.083333,-46.983333
br,mirassolandia,Mirassolândia,27,,-20.633333,-49.483333
br,mirassol,Mirassol,02,,-9.466667,-36.616667
br,mirassol,Mirassol,27,51559,-20.766667,-49.466667
br,miratinim,Miratinim,04,,-3.681111,-62.999444
br,mirazol,Mirazol,27,,-20.766667,-49.466667
br,mirianopolis,Mirianópolis,13,,-4.783333,-44.633333
br,mirilandia,Mirilândia,29,,-15.683333,-49.183333
br,mirim doce,Mirim Doce,26,,-27.2,-50.083333
br,mirim,Mirim,02,,-9.516667,-35.616667
br,mirim,Mirim,06,,-3.5,-40.266667
br,mirim,Mirim,13,,-3.351111,-43.071944
br,mirim,Mirim,23,,-33.2,-53.233333
br,mirim,Mirim,26,,-27.2,-50.083333
br,mirim,Mirim,30,,-8.533333,-37.7
br,mirindiba,Mirindiba,06,,-2.95,-40.016667
br,mirindiba,Mirindiba,20,,-6.533333,-42.083333
br,mirinsal,Mirinsal,13,,-2.016667,-44.716667
br,mirinzal,Mirinzal,13,,-2.016667,-44.716667
br,miriri,Miriri,17,,-6.866667,-34.9
br,miritiba de sao jose de piria,Miritiba de São José de Piriá,13,,-2.616667,-43.45
br,miritiba,Miritiba,13,,-2.616667,-43.45
br,miriti,Miriti,04,,-6.651111,-62.319444
br,miritituba,Miritituba,16,,-4.266667,-55.9
br,miritizal,Miritizal,01,,-7.7,-72.633333
br,mirituba,Mirituba,16,,-4.266667,-55.9
br,mirity,Mirity,04,,-6.651111,-62.319444
br,miriu,Miriú,22,,-5.55,-35.25
br,mirizal,Mirizal,25,,2.633333,-60.1
br,miroras,Mirorás,05,,-11.433333,-42.316667
br,miroro,Miroró,05,,-11.433333,-42.316667
br,miroro,Miroró,13,,-5.95,-43.166667
br,miroros,Mirorós,05,,-11.433333,-42.316667
br,misael,Misael,11,,-21.883333,-55.4
br,misercordia,Misercórdia,05,,-12.933333,-38.666667
br,misericordia,Misericórdia,05,,-12.933333,-38.666667
br,misericordia,Misericórdia,17,,-7.3,-38.166667
br,misericordia,Misericórdia,24,,-10.283333,-65.3
br,missao de sao francisco,Missão de São Francisco,16,,-7.533333,-57.733333
br,missao do cururu,Missão do Cururu,16,,-7.616667,-57.583333
br,missao do sahi,Missão do Sahi,05,,-10.533333,-40.233333
br,missao do sai,Missão do Saí,05,,-10.533333,-40.233333
br,missao,Missão,05,,-10.533333,-40.233333
br,missao,Missão,06,,-6.183333,-40.45
br,missao,Missão,16,,-5.25,-56.816667
br,missao,Missão,31,,-11.551944,-46.803333
br,missao nova,Missão Nova,06,,-7.35,-39.216667
br,missao sao francisco,Missão São Francisco,16,,-7.533333,-57.733333
br,missao velha,Missão Velha,06,13106,-7.25,-39.133333
br,missao velha,Missão Velha,16,,-5.533333,-56.916667
br,missao velho,Missão Velho,16,,-5.533333,-56.916667
br,missianopolis,Missianópolis,29,,-16.433333,-50.7
br,missi,Missi,06,,-3.616667,-39.833333
br,missionario,Missionário,15,,-21,-43.5
br,missioneiros,Missioneiros,23,,-28.466667,-54.716667
br,missoes,Missões,04,,-7.433333,-64.866667
br,missoes,Missões,05,,-12.05,-44.466667
br,missoes,Missões,15,,-14.883333,-44.083333
br,missoes,Missões,31,,-11.551944,-46.803333
br,mista,Mista,27,,-20.466667,-47.766667
br,miudeza,Miudeza,05,,-12.116667,-40.7
br,mizael,Mizael,11,,-21.883333,-55.4
br,moacir,Moacir,05,,-19.233333,-40.483333
br,moca branca,Moça Branca,30,,-7.783333,-37.966667
br,mocacos,Mocacos,15,,-19.6,-44.25
br,mocada,Moçada,26,,-26.990193,-49.517255
br,mocaja,Mocajá,04,,-7.116667,-58.633333
br,mocajuba,Mocajuba,16,16567,-2.583333,-49.5
br,mocambeiro,Mocambeiro,15,,-19.533333,-44.033333
br,mocambinho,Mocambinho,03,,.566667,-52.2
br,mocambinho,Mocambinho,05,,-11.233333,-39.5
br,mocambinho,Mocambinho,13,,-3.133333,-43.316667
br,mocambinho,Mocambinho,15,,-16.166667,-43.35
br,mocambinho,Mocambinho,20,,-6.116667,-41.933333
br,mocambinho,Mocambinho,30,,-7.866667,-37.816667
br,mocambo de baixo,Mocambo de Baixo,13,,-3.15,-42.024722
br,mocambo de cima,Mocambo de Cima,13,,-3.159722,-42.05
br,mocambo do espirito santo,Mocambo do Espírito Santo,16,,.7,-55.916667
br,mocambo do vento,Mocambo do Vento,05,,-10.833333,-42.883333
br,mocambo,Mocambo,02,,-9.75,-36.466667
br,mocambo,Mocambo,03,,.6,-52.2
br,mocambo,Mocambo,05,,-11.733333,-42.983333
br,mocambo,Mocambo,06,,-3.033333,-41.2
br,mocambo,Mocambo,13,,-3.471389,-42.408889
br,mocambo,Mocambo,15,,-14.666667,-44.3
br,mocambo,Mocambo,17,,-6.95,-37.25
br,mocambo,Mocambo,20,,-10.5,-44.3
br,mocambo,Mocambo,28,,-10.15,-37.116667
br,mocambo,Mocambo,30,,-7.366667,-37.15
br,mocha,Mocha,20,,-7.016667,-42.133333
br,mochila,Mochila,04,,-7.516667,-71.316667
br,mocho,Môcho,30,,-7.716667,-39.216667
br,mocidade,Mocidade,25,,3.466667,-60.916667
br,mococa,Mococa,15,,-20.866667,-45.333333
br,mococa,Mococa,27,59656,-21.466667,-47.016667
br,moco,Mocó,05,,-10.983333,-39.216667
br,moco,Mocó,06,,-7.033333,-38.983333
br,moco,Mocó,20,,-7.866667,-41.566667
br,moco,Mocó,30,,-8.616667,-36.083333
br,mocooca,Mocoóca,27,,-23.583333,-45.316667
br,mocoro,Moçoró,22,,-5.191389,-37.344722
br,mocos,Mocós,06,,-5.333333,-38.283333
br,mocos,Mocós,13,,-4.3,-44.866667
br,mocoto,Mocotó,16,,-3.916667,-47.15
br,mocoto,Mocotó,21,,-21.85,-41.683333
br,mocozinho,Mocòzinho,05,,-14.65,-41.95
br,modelo,Modêlo,11,,-18.75,-57.233333
br,modelo,Modêlo,15,,-21.8,-45.433333
br,moderna,Moderna,30,,-8.433333,-37.416667
br,modesto,Modesto,05,,-14.316667,-40.45
br,moeda,Moeda,15,,-18.683333,-49.166667
br,moema,Moema,15,,-19.833333,-45.4
br,moema,Moema,16,,-1.316667,-48.2
br,moema,Moema,26,,-26.466667,-49.866667
br,moenda,Moenda,05,,-13.4,-39.4
br,mofumbo,Mofumbo,06,,-7.166667,-38.8
br,mofumbo,Mofumbo,17,,-6.716667,-37.866667
br,mofumbo,Mofumbo,22,,-6.666667,-37.483333
br,mogeiro,Mogeiro,17,4767,-7.3,-35.466667
br,mogi das cruzes,Mogi das Cruzes,27,,-23.516667,-46.183333
br,mogi-guacu,Mogi-Guaçu,27,,-22.366667,-46.95
br,mogi-mirim,Mogi-Mirim,27,,-22.433333,-46.95
br,mogiquicaba,Mogiquiçaba,05,,-16.083333,-38.966667
br,mogy das cruzes,Mogy das Cruzes,27,,-23.516667,-46.183333
br,mogy guassu,Mogy Guassú,27,,-22.366667,-46.95
br,mogy-mirim,Mogy-Mirim,27,,-22.433333,-46.95
br,moibanda,Moibanda,04,,-4.616667,-62.066667
br,moiboada,Moiboada,04,,-4.616667,-62.066667
br,moinho de santa rosa,Moinho de Santa Rosa,22,,-5.416389,-36.07
br,moinho grande,Moinho Grande,27,,-23.553137,-47.034139
br,moinho,Moinho,15,,-21.7,-45.416667
br,moinho,Moinho,22,,-5.433333,-36.816667
br,moinho,Moinho,27,,-23.330429,-47.958368
br,moinho,Moinho,29,,-13.9,-47.4
br,moinhos,Moinhos,15,,-21.9,-46.583333
br,moipora,Moiporá,29,,-16.566667,-50.7
br,moiraba,Moiraba,16,,-2.45,-49.416667
br,moises,Moisés,15,,-21.566667,-46.233333
br,moises,Moises,18,,-23.496116,-52.562937
br,moises quito,Moisés Quito,14,,-17.933333,-53.566667
br,moises quitos,Moisés Quitos,14,,-17.933333,-53.566667
br,moises sena,Moisés Sena,15,,-16.983333,-41.983333
br,moita bonita,Moita Bonita,28,3602,-10.583333,-37.366667
br,moita da conceicao,Moita da Conceiçao,02,,-9.466667,-37.283333
br,moita,Moita,05,,-12.616667,-38.233333
br,moita redonda,Moita Redonda,28,,-10.266667,-37.116667
br,moitas,Moitas,13,,-3.183333,-44.833333
br,moita verde,Moita Verde,22,,-5.883333,-35.266667
br,moitinha,Moitinha,15,,-19.916667,-45.016667
br,moitu,Moitu,29,,-16.733333,-50.633333
br,mojeiro,Mojeiro,17,,-7.3,-35.466667
br,moji das cruzes,Moji das Cruzes,27,325753,-23.516667,-46.183333
br,moji-guacu,Moji-Guaçu,27,,-22.366667,-46.95
br,moji-mirim,Moji-Mirim,27,78245,-22.433333,-46.95
br,mojiquicaba,Mojiquiçaba,05,,-16.083333,-38.966667
br,moju,Moju,16,21511,-1.883333,-48.766667
br,mojutapera,Mojutapera,16,,-2.6,-49.616667
br,moleque,Moleque,20,,-6.683333,-42.2
br,moleque,Moleque,29,,-13.4,-47.5
br,moleque,Moleque,30,,-7.716667,-37.583333
br,moleques,Moleques,17,,-6.616667,-37.75
br,molhadinha,Molhadinha,17,,-7.183333,-36.216667
br,molheiros,Molheiros,11,,-19.8,-57.7
br,molho,Môlho,05,,-13.7,-44.583333
br,molongo,Molongó,04,,-5.395833,-59.988889
br,momanas,Momanas,15,,-16.733333,-43.7
br,mombaca de cima,Mombaca de Cima,22,,-6.166667,-37.85
br,mombaca i,Mombaca I,13,,-3.293889,-42.370833
br,mombaca,Mombaça,05,,-11.616667,-38.916667
br,mombaca,Mombaça,20,17065,-5.75,-39.633333
br,mombach,Mombach,23,,-27.7,-54.75
br,mombacinha,Mombacinha,02,,-9.883333,-36.7
br,mombaco,Mombaço,29,,-15.716667,-48.716667
br,mombaim,Mombaim,23,,-27.7,-54.75
br,mombuca,Mombuca,15,,-16.283333,-40.966667
br,mombuca,Mombuca,27,,-22.933333,-47.566667
br,momosa,Momosa,22,,-5.884722,-37.1825
br,moncao do vaz,Moncão do Vaz,29,,-16.35,-50.9
br,moncao,Monção,13,11051,-3.5,-45.25
br,moncao,Monção,21,,-21.416667,-41.7
br,moncao,Monção,27,,-22.883333,-49.183333
br,monchao do vaz,Monchão do Vaz,29,,-16.35,-50.9
br,moncoes,Monções,27,,-20.866667,-50.083333
br,moncuaba,Moncuaba,21,,-23.016667,-44.216667
br,mondahy,Mondahy,26,,-27.083333,-53.416667
br,mondai,Mondaí,26,,-27.083333,-53.416667
br,mondego,Mondego,04,,-4.726667,-62.331111
br,mondubim,Mondubim,06,,-3.8,-38.583333
br,mondubim,Mondubim,13,,-6.483333,-43.266667
br,mondubim,Mondubim,20,,-5.066667,-41.25
br,monegate,Monegate,18,,-25.580878,-50.169664
br,mone,Mone,05,,-13.883333,-40.566667
br,monera,Monerá,21,,-22.066667,-42.416667
br,monero,Moneró,21,,-22.797072,-43.19933
br,mongaba,Mongaba,03,,.7,-51.866667
br,mongagua,Mongaguá,27,45931,-24.1,-46.616667
br,monguba,Monguba,06,,-3.65,-38.75
br,monguba,Monguba,16,,-6.433333,-57.633333
br,monica,Mônica,17,,-7.2,-36.166667
br,monica,Mônica,18,,-23.783333,-51.983333
br,monjolada,Monjolada,27,,-22.733333,-47.883333
br,monjolinho,Monjolinho,11,,-20.816667,-55.633333
br,monjolinho,Monjolinho,14,,-15.933333,-56.916667
br,monjolinho,Monjolinho,15,,-19.55,-49.25
br,monjolinho,Monjolinho,18,,-23.267824,-49.92223
br,monjolinho,Monjolinho,27,,-22.7021,-45.7123
br,monjolo,Monjolo,11,,-19.283333,-57.516667
br,monjolo,Monjolo,14,,-15.283333,-56.383333
br,monjolo,Monjolo,15,,-21.683333,-46.2
br,monjolo,Monjolo,18,,-25.549107,-50.712953
br,monjolo,Monjolo,21,,-22.816667,-42.95
br,monjolos,Monjolos,15,,-18.3,-44.083333
br,monleiro,Monleiro,17,,-7.366667,-37.633333
br,monlevade,Monlevade,15,,-19.833333,-43.133333
br,monlolo,Monlolo,11,,-19.283333,-57.516667
br,monsanto,Monsanto,15,,-21.2,-46.983333
br,monsaras,Monsarás,16,,-.933333,-48.583333
br,monsenhor gil,Monsenhor Gil,20,4751,-5.583333,-42.616667
br,monsenhor hipolito,Monsenhor Hipólito,20,,-6.983333,-41.116667
br,monsenhor horta,Monsenhor Horta,15,,-20.333333,-43.3
br,monsenhor joao alexandre,Monsenhor João Alexandre,15,,-20.366667,-44.683333
br,monsenhor paulo,Monsenhor Paulo,15,,-21.766667,-45.55
br,monsenhor tabosa,Monsenhor Tabosa,06,,-4.783333,-40.066667
br,monsores,Monsores,21,,-22.47,-43.556389
br,monsuaba,Monsuaba,21,,-23.016667,-44.216667
br,montalvao,Montalvão,27,,-22.033333,-51.35
br,mont' alverne,Mont' Alverne,23,,-29.566667,-52.333333
br,montana,Montana,08,,-18.133333,-40.35
br,montanha,Montanha,08,11934,-18.133333,-40.35
br,montanhas,Montanhas,22,8442,-6.483333,-35.3
br,montao,Montão,06,,-5.45,-39.95
br,montauri,Montauri,23,,-28.65,-52.066667
br,monte alegre de goias,Monte Alegre de Goiás,29,,-13.233333,-47.166667
br,monte alegre de minas,Monte Alegre de Minas,15,12451,-18.866667,-48.866667
br,monte alegre de sergipe,Monte Alegre de Sergipe,28,6816,-10.033333,-37.55
br,monte alegre do mahu,Monte Alegre do Mahú,16,,-.866667,-47.8
br,monte-alegre-do-mau,Monte-Alegre-do-Maú,16,,-.866667,-47.8
br,monte alegre do piaui,Monte Alegre do Piauí,20,,-9.740556,-45.285556
br,monte alegre do sul,Monte Alegre do Sul,27,,-22.666667,-46.683333
br,monte alegre,Monte Alegre,01,,-8.34,-72.741389
br,monte alegre,Monte Alegre,04,,-3.375833,-62.636667
br,monte alegre,Monte Alegre,05,,-11.266667,-38.566667
br,monte alegre,Monte Alegre,06,,-3.933333,-38.85
br,monte alegre,Monte Alegre,13,,-2.466667,-44.816667
br,monte alegre,Monte Alegre,15,,-18.866667,-48.866667
br,monte alegre,Monte Alegre,16,22841,-2.016667,-54.066667
br,monte alegre,Monte Alegre,17,,-7.216667,-36.05
br,monte alegre,Monte Alegre,18,,-24.216667,-50.45
br,monte alegre,Monte Alegre,20,,-10.083333,-45.533333
br,monte alegre,Monte Alegre,21,,-20.933333,-41.816667
br,monte alegre,Monte Alegre,22,6643,-5.889722,-36.301389
br,monte alegre,Monte Alegre,23,,-27.583333,-52.466667
br,monte alegre,Monte Alegre,24,,-9.533333,-63.533333
br,monte alegre,Monte Alegre,25,,2.216667,-60.933333
br,monte alegre,Monte Alegre,26,,-27.3,-50.433333
br,monte alegre,Monte Alegre,27,,-20.333333,-47.816667
br,monte alegre,Monte Alegre,28,,-10.033333,-37.55
br,monte alegre,Monte Alegre,30,,-7.666667,-38.75
br,monte alegre,Monte Alegre,31,,-12.775,-47.256111
br,monte alto,Monte Alto,05,,-10.166667,-43.466667
br,monte alto,Monte Alto,13,,-5.833333,-47.066667
br,monte alto,Monte Alto,15,,-19.7,-50.45
br,monte alto,Monte Alto,27,41894,-21.283333,-48.483333
br,monte alto,Monte Alto,31,,-7.516667,-48.166667
br,monte alverne,Monte Alverne,06,,-7.116667,-39.516667
br,monte alverne,Monte Alverne,23,,-29.566667,-52.333333
br,monte aprazivel,Monte Aprazível,27,16308,-20.75,-49.7
br,monte ararat,Monte Ararat,06,,-5.833333,-39.3
br,monte aurea,Monte Aurea,04,,-4.926944,-62.4725
br,monte aureo,Monte Áureo,04,,-3.270833,-62.968056
br,monte azul do turvo,Monte Azul do Turvo,27,,-20.916667,-48.633333
br,monte azul,Monte Azul,05,,-10.033333,-38.2
br,monte azul,Monte Azul,15,11222,-15.15,-42.883333
br,monte azul,Monte Azul,27,,-20.916667,-48.633333
br,monte azul paulista,Monte Azul Paulista,27,18117,-20.916667,-48.633333
br,monte bello,Monte Bello,15,,-21.333333,-46.383333
br,monte bello,Monte Bello,23,,-29.166667,-51.633333
br,monte bello,Monte Bello,27,,-21.15,-49.516667
br,monte belo,Monte Belo,01,,-7.866667,-73.483333
br,monte belo,Monte Belo,05,,-13.35,-42.483333
br,monte belo,Monte Belo,06,,-6.016667,-39.316667
br,monte belo,Monte Belo,08,,-20.75,-40.85
br,monte belo,Monte Belo,15,,-16.716667,-41.866667
br,monte belo,Monte Belò,20,,-5.6,-42.566667
br,monte belo,Monte Belo,23,,-29.166667,-51.633333
br,monte belo,Monte Belo,27,,-20.783333,-47.966667
br,monte berico,Monte Bérico,23,,-29.1351,-51.2183
br,monte branco,Monte Branco,05,,-13.85,-40.433333
br,monte carmello,Monte Carmello,04,,-7.816667,-71.033333
br,monte carmello,Monte Carmello,15,,-18.716667,-47.483333
br,monte carmelo,Monte Carmelo,04,,-2.916667,-68.55
br,monte carmelo,Monte Carmelo,15,44041,-18.716667,-47.483333
br,monte carmo,Monte Carmo,20,,-5.966667,-42.183333
br,monte castelo,Monte Castelo,06,,-5.733333,-40.483333
br,monte castelo,Monte Castelo,21,,-22.094167,-43.217222
br,monte castelo,Monte Castelo,26,,-26.5,-50.183333
br,monte castelo,Monte Castelo,27,,-21.3,-51.566667
br,monte celeste,Monte Celeste,15,,-20.9,-42.883333
br,monte christo,Monte Christo,04,,-7.766667,-68.883333
br,monte christo,Monte Christo,16,,-4.066667,-55.633333
br,monte claro,Monte Claro,05,,-13.233333,-39.866667
br,monte claro,Monte Claro,06,,-4.133333,-38.833333
br,monte claro,Monte Claro,08,,-19.116667,-40.75
br,monte cristo,Monte Cristo,04,,-3.235,-63.0175
br,monte cristo,Monte Cristo,08,,-20.883333,-41.15
br,monte cristo,Monte Cristo,16,,-4.066667,-55.633333
br,monte cruzeiro,Monte Cruzeiro,05,,-12.9,-39.516667
br,monte da alianca,Monte da Aliança,05,,-12.466667,-38.683333
br,monte de ouro,Monte de Ouro,02,,-9.6,-36.466667
br,monte do carmo,Monte do Carmo,31,,-10.791111,-48.006667
br,monte dourado,Monte Dourado,16,,-.866667,-52.516667
br,monte d'ouro,Monte d'Ouro,27,,-20.733333,-49.883333
br,monte fernandes,Monte Fernandes,17,,-6.95,-37.533333
br,monte flor,Monte Flôr,06,,-5.166667,-39.883333
br,monte formoso,Monte Formosó,17,,-6.25,-37.533333
br,monte gorda,Monte Gorda,05,,-12.666667,-38.116667
br,monte gordo,Monte Gordo,05,,-12.666667,-38.116667
br,monte grande,Monte Grande,05,,-12.95,-38.616667
br,monte horebe,Monte Horebe,17,,-7.2,-38.6
br,monteirinho,Monteirinho,17,,-8.166667,-36.75
br,monteiro lobato,Monteiro Lobato,27,,-22.966667,-45.833333
br,monteiro,Monteiro,04,,-5.866111,-60.781667
br,monteiro,Monteiro,05,,-12.75,-39.216667
br,monteiro,Monteiro,06,,-2.9,-40.366667
br,monteiro,Monteiro,15,,-20.866667,-41.966667
br,monteiro,Monteiro,16,,-1.583333,-51.35
br,monteiro,Monteiro,17,17727,-7.883333,-37.116667
br,monteiro,Monteiro,21,,-22.929635,-43.572681
br,monteiro,Monteiro,23,,-29.25,-49.866667
br,monteiro,Monteiro,27,,-20.316667,-49.9
br,monteiropolis,Monteirópolis,02,,-9.6,-37.25
br,monteiros,Monteiros,27,,-20.666667,-47.166667
br,monte libano,Monte Líbano,16,,-4.183333,-51.916667
br,monte,Monte,05,,-12.9,-39.516667
br,monte,Monte,06,,-5.2,-39.35
br,monte mor,Monte Mor,27,40291,-22.95,-47.333333
br,montenebo,Montenebo,06,,-5.333333,-40.833333
br,montenegro,Montenegro,03,,2.05,-50.8
br,montenegro,Montenegro,23,54058,-29.7,-51.466667
br,monte negro,Monte Negro,27,,-23.301342,-46.17779
br,monte pascoal,Monte Pascoal,05,,-16.75,-39.533333
br,monte pascoal,Monte Pascoal,06,,-3.916667,-39.966667
br,monte real,Monte Real,18,,-23.2296,-50.1403
br,monte reconcavo,Monte Recôncavo,05,,-12.65,-38.616667
br,monterio,Monterio,17,,-7.883333,-37.116667
br,monte rosa,Monte Rosa,17,,-7.016667,-37.866667
br,montes altos,Montes Altos,13,3518,-5.833333,-47.066667
br,monte santo de minas,Monte Santo de Minas,15,16617,-21.2,-46.983333
br,monte santo,Monte Santo,03,,-.25,-51.683333
br,monte santo,Monte Santo,04,,-5.781667,-61.171944
br,monte santo,Monte Santo,05,7398,-10.433333,-39.333333
br,monte santo,Monte Santo,15,,-21.2,-46.983333
br,monte santo,Monte Santo,20,,-7.816667,-40.65
br,monte santo,Monte Santo,24,,-9.583333,-62.116667
br,monte santo,Monte Santo,27,,-20.4,-47.866667
br,monte santo,Monte Santo,31,,-9.897778,-49.044444
br,montes clarinhos,Montes Clarinhos,15,,-15.966667,-42.133333
br,montes claros,Montes Claros,15,332384,-16.716667,-43.866667
br,montes claros,Montes Claros,17,,-6.55,-37.783333
br,montes claros,Montes Claros,20,,-6.1,-41.916667
br,montes claros,Montes Claros,22,,-5.996944,-36.835556
br,montes claros,Montes Claros,29,,-17.15,-48.166667
br,montese,Montese,11,,-22,-54.85
br,monte serrat,Monte Serrat,21,,-22.018611,-43.314167
br,monte siao,Monte Sião,06,,-5.083333,-38.8
br,monte siao,Monte Sião,15,11090,-22.433333,-46.566667
br,monte sinai,Monte Sinai,04,,-6.9775,-71.418611
br,monte sinai,Monte Sinai,06,,-5.033333,-38.833333
br,montesina,Montesina,27,,-21.25,-48.633333
br,montes,Montes,05,,-10.516667,-39.566667
br,monte veneto,Monte Veneto,23,,-29.016667,-51.7
br,monte verde,Monte Verde,05,,-12.666667,-40.683333
br,monte verde,Monte Verde,08,,-20.65,-41.8
br,monte verde,Monte Verde,11,,-18.25,-54.683333
br,monte verde,Monte Verde,15,,-21.8,-42.933333
br,monte verde,Monte Verde,21,,-21.466667,-41.916667
br,monte verde,Monte Verde,27,,-20.85,-48.8
br,monte verde paulista,Monte Verde Paulista,27,,-20.85,-48.8
br,montevideo,Montevidéo,13,,-5.316667,-43.916667
br,montevideu,Montevidéu,04,,-3.783333,-64.033333
br,montevideu,Montevidéu,13,,-3.016667,-45.083333
br,montevideu,Montevidéu,17,,-6.966667,-37.883333
br,montevideu,Montevidéu,29,,-17.4,-51.233333
br,montevideu,Montevidéu,31,,-7.516667,-48.116667
br,montevidi,Montevidi,06,,-2.956944,-41.0425
br,montevidio,Montevidio,29,,-17.4,-51.233333
br,montevidiu,Montevidiu,29,,-17.4,-51.233333
br,montezinho,Montezinho,06,,-5.45,-40.483333
br,montezuma,Montezuma,15,,-15.166667,-42.5
br,montivedeu,Montivedéu,06,,-5.4,-40.35
br,montividiu,Montividiu,29,,-17.4,-51.233333
br,montreal,Montreal,04,,-7.45,-72.466667
br,monumento,Monumento,21,,-22.718333,-43.851389
br,moqueiro,Moqueiro,16,,-1.166667,-48.466667
br,moquem,Moquém,06,,-5.666667,-40.483333
br,moquem,Moquém,11,,-20.733333,-55.4
br,moquem,Moquém,13,,-3.742778,-43.217222
br,moquem,Moquém,15,,-16.149444,-44.167222
br,moquem,Moquém,20,,-3.458611,-42.336111
br,moquem,Moquem,29,,-14.55,-48.133333
br,moquenho,Moquenho,30,,-7.8,-39.666667
br,moqueta,Moquetá,21,,-22.742526,-43.460125
br,morada bom lugar,Morada Bom Lugar,16,,-4.416944,-53.651111
br,morada limpa,Morada Limpa,31,,-9.916667,-48.733333
br,morada,Morada,14,,-14.816667,-56.633333
br,morada,Morada,15,,-18.616667,-45.366667
br,morada,Morada,22,,-6,-37.85
br,morada nova de minas,Morada Nova de Minas,15,,-18.616667,-45.366667
br,morada nova,Morada Nova,03,,.233333,-52.05
br,morada nova,Morada Nova,06,37390,-5.116667,-38.383333
br,morada nova,Morada Nova,13,,-3.378056,-42.470833
br,morada nova,Morada Nova,15,,-18.616667,-45.366667
br,morada nova,Morada Nova,17,,-6.65,-38.333333
br,morada nova,Morada Nova,20,,-3.861944,-42.343889
br,morada nova,Morada Nova,22,,-5.243611,-37.404444
br,morada nova,Morada Nova,31,,-6.466667,-48.283333
br,moradas,Moradas,14,,-14.816667,-56.633333
br,moradas,Moradas,20,,-7.65,-41.483333
br,morada verde,Morada Verde,21,,-22.873265,-43.646143
br,moradinha,Moradinha,30,,-7.983333,-37.783333
br,moradores,Moradores,11,,-20.516667,-51.516667
br,moradores,Moradores,14,,-15.633333,-57.516667
br,moradores novos,Moradores Novos,15,,-22.5235,-45.7273
br,morador queiroz,Morador Queiroz,11,,-20.3,-51.45
br,moraes,Moraes,13,,-3.541667,-43.063056
br,moraes,Moraes,30,,-7.65,-40.4
br,moraiba,Moraíba,16,,-2.45,-49.416667
br,morais,Morais,03,,.3,-51.216667
br,morais,Morais,05,,-12.016667,-39.716667
br,morais,Morais,30,,-7.65,-40.4
br,morangaba,Morangaba,21,,-21.733333,-41.616667
br,morao,Morão,05,,-11.816667,-42.183333
br,morao,Morão,27,,-21.716667,-51.183333
br,morari,Morari,04,,-5.716667,-67.783333
br,morato,Morato,18,,-25.18037,-48.296126
br,moraujo,Moraújo,06,,-3.416667,-40.683333
br,moravania,Moravânia,15,,-18.616667,-45.366667
br,morcegao,Morcegão,20,,-3.401389,-42.099167
br,morcego,Morcego,04,,-5.7075,-60.921944
br,morcego,Morcégo,06,,-4.4,-38.616667
br,morcego,Morcego,13,,-3.664444,-43.270833
br,morcego,Morcêgo,16,,-.966667,-52.666667
br,morcego,Morcêgo,17,,-6.866667,-36.516667
br,morcegos,Morcêgos,13,,-6.05,-43.933333
br,moreiao,Moreião,23,,-28.533333,-50.8
br,moreias,Moréias,06,,-2.883333,-40.833333
br,moreira cesar,Moreira César,27,,-22.916667,-45.366667
br,moreira marques,Moreira Marques,15,,-17.466667,-41.283333
br,moreira,Moreira,02,,-9.316667,-37.866667
br,moreira,Moreira,04,,-4.703889,-59.416111
br,moreira,Moreira,05,,-12.05,-40.4
br,moreira,Moreira,06,,-2.883333,-40.833333
br,moreira,Moreira,13,,-3.5,-44.316667
br,moreira,Moreira,20,,-8.633333,-42.133333
br,moreira,Moreira,30,,-7.966667,-36.016667
br,moreira sales,Moreira Sales,18,8699,-24.016667,-53.05
br,moreiras,Moreiras,06,,-2.883333,-40.833333
br,morena,Morena,24,,-9.6,-62.116667
br,morena,Morena,30,,-8.933333,-38.15
br,moreno,Moreno,05,,-12.783333,-41.15
br,moreno,Moreno,17,,-6.75,-35.65
br,moreno,Moreno,30,45238,-8.116667,-35.1
br,morere,Moreré,05,,-13.616667,-38.883333
br,morete,Morete,21,,-21.666667,-41.75
br,morgado,Morgado,06,,-5.55,-40.7
br,moriru,Moriru,25,,3.866667,-61.1
br,mormaco,Mormaço,23,,-28.633333,-52.516667
br,moroco,Moroco,14,,-13.75,-55.383333
br,morore,Mororé,02,,-9.433333,-37.466667
br,mororo do peixoto,Mororó do Peixoto,30,,-8.15,-39.483333
br,mororo,Mororó,06,,-4.583333,-40.833333
br,mororo,Mororó,17,,-6.75,-37.633333
br,mororo,Mororó,20,,-3.6275,-42.041667
br,mororo,Mororó,30,,-7.666667,-39.666667
br,mororos,Mororós,20,,-7.483333,-41.9
br,morotim,Morotim,23,,-28.433333,-53.633333
br,morpara,Morpará,05,,-11.566667,-43.283333
br,morrao,Morrão,13,,-6.666667,-43.783333
br,morretes,Morretes,18,,-25.475426,-48.829275
br,morretes,Morretes,23,,-29.9248,-51.285
br,morretes,Morretes,26,,-26.352,-48.5661
br,morrinho,Morrinho,05,,-12.45,-41
br,morrinho,Morrinho,06,,-3.233333,-40.116667
br,morrinho,Morrinho,11,,-20.3,-56.55
br,morrinho,Morrinho,14,,-16.183333,-56.516667
br,morrinho,Morrinho,20,,-5.366667,-42.683333
br,morrinho,Morrinho,27,,-21.183333,-47.383333
br,morrinhos,Morrinhos,05,,-11.033333,-45.05
br,morrinhos,Morrinhos,06,,-3.233333,-40.116667
br,morrinhos,Morrinhos,15,,-14.866667,-43.933333
br,morrinhos,Morrinhos,20,,-3.462778,-42.235833
br,morrinhos,Morrinhos,27,,-21.516667,-47.233333
br,morrinhos,Morrinhos,29,34144,-17.733333,-49.116667
br,morro agudo,Morro Agudo,20,,-7.233333,-41.6
br,morro agudo,Morro Agudo,27,25266,-20.733333,-48.066667
br,morro alegre,Morro Alegre,13,,-3.678056,-42.873333
br,morro alto,Morro Alto,15,,-20.933333,-47.116667
br,morro alto,Morro Alto,27,,-21.783333,-47.416667
br,morro arai muru,Morro Arai Muru,24,,-11.166667,-63.3
br,morro azul do tingua,Morro Azul do Tinguá,21,,-22.474167,-43.582778
br,morro azul,Morro Azul,21,,-22.474167,-43.582778
br,morro azul,Morro Azul,23,,-29.416667,-49.966667
br,morro azul,Morro Azul,26,,-28.616667,-49.083333
br,morro baixo,Morro Baixo,08,,-20.433333,-40.633333
br,morro bonito,Morro Bonito,05,,-13.2,-39.883333
br,morro branco,Morro Branco,06,,-4.15,-38.1
br,morro branco,Morro Branco,13,,-4.2,-43.666667
br,morro branco,Morro Branco,14,,-16.15,-58.783333
br,morro branco,Morro Branco,20,,-4.466667,-42.5
br,morro da cruz,Morro da Cruz,18,,-25.566707,-49.965273
br,morro da cruz,Morro da Cruz,26,,-26.2969,-48.649
br,morro da cupira,Morro da Cupira,20,,-6.85,-40.883333
br,morro da fumaca,Morro da Fumaça,26,13952,-28.666667,-49.2
br,morro da garca,Morro da Garça,15,,-18.533333,-44.6
br,morro da graca,Morro da Graça,15,,-18.533333,-44.6
br,morro d'agua,Morro d'Agua,20,,-9.159444,-45.240833
br,morro da lagoa,Morro da Lagoa,20,,-7.266667,-41.4
br,morro da marinha,Morro da Marinha,20,,-2.851667,-41.813333
br,morro da moenda,Morro da Moenda,05,,-13.4,-39.416667
br,morro d'anta,Morro d'Anta,08,,-18.316667,-39.95
br,morro da onca,Morro da Onça,20,,-7.666667,-41.383333
br,morro da palha,Morro da Palha,26,,-26.3138,-48.6368
br,morro da rosa,Morro da Rosa,05,,-13.333333,-40.233333
br,morro das flores,Morro das Flores,05,,-12.4,-40.55
br,morro das moedas,Morro das Moedas,21,,-22.766667,-42.45
br,morro das moendas,Morro das Moendas,21,,-22.766667,-42.45
br,morro de chapeo,Morro de Chapeo,05,,-11.55,-41.15
br,morro de coco,Morro de Côco,21,,-21.383333,-41.35
br,morro de dentro,Morro de Dentro,20,,-7.916667,-41.4
br,morro de pedra,Morro de Pedra,05,,-12.85,-40.066667
br,morro de pedra,Morro de Pedra,13,,-3.029722,-42.091944
br,morro do alemao,Morro do Alemão,21,,-22.855237,-43.273986
br,morro do alto,Morro do Alto,27,,-23.479107,-47.954498
br,morro do arara,Morro do Arara,20,,-9.216667,-45.783333
br,morro do banco,Morro do Banco,21,,-22.987369,-43.294684
br,morro do boi,Morro do Boi,05,,-13.8,-41.8
br,morro do cachimbo,Morro do Cachimbo,20,,-3.944722,-42.027778
br,morro do capitao freire,Morro do Capitão Freire,27,,-23.369538,-46.550375
br,morro do carrapato,Morro do Carrapato,26,,-27.033025,-49.562469
br,morro do cedro,Morro do Cedro,06,,-7.3,-40.15
br,morro do chapeo,Morro do Chapéo,05,,-11.55,-41.15
br,morro do chapeo,Morro do Chapeo,15,,-20.783333,-43.683333
br,morro do chapeu,Morro do Chapéu,05,,-11.55,-41.15
br,morro do chapeu,Morro do Chapéu,15,,-20.783333,-43.683333
br,morro do chapeu,Morro do Chapéu,20,,-3.766667,-42.3
br,morro do coco,Morro do Côco,21,,-21.383333,-41.35
br,morro do convento,Morro do Convento,21,,-23.002551,-43.632643
br,morro do cupim,Morro do Cupim,20,,-6.816667,-40.883333
br,morro do ferro,Morro do Ferro,15,,-20.766667,-44.583333
br,morro do fogo,Morro do Fogo,05,,-13.383333,-42.083333
br,morro do gomes,Morro do Gomes,05,,-11.683333,-42.116667
br,morro do icanhema,Morro do Icanhema,04,,1.083333,-67.583333
br,morro do jati,Morro do Jati,20,,-5.383333,-41.066667
br,morro do mamote,Morro do Mamote,05,,-11.483333,-39.616667
br,morro do mato,Morro do Mato,31,,-8.666667,-48.966667
br,morro do meio,Morro do Meio,18,,-25.5591,-48.98
br,morro do meio,Morro do Meio,20,,-6.533333,-41.333333
br,morro do olho d'agua,Morro do Olho d'Agua,05,,-13.35,-40.216667
br,morro do pilar,Morro do Pilar,15,,-19.2,-43.383333
br,morro do sal,Morro do Sal,13,,-6.016667,-46.75
br,morro dos borges,Morro dos Borges,23,,-29.416667,-51.05
br,morro dos bugres,Morro dos Bugres,23,,-29.416667,-51.05
br,morro dos conventos,Morro dos Conventos,26,,-28.95,-49.383333
br,morro dos paus,Morro dos Paus,05,,-14.45,-40.366667
br,morro do tibau,Morro do Tibau,22,,-4.835833,-37.250833
br,morro do veridiano,Morro do Veridiano,13,,-3.1,-43.533333
br,morro frio,Morro Frio,21,,-22.4355,-42.796251
br,morro grande,Morro Grande,05,,-12.366667,-39.3
br,morro grande,Morro Grande,08,,-20.8,-41.133333
br,morro grande,Morro Grande,14,,-15.816667,-56.033333
br,morro grande,Morro Grande,15,,-19.933333,-43.466667
br,morro grande,Morro Grande,18,,-25.351096,-48.768311
br,morro grande,Morro Grande,21,,-22.8,-42.35
br,morro grande,Morro Grande,23,,-28.666667,-49.1
br,morro grande,Morro Grande,26,,-26.2797,-48.6269
br,morro grande,Morro Grande,27,,-20.933333,-47.716667
br,morro,Morro,05,,-12.3,-40.116667
br,morro,Morro,06,,-5.283333,-40.483333
br,morro,Morro,13,,-3.579167,-43.088611
br,morro,Morro,15,,-16.040278,-44.681944
br,morro,Morro,20,,-9.516667,-44.966667
br,morro pelado,Morro Pelado,05,,-13.9,-42.083333
br,morro pequeno,Morro Pequeno,26,,-28.666667,-49.083333
br,morro pintado,Morro Pintado,22,,-4.945,-37.020556
br,morro preto,Morro Prêto,05,,-12.7,-39.8
br,morro redondo,Morro Redondo,05,,-14.75,-39.416667
br,morro-redondo,Morro-Redondo,05,,-14.8,-39.1
br,morro redondo,Morro Redondo,13,,-6.5,-43.5
br,morro redondo,Morro Redondo,20,,-5.433333,-42.7
br,morro redondo,Morro Redondo,21,,-22.333333,-41.916667
br,morro reuter,Morro Reuter,23,,-29.533333,-51.083333
br,morros da mariana,Morros da Mariana,20,,-2.851667,-41.813333
br,morro seco,Morro Sêco,15,,-20.533333,-41.916667
br,morros,Morros,05,,-13.266667,-40.35
br,morros,Morros,06,,-4.316667,-38.5
br,morros,Morros,13,4829,-9.446667,-46.300278
br,morros,Morros,18,,-24.95,-49.816667
br,morros,Morros,20,,-5.8,-43.016667
br,morros,Morros,22,,-5.083333,-35.75
br,morro urubu,Morro Urubu,06,,-4.55,-37.666667
br,morro verde,Morro Verde,05,,-13.75,-40.266667
br,morro verde,Morro Verde,18,,-25.85,-52.216667
br,morro vermelho,Morro Vermelho,13,,-3.260278,-42.262222
br,morro vermelho,Morro Vermelho,15,,-19.933333,-43.7
br,morro vermelho,Morro Vermelho,20,,-8.516667,-45.733333
br,morro vermelho,Morro Vermelho,27,,-21.216667,-47.233333
br,morsing,Morsing,21,,-22.540556,-43.776944
br,mortugaba,Mortugaba,05,,-14.983333,-42.316667
br,morumbi,Morumbi,11,,-23.766667,-54.1
br,morungaba,Morungaba,27,,-22.866667,-46.8
br,morungava,Morungava,23,,-29.8523,-50.9081
br,morzalandia,Morzalândia,29,,-14.783333,-50.583333
br,mosele,Mosele,17,,-7.166667,-37.7
br,moselo,Mosêlo,06,,-6.7,-38.766667
br,mosqueiro,Mosqueiro,16,,-1.166667,-48.466667
br,mosqueiro,Mosqueiro,28,,-11.116667,-37.15
br,mosquitinho,Mosquitinho,26,,-27.266667,-49.733333
br,mosquito,Mosquito,02,,-9.8,-36.35
br,mosquito,Mosquito,06,,-3.083333,-39.683333
br,mosquito,Mosquito,13,,-3.049444,-43.3525
br,mosquito,Mosquito,20,,-3.5275,-42.501389
br,mosquito,Mosquito,26,,-27.266667,-49.733333
br,mosquito,Mosquito,31,,-6.616667,-47.377222
br,mossamedes,Mossâmedes,29,,-16.116667,-50.183333
br,mossoro,Mossoró,16,,-1.033333,-47.766667
br,mossoro,Mossoró,22,202010,-5.191389,-37.344722
br,mossurepe,Mossurepe,21,,-21.95,-41.133333
br,mostarda,Mostarda,23,,-31.1,-50.95
br,mostardas,Mostardas,23,,-31.1,-50.95
br,mostardos,Mostardos,23,,-31.1,-50.95
br,mota,Mota,14,,-14.65,-56.166667
br,mota,Mota,15,,-21.2,-45.533333
br,mota,Mota,16,,-.616667,-47.416667
br,mota,Mota,17,,-7.116667,-38.366667
br,mota paes,Mota Paes,27,,-22.216667,-46.783333
br,mota pais,Mota Pais,27,,-22.216667,-46.783333
br,motuca,Motuca,27,,-21.5,-48.15
br,moura brasil,Moura Brasil,21,,-22.125833,-43.154722
br,moura,Moura,04,,-1.45,-61.633333
br,moura,Moura,05,,-13.3,-39.666667
br,moura,Moura,13,,-3.504722,-43.043889
br,mourao,Mourão,05,,-12.666667,-44.366667
br,mourao,Mourão,13,,-6.666667,-43.783333
br,mourao,Mourão,17,,-7.5,-36.4
br,mourao,Mourão,18,,-24.05,-52.366667
br,mourao,Mourão,20,,-5.016667,-41.416667
br,mourao,Mourão,22,,-5.700556,-37.050556
br,mouras,Mouras,27,,-23.260428,-47.969351
br,moxoto,Moxotó,30,,-8.733333,-37.516667
br,mozarlandia,Mozarlândia,29,11252,-14.783333,-50.583333
br,mozondo,Mozondó,05,,-12.383333,-44.716667
br,muana,Muaná,16,7464,-1.533333,-49.216667
br,muanel feliciano,Muanel Feliciano,05,,-16.266667,-39.85
br,mucaia,Mucaiá,25,,-2.866667,-61.3
br,mucaja,Mucajá,04,,-3.95,-57.533333
br,mucambinho,Mucambinho,13,,-3.133333,-43.316667
br,mucambinho,Mucambinho,20,,-3.483333,-42.416667
br,mucambo dos ventos,Mucambo dos Ventos,05,,-10.833333,-42.883333
br,mucambo,Mucambo,02,,-9.85,-36.7
br,mucambo,Mucambo,05,,-11.366667,-38.35
br,mucambo,Mucambo,06,,-3.033333,-41.2
br,mucambo,Mucambo,13,,-6.266667,-43.5
br,mucambo,Mucambo,20,,-10.5,-44.3
br,mucambo,Mucambo,28,,-10.15,-37.116667
br,mucambos,Mucambos,30,,-9.05,-36.85
br,mucana,Mucanã,13,,-6.083333,-43.166667
br,muchila,Muchila,04,,-7.516667,-71.316667
br,mucuge,Mucugê,05,,-12.2,-37.883333
br,mucuiba,Mucuíba,21,,-22.954852,-43.481418
br,mucuim,Muçuim,05,,-12.616667,-38.483333
br,mucuim,Mucuim,13,,-3.652778,-43.254444
br,mucui,Mucuí,08,,-21,-40.883333
br,mucuitu,Mucuitu,17,,-7.216667,-36.633333
br,mucuja,Mucujá,04,,-3.95,-57.533333
br,mucuje,Mucujê,05,,-12.2,-37.883333
br,mucujo,Mucujó,05,,-13.033333,-38.866667
br,mucum,Muçum,23,,-29.166667,-51.883333
br,mucum,Mucum,30,,-8.6,-35.633333
br,mucuna,Mucuna,06,,-4.35,-38.883333
br,mucuna,Mucunã,13,,-1.183333,-45.75
br,mucuna,Mucunã,17,,-6.85,-37.316667
br,mucura,Mucura,04,,-2.516667,-62.716667
br,mucuras,Mucuras,04,,-2.904444,-60.461667
br,mucurata,Mucurata,08,,-19.983333,-40.25
br,mucurepe,Muçurepe,21,,-21.95,-41.133333
br,mucurici,Mucurici,08,9524,-18.1,-40.516667
br,mucuri,Mucuri,05,26823,-18.083333,-39.566667
br,mucuripe,Mucuripe,01,,-8.85,-71.083333
br,mucuripe,Mucuripe,04,,-2.866667,-69.416667
br,mucuripe,Mucuripe,06,,-3.716667,-38.483333
br,mucuroca,Muçuroca,30,,-7.9,-35.116667
br,mucury,Mucury,05,,-18.083333,-39.566667
br,muda,Muda,21,,-22.937888,-43.24361
br,mudanca,Mudança,20,,-3.65,-41.916667
br,mufumbo,Mufumbo,06,,-7.2,-40.316667
br,mugiqui,Mugiqui,17,,-7.683333,-37.1
br,muiraneu,Muiraneu,13,,-2,-44.55
br,muirapinima,Muirapinima,04,,-2.180278,-61.142778
br,muirapirima,Muirapirima,16,,-2.4,-56.3
br,muitas cabras,Muitas Cabras,30,,-8.85,-35.333333
br,muitos capoes,Muitos Capões,23,,-28.316667,-51.183333
br,mujiqui,Mujiqui,17,,-7.683333,-37.1
br,mulada,Mulada,23,,-28.883333,-50.883333
br,mulata do velho veloso,Mulata do Velho Veloso,20,,-6.083333,-42.616667
br,mulata,Mulata,16,,-1.716667,-54.016667
br,mulato,Mulato,16,,-1.716667,-53.983333
br,mulde alta,Mulde Alta,26,,-26.7739,-49.2097
br,mulde baixa,Mulde Baixa,26,,-26.857,-49.2217
br,mulde central,Mulde Central,26,,-26.8143,-49.2222
br,muliterno,Muliterno,23,,-28.333333,-51.766667
br,muller,Müller,27,,-21.483333,-49.016667
br,mulunga,Mulunga,06,,-3.566667,-40.116667
br,mulungu do morro,Mulungu do Morro,05,,-11.95,-41.616667
br,mulungu dos inacios,Mulungu dos Inácios,30,,-8.466667,-36.716667
br,mulungu,Mulungu,02,,-9.65,-37.266667
br,mulungu,Mulungu,05,,-10.066667,-41.6
br,mulungu,Mulungu,06,,-3.433333,-39.983333
br,mulungu,Mulungu,17,4181,-7.033333,-35.466667
br,mulungu,Mulungu,20,,-4.35,-41.766667
br,mulungu,Mulungu,22,,-5.321111,-37.224444
br,mulungu,Mulungu,28,,-10.2,-37.066667
br,mulungu,Mulungu,30,,-7.283333,-37.2
br,mulunguzinho,Mulunguzinho,17,,-6.866667,-37.016667
br,mumbaba,Mumbaba,06,,-3.583333,-40.333333
br,mumbada,Mumbada,06,,-3.583333,-40.333333
br,mumba,Mumba,06,,-3.683333,-41.316667
br,mumbuca,Mumbuca,05,,-13.25,-40.583333
br,mumbuca,Mumbuca,27,,-22.933333,-47.566667
br,mundahu mirim,Mundahú Mirim,02,,-9.15,-36.183333
br,mundahu,Mundahu,06,,-3.2,-39.366667
br,mundau mirim,Mundaú Mirim,02,,-9.15,-36.183333
br,mundau,Mundaú,01,,-8,-73.466667
br,mundau,Mundaú,06,,-3.2,-39.366667
br,munde,Mundé,05,,-13.85,-40.866667
br,munde,Mundé,17,,-7.7,-37.966667
br,mundeos,Mundeos,21,,-22.216667,-41.966667
br,mundeus,Mundéus,21,,-22.216667,-41.966667
br,mundial,Mundial,06,,-5.333333,-38.183333
br,mundo nova,Mundo Nõva,17,,-7.866667,-36.966667
br,mundo novo da anhaia,Mundo Novo da Anháia,18,,-25.5368,-48.8629
br,mundo novo,Mundo Novo,02,,-9.5,-37.816667
br,mundo novo,Mundo Novo,03,,.466667,-52.183333
br,mundo novo,Mundo Novo,04,,-3.066667,-57.15
br,mundo novo,Mundo Novo,05,11912,-11.866667,-40.466667
br,mundo novo,Mundo Novo,06,,-3.266667,-39.316667
br,mundo novo,Mundo Novo,08,,-20.633333,-41.8
br,mundo novo,Mundo Novo,13,,-2.866667,-43.133333
br,mundo novo,Mundo Novo,14,,-15.216667,-55.5
br,mundo novo,Mundo Novo,15,,-15.333333,-41.7
br,mundo novo,Mundo Nôvo,17,,-7.216667,-36.4
br,mundo novo,Mundo Novo,18,,-23.805945,-50.133008
br,mundo novo,Mundo Novo,20,,-3.732778,-42.418056
br,mundo novo,Mundo Novo,21,,-23.001985,-43.392347
br,mundo novo,Mundo Nôvo,22,,-5.2,-35.666667
br,mundo novo,Mundo Novo,23,,-29.533333,-50.8
br,mundo novo,Mundo Novo,26,,-28.066667,-49.65
br,mundo novo,Mundo Novo,27,,-21.216667,-49.283333
br,mundo novo,Mundo Novo,29,,-16.75,-47.1
br,mundo novo,Mundo Novo,30,,-7.583333,-37.2
br,mundo novo,Mundo Novo,31,,-11.7,-49
br,mundubim,Mundubim,06,,-3.816667,-38.55
br,munduri,Munduri,05,,-12.633333,-40.85
br,munduri,Munduri,20,,-5.9,-41
br,munduri,Munduri,30,,-8.233333,-40.616667
br,mundurucus,Mundurucus,01,,-7.866667,-72.716667
br,mundurucus,Mundurucus,04,,-4.783333,-58.266667
br,munguba,Munguba,02,,-9.066667,-36.183333
br,munguba,Munguba,04,,-5.140556,-59.820278
br,munguba,Munguba,13,,-3.020556,-42.392778
br,munguba,Munguba,16,,-.9,-52.416667
br,munhoz da rocha,Munhoz da Rocha,18,,-24.9,-53.133333
br,munhoz de melo,Munhoz de Melo,18,,-23.133333,-51.766667
br,munhoz,Munhoz,15,,-22.616667,-46.366667
br,municipio de xiririca,Município de Xiririca,27,,-24.522222,-48.1075
br,munim,Munim,13,,-3.06,-43.065278
br,muniz ferreira,Muniz Ferreira,05,,-13,-39.116667
br,muniz ferreiro,Muniz Ferreiro,05,,-13,-39.116667
br,muniz freire,Muniz Freire,08,8312,-20.466667,-41.416667
br,muniz,Muniz,06,,-4.616667,-40.083333
br,muniz,Muniz,27,,-23.583333,-49.183333
br,munjolo,Munjolo,14,,-16.366667,-57.4
br,muqueca,Muqueca,30,,-8.683333,-36.616667
br,muquem ferrado,Muquém Ferrado,05,,-13.216667,-43.483333
br,muquem,Muquém,05,,-12.316667,-39.533333
br,muquem,Muquém,06,,-4.733333,-38.966667
br,muquem,Muquém,11,,-20.733333,-55.4
br,muquem,Muquém,13,,-5.383333,-43.1
br,muquem,Muquém,15,,-16.149444,-44.167222
br,muquem,Muquém,18,,-24.016667,-50.283333
br,muquem,Muquém,20,,-6.033333,-41.866667
br,muquem,Muquém,26,,-27.483333,-48.416667
br,muquem,Muquém,29,,-14.55,-48.133333
br,muquem patos,Muquém Patos,05,,-11.416667,-42.983333
br,muque,Muque,17,,-7.3,-38.083333
br,muquicaba,Muquiçaba,08,,-20.666667,-40.5
br,muquicoba,Muquiçoba,08,,-20.666667,-40.5
br,muquilao,Muquilão,18,,-24.233333,-52.116667
br,muqui,Muqui,08,8614,-20.95,-41.3
br,muquy,Muquy,08,,-20.95,-41.3
br,muraipinima,Muraipinima,04,,-2.180278,-61.142778
br,muraja,Murajá,16,,-.783333,-47.95
br,mura,Mura,04,,-3.316667,-58.816667
br,muratinga,Muratinga,04,,-3.433333,-59.2
br,murereiba,Murereíba,06,,-4.016667,-41.2
br,murereibu,Murereibu,06,,-4.016667,-41.2
br,murgo,Murgo,02,,-9.533333,-36.883333
br,muriae,Muriaé,15,91174,-21.133333,-42.366667
br,muriahe,Muriahé,15,,-21.133333,-42.366667
br,muriahe,Muriahé,21,,-21.2,-42.116667
br,muribeca dos guararapes,Muribeca dos Guararapes,30,,-8.166667,-35.016667
br,muribeca,Muribeca,05,,-12.45,-38.766667
br,muribeca,Muribeca,06,,-3.316667,-39.3
br,muribeca,Muribeca,08,,-20.1,-40.35
br,muribeca,Muribeca,28,,-10.433333,-36.983333
br,muribeca,Muribeca,30,,-8.166667,-35.016667
br,murici de dentro,Murici de Dentro,20,,-7.2,-41.916667
br,muricilandia,Muricilândia,31,,-7.123889,-48.444167
br,murici,Murici,02,20420,-9.316667,-35.933333
br,murici,Murici,05,,-12,-38.816667
br,murici,Murici,13,,-3.262222,-42.148056
br,murici,Murici,20,,-3.830833,-42.614444
br,murici,Murici,30,,-8.316667,-39.15
br,muricizal,Muricizal,16,,-5.65,-48.166667
br,muricizal,Muricizal,31,,-7.15,-48.616667
br,muricizinho,Muricizinho,20,,-3.520833,-42.268611
br,muricoca,Muriçoca,05,,-11.883333,-45.85
br,muricoca,Muriçoca,13,,-4.416667,-45.716667
br,muricoca,Muricoca,20,,-5.05,-42.433333
br,muricoca,Muriçoca,30,,-7.516667,-37.616667
br,murihe,Murihe,15,,-21.133333,-42.366667
br,murihu,Murihú,22,,-5.55,-35.25
br,murimure,Murimurê,23,,-28.116667,-53.083333
br,muri,Muri,05,,-17.266667,-39.35
br,murineli,Murinéli,21,,-22.116667,-42.616667
br,muriqueira,Muriqueira,05,,-12.783333,-38.35
br,muriquera,Muriquera,05,,-12.783333,-38.35
br,muriquioca,Muriquioca,08,,-20.666667,-40.6
br,muritiba,Muritiba,05,22388,-12.916667,-39.25
br,muriti,Muriti,05,,-9.966667,-38.333333
br,muriti,Muriti,06,,-7.216667,-39.383333
br,murituba de baixo,Murituba de Baixo,02,,-10.283333,-36.4
br,murityba,Murityba,05,,-12.65,-38.983333
br,muriu,Muriú,22,,-5.55,-35.25
br,muro de pedra,Muro de Pedra,15,,-22.016667,-46.083333
br,murriae,Murriae,15,,-21.133333,-42.366667
br,murro baixo do joao ferreira,Murro Baixo do João Ferreira,08,,-20.433333,-40.633333
br,murta,Murta,28,,-10.55,-37
br,murtinho,Murtinho,24,,-10.4,-65.366667
br,murucupi,Murucupi,16,,-1.566667,-48.75
br,muruja,Murujá,16,,-.783333,-47.95
br,murundu,Murundu,15,,-17.233333,-41.483333
br,murundu,Murundu,21,,-21.383333,-41.466667
br,murundu,Murundu,27,,-23.8,-47.266667
br,murungaba,Murungaba,27,,-22.866667,-46.8
br,murupe,Murupé,30,,-7.65,-35.433333
br,murupu,Murupu,25,,2.85,-60.783333
br,mururu,Mururu,13,,-4.133333,-45.133333
br,murutinga do sul,Murutinga do Sul,27,,-20.983333,-51.3
br,murutinga,Murutinga,04,,-3.433333,-59.2
br,murutuba,Murutuba,05,,-12.566667,-38.916667
br,museu,Museu,20,,-8.05,-41.55
br,musquiada,Musquiada,20,,-6.016667,-42.166667
br,mussum,Mussum,23,,-29.166667,-51.883333
br,mussurepe,Mussurepe,21,,-21.95,-41.133333
br,mutamba feiticeiro,Mutamba Feiticeiro,06,,-4.866667,-38.316667
br,mutamba,Mutamba,05,,-11.216667,-46.366667
br,mutamba,Mutamba,06,,-3.416667,-39.333333
br,mutamba,Mutamba,30,,-9.05,-36.85
br,mutambeira,Mutambeira,06,,-5.916667,-38.716667
br,mutambeiras,Mutambeiras,06,,-3.333333,-40.15
br,mutambo,Mutambo,05,,-12.866667,-38.883333
br,muta,Mutá,05,,-12.983333,-38.766667
br,mutans,Mutans,05,,-14.333333,-42.983333
br,mutari,Mutari,05,,-16.316667,-39.033333
br,mutas,Mutãs,05,,-14.333333,-42.983333
br,mutrapeba,Mutrapeba,08,,-20.016667,-40.416667
br,mutucal,Mutucal,16,,-.683333,-47.95
br,mutuca,Mutuca,05,,-12.533333,-38.866667
br,mutuca,Mutuca,21,,-21.333333,-41.3
br,mutuca,Mutuca,27,,-21.5,-48.15
br,mutuca,Mutuca,30,,-8.25,-38.466667
br,mutuca ponta,Mutuca Ponta,04,,.966667,-67.45
br,mutuipe,Mutuípe,05,10016,-13.25,-39.516667
br,mutum de cima,Mutum de Cima,21,,-21.2,-41.55
br,mutum,Mutum,01,,-9.681111,-67.746944
br,mutum,Mutum,04,,-3.853056,-62.7275
br,mutum,Mutum,05,,-12.883333,-39.133333
br,mutum,Mutum,08,,-19.65,-40.616667
br,mutum,Mutum,11,,-20.483333,-53.266667
br,mutum,Mutum,13,,-3.083333,-43.933333
br,mutum,Mutum,14,,-15.8,-54.883333
br,mutum,Mutum,15,12582,-19.816667,-41.433333
br,mutum,Mutum,21,,-21.2,-41.55
br,mutum,Mutum,24,,-8.55,-63.7
br,mutum,Mutum,27,,-20.7,-51.583333
br,mutum,Mutum,29,,-16.016667,-51.816667
br,mutumparana,Mutumparaná,24,,-9.633333,-64.95
br,mutunopolis,Mutunópolis,29,,-13.666667,-49.25
br,mutuns,Mutuns,05,,-14.333333,-42.983333
br,mutuns,Mutuns,20,,-3.536111,-42.529167
br,mutuns,Mutuns,24,,-8.55,-63.7
br,muxiopo,Muxiopó,06,,-4.816667,-38.983333
br,muxure velho,Muxuré Velho,06,,-5.383333,-39.3
br,muzambinho,Muzambinho,15,16254,-21.366667,-46.533333
br,muzelinha,Muzelinha,30,,-8.583333,-36.416667
br,muzema,Muzema,21,,-22.98983,-43.321481
br,nacamura,Nacamura,27,,-21.583333,-50.25
br,nack,Nack,15,,-19.233333,-42.316667
br,nado,Nado,05,,-13.683333,-41.866667
br,nage,Nagé,05,,-12.716667,-38.95
br,naje,Najé,05,,-12.716667,-38.95
br,nambi,Nambi,06,,-5.616667,-39.983333
br,nambu,Nambu,13,,-3.795,-43.035
br,namorado,Namorado,22,,-6.183333,-36.533333
br,nantes,Nantes,27,,-22.516667,-51.25
br,nanuque,Nanuque,15,37825,-17.833333,-40.35
br,nao beber,Não Beber,05,,-9.483333,-38.366667
br,nao-me-toque,Não-Me-Toque,23,12556,-28.466667,-52.816667
br,nao me toques,Não Me Toques,23,,-28.466667,-52.816667
br,naque,Naque,15,,-19.233333,-42.316667
br,narandiba,Narandiba,27,,-22.4,-51.516667
br,naraniu,Naraniú,06,,-6.666667,-39.25
br,narciso,Narciso,15,,-21.533333,-46.183333
br,narino,Nariño,04,,-1.395833,-69.422222
br,naru,Naru,13,,-5.466667,-45.566667
br,nascenca,Nascença,22,,-5.6,-35.466667
br,nascente,Nascente,06,,-3.266667,-39.9
br,nascente,Nascente,11,,-21.566667,-54.216667
br,nascente,Nascente,23,,-31.816667,-53.483333
br,nascente,Nascente,25,,3.916667,-60.25
br,nascente,Nascente,30,,-7.816667,-40.45
br,nascentes,Nascentes,23,,-31.816667,-53.483333
br,nascimento,Nascimento,20,,-9.016667,-42.8
br,nassaro,Nassaro,30,,-8.15,-36.15
br,natal,Natal,04,,-2.716667,-66.8
br,natal,Natal,05,,-15.6,-39.883333
br,natal,Natal,11,,-18.95,-55.716667
br,natal,Natal,15,,-17.9,-40.55
br,natal,Natal,18,,-25.2,-50.783333
br,natal,Natal,20,,-5.583333,-42.616667
br,natal,Natal,22,763057,-5.783333,-35.216667
br,natal,Natal,23,,-29.466667,-51.416667
br,natal,Natal,31,,-5.832778,-48.001944
br,natercia,Natércia,15,,-22.116667,-45.5
br,natingui,Natingui,18,,-24.05,-50.8
br,natinopolis,Natinópolis,29,,-15.166667,-49.333333
br,natividade da serra,Natividade da Serra,27,,-23.4,-45.433333
br,natividade do carangola,Natividade do Carangola,21,,-21.05,-41.983333
br,natividade,Natividade,06,,-3.433333,-39.433333
br,natividade,Natividade,21,12014,-21.05,-41.983333
br,natividade,Natividade,27,,-23.4,-45.433333
br,natividade,Natividade,31,,-11.468889,-46.7825
br,natuba,Natuba,05,,-11.233333,-38.483333
br,natuba,Natuba,17,3333,-7.633333,-35.566667
br,nauari,Nauari,16,,.95,-54.5
br,navalha,Navalha,14,,-7.433333,-58.1
br,navalha,Navalha,17,,-7.166667,-36.266667
br,navegantes,Navegantes,23,,-30,-51.194444
br,navegantes,Navegantes,26,47782,-26.9,-48.65
br,navio,Navio,02,,-9.283333,-37.833333
br,navio,Navio,17,,-7.316667,-36.1
br,navio,Navio,30,,-8.633333,-38.383333
br,navirai,Naviraí,11,36453,-23.133333,-54.216667
br,nazare da mata,Nazaré da Mata,30,26485,-7.733333,-35.233333
br,nazare das farinhas,Nazaré das Farinhas,05,,-13.033333,-39
br,nazare do badaro,Nazaré do Badaró,04,,-6.7,-64.483333
br,nazare do piaui,Nazaré do Piauí,20,,-6.983333,-42.666667
br,nazare do retiro,Nazaré do Retiro,04,,-6.016667,-61.7
br,nazare dos patos,Nazaré dos Patos,16,,-3.4,-49.616667
br,nazare,Nazaré,01,,-10.6,-68.616667
br,nazare,Nazaré,03,,1.283333,-50.9
br,nazare,Nazaré,04,,1.216667,-67.85
br,nazare,Nazaré,05,25604,-13.033333,-39
br,nazare,Nazaré,06,,-3.016667,-40.45
br,nazare,Nazaré,08,,-20.616667,-41.833333
br,nazare,Nazaré,13,,-1.316667,-46.15
br,nazare,Nazaré,15,,-21.216667,-44.616667
br,nazare,Nazaré,16,,-.116667,-49.65
br,nazare,Nazaré,17,,-6.9,-38.333333
br,nazare,Nazaré,20,,-4.35,-41.566667
br,nazare,Nazaré,22,,-5.4,-35.95
br,nazare,Nazaré,24,,-10.083333,-62.3
br,nazare,Nazaré,27,,-22.116667,-51.966667
br,nazare,Nazaré,30,,-7.733333,-35.233333
br,nazare,Nazaré,31,,-6.383333,-47.493889
br,nazareno,Nazareno,15,,-21.216667,-44.616667
br,nazareno,Nazareno,18,,-24.55,-50.716667
br,nazare paulista,Nazaré Paulista,27,,-23.183333,-46.4
br,nazareth do badara,Nazareth do Badara,04,,-6.7,-64.483333
br,nazareth do retiro,Nazareth do Retiro,04,,-6.016667,-61.7
br,nazareth,Nazareth,01,,-8.45,-70.466667
br,nazareth,Nazareth,03,,1.283333,-50.9
br,nazareth,Nazareth,04,,1.216667,-67.85
br,nazareth,Nazareth,05,,-13.033333,-39
br,nazareth,Nazareth,15,,-21.216667,-44.616667
br,nazareth,Nazareth,16,,-.116667,-49.65
br,nazareth,Nazareth,17,,-6.9,-38.333333
br,nazareth,Nazareth,20,,-6.983333,-42.666667
br,nazareth,Nazareth,24,,-10.083333,-62.3
br,nazareth,Nazareth,27,,-23.183333,-46.4
br,nazareth,Nazareth,30,,-7.733333,-35.233333
br,nazaret,Nazaret,16,,-.116667,-49.65
br,nazaret,Nazarét,30,,-7.7,-37.65
br,nazarezinho,Nazarèzinho,17,,-6.9,-38.333333
br,nazaria de baixo,Nazária de Baixo,04,,-3.839444,-62.656667
br,nazaria,Nazária,08,,-20.616667,-41.833333
br,nazaria,Nazária,20,,-5.35,-42.85
br,nazaria,Nazaria,29,,-16.6,-49.9
br,nazari,Nazari,30,,-8.633333,-37.816667
br,nazario,Nazário,29,,-16.6,-49.9
br,nazaro,Názaro,06,,-5.1,-40.966667
br,n. bento,N. Bento,23,,-30.116667,-57.216667
br,negao,Negão,06,,-4.166667,-39.75
br,negras,Negras,05,,-9.466667,-42.3
br,negro da mota,Negro da Mota,20,,-7.9,-41.95
br,negro,Negro,13,,-3.8725,-43.1275
br,negro,Negro,20,,-3.624167,-42.488056
br,negros,Negros,17,,-7.716667,-38.4
br,neise central,Neise Central,26,,-27.116667,-49.333333
br,neisse central,Neisse Central,26,,-27.116667,-49.333333
br,nelson de sena,Nélson de Sena,15,,-18.4,-42.7
br,nenem,Neném,15,,-16.433333,-40.666667
br,neopolis,Neópolis,28,12422,-10.3,-36.583333
br,nepomuceno,Nepomuceno,15,18911,-21.233333,-45.25
br,nereu ramos,Nereu Ramos,26,,-26.45,-49.166667
br,neris,Neris,06,,-7.216667,-40.183333
br,neropolis,Nerópolis,29,21870,-16.416667,-49.233333
br,nestor cue,Nestor Cuê,11,,-22.933333,-55.2
br,nestor gomes,Nestor Gomes,08,,-18.716667,-40.216667
br,nestor goncalves,Nestor Gonçalves,11,,-21.066667,-56.55
br,neto,Neto,30,,-8.466667,-36.266667
br,neves,Neves,05,,-12.65,-38.45
br,neves,Neves,15,,-17.083333,-41.9
br,neves,Neves,21,,-22.333333,-41.95
br,neves,Neves,27,,-20.816667,-49.633333
br,neves,Neves,30,,-8.683333,-36.666667
br,neves paulista,Neves Paulista,27,,-20.816667,-49.633333
br,nevez,Nevez,15,,-19.783333,-44.1
br,nha luz,Nha Luz,27,,-23.516667,-45.8
br,nhambiquara,Nhambiquara,14,,-12.75,-59.8
br,nhambiquaras,Nhambiquaras,14,,-12.75,-59.8
br,nhambuca,Nhambucá,27,,-23.67271,-47.045769
br,nhamunda,Nhamundá,04,7772,-2.233333,-56.716667
br,nhandeara,Nhandeara,27,,-20.666667,-50.033333
br,nhandu,Nhandu,17,,-6.583333,-37.916667
br,nhandutiba,Nhandutiba,15,,-14.616667,-44.2
br,nhangapi,Nhangapi,21,,-22.5,-44.633333
br,nhecolandia,Nhecolândia,11,,-19.266667,-57.066667
br,nhonhepe,Nhonhepe,15,,-19.316667,-41.8
br,nhonho morais,Nhonho Morais,18,,-22.616667,-52.166667
br,nhunguagu,Nhunguagu,21,,-22.343596,-42.861477
br,nhunguara,Nhunguara,27,,-24.602681,-48.470404
br,nhunguau,Nhunguau,21,,-22.343596,-42.861477
br,nhunguvira,Nhunguvira,27,,-24.743944,-48.107921
br,nhu-vera,Nhu-Verá,11,,-23.233333,-55.533333
br,nhuvera,Nhuvera,11,,-23.25,-55.516667
br,nicacio,Nicácio,06,,-5.35,-40.266667
br,nicacio,Nicácio,22,,-5.558333,-36.451389
br,nicacio preto,Nicácio Prêto,11,,-23.3,-54.733333
br,nicacio prieto,Nicacio Prieto,11,,-23.3,-54.733333
br,nicaragua,Nicarágua,15,,-16.4,-40.95
br,nicolandia,Nicolândia,15,,-19.2,-40.983333
br,nicolau,Nicolau,06,,-6.683333,-40.066667
br,nicolau,Nicolau,13,,-3.595,-43.091667
br,nicolau,Nicolau,15,,-18.516667,-48.45
br,nictheroi,Nictheroi,21,,-22.90214,-43.130301
br,nictheroy,Nictheroy,04,,-7.633333,-70.083333
br,nictheroy,Nictheroy,21,,-22.90214,-43.130301
br,nilo pecanha,Nilo Peçanha,05,,-13.616667,-39.1
br,nilo pecanha,Nilo Peçanha,21,,-22.966667,-42.683333
br,nilo pecanha,Nilo Peçanha,26,,-27.3,-49.45
br,nilopolis,Nilópolis,21,147283,-22.808487,-43.419792
br,nina,Nina,13,,-3.611389,-43.498611
br,ninfas,Ninfas,15,,-21.783333,-45.083333
br,ninho de gato,Ninho de Gato,05,,-8.566667,-39.433333
br,nioac,Nioac,11,,-21.133333,-55.8
br,nioaque,Nioaque,11,6899,-21.133333,-55.8
br,nipoa,Nipoã,27,,-20.883333,-49.783333
br,nipoan,Nipoan,27,,-20.883333,-49.783333
br,nipolandia,Nipolândia,27,,-21.4,-50.466667
br,niquelandia,Niquelândia,29,27544,-14.45,-48.45
br,nisia floresta,Nísia Floresta,22,10115,-6.066667,-35.133333
br,nissoes,Nissões,15,,-14.883333,-44.083333
br,niteroi de itabapoana,Niterói de Itabapoana,21,,-21.216667,-41.9
br,niteroi,Niterói,04,,-6.7,-59.1
br,niteroi,Niterói,11,,-21.6,-54.1
br,niteroi,Niterói,21,456461,-22.90214,-43.130301
br,niteroi,Niterói,23,,-29.95,-51.166667
br,niteroi,Niterói,26,,-27.023207,-49.638694
br,niteroi,Niterói,28,,-9.766667,-37.433333
br,niteroi,Niteroi,30,,-7.566667,-39.7
br,nitero,Niteró,04,,-7.633333,-70.083333
br,nobre,Nobre,20,,-5.8,-42.2
br,nobres,Nobres,14,12010,-14.733333,-56.333333
br,noe,Noê,25,,2.866667,-60.75
br,nogueira,Nogueira,13,,-4.283333,-44.166667
br,nogueira,Nogueira,17,,-8.116667,-36.666667
br,nogueira,Nogueira,22,,-6.083333,-37.85
br,nogueira,Nogueira,27,,-22.183333,-49.3
br,nogueiras,Nogueiras,18,,-25.4411,-50.6612
br,noite grande,Noite Grande,02,,-9.95,-36.1
br,noite negra,Noite Negra,27,,-22.266667,-51.416667
br,nonoai,Nonoai,23,,-27.35,-52.783333
br,nonohay,Nonohay,23,,-27.35,-52.783333
br,norberto martins,Norberto Martins,23,,-30.516667,-56.283333
br,nordestina,Nordestina,05,,-10.833333,-39.433333
br,norma,Norma,05,,-13.25,-40.05
br,nortelandia,Nortelândia,14,9636,-14.416667,-56.8
br,nortelandia,Nortelândia,29,,-14.916667,-49.4
br,norte,Norte,21,,-20.966667,-41.983333
br,nos-convem,Nos-Convém,05,,-12.683333,-42.216667
br,nossa senhora aparecida,Nossa Senhora Aparecida,18,,-23.881625,-50.590861
br,nossa senhora aparecida,Nossa Senhora Aparecida,24,,-12.366667,-60.620833
br,nossa senhora caravaggio,Nossa Senhora Caravaggio,23,,-29.1806,-51.0939
br,nossa senhora conceicao,Nossa Senhora Conceição,23,,-29.2155,-51.234
br,nossa senhora da abadia da agua suja,Nossa Senhora da Abadia da Água Suja,15,,-18.883333,-47.633333
br,nossa senhora da ajuda,Nossa Senhora da Ajuda,05,,-16.5,-39.083333
br,nossa senhora da aparecida,Nossa Senhora da Aparecida,15,,-20.2,-41.733333
br,nossa senhora da aparecida,Nossa Senhora da Aparecida,21,,-22.033333,-42.8
br,nossa senhora da candelaria,Nossa Senhora da Candelária,18,,-23.161,-50.2496
br,nossa senhora da conceicao da ponte alta,Nossa Senhora da Conceição da Ponte Alta,15,,-21.766667,-45.55
br,nossa senhora da conceicao de itanhaem,Nossa Senhora da Conceição de Itanhaém,27,,-24.183333,-46.783333
br,nossa senhora da conceicao,Nossa Senhora da Conceição,04,,-4.477778,-59.881944
br,nossa senhora da conceicao,Nossa Senhora da Conceição,15,,-19.35,-47.283333
br,nossa senhora da conceicao,Nossa Senhora da Conceição,29,,-15.616667,-49.033333
br,nossa senhora da gloria,Nossa Senhora da Glória,04,,-7.1,-73.783333
br,nossa senhora da gloria,Nossa Senhora da Glória,15,,-18.466667,-44.2
br,nossa senhora da gloria,Nossa Senhora da Glória,28,18613,-10.233333,-37.416667
br,nossa senhora da guia,Nossa Senhora da Guia,04,,.433333,-67.333333
br,nossa senhora da guia,Nossa Senhora da Guia,14,,-14.633333,-57.066667
br,nossa senhora da guia,Nossa Senhora da Guia,17,,-6.95,-34.883333
br,nossa senhora da luz do aterrado,Nossa Senhora da Luz do Aterrado,15,,-19.8,-45.666667
br,nossa senhora da luz,Nossa Senhora da Luz,30,,-8.05,-35.1
br,nossa senhora da mae dos homens,Nossa Senhora da Mãe dos Homens,27,,-22.866667,-46.616667
br,nossa senhora da paz,Nossa Senhora da Paz,05,,-12.25,-38.366667
br,nossa senhora da penha,Nossa Senhora da Penha,21,,-21.283333,-41.75
br,nossa senhora da piedade,Nossa Senhora da Piedade,21,,-22.124444,-43.241944
br,nossa senhora da roca,Nossa Senhora Da Roça,23,,-29.2108,-51.1035
br,nossa senhora das candeias,Nossa Senhora das Candeias,05,,-12.666667,-38.55
br,nossa senhora das dores,Nossa Senhora das Dores,21,,-22.464444,-43.945278
br,nossa senhora das dores,Nossa Senhora das Dores,28,14550,-10.483333,-37.216667
br,nossa senhora das gracas,Nossa Senhora das Graças,18,,-22.85,-51.766667
br,nossa senhora das gracas,Nossa Senhora Das Graças,23,,-29.1544,-51.0949
br,nossa senhora das neves,Nossa Senhora das Neves,05,,-12.8,-38.516667
br,nossa senhora de campos do rio real,Nossa Senhora de Campos do Rio Real,28,,-11.183333,-38.016667
br,nossa senhora de fatima,Nossa Senhora de Fãtima,06,,-5.016667,-37.733333
br,nossa senhora de fatima,Nossa Senhora de Fátima,18,,-26.175278,-53.606111
br,nossa senhora de lourdes,Nossa Senhora de Lourdes,28,,-10.083333,-37.05
br,nossa senhora de o de ipojuca,Nossa Senhora de O de Ipojuca,30,,-8.433333,-35.016667
br,nossa senhora do amparo,Nossa Senhora do Amparo,21,,-22.366667,-44.083333
br,nossa senhora do carmo,Nossa Senhora do Carmo,08,,-20.333333,-41.016667
br,nossa senhora do carmo,Nossa Senhora do Carmo,15,,-19.5,-43.366667
br,nossa senhora do carmo,Nossa Senhora do Carmo,25,,.266667,-61.766667
br,nossa senhora do conceicao,Nossa Senhora do Conceição,15,,-19.35,-47.283333
br,nossa senhora do desterro,Nossa Senhora do Destêrro,26,,-27.583333,-48.566667
br,nossa senhora do itanhem,Nossa Senhora do Itanhem,05,,-17.15,-40.333333
br,nossa senhora do livramento,Nossa Senhora do Livramento,14,,-15.8,-56.366667
br,nossa senhora do livramento,Nossa Senhora do Livramento,17,,-7.05,-34.9
br,nossa senhora do mae dos homens do turvo,Nossa Senhora do Mãe dos Homens do Turvo,15,,-18.45,-43.05
br,nossa senhora do monte de itapicuru da praia,Nossa Senhora do Monte de Itapicuru da Praia,05,,-11.816667,-37.616667
br,nossa senhora do o,Nossa Senhora do Ó,27,,-23.498773,-46.699829
br,nossa senhora do o,Nossa Senhora do Ó,30,,-8.433333,-35.016667
br,nossa senhora do pendancino,Nossa Senhora do Pendancino,23,,-29.0969,-51.1873
br,nossa senhora do porto,Nossa Senhora do Porto,15,,-18.883333,-43.1
br,nossa senhora dos milagres,Nossa Senhora dos Milagres,05,,-12.866667,-39.85
br,nossa senhora do socorro,Nossa Senhora do Socorro,28,163996,-10.866667,-37.116667
br,nossa senhora dos prazeres do inhambupe,Nossa Senhora dos Prazeres do Inhambupe,05,,-11.933333,-38.083333
br,nossa senhora dos prazeres,Nossa Senhora dos Prazeres,30,,-8.166667,-34.933333
br,nossa senhora dos remedios,Nossa Senhora dos Remédios,20,,-3.983333,-42.666667
br,nossa senhora mae dos homens do turvo,Nossa Senhora Mãe dos Homens do Turvo,15,,-18.45,-43.05
br,nossa senhora mae dos homens,Nossa Senhora Mãe dos Homens,27,,-22.866667,-46.616667
br,nossa senhora,Nossa Senhora,02,,-9.416667,-38.033333
br,nova acao,Nova Ação,04,,-6.133333,-64.233333
br,nova accao,Nova Acção,04,,-6.133333,-64.233333
br,nova aguia,Nova Aguia,04,,-6.5,-69.433333
br,nova alegria,Nova Alegria,04,,-4.411944,-59.933611
br,nova alegria,Nova Alegria,05,,-16.916667,-39.733333
br,nova alianca do avai,Nova Aliança do Avaí,18,,-23.116667,-52.65
br,nova alianca do ivai,Nova Aliança do Ivaí,18,,-23.116667,-52.65
br,nova alianca,Nova Aliança,27,,-21.033333,-49.5
br,nova almeida,Nova Almeida,08,,-20.05,-40.2
br,nova alvorada,Nova Alvorada,14,,-13.65,-59.9125
br,nova amelia,Nova Amélia,01,,-10.466667,-68.05
br,nova america da colina,Nova América da Colina,18,,-23.333333,-50.7
br,nova america,Nova América,05,,-12.033333,-39.283333
br,nova america,Nova América,27,,-21.5,-48.666667
br,nova america,Nova América,29,,-15.016667,-49.933333
br,nova araca,Nova Araçá,23,,-28.666667,-51.75
br,nova assis,Nova Assis,06,,-3.433333,-39.466667
br,nova aurora,Nova Aurora,01,,-10.633333,-68.416667
br,nova aurora,Nova Aurora,04,,-3.366667,-67.85
br,nova aurora,Nova Aurora,11,,-22.75,-55.45
br,nova aurora,Nova Aurora,13,,-5.566667,-43.166667
br,nova aurora,Nova Aurora,18,9013,-22.866667,-52.566667
br,nova aurora,Nova Aurora,29,,-18.066667,-48.266667
br,nova barra,Nova Barra,21,,-23.012221,-43.471344
br,nova bassano,Nova Bassano,23,,-28.733333,-51.7
br,nova belem,Nova Belém,13,,-4.233333,-43.366667
br,nova beluno,Nova Beluno,26,,-28.583333,-49.433333
br,nova betania,Nova Betânia,06,,-6.85,-39.55
br,nova betania,Nova Betânia,08,,-20.816667,-40.666667
br,nova brasilandia d'oeste,Nova Brasilandia d'Oeste,24,,-11.75,-62.333333
br,nova brasilia,Nova Brasília,21,,-22.863536,-43.271525
br,nova brescia,Nova Bréscia,23,,-29.2,-52.033333
br,nova buenopolis,Nova Buenópolis,27,,-21.2,-50.966667
br,nova california,Nova California,15,,-21.795833,-43.401389
br,nova canaa,Nova Canaã,05,,-14.783333,-40.133333
br,nova canaa,Nova Canaã,08,,-21.05,-40.9
br,nova canaa,Nova Canaã,27,,-20.4,-50.966667
br,nova casa,Nova Casa,20,,-7.966667,-41.866667
br,nova cintra,Nova Cintra,25,,2.583333,-60.033333
br,nova cintra,Nova Cintra,27,,-22.216667,-46.766667
br,nova concordia,Nova Concórdia,18,,-24.716667,-53.866667
br,nova conquista,Nova Conquista,05,,-15.5,-41.25
br,nova cravinhos,Nova Cravinhos,27,,-21.983333,-50.1
br,nova cruz,Nova Cruz,05,,-12.133333,-40.25
br,nova cruz,Nova Cruz,06,,-5.866667,-39.85
br,nova cruz,Nova Cruz,22,23166,-6.466667,-35.433333
br,nova cruz,Nova Cruz,30,,-7.85,-34.85
br,nova dantzig,Nova Dantzig,18,,-23.233333,-51.25
br,nova descoberta,Nova Descoberta,08,,-21.133333,-41.216667
br,nova descoberta,Nova Descoberta,30,,-7.75,-38.783333
br,nova dourados,Nova Dourados,11,,-18.066667,-57.5
br,nova empresa,Nova Emprêsa,01,,-10,-67.866667
br,nova era,Nova Era,15,15595,-19.75,-43.05
br,novaes,Novaes,05,,-10.65,-43.133333
br,nova esperanca,Nova Esperança,01,,-10.7,-68.5
br,nova esperanca,Nova Esperança,05,,-16.3,-39.233333
br,nova esperanca,Nova Esperança,18,24833,-23.182485,-52.203005
br,nova esperanca,Nova Esperança,22,,-5.270833,-36.356389
br,nova esperanca,Nova Esperança,23,,-29.416667,-54.833333
br,nova esperanca,Nova Esperança,24,,-8.15,-63.033333
br,nova esperanca,Nova Esperança,26,,-26.997017,-49.76109
br,nova estrela,Nova Estrêla,08,,-20.666667,-40.833333
br,nova estrela,Nova Estrêla,25,,3.670116,-59.741216
br,nova europa,Nova Europa,27,,-21.766667,-48.55
br,nova fatima,Nova Fátima,18,,-23.433333,-50.55
br,nova fazenda,Nova Fazenda,20,,-7.116667,-42.333333
br,nova fe,Nova Fé,13,,-3.888889,-42.939167
br,nova floresta,Nova Floresta,06,,-5.3,-39.35
br,nova floresta,Nova Floresta,17,8623,-6.45,-36.2
br,nova flor,Nova Flor,05,,-12.55,-39.55
br,nova fortaleza,Nova Fortaleza,20,,-5.45,-42.5
br,nova friburgo,Nova Friburgo,21,153363,-22.266667,-42.533333
br,nova galicia,Nova Galícia,26,,-26.366667,-51.15
br,nova galizia,Nova Galizia,26,,-26.366667,-51.15
br,nova granada,Nova Granada,18,,-23.183333,-50.183333
br,nova granada,Nova Granada,27,15716,-20.483333,-49.316667
br,nova guataporanga,Nova Guataporanga,27,,-21.333333,-51.633333
br,nova helena,Nova Helena,06,,-6.166667,-38.833333
br,nova holanda,Nova Holanda,06,,-4.75,-40.35
br,nova holanda,Nova Holanda,21,,-22.853836,-43.242413
br,nova holanda,Nova Holanda,24,,-8.966667,-62.75
br,nova holandia,Nova Holandia,24,,-8.966667,-62.75
br,nova hollanda,Nova Hollanda,24,,-8.966667,-62.75
br,nova hollandia,Nova Hollandia,24,,-8.966667,-62.75
br,nova ibia,Nova Ibiá,05,,-13.8,-39.583333
br,nova iguacu,Nova Iguaçu,21,1002129,-22.759188,-43.431887
br,nova iguassu,Nova Iguassú,21,,-22.759188,-43.431887
br,nova independencia,Nova Independência,27,,-21.1,-51.483333
br,nova iorque,Nova Iorque,04,,-6.783889,-70.983056
br,nova iorque,Nova Iorque,13,,-2.933333,-44.933333
br,nova ipanema,Nova Ipanema,21,,-23.002927,-43.359805
br,nova ipira,Nova Ipira,18,,-24.183333,-53.916667
br,novais,Novais,05,,-10.65,-43.133333
br,novais,Novais,15,,-19.833333,-45.066667
br,novais,Novais,27,,-20.983333,-48.933333
br,nova itaguai,Nova Itaguaí,21,,-22.88316,-43.768628
br,nova itaipe,Nova Itaípe,05,,-13.133333,-40.2
br,nova italia,Nova Itália,23,,-27.433333,-52.133333
br,nova itapirema,Nova Itapirema,27,,-21.1,-49.533333
br,nova itarana,Nova Itarana,05,,-13.033333,-40.05
br,nova jerusalem,Nova Jerusalém,04,,-3.946111,-62.819444
br,nova laje do gaviao,Nova Laje do Gavião,05,,-14.4,-41.083333
br,nova laje,Nova Laje,14,,-7.7,-58.2
br,nova lapa,Nova Lapa,20,,-8.816667,-44.216667
br,nova laranjeiras,Nova Laranjeiras,18,,-25.3,-52.533333
br,nova licao,Nova Lição,01,,-7.65,-73.283333
br,nova lidice,Nova Lídice,05,,-17.433333,-40.05
br,nova lima,Nova Lima,15,88400,-19.983333,-43.85
br,nova londres,Nova Londres,18,,-25.766667,-52.866667
br,nova londrina,Nova Londrina,18,11042,-22.75,-53
br,nova lourdes,Nova Lourdes,18,,-25.766667,-52.866667
br,nova lusitania,Nova Lusitânia,27,,-20.866667,-50.25
br,nova macajuba,Nova Macajuba,16,,-1.233333,-46.866667
br,nova maripa,Nova Maripá,18,,-24.416667,-53.833333
br,nova milano,Nova Milano,23,,-29.3,-51.333333
br,nova mocajuba,Nova Mocajuba,16,,-1.233333,-46.866667
br,nova modica,Nova Módica,15,,-18.433333,-41.5
br,nova,Nova,02,,-8.966667,-37.75
br,nova,Nova,05,,-10.516667,-42.25
br,nova,Nova,06,,-5.083333,-37.85
br,nova,Nova,11,,-21.866667,-56.533333
br,nova,Nova,14,,-14.15,-56.283333
br,nova,Nova,17,,-6.983333,-37.85
br,nova,Nova,22,,-5.65,-35.7
br,nova,Nova,23,,-30.133333,-54.516667
br,nova,Nova,30,,-7.916667,-38.216667
br,nova,Nova,31,,-8.933333,-48.316667
br,nova odessa,Nova Odessa,27,49433,-22.783333,-47.3
br,nova olimpia,Nova Olímpia,14,19283,-14.816667,-57.333333
br,nova olinda do norte,Nova Olinda do Norte,04,12344,-3.75,-59.05
br,nova olinda,Nova Olinda,01,,-10.116667,-69.183333
br,nova olinda,Nova Olinda,04,,-3.416667,-67.883333
br,nova olinda,Nova Olinda,05,,-11.366667,-38.35
br,nova olinda,Nova Olinda,06,,-5.916667,-40.1
br,nova olinda,Nova Olinda,13,,-6.7,-43.466667
br,nova olinda,Nova Olinda,16,,-5.116667,-54.45
br,nova olinda,Nova Olinda,17,,-6.95,-38.25
br,nova olinda,Nova Olinda,20,,-5.333333,-41.283333
br,nova olinda,Nova Olinda,22,,-5.8925,-37.201389
br,nova olinda,Nova Olinda,25,,2.866667,-60.75
br,nova olinda,Nova Olinda,30,,-8.833333,-39.916667
br,nova olinda,Nova Olinda,31,,-7.6025,-48.293611
br,nova olioda,Nova Olioda,16,,-7.1,-51.666667
br,nova padua,Nova Pádua,23,,-29.033333,-51.316667
br,nova palma,Nova Palma,05,,-14.316667,-39.533333
br,nova palma,Nova Palma,23,,-29.466667,-53.466667
br,nova palmeira,Nova Palmeira,17,,-6.683333,-36.416667
br,nova palmeira,Nova Palmeira,23,,-29.316667,-51.2
br,nova palmeiras,Nova Palmeiras,17,,-6.683333,-36.416667
br,nova palmira,Nova Palmira,23,,-29.316667,-51.2
br,nova palmira,Nova Palmira,27,,-20.716667,-50.433333
br,nova parnagua,Nova Parnaguá,20,,-10.033333,-44.283333
br,nova patria,Nova Pátria,27,,-22.2,-51.75
br,nova paz,Nova Paz,06,,-5.733333,-39.233333
br,nova petropolis,Nova Petropolis,08,,-19.816667,-40.666667
br,nova petropolis,Nova Petrópolis,23,16050,-29.366667,-51.133333
br,nova petropolis,Nova Petrópolis,26,,-27.116667,-51.616667
br,nova ponte,Nova Ponte,15,,-19.133333,-47.683333
br,nova prata,Nova Prata,23,17943,-28.783333,-51.6
br,nova resende,Nova Resende,15,,-21.133333,-46.416667
br,nova restinga,Nova Restinga,18,,-25.508638,-49.949813
br,nova riqueza,Nova Riqueza,18,,-26.056944,-53.552778
br,nova roma,Nova Roma,06,,-7.066667,-40.383333
br,nova roma,Nova Roma,23,,-28.966667,-51.4
br,nova roma,Nova Roma,26,,-28.75,-49.783333
br,nova roma,Nova Roma,29,,-13.85,-46.95
br,nova rosalandia,Nova Rosalândia,31,,-10.569722,-48.828611
br,nova russas,Nova Russas,06,21986,-4.7,-40.566667
br,nova santa medianeira,Nova Santa Medianeira,18,,-25.283333,-54.083333
br,nova santa quiteria,Nova Santa Quitéria,13,,-3.501389,-42.563056
br,nova sede,Nova Sede,14,,-9.983333,-59.3
br,nova serrana,Nova Serrana,15,51103,-19.866667,-44.983333
br,nova serrinha,Nova Serrinha,27,,-21.133333,-50.766667
br,nova sorte,Nova Sorte,05,,-12.05,-40.183333
br,nova soure,Nova Soure,05,11340,-11.233333,-38.483333
br,nova stittin,Nova Stittin,26,,-27.0566,-49.5612
br,nova tabajara,Nova Tabajara,27,,-22.45,-50.366667
br,nova teutonia,Nova Teutônia,26,,-27.05,-52.4
br,nova timboteua,Nova Timboteua,16,,-1.2,-47.4
br,novatos,Novatos,15,,-19.183333,-48.683333
br,nova trento,Nova Trento,26,,-27.283333,-48.916667
br,nova troviso,Nova Troviso,26,,-28.516667,-49.466667
br,nova uniao,Nova União,18,,-25.0323,-53.75
br,nova venecia,Nova Venécia,08,28363,-18.716667,-40.4
br,nova venesa,Nova Venesa,23,,-29.016667,-51.266667
br,nova veneza,Nova Veneza,23,,-29.016667,-51.266667
br,nova veneza,Nova Veneza,26,,-28.65,-49.5
br,nova veneza,Nova Veneza,27,,-22.783333,-47.25
br,nova veneza,Nova Veneza,29,,-16.383333,-49.316667
br,nova venezia,Nova Venêzia,23,,-29.016667,-51.266667
br,nova verona,Nova Verona,08,,-18.75,-40.366667
br,nova viaa,Nova Viaa,31,,-11.883333,-47.8
br,nova vicenca,Nova Vicença,26,,-28.85,-49.8
br,nova vicencia,Nova Vicência,26,,-28.85,-49.8
br,nova vicenza,Nova Vicenza,26,,-27.066667,-51.616667
br,nova vicosa,Nova Viçosa,05,56001,-17.883333,-39.366667
br,nova vida,Nova Vida,01,,-8.378889,-72.790833
br,nova vida,Nova Vida,04,,-3.966667,-66.416667
br,nova vida,Nova Vida,05,,-12,-40.4
br,nova vida,Nova Vida,06,,-4.75,-38.55
br,nova vida,Nova Vida,13,,-5.15,-44.966667
br,nova vida,Nova Vida,16,,-3.683333,-56.666667
br,nova vida,Nova Vida,22,,-6.2,-38.116667
br,nova vida,Nova Vida,24,,-10.183333,-62.827222
br,nova vida,Nova Vida,25,,-3.2,-59.916667
br,nova vida,Nova Vida,27,,-21.133333,-51.216667
br,nova vida,Nova Vida,31,,-11.883333,-47.8
br,nova vila do campo maior,Nova Vila do Campo Maior,06,,-5.2,-39.283333
br,nova vincenza,Nova Vincenza,26,,-27.066667,-51.616667
br,nova vista,Nova Vista,04,,-7.383333,-58.216667
br,nova vista,Nova Vista,05,,-12.15,-40.266667
br,nova vista,Nova Vista,20,,-10,-44.016667
br,nova vista,Nova Vista,22,,-6.85,-36.033333
br,nova vola,Nova Vola,18,,-23.8107,-50.3623
br,nova volta,Nova Volta,18,,-23.8107,-50.3623
br,nova xavantina,Nova Xavantina,26,,-27.083333,-52.333333
br,nova york,Nova York,13,,-6.75,-44.05
br,novilha ii,Novilha II,13,,-3.305833,-43.436111
br,novilha i,Novilha I,13,,-3.319722,-43.441944
br,novilhona,Novilhona,15,,-17.466667,-42.016667
br,novilho,Novilho,06,,-5.016667,-40.55
br,novo acordo,Novo Acôrdo,16,,-3.566667,-52.266667
br,novo acre,Novo Acre,05,,-13.45,-41.1
br,novo airao,Novo Airão,04,,-2.626944,-60.95
br,novo amparo,Novo Amparo,05,,-10.683333,-38.283333
br,novo apua,Novo Apuá,04,,-8.383333,-65.75
br,novo areal,Novo Areal,04,,-6.683333,-64.583333
br,novo areal,Novo Areal,17,,-7.033333,-35.883333
br,novo areial,Novo Areial,17,,-7.033333,-35.883333
br,novo aripuana,Novo Aripuanã,04,11044,-5.120278,-60.378889
br,novo belem,Novo Belém,13,,-4.233333,-43.366667
br,novo bellamo,Novo Bellamo,26,,-28.583333,-49.433333
br,novo birigui,Novo Birigui,18,,-23.050491,-52.092865
br,novo brasil,Novo Brasil,08,,-19.233333,-40.6
br,novo brasil,Novo Brasil,24,,-12.202778,-60.083333
br,novo brasil,Novo Brasil,29,,-16.183333,-50.633333
br,novo capricho,Novo Capricho,04,,-5.6,-63.05
br,novo cayaue,Novo Cayaue,04,,-3.05,-65.966667
br,novo cravinhos,Novo Cravinhos,27,,-21.983333,-50.1
br,novo cruzeiro,Novo Cruzeiro,15,10385,-17.483333,-41.883333
br,novo destino,Novo Destino,04,,-7.1,-71.766667
br,novo destino,Novo Destino,06,,-5.983333,-38.733333
br,novo destino,Novo Destino,21,,-22.166667,-41.616667
br,novo destino,Novo Destino,25,,3.75,-59.683333
br,novo estado,Novo Estado,20,,-5.066667,-43.016667
br,novo exu,Novo Exu,30,,-7.516667,-39.716667
br,novo granaoa,Novo Granaoa,27,,-20.483333,-49.316667
br,novo hamburg,Novo Hamburg,23,,-29.683333,-51.133333
br,novo hamburgo,Novo Hamburgo,23,253846,-29.683333,-51.133333
br,novo horizonte,Novo Horizonte,05,,-12.1,-45.083333
br,novo horizonte,Novo Horizonte,11,,-19.266667,-54.75
br,novo horizonte,Novo Horizonte,15,,-18.3,-41.15
br,novo horizonte,Novo Horizonte,16,,-7.716667,-51.183333
br,novo horizonte,Novo Horizonte,18,,-24.85,-53.516667
br,novo horizonte,Novo Horizonte,20,,-9.2,-44.4
br,novo horizonte,Novo Horizonte,21,,-21.733333,-41.616667
br,novo horizonte,Novo Horizonte,26,,-28.4,-49.533333
br,novo horizonte,Novo Horizonte,27,30159,-21.466667,-49.216667
br,novo horizonte,Novo Horizonte,29,,-16.466667,-49.966667
br,novo horizonte,Novo Horizonte,30,,-9,-36.566667
br,novo intento,Novo Intento,04,,-6.666667,-64.5
br,novo itento,Novo Itento,04,,-6.666667,-64.5
br,novo japao,Novo Japão,01,,-8.833333,-70.6
br,novo jardim,Novo Jardim,18,,-23.660431,-50.199152
br,novo jardim,Novo Jardim,31,,-11.871111,-46.563333
br,novo jaruapuca,Novo Jaruapuca,04,,-2.833333,-65.916667
br,novo leblon,Novo Leblon,21,,-23.003545,-43.383153
br,novolina,Novolina,06,,-3.416667,-40.216667
br,novo lino,Novo Lino,02,5538,-9.016667,-35.616667
br,novolino,Novolino,30,,-8.833333,-39.916667
br,novo marapi,Novo Marapi,04,,-1.766667,-65.75
br,novo mundo,Novo Mundo,02,,-9.883333,-37.15
br,novo mundo,Novo Mundo,04,,-7.466667,-70.166667
br,novo mundo,Novo Mundo,05,,-9.7,-39.6
br,novo mundo,Novo Mundo,14,,-15.216667,-55.5
br,novo mundo,Nôvo Mundo,22,,-5.928611,-36.178056
br,novo nilo,Novo Nilo,20,,-4.4,-42.9
br,novo,Nôvo,06,,-5.366667,-39.716667
br,novo,Novo,13,,-8.5,-46.466667
br,novo,Nôvo,17,,-7.133333,-36.633333
br,novo oeste,Novo Oeste,14,,-13.679167,-59.729167
br,novo oriente,Novo Oriente,04,,-3.994444,-62.853333
br,novo oriente,Novo Oriente,05,,-14.183333,-40.1
br,novo oriente,Nôvo Oriente,06,14529,-5.533333,-40.766667
br,novo oriente,Novo Oriente,08,,-19.466667,-40.766667
br,novo oriente,Novo Oriente,13,,-3.023333,-42.065278
br,novo oriente,Novo Oriente,20,,-6.45,-41.933333
br,novo oriente,Nôvo Oriente,22,,-5.233333,-36.063333
br,novo oriente,Novo Oriente,27,,-20.633333,-51.116667
br,novo ouricuri,Novo Ouricuri,05,,-12.266667,-39.75
br,novo paraiso,Novo Paraíso,04,,-2.866667,-65.883333
br,novo paraiso,Novo Paraíso,05,,-13,-39.516667
br,novo porto,Novo Pôrto,01,,-8.483333,-70.483333
br,novo prado,Novo Prado,23,,-27.133333,-53.4
br,novo recreio,Novo Recreio,01,,-7.433333,-73.433333
br,novo recreio,Novo Recreio,13,,-8.116667,-46.35
br,novo remedio,Novo Remédio,04,,-4.3675,-59.767778
br,novo sarandi,Novo Sarandi,18,,-24.566667,-53.916667
br,novo sitio,Novo Sítio,13,,-6.016667,-43.616667
br,novos,Novos,20,,-6.716667,-40.666667
br,novos prazeres,Novos Prazeres,04,,-5.569167,-61.101667
br,novo timboteua,Novo Timboteua,16,,-1.2,-47.4
br,novo tres passos,Novo Três Passos,18,,-24.483333,-54.016667
br,novo treviso,Novo Treviso,23,,-28.95,-51.383333
br,n. s. das gracas,N. S. das Graças,04,,-3.110833,-60.021111
br,nucleo bandeirante,Núcleo Bandeirante,07,,-15.866667,-47.966667
br,nucleo caio prado,Núcleo Caio Prado,27,,-22.4,-47.233333
br,nucleo colonial de uma,Núcleo Colonial de Uma,05,,-15.25,-39.25
br,nucleo colonial de una,Núcleo Colonial de Una,05,,-15.25,-39.25
br,nucleo colonial,Núcleo Colonial,21,,-22.333333,-42.416667
br,nucleo dos bandeirantes,Núcleo dos Bandeirantes,07,,-15.866667,-47.966667
br,nucleo hercilio luz,Nucleo Hercilio Luz,26,,-28.75,-49.366667
br,nucleo ibicatu,Núcleo Ibicatu,27,,-22.216667,-47.266667
br,nucleo ingles de sousa,Núcleo Inglês de Sousa,16,,-1.933333,-54.166667
br,nucleo ingles de souza,Núcleo Inglês de Souza,16,,-1.933333,-54.166667
br,nucleo leiteiro,Núcleo Leiteiro,18,,-25.6763,-49.815
br,nucleo mato branco,Núcleo Mato Branco,18,,-25.833333,-52.333333
br,nucleo maua,Núcleo Mauá,15,,-22.316667,-44.566667
br,nucleo passa quatro,Núcleo Passa Quatro,18,,-25.95,-52.433333
br,nucleo residencial d.e.r.,Núcleo Residencial D.E.R.,18,,-23.493055,-49.929663
br,nucleo residencial vila palmeiras,Núcleo Residencial Vila Palmeiras,18,,-25.493672,-48.818682
br,nucleo santa cruz,Núcleo Santa Cruz,27,,-23.842772,-46.596253
br,nucleo sao miguel,Núcleo São Miguel,22,,-5.633333,-35.283333
br,nucleo sao vicente de paulo,Nucleo São Vicente de Paulo,27,,-23.337195,-46.652585
br,nudrin,Nudrin,15,,-17.483333,-41.45
br,nuguacu,Nuguaçu,05,,-10.816667,-40.516667
br,nunca-te-vi,Nunca-te-vi,11,,-22.066667,-56.45
br,nunes freire,Nunes Freire,13,,-5.416667,-46.783333
br,nunes,Nunes,04,,-4.664167,-59.433333
br,nunes,Nunes,05,,-12.333333,-39.033333
br,nunes,Nunes,08,,-20.6,-41.816667
br,nuno pereira,Nuno Pereira,15,,-16.783333,-40.766667
br,nupeba,Nupeba,05,,-11.85,-44.75
br,nuporanga,Nuporanga,27,,-20.733333,-47.75
br,nuputira,Nuputira,29,,-18.266667,-52
br,nuretama,Nuretama,27,,-22.6,-50.016667
br,oacari,Oacari,04,,-3.883333,-58.616667
br,oacary,Oacary,04,,-3.883333,-58.616667
br,oampo alegre,Oampo Alegre,23,,-27.633333,-54.633333
br,oari,Oari,16,,-6.8,-57.35
br,oasis,Oasis,20,,-6.3,-41.3
br,oasis,Oásis,27,,-21.416667,-51.516667
br,oassara,Oassara,24,,-13.216667,-62.1
br,oberica,Oberica,22,,-5.516667,-35.533333
br,obidos,Óbidos,16,24971,-1.908333,-55.518889
br,observatorio sumauma,Observatório Sumaúma,04,,-.366667,-62.783333
br,ocara,Ocara,06,6793,-4.483333,-38.616667
br,ocaucu,Ocauçu,27,,-22.433333,-49.933333
br,occidente,Occidente,15,,-20.016667,-41.466667
br,occulto,Occulto,11,,-23.166667,-54.083333
br,ocean front,Ocean Front,21,,-23.010565,-43.32284
br,ocidente,Ocidente,15,,-20.016667,-41.466667
br,oco do mundo,Ôco do Mundo,04,,-8.033333,-67.25
br,octaviano fonseca,Octaviano Fonseca,11,,-21.883333,-53.466667
br,oculto,Oculto,11,,-23.166667,-54.083333
br,odilon guimaraes,Odilon Guimarães,15,,-15.116667,-46.866667
br,oeiras do para,Oeiras do Pará,16,10163,-1.966667,-49.85
br,oeiras,Oeiras,20,21071,-7.016667,-42.133333
br,oeste,Oeste,23,,-28.75,-52.033333
br,oficina,Oficina,15,,-17.633333,-41.716667
br,oficina,Oficina,20,,-3.505833,-42.235
br,oficinas,Oficinas,15,,-17.633333,-41.716667
br,oficinas,Oficinas,22,,-5.216667,-36.716667
br,oiapoque,Oiapoque,03,,3.833333,-51.833333
br,oiricuri,Oiricuri,05,,-12.133333,-41.666667
br,oitavada,Oitavada,15,,-16.796944,-44.676389
br,oiteiras,Oiteiras,28,,-10.9,-37.85
br,oiteiro,Oiteiro,05,,-8.8,-38.833333
br,oiteiro,Oiteiro,13,,-3.623889,-43.418889
br,oiteiros,Oiteiros,28,,-10.9,-37.85
br,oiticeiro,Oiticeiro,05,,-12.883333,-38.366667
br,oiticica,Oiticica,05,,-15.4,-39
br,oiticica,Oiticica,06,,-3.633333,-40.1
br,oiticica,Oiticica,17,,-6.95,-38.166667
br,oiticica,Oiticica,20,,-5.233333,-41.8
br,oiticica,Oiticica,21,,-22.879731,-43.566065
br,oiticica,Oiticica,22,,-5.062222,-37.496667
br,oiticica,Oiticica,30,,-7.9,-38.666667
br,oiticicatuba,Oiticicatuba,17,,-6.95,-38.166667
br,oiticiquinha,Oiticiquinha,06,,-5.216667,-40.35
br,oiti,Oiti,06,,-5.4,-39.783333
br,oiti,Oiti,20,,-6.25,-41.516667
br,oitis,Oitis,06,,-5.366667,-39.7
br,oitis,Oitis,13,,-3.249722,-42.222778
br,oitis,Oitis,17,,-7.15,-38.566667
br,oitis,Oitis,30,,-7.55,-37.65
br,oitiua,Oitiua,13,,-2.433333,-44.633333
br,oitiva,Oitiva,13,,-2.433333,-44.633333
br,oitizeiro,Oitizeiro,02,,-9.633333,-35.95
br,oitizeiro,Oitizeiro,05,,-12.883333,-38.366667
br,oitizinho,Oitizinho,20,,-6.85,-41.45
br,oito irmaos,Oito Irmãos,22,,-5.331111,-36.181111
br,ojo del mundo,Ojo del Mundo,01,,-11,-68.566667
br,o labyrintho,O Labyrintho,27,,-21.166667,-51.883333
br,olaria do lara,Olaria do Lara,11,,-18.233333,-55.25
br,olaria,Olaria,05,,-10.016667,-42.733333
br,olaria,Olaria,11,,-18.233333,-55.25
br,olaria,Olaria,13,,-3.673611,-42.727778
br,olaria,Olaria,14,,-15.75,-57.5
br,olaria,Olaria,15,,-19.55,-45.2
br,olaria,Olaria,18,,-24.033333,-49.75
br,olaria,Olaria,20,,-5.333333,-41.283333
br,olaria,Olaria,21,,-22.851033,-43.269836
br,olarias,Olarias,23,,-29.433333,-52.033333
br,olaria velha,Olaria Velha,27,,-20.816667,-51.366667
br,olario,Olario,15,,-16.05,-40.383333
br,olavo bilac,Olavo Bilac,21,,-22.768056,-43.325
br,olea,Olea,25,,4.416667,-60.15
br,olegario maciel,Olegário Maciel,15,,-22.316667,-45.583333
br,oleo,Óleo,27,,-22.966667,-49.35
br,olha d'a'gua,Olha d'A'gua,05,,-9.85,-40.45
br,olha d'agua,Olha d'Agua,06,,-5.116667,-41.033333
br,olha d'aguinha,Olha D'aguinha,17,,-6.4,-37.916667
br,olho da a'gua,Olho da A'gua,06,,-7.25,-38.733333
br,olho d'agua branca,Olho d'Agua Branca,17,,-7.5,-36.916667
br,olho d'agua da bica,Olho d'Agua da Bica,06,,-5.316667,-38.033333
br,olho d'agua da canoa,Olho d'Agua da Canoa,02,,-9.733333,-36.766667
br,olho d'agua da gama,Olho d'Agua da Gama,30,,-7.966667,-38.583333
br,olho d'agua da mandioca,Olho d'Agua da Mandioca,06,,-5.033333,-40.016667
br,olho d'agua da mariquinha,Olho d'Agua da Mariquinha,05,,-12.433333,-44.25
br,olho d'agua da mata,Olho d'Agua da Mata,30,,-9.066667,-36.633333
br,olho d'agua das bestas,Olho d'Agua das Bestas,30,,-8.85,-36.15
br,olho d'agua das eguas,Olho d'Agua das Eguas,06,,-6.833333,-38.8
br,olho d'agua das flores,Olho d'Agua das Flores,02,,-9.55,-37.283333
br,olho-d'agua das palmeiras,Olho-d'Agua das Palmeiras,20,,-3.8325,-42.097778
br,olho d'agua das pedras,Olho d'Agua das Pedras,20,,-3.955,-42.033889
br,olho d'agua de cantaduva,Olho d'Agua de Cantaduva,22,,-5.358333,-36.201389
br,olho d'agua de dentro,Olho d'Agua de Dentro,15,,-15.583333,-41.883333
br,olho d'agua de igreja,Olho d'Agua de Igreja,06,,-7.283333,-38.933333
br,olho d'agua de milho,Olho d'Agua de Milho,06,,-5.333333,-39.633333
br,olho d'agua de pedra,Olho d'Agua de Pedra,20,,-7.516667,-43.183333
br,olho-d'agua do abraao,Olho-d'Agua do Abraao,13,,-3.688889,-43.2375
br,olho d'agua do basilio,Olho d'Agua do Basilio,05,,-12.6,-41.916667
br,olho d'agua do boi,Olho d'Agua do Boi,06,,-5.566667,-39.733333
br,olho d'agua do borges,Olho d'Agua do Borges,22,,-5.95,-37.7
br,olho-d'agua-do-borges,Olho-d'Agua-do-Borges,22,,-6.166667,-36.15
br,olho d'agua do campo,Olho d'Agua do Campo,20,,-5.566667,-42.116667
br,olho d'agua do capim,Olho d'Agua do Capim,22,,-5.432778,-36.085278
br,olho d'agua do casado,Olho d'Agua do Casado,02,,-9.5,-37.95
br,olho d'agua do chapeu,Olho d'Agua do Chapeu,22,,-5.766667,-35.433333
br,olho d'agua do cruzeiro,Olho d'Agua do Cruzeiro,05,,-13.5,-40.933333
br,olho d'agua do facundo,Olho d'Agua do Facundo,05,,-10.933333,-41.266667
br,olho d'agua do gado,Olho d'Agua do Gado,06,,-4.6,-39.666667
br,olho d'agua dois irmaos,Olho d'Agua Dois Irmaos,22,,-5.438889,-36.1675
br,olho d'agua do mato,Olho d'Agua do Mato,22,,-5.566111,-37.045833
br,olho d'agua do negro,Olho d'Agua do Negro,02,,-9.25,-37.333333
br,olho d'agua do noga,Olho d'Agua do Noga,13,,-5.85,-43.483333
br,olho d'agua do pico,Olho d'Agua do Pico,17,,-7.2,-36.966667
br,olho d'agua do pinga,Olho d'Agua do Pinga,20,,-9.15,-43.983333
br,olho d'agua dos bois,Olho d'Agua dos Bois,06,,-4.733333,-40.2
br,olho d'agua dos borges,Olho d'Agua dos Borges,22,,-5.95,-37.7
br,olho d'agua do seco,Olho d'Agua do Seco,05,,-12.533333,-42.116667
br,olho d'agua do serafim,Olho d'Agua do Serafim,05,,-12.766667,-42.05
br,olho d'agua dos fagundes,Olho d'Agua dos Fagundes,06,,-4.95,-39.75
br,olho d'agua dos galheiros,Olho d'Agua dos Galheiros,20,,-5.283333,-42.116667
br,olho d'agua do silva,Olho d'Agua do Silva,17,,-7.883333,-37.216667
br,olho-d'agua dos pires,Olho-d'Agua dos Pires,20,,-3.858333,-42.373889
br,olho d'agua dos pombos,Olho d'Agua dos Pombos,30,,-8.683333,-36.35
br,olho d'agua dos vieiras,Olho d'Agua dos Vieiras,06,,-5.1,-39.316667
br,olho d'agua do urucu,Olho d'Agua do Urucu,06,,-6.533333,-40.533333
br,olho d'agua grande,Olho d'Agua Grande,02,,-10.05,-36.8
br,olho d'agua grande,Olho d'Agua Grande,13,,-4.716667,-44.566667
br,olho-d'agua grande,Olho-d'Agua Grande,20,,-3.546111,-42.435278
br,olho d'agua grande,Olho d'Agua Grande,20,,-4.25,-41.283333
br,olho d'agua,Olho d'Agua,02,,-9.166667,-37.35
br,olho d'agua,Olho d'Agua,05,,-10.816667,-43.35
br,olho d'agua,Olho d'Agua,06,,-2.883333,-39.95
br,olho d' agua,Olho d' Agua,06,,-2.948056,-41.015556
br,olho d'agua,Olho d'Agua,06,,-3.266667,-39.383333
br,olho d'agua,Olho d'Agua,11,,-19.833333,-55.383333
br,olho d'agua,Olho d'Agua,13,,-2.516667,-44.233333
br,olho-d'agua,Olho-d'Agua,13,,-3.017778,-42.053889
br,olho d'agua,Olho d'Agua,13,,-3.1,-45.116667
br,olho-d'agua,Olho-d'Agua,13,,-3.283056,-43.428056
br,olho d'agua,Olho d'Agua,13,,-3.483333,-44.416667
br,olho-d'agua,Olho-d'Agua,13,,-3.548611,-42.640833
br,olho d'agua,Olho d'Agua,13,,-4.166667,-43.033333
br,olho d'agua,Olho d'Agua,14,,-16.066667,-56.833333
br,olho-d'agua,Olho-d'Agua,15,,-20.533333,-45.183333
br,olho d'agua,Olho D'agua,17,,-6.233333,-37.716667
br,olho d'agua,Olho d'Agua,18,,-25.783333,-50.333333
br,olho d'agua,Olho d'Agua,20,,-10.216667,-44.583333
br,olho-d'agua,Olho-d'Agua,20,,-3.521667,-42.475
br,olho d'agua,Olho d'Agua,20,,-4.6,-41.566667
br,olho d'agua,Olho d'Agua,22,,-5.133333,-35.75
br,olho-d'agua,Olho-d'Agua,22,,-6.166667,-36.15
br,olho d'agua,Olho d'Agua,25,,3.833333,-60.216667
br,olho d'agua,Olho d'Agua,26,,-28.75,-49.2
br,olho d'agua,Olho d'Agua,29,,-15.283333,-50.116667
br,olho d'agua,Olho d'Agua,30,,-7.816667,-40.45
br,olho d'agua,Olho d'Agua,31,,-6.466667,-48.35
br,olho d'agua preta,Olho d'Agua Preta,02,,-9.9,-37.016667
br,olho d'agua preta,Olho d'Agua Preta,30,,-8.733333,-36.416667
br,olho d'agua seco,Olho d'Agua Seco,06,,-4.416667,-39.633333
br,olho d'agua seco,Olho d'Agua Seco,17,,-6.5,-38.333333
br,olho d'agua seco,Olho d'Agua Seco,30,,-8.683333,-36.133333
br,olho d'agua velha,Olho d'Agua Velha,17,,-7.2,-37.45
br,olho d'agua velho,Olho d'Agua Velho,22,,-5.4375,-36.225
br,olho d'aguinha,Olho d'Aguinha,06,,-5.733333,-40.016667
br,olho d'aguinha,Olho d'Aguinha,20,,-6.216667,-41.983333
br,olho-de agua,Olho-de Água,27,,-23.291809,-46.571628
br,olho do mundo,Ôlho do Mundo,01,,-11,-68.566667
br,olho do sertao,Ôlho do Sertão,02,,-9.833333,-36.75
br,olhos d'agua da barriguda,Olhos d'Agua da Barriguda,05,,-13.6,-40.866667
br,olhos d'agua das bestas,Olhos d'Agua das Bestas,30,,-8.85,-36.15
br,olhos dagua do acioli,Olhos Dágua do Acioli,02,,-9.55,-36.633333
br,olhos d'agua do basilio,Olhos d'Agua do Basilio,05,,-12.6,-41.916667
br,olhos d'agua do casado,Olhos d'Agua do Casado,02,,-9.516667,-37.85
br,olhos d'agua do seco,Olhos d'Agua do Seco,05,,-12.533333,-42.116667
br,olhos d'agua,Olhos d'Agua,02,,-10.066667,-36.883333
br,olhos d'agua,Olhos d'Agua,05,,-10.816667,-43.35
br,olhos d'agua,Olhos d'Agua,06,,-6.85,-38.75
br,olhos d'agua,Olhos d'Agua,11,,-20.233333,-56.683333
br,olhos d'agua,Olhos d'Agua,14,,-16.233333,-57.3
br,olhos d'agua,Olhos d'Agua,15,,-17.416667,-43.55
br,olhos d'agua,Olhos d'Agua,20,,-10.216667,-44.583333
br,olhos d'agua,Olhos d'Agua,27,,-20.45,-48.033333
br,olhos d'agua,Olhos d'Agua,28,,-10.783333,-37.683333
br,olhos d'agua,Olhos d'Agua,29,,-18.383333,-47.9
br,olhos d'agua,Olhos d'Agua,30,,-8.566667,-36.866667
br,olhos d'agua seco,Olhos d'Agua Seco,05,,-12.533333,-42.116667
br,olhos d'aguas,Olhos d'Aguas,05,,-13.716667,-41.3
br,olhos de agua,Olhos de Água,15,,-20.0012,-43.9733
br,olho torto,Ôlho Torto,05,,-10.683333,-40.966667
br,olhoz d'agua,Olhoz d'Agua,05,,-12.466667,-38.033333
br,olimpia,Olímpia,27,45200,-20.733333,-48.9
br,olimpio de freitas,Olímpio de Freitas,15,,-19.166667,-48.366667
br,olimpio jacinto,Olímpio Jacinto,15,,-18.933333,-48.433333
br,olimpio lopes,Olímpio Lopes,18,,-23.4,-51.116667
br,olimpio noronha,Olímpio Noronha,15,,-22.066667,-45.266667
br,olimpo,Olimpo,23,,-31.866667,-52.833333
br,olinda matos,Olinda Matos,15,,-16.833333,-41.233333
br,olinda,Olinda,04,,-6.433333,-68.483333
br,olinda,Olinda,06,,-4.733333,-39.933333
br,olinda,Olinda,20,,-4.616667,-42.4
br,olinda,Olinda,21,,-22.818156,-43.41666
br,olinda,Olinda,22,,-6.516667,-36.783333
br,olinda,Olinda,23,,-28.35,-51.466667
br,olinda,Olinda,30,366761,-8.016667,-34.85
br,olindina,Olindina,05,12317,-11.366667,-38.35
br,olindo,Olindo,06,,-4.733333,-39.933333
br,olinto,Olinto,23,,-28.35,-51.466667
br,oliva,Oliva,11,,-22.2,-56.316667
br,oliva,Oliva,23,,-29.233333,-50.883333
br,olivar,Olivar,27,,-23.6476,-47.5453
br,olivedos,Olivedos,17,,-6.983333,-36.25
br,oliveira do brejinho,Oliveira do Brejinho,05,,-12.316667,-42.9
br,oliveira dos brejinhos,Oliveira dos Brejinhos,05,5596,-12.316667,-42.9
br,oliveira dos campinhas,Oliveira dos Campinhas,05,,-12.416667,-38.783333
br,oliveira fortes,Oliveira Fortes,15,,-21.333333,-43.45
br,oliveira,Oliveira,05,,-12.383333,-38.416667
br,oliveira,Oliveira,11,,-19.683333,-55.183333
br,oliveira,Oliveira,15,34711,-20.683333,-44.816667
br,oliveira,Oliveira,16,,-1,-47.5
br,oliveira,Oliveira,18,,-23.385878,-49.801236
br,oliveira,Oliveira,26,,-27.166667,-48.75
br,oliveira,Oliveira,31,,-6.55,-48.666667
br,oliveiras,Oliveiras,06,,-5.066667,-40.416667
br,oliveiropolis,Oliveirópolis,20,,-4.366667,-41.783333
br,olivenca,Olivença,02,2848,-9.516667,-37.183333
br,olivenca,Olivença,05,,-14.95,-39.016667
br,olivera,Olivera,15,,-20.683333,-44.816667
br,oliveria dos campinhos,Oliveria dos Campinhos,05,,-12.416667,-38.783333
br,olivia,Olivia,11,,-22.033333,-57.6
br,olivio pedrosa,Olívio Pedrosa,08,,-20.866667,-41.466667
br,olivio peres,Olívio Peres,29,,-16.05,-51.766667
br,olmiro pires,Olmiro Pires,23,,-29.883333,-55.216667
br,oloialermong,Oloialermong,25,,4.266667,-60.833333
br,oloyalemong,Oloyalemong,25,,4.266667,-60.833333
br,olympia,Olympia,27,,-20.733333,-48.9
br,onca do salvador,Onça do Salvador,13,,-3.12,-42.885
br,onca dos paneiros,Onça dos Paneiros,13,,-3.149722,-42.928889
br,onca,Onça,04,,-2.7,-65.366667
br,onca,Onça,05,,-13.683333,-41.816667
br,onca,Onça,06,,-5,-40.483333
br,onca,Onça,13,,-3.341389,-42.655556
br,onca,Onça,14,,-16.3,-57.966667
br,onca,Onça,15,,-19.15,-43.966667
br,onca,Onça,16,,-7.7,-57.816667
br,onca,Onca,17,,-7.016667,-37.35
br,onca,Onça,20,,-3.370833,-42.116944
br,onca,Onça,27,,-21.266667,-47.35
br,onca,Onça,30,,-7.816667,-39.85
br,onca parda,Onça Parda,14,,-15.333333,-56.883333
br,onca-parda,Onça-Parda,27,,-24.744909,-48.150763
br,oncas,Onças,04,,-2.7,-65.366667
br,oncas,Onças,27,,-24.683333,-48.866667
br,oncas,Onças,30,,-8.233333,-36.016667
br,onda branca,Onda Branca,27,,-20.466667,-49.416667
br,onda verde,Onda Verde,27,,-20.616667,-49.3
br,ondina,Ondina,05,,-12.166667,-45.133333
br,oneide,Oneide,24,,-10.45,-62.033333
br,onha,Onha,05,,-13,-39.066667
br,onhapora,Onhaporã,23,,-28.633333,-52.866667
br,onisio pereira,Onísio Pereira,15,,-18.383333,-48.283333
br,onofre,Onofre,15,,-17.183333,-40.616667
br,onos,Onos,06,,-6.25,-38.916667
br,opa,Ôpa,30,,-7.85,-37.616667
br,oquiniguia,Oquiniguia,14,,-15.7,-60.283333
br,oquinimia,Oquinimia,14,,-15.7,-60.283333
br,oratorio,Oratório,15,,-16.333333,-40.966667
br,oratorio,Oratório,17,,-7.4,-35.15
br,oratorios,Oratórios,15,,-20.433333,-42.8
br,orelha da onca,Orelha da Onça,20,,-3.43,-42.137222
br,oriando pedra,Oriando Pedra,15,,-18.55,-41.566667
br,orico,Oricó,05,,-14.3,-39.366667
br,oriental,Oriental,11,,-22.866667,-55.333333
br,oriental,Oriental,13,,-3.166667,-45.133333
br,oriental,Oriental,27,,-23.572046,-47.234203
br,orienta,Orienta,20,,-6.4,-41.916667
br,oriente novo,Oriente Novo,05,,-14.183333,-40.1
br,oriente,Oriente,04,,-3.437222,-62.776111
br,oriente,Oriente,05,,-12.183333,-39.35
br,oriente,Oriente,06,,-3.766667,-40.183333
br,oriente,Oriente,08,,-20.4,-41.15
br,oriente,Oriente,11,,-20.966667,-55.916667
br,oriente,Oriente,13,,-3.166667,-45.133333
br,oriente,Oriente,17,,-6.966667,-37.583333
br,oriente,Oriente,20,,-7.566667,-42.1
br,oriente,Oriente,22,,-5.786667,-36.135556
br,oriente,Oriente,24,,-9.6,-62.116667
br,oriente,Oriente,27,,-22.15,-50.1
br,oriente,Oriente,30,,-7.466667,-39.8
br,oriente,Oriente,31,,-12.289167,-46.385833
br,oriente velho,Oriente Velho,24,,-9.75,-62.616667
br,orindiuva,Orindiúva,27,,-20.2,-49.366667
br,orion,Orion,11,,-21.966667,-56.216667
br,orion,Orion,14,,-16.983333,-58.333333
br,ori,Ori,30,,-7.683333,-39.366667
br,oriximina,Oriximiná,16,35582,-1.765278,-55.863889
br,orizania,Orizânia,15,,-20.5,-42.216667
br,orizona,Orizona,29,7583,-17.05,-48.3
br,orlandia,Orlândia,27,44767,-20.716667,-47.883333
br,orlando,Orlando,14,,-14.583333,-56.733333
br,orleaes,Orleães,26,,-28.35,-49.3
br,orleans do sul,Orleans do Sul,26,,-28.35,-49.3
br,orleans,Orleans,26,16422,-28.35,-49.3
br,orminda costa,Orminda Costa,15,,-16.5,-40.833333
br,orna daniel,Ornã Daniel,15,,-21.45,-46.35
br,orobo,Orobó,05,,-13.216667,-40.9
br,orobo,Orobó,30,5884,-7.733333,-35.6
br,oroco,Orocó,30,,-8.616667,-39.6
br,oros,Orós,06,16329,-6.25,-38.916667
br,ortigeira,Ortigeira,18,,-24.2,-50.916667
br,ortigueira,Ortigueira,18,11541,-24.2,-50.916667
br,os algodoes,Os Algodões,05,,-10.7,-39.05
br,osasco,Osasco,27,677869,-23.566667,-46.783333
br,oscar bressane,Oscar Bressane,27,,-22.3,-50.283333
br,oscar nelson,Oscar Nelson,22,,-5.75,-36.783333
br,oscar resende,Oscar Resende,15,,-21.15,-46.666667
br,os cesares,Os Césares,27,,-22.783333,-46.816667
br,os cesar,Os Cesar,27,,-22.783333,-46.816667
br,osorio felipe,Osório Felipe,15,,-18.616667,-48.083333
br,osorio,Osório,15,,-20.25,-45.766667
br,osorio,Osório,23,34628,-29.9,-50.266667
br,os quatro,Os Quatro,05,,-15.416667,-39.516667
br,os quebos,Os Quebos,14,,-14.6,-56.066667
br,os ribeiros,Os Ribeiros,27,,-22.1,-46.816667
br,osso de porco,Osso de Porco,18,,-23.2296,-50.1403
br,ossuna,Ossuna,11,,-21.716667,-56.85
br,ostras,Ostras,05,,-18.183333,-39.633333
br,osvaldo amaral,Osvaldo Amaral,26,,-26.383333,-49.266667
br,osvaldo amaro,Osvaldo Amaro,26,,-26.383333,-49.266667
br,osvaldo cruz,Osvaldo Cruz,21,,-22.873334,-43.34789
br,osvaldo cruz,Osvaldo Cruz,27,25747,-21.783333,-50.833333
br,osvaldo kroeff,Osvaldo Kroeff,23,,-28.933333,-50.05
br,osvaldo prado,Osvaldo Prado,15,,-21.05,-46.916667
br,oswaldo cruz,Oswaldo Cruz,23,,-27.416667,-53.416667
br,oswaldo kroeff,Oswaldo Kroeff,23,,-28.933333,-50.05
br,otacilia specia,Otacilia Specia,23,,-29.95,-54.233333
br,otacilio costa,Otacílio Costa,26,14557,-27.566667,-50.116667
br,otavio muniz,Otávio Muniz,15,,-21.75,-46.183333
br,otavio rocha,Otávio Rocha,23,,-29.05,-51.25
br,oticica,Oticica,06,,-5.05,-41.083333
br,ourania,Ourânia,21,,-21.033333,-41.9
br,ourem,Ourém,16,8145,-1.55,-47.1
br,ouricana,Ouricana,05,,-15.7,-39.1
br,ouricangas,Ouriçangas,05,,-12.016667,-38.616667
br,ouricuri do ouro,Ouricuri do Ouro,05,,-12.05,-42.483333
br,ouricuri,Ouricuri,02,,-9.55,-36.183333
br,ouricuri,Ouricuri,05,,-10.605556,-45.835833
br,ouricuri,Ouricuri,22,,-5.930833,-37.234722
br,ouricuri,Ouricuri,30,29318,-7.883333,-40.083333
br,ouricurituba,Ouricurituba,05,,-12.3,-38.75
br,ouricury,Ouricury,30,,-7.883333,-40.083333
br,ourinhos,Ourinhos,27,97801,-22.983333,-49.866667
br,ourives,Ourives,05,,-14.1,-41.283333
br,ourizona,Ourizona,18,,-23.383333,-52.183333
br,ouro branco de santana do ipanema,Ouro Branco de Santana do Ipanema,02,,-9.166667,-37.35
br,ouro branco,Ouro Branco,02,,-9.166667,-37.35
br,ouro branco,Ouro Branco,05,,-10.333333,-41.833333
br,ouro branco,Ouro Branco,15,26687,-20.533333,-43.7
br,ouro branco,Ouro Branco,22,,-6.7,-36.95
br,ouro branco,Ouro Branco,23,,-29.466667,-51.8
br,ouro fala,Ouro Fala,15,,-21.95,-45.666667
br,ourofina,Ourofina,23,,-28.983333,-52.816667
br,ouro fino,Ouro Fino,15,,-16.533333,-42.116667
br,ouro-fino,Ouro-Fino,18,,-24.966667,-49.1
br,ouro fino,Ouro Fino,21,,-21.033333,-41.9
br,ouro fino,Ouro Fino,23,21076,-28.983333,-52.816667
br,ouro fino,Ouro Fino,27,,-23.2829,-46.245112
br,ouro fino,Ouro Fino,29,,-15.966667,-50.05
br,ouro grosso,Ouro Grosso,27,,-24.550067,-48.220736
br,ouro leve,Ouro Leve,27,,-24.583723,-48.307568
br,ouro,Ouro,06,,-5.5,-39.633333
br,ouro,Ouro,13,,-8.163056,-46.235
br,ouro,Ouro,20,,-9.5,-45.516667
br,ouro,Ouro,26,,-27.35,-51.683333
br,ouro,Ouro,30,,-7.516667,-39.783333
br,ouro preto d'oeste,Ouro Preto d'Oeste,24,,-10.666667,-62.3
br,ouro preto do oeste,Ouro Prêto do Oeste,24,26686,-10.666667,-62.3
br,ouro preto,Ouro Prêto,13,,-4.933333,-44.366667
br,ouro preto,Ouro Prêto,14,,-15.15,-55.583333
br,ouro preto,Ouro Prêto,15,63679,-20.383333,-43.5
br,ouro preto,Ouro Prêto,16,,-4.816667,-54.25
br,ouro preto,Ouro Prêto,22,,-5.716667,-35.966667
br,ouro velho,Ouro Velho,15,,-18.083333,-41.216667
br,ouro velho,Ouro Velho,17,,-7.616667,-37.166667
br,ouro verde de minas,Ouro Verde de Minas,15,,-18.083333,-41.216667
br,ouro verde,Ouro Verde,11,,-21.9,-54.35
br,ouro verde,Ouro Verde,14,,-14.5,-57.95
br,ouro verde,Ouro Verde,18,,-23.483422,-49.975471
br,ouro verde,Ouro Verde,26,,-26.166667,-50.4
br,ouro verde,Ouro Verde,27,,-21.483333,-51.7
br,ourupu,Ourupú,23,,-28.733333,-53.616667
br,outeira,Outeira,13,,-2.016667,-44.516667
br,outeiro alegre,Outeiro Alegre,05,,-13.9,-39.1
br,outeiro mata-fome,Outeiro Mata-Fome,05,,-13.083333,-38.95
br,outeiro,Outeiro,05,,-13.083333,-38.95
br,outeiro,Outeiro,06,,-4.633333,-37.783333
br,outeiro,Outeiro,13,,-2.016667,-44.516667
br,outeiro,Outeiro,16,,-1.266667,-48.466667
br,outeiro redondo,Outeiro Redondo,05,,-12.7,-39.016667
br,outeiro redondo,Outeiro Redondo,15,,-15.366667,-41.933333
br,ouvidor,Ouvidor,29,,-18.233333,-47.833333
br,ovelhas,Ovelhas,18,,-26.16261,-49.583348
br,ovidio,Ovídio,15,,-16.55,-40.166667
br,ovo choco,Ovo Chôco,05,,-11.45,-42.8
br,ovo de ema,Ôvo de Ema,11,,-21.85,-57.8
br,oxford,Oxford,26,,-26.233333,-49.4
br,pablo fernandes,Pablo Fernandes,23,,-30.283333,-57.533333
br,pacaembu,Pacaembu,27,10101,-21.566667,-51.283333
br,pacajus,Pacajus,06,41558,-4.166667,-38.466667
br,pacaparra,Pacaparra,21,,-22.366667,-41.85
br,pacas,Pacas,03,,.4,-51.733333
br,pacas,Pacas,13,,-2.583333,-45.116667
br,pacas,Pacas,18,,-24.943363,-48.855858
br,pacas,Pacas,23,,-28.5,-53.033333
br,pacataga,Pacataga,22,,-5.95,-35.3
br,pacatiba,Pacatiba,28,,-10.433333,-36.65
br,pacatuba,Pacatuba,04,,-2.308333,-61.078333
br,pacatuba,Pacatuba,06,55292,-3.966667,-38.616667
br,pacatuba,Pacatuba,17,,-7.05,-35.166667
br,pacatuba,Pacatuba,28,2616,-10.433333,-36.65
br,pacatu,Pacatu,05,,-11.95,-38.966667
br,pacencia,Pacencia,23,,-29.966667,-51.633333
br,pachecao,Pachecão,13,,-3.543611,-43.215556
br,pacheca,Pacheca,23,,-31.133333,-51.8
br,pacheco,Pacheco,13,,-3.116667,-45.283333
br,pacheco,Pacheco,14,,-14.466667,-54.583333
br,pacheco,Pacheco,15,,-20.466667,-45.25
br,pacheco,Pacheco,21,,-22.833333,-42.966667
br,pacheco,Pacheco,22,,-5.3225,-36.823889
br,pacheco,Pacheco,25,,.497222,-61.658611
br,pacheco,Pacheco,30,,-9.066667,-36.65
br,pachecos,Pachecos,21,,-22.8,-42.833333
br,pachequinho,Pachequinho,13,,-3.529444,-43.225556
br,pacia,Paciá,04,,-7.15,-64.65
br,paciencia do macabu,Paciência do Macabú,21,,-22.083333,-41.733333
br,paciencia,Paciência,06,,-5.666667,-39.666667
br,paciencia,Paciência,14,,-15.016667,-56.666667
br,paciencia,Paciência,21,,-22.066667,-41.75
br,paciencia,Paciência,26,,-26.083333,-50.65
br,paciencia,Paciência,31,,-8.133333,-48.166667
br,pacira,Pacira,30,,-7.95,-35.633333
br,pacoca,Paçoca,14,,-16.566667,-56.266667
br,paco dantas,Paço Dantas,20,,-6.3,-41.833333
br,paco gordo,Paço Gordo,21,,-21.816667,-41.233333
br,paco imperial,Paço Imperial,06,,-2.983333,-41.133333
br,paco,Paço,14,,-15.066667,-56.5
br,paco-paco,Paco-Paco,20,,-3.664167,-42.045556
br,pacoti,Pacoti,06,,-4.216667,-38.933333
br,pacoti,Pacoti,13,,-3.698889,-42.838889
br,pacotuba,Pacotuba,08,,-20.766667,-41.283333
br,paco tucano,Paço Tucano,04,,.183333,-69.333333
br,pacoty,Pacoty,06,,-4.216667,-38.933333
br,pacovais,Pacovais,04,,-3.083333,-68.133333
br,pacovalinho,Pacovalinho,04,,-5.64,-64.316944
br,pacoval,Pacoval,16,,-1.766667,-55
br,pacovalzinho,Pacovalzinho,04,,-5.64,-64.316944
br,pacova,Pacova,13,,-3.218611,-43.068611
br,pacuhy,Pacuhy,05,,-10.1,-40.816667
br,pacui,Pacuí,05,,-10.1,-40.816667
br,pacuja,Pacuja,01,,-8.383333,-71
br,pacuja,Pacujá,06,,-3.983333,-40.683333
br,pacu,Pacu,15,,-15.233333,-43.683333
br,pacu,Pacu,29,,-16.133333,-52.45
br,pacuri,Pacuri,11,,-22.616667,-55.583333
br,padeiros,Padeiros,27,,-23.1515,-47.8484
br,paderinha,Paderinha,16,,-2.533333,-54.283333
br,padilha,Padilha,23,,-29.333333,-53.45
br,padre andre,Padre André,27,,-24.632873,-48.055217
br,padre bernardo,Padre Bernardo,29,16118,-15.35,-48.5
br,padre brito,Padre Brito,15,,-21.3,-43.983333
br,padre cicero,Padre Cícero,06,,-7.15,-39.316667
br,padre cosme,Padre Cosme,22,,-6.316667,-38.483333
br,padre eterno,Padre Eterno,23,,-29.5,-50.95
br,padre fialho,Padre Fialho,15,,-20.366667,-42.383333
br,padre goncalves,Padre Gonçalves,23,,-27.416667,-53.95
br,padre gonzales,Padre Gonzales,23,,-27.416667,-53.95
br,padre joao afonso,Padre João Afonso,15,,-17.95,-42.65
br,padre limhares,Padre Limhares,06,,-3.433333,-40.5
br,padre linhares,Padre Linhares,06,,-3.433333,-40.5
br,padre marcos,Padre Marcos,20,,-7.35,-40.9
br,padre miguelinho,Padre Miguelinho,22,,-6.3,-35.45
br,padre miguel,Padre Miguel,21,,-22.880237,-43.445359
br,padre nobrega,Padre Nóbrega,27,,-22.15,-50.016667
br,padre,Padre,05,,-12.05,-38
br,padre,Padre,16,,-6.316667,-48.433333
br,padre paraiso,Padre Paraíso,15,10608,-17.1,-41.516667
br,padre pinto,Padre Pinto,15,,-20,-43.116667
br,padres,Padres,25,,-2.766667,-60.7
br,padre viegas,Padre Viegas,15,,-20.466667,-43.333333
br,padre vieira,Padre Vieira,06,,-3.566667,-41.333333
br,padronal,Padronal,14,,-13.179167,-59.875
br,padua,Pádua,04,,-7.333056,-62.924444
br,padua sales,Pádua Sales,27,,-22.3,-47.133333
br,paes landim,Paes Landim,20,,-7.8,-42.266667
br,paes leme,Paes Leme,21,,-22.575278,-43.601667
br,paga bem,Paga Bem,15,,-19.333333,-41.716667
br,paga-conta,Paga-Conta,16,,-4.933333,-54.566667
br,paga vista,Paga Vista,14,,-17.316667,-57.3
br,pagem,Pagem,05,,-14.016667,-42.733333
br,page,Pagé,25,,4.466667,-60.933333
br,pageu,Pageú,05,,-14.016667,-42.733333
br,pageu,Pageú,30,,-8.183333,-38.55
br,pagode,Pagode,15,,-16.266667,-41.1
br,paiaguas,Paiaguás,11,,-18.383333,-57.166667
br,paiaia,Paiaiá,05,,-11.316667,-38.433333
br,pai amaro,Pai Amaro,20,,-7.066667,-41.616667
br,paiano,Paiano,06,,-5.6,-38.35
br,paiano,Paiano,15,,-20.2134,-43.9928
br,pai antonio,Pai Antônio,22,,-5.284722,-37.244722
br,pai bento,Pai Bento,15,,-19.416667,-44.033333
br,paicandu,Paiçandu,04,,-5.715278,-61.283611
br,paicandu,Paiçandu,16,,-4.523889,-52.665
br,paicandu,Paiçandu,18,34365,-23.45,-52.033333
br,pai chicou,Pai Chicou,20,,-6.533333,-42.166667
br,pai coelho,Pai Coelho,15,,-20.0314,-43.8903
br,pai diogo,Pai Diogo,05,,-12.416667,-39.25
br,pai goncalves,Pai Goncalves,06,,-4.516667,-40.4
br,pai joao,Pai João,13,,-3.782778,-43.366111
br,pai joaquim,Pai Joaquim,22,,-5.25,-37.116667
br,pai jose,Pai José,30,,-8.45,-38.833333
br,pai manoel,Pai Manoel,05,,-13.7,-40.6
br,pai manuel,Pai Manuel,05,,-13.7,-40.6
br,paim filho,Paim Filho,23,,-27.683333,-51.783333
br,paind do araguaia,Paind do Araguaia,31,,-11.440278,-50.314167
br,paineiras,Paineiras,08,,-20.966667,-40.95
br,paineiras,Paineiras,15,,-18.9,-45.516667
br,paineiras,Paineiras,21,,-22.948739,-43.21798
br,paineiras,Paineiras,27,,-20.483333,-47.666667
br,paineirinha,Paineirinha,18,,-23.6593,-49.8982
br,painel,Painel,26,,-27.916667,-50.1
br,pains,Pains,15,,-20.366667,-45.666667
br,paiois,Paióis,18,,-25.915112,-50.002101
br,paiol da vargem,Paiol da Vargem,15,,-22.683333,-46.433333
br,paiol de baixo,Paiol de Baixo,18,,-25.216616,-48.905097
br,paiol grande,Paiol Grande,23,,-27.633333,-52.283333
br,paiol grande,Paiol Grande,27,,-22.6615,-45.6628
br,paiolinho,Paiolinho,15,,-21.866667,-45.9
br,paiol,Paiol,05,,-12.716667,-41.833333
br,paiol,Paiol,11,,-18.983333,-57.2
br,paiol,Paiol,13,,-3.733333,-45.05
br,paiol,Paiol,14,,-16.333333,-57.416667
br,paiol,Paiol,18,,-25.71148,-49.885677
br,paiol velho,Paiol Velho,18,,-25.207847,-48.888917
br,paiol velho,Paiol Velho,27,,-22.7462,-45.6766
br,paiolzinho,Paiolzinho,15,,-22.592045,-45.60799
br,paio,Paio,27,,-23.4145,-46.0077
br,pai paulo,Pai Paulo,06,,-6.466667,-40.35
br,pai paulo,Pai Paulo,17,,-7.15,-36.216667
br,pai paulo,Pai Paulo,18,,-25.9429,-48.8
br,pai pedro,Pai Pedro,14,,-16.716667,-56.733333
br,pai pedro,Pai Pedro,17,,-6.6,-37.85
br,pai pedro,Pai Pedro,20,,-6.483333,-41.833333
br,paiquere de baixo,Paiquerê de Baixo,18,,-25.676825,-50.084312
br,paiquere de cima,Paiquerê de Cima,18,,-25.673783,-50.074351
br,paiquere,Paiquerê,18,,-23.533333,-51.066667
br,paisandu,Paisandú,16,,-4.549167,-52.677778
br,pais leme,Pais Leme,21,,-22.575278,-43.601667
br,pais,Pais,30,,-8.483333,-36.033333
br,paissandu,Paissandu,16,,-4.549167,-52.677778
br,paissandu,Paissandu,18,,-23.45,-52.033333
br,paiva,Paiva,15,,-21.3,-43.416667
br,paixao,Paixão,15,,-16.316667,-40.633333
br,pajau,Pajau,04,,-7.25,-72.233333
br,pajehu,Pajehú,05,,-14.016667,-42.733333
br,pajehu,Pajehú,06,,-4.983333,-40.266667
br,pajeu do vento,Pajeú do Vento,05,,-14.016667,-42.733333
br,pajeu,Pajeú,05,,-10.616667,-44.05
br,pajeu,Pajeú,06,,-4.983333,-40.266667
br,pajeu,Pajeú,13,,-3.242778,-42.036667
br,pajeu,Pajeu,17,,-7.266667,-38.516667
br,pajeu,Pajeú,20,,-5.3,-41.883333
br,pajeu,Pajeu,22,,-5.223611,-37.461944
br,pajeu,Pajeú,30,,-8.183333,-38.55
br,pajeuzinho,Pajeúzinho,05,,-12.716667,-42.65
br,pajou,Pajou,04,,-7.25,-72.233333
br,pajucara,Pajuçara,06,,-3.85,-38.6
br,pajucara,Pajuçara,22,,-5.733333,-35.216667
br,palacete,Palacete,21,,-21.75,-41.166667
br,palacio,Palacio,30,,-7.8,-39.75
br,palame,Palame,05,,-12.1,-37.716667
br,palanque,Palanque,27,,-23.466431,-47.85644
br,palapouta,Palapouta,25,,4.4,-60.116667
br,paleomano,Paleomanó,16,,1.383333,-54.733333
br,palermo,Palermo,04,,-6.5,-69.016667
br,palermo,Palermo,26,,-28.416667,-49.433333
br,palestina,Palestina,02,,-9.7,-37.35
br,palestina,Palestina,04,,-4.533333,-69.166667
br,palestina,Palestina,05,,-10.8,-43.866667
br,palestina,Palestina,06,,-3.583333,-40.45
br,palestina,Palestina,13,,-3.689722,-42.993889
br,palestina,Palestina,15,,-15.9,-40.183333
br,palestina,Palestina,17,,-7.083333,-36.266667
br,palestina,Palestina,20,,-6.65,-41.75
br,palestina,Palestina,21,,-21.066667,-41.866667
br,palestina,Palestina,22,,-5.656111,-37.206111
br,palestina,Palestina,27,,-20.383333,-49.416667
br,palhal,Palhal,04,,-5.235,-60.368333
br,palhal,Palhal,16,,-4.616667,-56.233333
br,palhano,Palhano,06,,-4.733333,-37.95
br,palha,Palha,05,,-14.816667,-39.3
br,palha,Palha,23,,-29.8281,-50.8579
br,palheiro,Palheiro,22,,-5.5175,-37.090278
br,palheta,Palheta,16,,-1.833333,-47.766667
br,palhoca,Palhoça,26,122425,-27.633333,-48.666667
br,palhocinha,Palhocinha,26,,-28.05,-48.666667
br,palmacia,Palmácia,06,,-4.133333,-38.833333
br,palma,Palma,02,,-9.65,-37.35
br,palma,Palma,05,,-12.95,-40.483333
br,palma,Palma,06,,-3.55,-40.65
br,palma,Palma,15,,-21.366667,-42.316667
br,palma,Palma,22,,-6.65,-37.033333
br,palma,Palma,23,,-29.466667,-53.466667
br,palma,Palma,27,,-22.083333,-50.516667
br,palma,Palma,31,,-12.640556,-47.7925
br,palmares do sul,Palmares do Sul,23,8393,-30.266667,-50.516667
br,palmares,Palmares,01,,-10.416667,-67.733333
br,palmares,Palmares,05,,-12.816667,-41.7
br,palmares,Palmares,11,,-23.566667,-55.116667
br,palmares,Palmares,15,,-16.333333,-40.766667
br,palmares,Palmares,21,,-22.867298,-43.647564
br,palmares,Palmares,23,,-30.266667,-50.516667
br,palmares,Palmares,26,,-27.333333,-50.9
br,palmares,Palmares,27,,-21.1,-48.783333
br,palmares,Palmares,28,,-10.916667,-37.933333
br,palmares,Palmares,30,41680,-8.683333,-35.6
br,palmares paulista,Palmares Paulista,27,,-21.1,-48.783333
br,palmas de monte alto,Palmas de Monte Alto,05,7091,-14.266667,-43.166667
br,palmas,Palmas,18,39150,-26.5,-52
br,palmas,Palmas,23,,-31.05,-53.583333
br,palmas,Palmas,31,196332,-10.222778,-48.277778
br,palmatoria,Palmatória,06,,-4.666667,-39.066667
br,palmeira alta,Palmeira Alta,02,,-10.1,-36.416667
br,palmeira das missoes,Palmeira das Missões,23,30954,-27.916667,-53.283333
br,palmeira de baixo,Palmeira de Baixo,05,,-13.833333,-41.1
br,palmeira de goias,Palmeira de Goiás,29,,-16.816667,-49.916667
br,palmeira d' oeste,Palmeira d' Oeste,27,,-20.383333,-50.783333
br,palmeira do mendes,Palmeira do Mendes,05,,-12.4,-42.016667
br,palmeira do meneses,Palmeira do Meneses,05,,-12.35,-41.9
br,palmeira do menezes,Palmeira do Menezes,05,,-12.35,-41.9
br,palmeira do norte,Palmeira do Norte,13,,-4.4,-43.516667
br,palmeira do oeste,Palmeira do Oeste,27,,-20.383333,-50.783333
br,palmeira dos indios,Palmeira dos Índios,02,,-9.416667,-36.616667
br,palmeira dos indos,Palmeira Dos Indos,02,,-9.416667,-36.616667
br,palmeirais,Palmeirais,20,4262,-5.966667,-43.066667
br,palmeiral,Palmeiral,15,,-21.633333,-46.516667
br,palmeirante,Palmeirante,31,,-7.802222,-47.798611
br,palmeira,Palmeira,05,,-11.416667,-40.766667
br,palmeira,Palmeira,06,,-3.733333,-40.083333
br,palmeira,Palmeira,08,,-19.683333,-40.833333
br,palmeira,Palmeira,11,,-18.966667,-57.066667
br,palmeira,Palmeira,13,,-3.041667,-42.851667
br,palmeira,Palmeira,14,,-15.95,-55.55
br,palmeira,Palmeira,15,,-15.366667,-44.683333
br,palmeira,Palmeira,17,,-7.366667,-37.616667
br,palmeira,Palmeira,18,18630,-25.426111,-50.003333
br,palmeira,Palmeira,20,,-3.583333,-41.716667
br,palmeira,Palmeira,23,,-27.916667,-53.283333
br,palmeira,Palmeira,26,,-27.583333,-50.15
br,palmeira,Palmeira,27,,-23.370909,-46.620357
br,palmeira,Palmeira,30,,-8.933333,-36.283333
br,palmeiras da serra,Palmeiras da Serra,21,,-22.574444,-43.678056
br,palmeiras de goias,Palmeiras de Goiás,29,13573,-16.816667,-49.916667
br,palmeiras juntas,Palmeiras Juntas,13,,-3.649722,-42.839722
br,palmeiras,Palmeiras,05,,-11.15,-42.05
br,palmeiras,Palmeiras,06,,-4.133333,-38.833333
br,palmeiras,Palmeiras,08,,-19.816667,-40.416667
br,palmeiras,Palmeiras,11,,-18.966667,-57.066667
br,palmeiras,Palmeiras,13,,-2.566667,-44.866667
br,palmeiras,Palmeiras,14,,-15.65,-57.25
br,palmeiras,Palmeiras,15,,-18.866667,-46.016667
br,palmeiras,Palmeiras,20,,-8.85,-43.916667
br,palmeiras,Palmeiras,21,,-22.05,-41.483333
br,palmeiras,Palmeiras,22,,-6.133333,-37.6
br,palmeiras,Palmeiras,26,,-28.4,-49.216667
br,palmeiras,Palmeiras,27,,-20.516667,-47.8
br,palmeiras,Palmeiras,29,,-16.816667,-49.916667
br,palmeiras,Palmeiras,30,,-8.933333,-36.283333
br,palmeira torta,Palmeira Torta,13,,-4.616667,-45.383333
br,palmeirina,Palmeirina,30,,-8.933333,-36.283333
br,palmeirinha ii,Palmeirinha II,13,,-3.09,-42.063056
br,palmeirinha i,Palmeirinha I,13,,-3.096667,-42.3175
br,palmeirinha,Palmeirinha,02,,-9.716667,-36.216667
br,palmeirinha,Palmeirinha,05,,-11.583333,-40.466667
br,palmeirinha,Palmeirinha,06,,-3.75,-41.133333
br,palmeirinha,Palmeirinha,11,,-18.85,-57.066667
br,palmeirinha,Palmeirinha,13,,-3.063333,-42.8975
br,palmeirinha,Palmeirinha,18,,-23.453403,-52.620297
br,palmeirinha,Palmeirinha,20,,-3.583333,-41.716667
br,palmeiropolis,Palmeirópolis,31,,-13.062222,-48.366944
br,palmelas,Palmelas,24,,-12.85,-62.9
br,palmelo,Palmelo,29,,-17.333333,-48.45
br,palminopolis,Palminópolis,29,,-16.783333,-50.133333
br,palmira,Palmira,05,,-15.2,-39.6
br,palmira,Palmira,06,,-5.2,-39.65
br,palmira,Palmira,13,,-3.083333,-43.05
br,palmira,Palmira,18,,-25.67777,-50.154806
br,palmital de baixo,Palmital de Baixo,18,,-25.755772,-50.130261
br,palmital de cima,Palmital de Cima,18,,-25.799908,-50.105088
br,palmital grande,Palmital Grande,14,,-14.85,-57.033333
br,palmital,Palmital,05,,-13.466667,-41.766667
br,palmital,Palmital,08,,-20.933333,-40.916667
br,palmital,Palmital,15,,-16.116667,-47.316667
br,palmital,Palmital,18,,-23.2545,-50.0741
br,palmital,Palmital,21,,-22.9,-42.466667
br,palmital,Palmital,23,,-29.666667,-52.933333
br,palmital,Palmital,26,,-26.016667,-48.85
br,palmital,Palmital,27,18540,-22.783333,-50.2
br,palmitalzinho,Palmitalzinho,18,,-25.216667,-49.783333
br,palmitinho,Palmitinho,23,,-27.333333,-53.566667
br,palmitinhos,Palmitinhos,23,,-27.333333,-53.566667
br,palmitos,Palmitos,23,,-27.333333,-53.566667
br,palmitos,Palmitos,26,,-27.083333,-53.133333
br,palmitos,Palmitos,27,,-20.683333,-47.9
br,palmopolis,Palmópolis,15,,-16.75,-40.416667
br,palmorindo,Palmorindo,08,,-21.066667,-41.116667
br,palmyra,Palmyra,15,,-21.466667,-43.566667
br,palmyra,Palmyra,18,,-25.67777,-50.154806
br,palomas,Palomas,23,,-30.816667,-55.383333
br,palotina,Palotina,18,23059,-24.283333,-53.833333
br,pama,Pamá,04,,1.783333,-67.333333
br,pambu,Pambu,05,,-8.566667,-39.35
br,pameranos,Pameranos,26,,-26.683333,-49.25
br,pamonha,Pamonha,30,,-7.616667,-39.816667
br,pampa,Pampa,11,,-21.8,-54.716667
br,pampa,Pampã,15,,-16.9,-40.933333
br,pampeiro,Pampeiro,04,,-7.133333,-69.616667
br,pampeiro,Pampeiro,23,,-30.633333,-55.266667
br,pampulha,Pampulha,15,,-19.9,-43.933333
br,panacuhy,Panacuhy,06,,-3.216667,-40.4
br,panacui,Panacuí,06,,-3.216667,-40.4
br,panama,Panamá,15,,-16.216667,-41.316667
br,panama,Panamá,29,,-18.183333,-49.35
br,panambi,Panambi,11,,-21.95,-54.733333
br,panambi,Panambi,23,30408,-28.3,-53.5
br,pana pana,Panã Panã,04,,-6.844167,-70.672222
br,panaripe,Panaripé,04,,-7.916667,-67.133333
br,panasco,Panasco,05,,-9.866667,-38.05
br,panasco,Panasco,06,,-7.4,-38.8
br,panati,Panati,22,,-6.366667,-38.2
br,panatis,Panatis,22,,-6.3,-38.166667
br,pancas,Pancas,08,8184,-19.233333,-40.85
br,pancudo,Pançudo,03,,-.183333,-51.8
br,panela de ferro,Panela de Ferro,31,,-8.4,-48.1
br,panela do amaro,Panela do Amaro,22,,-5.255,-37.410556
br,panela,Panela,13,,-3.492778,-42.86
br,panela,Panela,17,,-7.716667,-36.1
br,panela queimada,Panela Queimada,05,,-9.916667,-38.9
br,panelas de brejauva,Panelas de Bréjauva,18,,-24.679336,-48.919977
br,panelas,Panelas,02,,-9.466667,-37.716667
br,panelas,Panelas,05,,-10.216667,-40.6
br,panelas,Panelas,06,,-6.05,-39.383333
br,panelas,Panelas,17,,-6.85,-38.216667
br,panelas,Panelas,22,,-5.966667,-35.533333
br,panelas,Panelas,30,12625,-8.666667,-36.016667
br,panellas,Panellas,22,,-5.966667,-35.533333
br,panellas,Panellas,30,,-8.666667,-36.016667
br,panema,Panema,18,,-22.95,-50.583333
br,panfilo sampaio,Panfilo Sampaio,05,,-13.7,-40.05
br,panfilo sanpaio,Panfilo Sanpaio,05,,-13.7,-40.05
br,pangare,Pangaré,18,,-25.9187,-49.4822
br,pangare velho,Pangaré Velho,18,,-25.927,-49.4621
br,panon,Panon,22,,-5.43,-36.888611
br,panorama,Panorama,27,14227,-21.35,-51.85
br,panta alegre,Panta Alegre,04,,-5.348889,-62.816944
br,pantanal,Pantanal,14,,-16.35,-56.666667
br,pantanal,Pantanal,18,,-25.5153,-48.8617
br,pantanalzinho,Pantanalzinho,14,,-14.233333,-55.633333
br,pantano do sul,Pântano do Sul,26,,-27.780556,-48.507778
br,pantano grande,Pântano Grande,23,,-30.183333,-52.366667
br,pantano,Pântano,15,,-18.55,-46.833333
br,pantano,Pântano,18,,-25.737222,-50.583611
br,pantano,Pântano,27,,-22.366667,-47.25
br,pantano preto,Pântano Préto,18,,-25.737467,-50.553381
br,pantanozinho,Pantanozinho,15,,-22.5639,-45.6223
br,pantojo,Pantojo,27,,-21.766667,-46.9
br,pao a pique,Páo a Pique,05,,-9.65,-41.6
br,pao branco,Pão Branco,30,,-8.016667,-37.333333
br,pao de acucar,Pão de Açúcar,02,11497,-9.75,-37.433333
br,pao de acucar,Pão de Açucar,30,,-7.95,-36.133333
br,pao de assucar,Páo de Assucar,02,,-9.75,-37.433333
br,pao de ouro,Pão de Ouro,13,,-4.916667,-44.383333
br,pao de ouro,Pão de Ouro,16,,-3.683333,-47.05
br,pao dos ferros,Pão dos Ferros,22,,-6.116667,-38.166667
br,pao duro,Pão Duro,13,,-4.916667,-44.383333
br,pao ferro,Páo Ferro,30,,-8.85,-36.116667
br,pao gigante,Páo Gigante,08,,-19.833333,-40.366667
br,pao,Paó,05,,-13.766667,-39.533333
br,papacaio,Papaçaio,24,,-8.166667,-63.083333
br,papa do meio,Papa do Meio,06,,-6.45,-38.916667
br,papagaio,Papagaio,04,,-7.405278,-71.058333
br,papagaio,Papagaio,05,,-12.033333,-39.716667
br,papagaio,Papagaio,06,,-6.416667,-40.633333
br,papagaio,Papagaio,11,,-20.633333,-54.083333
br,papagaio,Papagaio,13,,-6.016667,-45.35
br,papagaio,Papagaio,16,,-5.533333,-49.1
br,papagaio,Papagaio,20,,-10.033333,-45.2
br,papagaio,Papagaio,21,,-23.333333,-44.716667
br,papagaio,Papagaio,22,,-5.778611,-36.616111
br,papagaio,Papagaio,24,,-8.166667,-63.083333
br,papagaio,Papagaio,25,,3.366667,-60.283333
br,papagaio,Papagaio,30,,-8.55,-36.65
br,papagaios novos,Papagaios Novos,18,,-25.383333,-50.133333
br,papagaios,Papagaios,06,,-6.416667,-40.633333
br,papagaios,Papagaios,15,11850,-19.533333,-44.75
br,papagaios,Papagaios,18,,-25.383333,-50.133333
br,papagaios,Papagaios,24,,-8.166667,-63.083333
br,papageios,Papageios,24,,-8.166667,-63.083333
br,papamel,Papamel,30,,-7.7,-39.216667
br,papa milho,Papa Milho,15,,-20.0591,-43.8516
br,papanduba,Papanduba,26,,-26.416667,-50.15
br,papanduva,Papanduva,18,,-25.243122,-48.988938
br,papanduva,Papanduva,26,,-26.416667,-50.15
br,papaokena,Papaokena,21,,-21.5,-42.25
br,papari,Papari,22,,-6.066667,-35.133333
br,papary,Papary,22,,-6.066667,-35.133333
br,papemal,Papemal,28,,-11.366667,-37.65
br,papera,Papera,04,,-.416667,-64.6
br,papo da ema,Papo da Ema,20,,-3.6525,-42.105556
br,papoula,Papoula,13,,-3.916667,-44.2
br,papuam,Papuam,26,,-26.983333,-51.4
br,papuan,Papuan,26,,-26.983333,-51.4
br,papua,Papuã,18,,-23.883333,-51.283333
br,papua,Papuã,26,,-26.983333,-51.4
br,papua,Papuã,29,,-14.683333,-49.45
br,papucu,Papuçu,05,,-12.516667,-38.55
br,papuda,Papuda,07,,-15.9,-47.766667
br,papulina sol,Papulina Sol,27,,-19.966667,-50.533333
br,papunhas,Papunhas,04,,-7.316667,-62.933333
br,papuri,Papuri,04,,-7.483333,-65.366667
br,paquara,Paquara,21,,-22.919444,-43.374444
br,paquequer,Paquequer,21,,-21.866667,-42.633333
br,paquequer pequeno,Paquequer Pequeno,21,,-22.311011,-42.979279
br,paqueta,Paquetá,04,,-5.221111,-60.365
br,paqueta,Paquetá,05,,-12.266667,-40.616667
br,paqueta,Paquetá,20,,-7.066667,-41.616667
br,paquevira,Paquevira,02,,-9.366667,-36.466667
br,paquevira,Paquevira,30,,-8.933333,-36.1
br,paquicama,Paquiçama,16,,-3.266667,-51.866667
br,paracambi,Paracambi,21,36099,-22.608611,-43.712778
br,paracambuca,Paracambuca,06,,-3.6,-38.766667
br,paracamby,Paracamby,21,,-22.608611,-43.712778
br,paracampos,Paracampos,21,,-22.433333,-41.933333
br,paracatu,Paracatu,05,,-11.683333,-38.733333
br,paracatu,Paracatu,15,70754,-17.216667,-46.866667
br,paraciba,Paraciba,05,,-12.8,-38.3
br,paracua,Paracuá,06,,-3.366667,-40.766667
br,paracumbuca,Paracumbuca,06,,-3.6,-38.766667
br,paracuru,Paracuru,06,21197,-3.4,-39.066667
br,parada 29,Parada 29,16,,-1.1,-46.516667
br,parada 57,Parada 57,27,,-23.8675,-46.6651
br,parada ceci,Parada Ceci,27,,-24.621308,-48.074788
br,parada cinquenta e sete,Parada Cinquenta e Sete,27,,-23.8675,-46.6651
br,parada cristal,Parada Cristal,23,,-29.0881,-51.1226
br,parada de lucas,Parada de Lucas,21,,-22.817841,-43.295405
br,parada de taipas,Parada de Taipas,27,,-23.419414,-46.714463
br,parada ivai,Parada Ivaí,23,,-29.016667,-53.8
br,parada,Parada,06,,-3.583333,-38.9
br,parada vinte e nove,Parada Vinte e Nove,16,,-1.1,-46.516667
br,para de minas,Pará de Minas,15,75787,-19.85,-44.616667
br,parade,Paradé,06,,-5.5,-39.466667
br,parade,Paradé,20,,-6.933333,-40.616667
br,parado,Parado,21,,-22.833,-44.1921
br,parafuso,Parafuso,13,,-3.570833,-43.200833
br,parafuso,Parafuso,27,,-24.730869,-48.138146
br,paragominas,Paragominas,16,69616,-2.966667,-47.483333
br,paraguacu,Paraguaçu,05,,-12.75,-40.216667
br,paraguacu,Paraguaçu,15,15742,-21.55,-45.733333
br,paraguacu,Paraguaçu,23,,-30.916667,-51.483333
br,paraguacu,Paraguaçu,26,,-26.383333,-49.916667
br,paraguacu,Paraguaçu,27,,-22.416667,-50.566667
br,paraguacu paulista,Paraguaçu Paulista,27,39120,-22.416667,-50.566667
br,paraguaio,Paraguaio,22,,-5.55,-35.633333
br,paraguai,Paraguai,15,,-15.55,-41.65
br,paraguai,Paraguai,17,,-7.916667,-36.966667
br,paragua,Paragua,20,,-6.85,-42.233333
br,paragua,Paraguá,22,,-5.1,-37.716667
br,paraguari,Paraguari,14,,-15.2,-57.266667
br,paraguassu,Paraguassú,05,,-12.75,-40.216667
br,paraguassu,Paraguassú,15,,-21.55,-45.733333
br,paraguassu,Paraguassú,26,,-26.383333,-49.916667
br,paraguassu,Paraguassú,27,,-22.416667,-50.566667
br,parahiba,Parahiba,17,,-7.116667,-34.866667
br,parahu,Parahú,22,,-5.776111,-37.101111
br,parahyba do sul,Parahyba do Sul,21,,-22.1575,-43.290556
br,parahyba,Parahyba,17,,-7.116667,-34.866667
br,parahybuna,Parahybuna,27,,-23.383333,-45.65
br,paraiba do sul,Paraíba do Sul,21,35518,-22.1575,-43.290556
br,paraibano,Paraibano,13,12364,-6.5,-44.016667
br,paraibao,Paraibão,24,,-11.4,-61.766667
br,paraiba,Paraíba,02,,-9.416667,-36.066667
br,paraiba,Paraíba,04,,-2.7,-65.716667
br,paraiba,Paraíba,17,,-7.116667,-34.866667
br,paraiba,Paraíba,30,,-9.083333,-36.65
br,paraibuna,Paraibuna,27,,-23.383333,-45.65
br,paraim,Paraim,20,,-10.583333,-44.933333
br,paraim,Paraim,21,,-22.2,-42.4
br,paraipaba,Paraipaba,06,18424,-3.433333,-39.116667
br,parai,Paraí,23,,-28.6,-51.783333
br,parai,Paraí,27,,-23.2,-45.583333
br,paraisinho,Paraísinho,21,,-21.416667,-41.833333
br,paraiso da cantareira,Paraíso da Cantareira,27,,-23.358856,-46.561337
br,paraiso da fonseca,Paraíso da Fonseca,22,,-5.316667,-35.45
br,paraiso do leste,Paraíso do Leste,14,,-16.1,-54.2
br,paraiso do norte,Paraíso do Norte,18,,-23.216667,-52.633333
br,paraiso do sul,Paraíso do Sul,23,,-29.666667,-53.183333
br,paraiso do tobias,Paraíso do Tobias,21,,-21.433333,-42.1
br,paraiso do tocantins,Paraíso do Tocantins,31,,-10.181389,-48.795
br,paraiso garcia,Paraíso Garcia,15,,-21.533333,-43.883333
br,paraisolandia,Paraisolândia,27,,-22.533333,-47.716667
br,paraiso,Paraíso,01,,-10.233333,-67.866667
br,paraiso,Paraíso,04,,-1.366667,-61.85
br,paraiso,Paraíso,05,,-12.216667,-40.75
br,paraiso,Paraíso,06,,-4.5,-40.166667
br,paraiso,Paraíso,08,,-21.083333,-41.283333
br,paraiso,Paraíso,11,,-19.05,-52.983333
br,paraiso,Paraíso,13,,-3.300833,-42.400278
br,paraiso,Paraíso,14,,-17.083333,-53.233333
br,paraiso,Paraíso,15,,-16.033333,-41.216667
br,paraiso,Paraíso,16,,-1.333333,-51.45
br,paraiso,Paraiso,17,,-6.6,-38.066667
br,paraiso,Paraíso,18,,-25.766667,-52.75
br,paraiso,Paraiso,20,,-5.333333,-42.816667
br,paraiso,Paraíso,21,,-21.366667,-41.733333
br,paraiso,Paraiso,22,,-5.204722,-36.959722
br,paraiso,Paraíso,23,,-28.65,-52.266667
br,paraiso,Paraíso,25,,-2.516667,-60.05
br,paraiso,Paraíso,26,,-26.6,-53.65
br,paraiso,Paraíso,27,,-21.033333,-48.766667
br,paraiso,Paráiso,30,,-7.466667,-39.85
br,paraisopolis,Paraisópolis,15,13563,-22.55,-45.783333
br,paraitinga,Paraitinga,27,,-22.99661,-45.043959
br,paraizinho,Paraizinho,01,,-8.539722,-72.860278
br,paraizinho,Paraizinho,21,,-21.416667,-41.833333
br,paraizo,Paraizo,04,,-6.816667,-64.583333
br,paraizo,Paraizo,23,,-29.666667,-53.183333
br,paraju,Paraju,08,,-20.316667,-40.8
br,parajuru,Parajuru,06,,-4.366667,-37.866667
br,paralso,Paralso,04,,-1.366667,-61.85
br,paralso,Paralso,21,,-21.366667,-41.733333
br,paramana,Paramana,05,,-12.8,-38.633333
br,paramano,Paramano,05,,-12.8,-38.633333
br,parambu,Parambu,06,14656,-6.216667,-40.716667
br,paramirim,Paramirim,05,7421,-13.433333,-42.25
br,para-mirim,Para-Mirim,13,,-3.984722,-42.959722
br,paramoti,Paramoti,06,,-4.1,-39.25
br,paranabi,Paranabi,27,,-23.9,-45.233333
br,paranacity,Paranacity,18,,-22.9,-52.15
br,parana d' oeste,Parana d' Oeste,18,,-24.116667,-52.883333
br,parana do ramos,Paraná do Ramos,04,,-2.6,-56.65
br,paranagi,Paranagi,18,,-22.866667,-50.866667
br,paranaguacu,Paranaguaçu,18,,-22.95,-53.416667
br,paranagua-mirim,Paranaguá-Mirim,26,,-26.344,-48.7274
br,paranagua,Paranaguá,04,,-3.45,-66.05
br,paranagua,Paranaguá,18,141014,-25.516667,-48.5
br,paranaiba de goias,Paranaíba de Goiás,29,,-18.366667,-47.783333
br,paranaiba,Paranaíba,11,32218,-19.666667,-51.183333
br,paranaiba,Paranaíba,29,,-18.416667,-49.216667
br,paranaidji,Paranaidji,13,,-6.55,-47.45
br,paranai,Paranaí,18,,-24.659641,-48.99079
br,paranai,Paranaí,27,,-21.5,-51.666667
br,paranal,Paranal,27,,-21.5,-51.666667
br,paranapanema,Paranapanema,27,16218,-23.383333,-48.716667
br,parana,Paraná,06,,-4.083333,-40.233333
br,parana,Paraná,08,,-19.166667,-40.883333
br,parana,Parana,17,,-6.3,-38.466667
br,parana,Paraná,25,,3.7,-61.383333
br,parana,Paranã,31,2751,-12.640556,-47.7925
br,paranapara,Paranapara,04,,-5.673056,-60.823889
br,paranapiacaba,Paranapiacaba,27,,-23.783333,-46.316667
br,paranapoema,Paranapoema,18,,-22.65,-52.1
br,paranapolis,Paranápolis,27,,-20.866667,-51.416667
br,paranapua,Paranapuá,27,,-20.1,-50.6
br,paranaril,Paranaril,04,,-.25,-65.883333
br,paranari,Paranari,04,,-.25,-65.883333
br,paranary,Paranary,04,,-.25,-65.883333
br,paranatama,Paranatama,30,,-8.916667,-36.65
br,paranauna,Paranaúna,21,,-22.166667,-42.95
br,paranavai,Paranavaí,18,72849,-23.066667,-52.466667
br,parangaba,Parangaba,06,,-3.75,-38.55
br,paranhos,Paranhos,11,6516,-23.916667,-55.416667
br,paranoa,Paranoá,07,,-15.833333,-47.816667
br,paranvai,Paranvaí,18,,-23.066667,-52.466667
br,paraokena,Paraokena,21,,-21.5,-42.25
br,paraopeba,Paraopeba,15,19151,-19.3,-44.416667
br,paraoquena,Paraoquena,21,,-21.5,-42.25
br,para,Pará,05,,-11.566667,-43.283333
br,para,Pará,06,,-7.016667,-38.733333
br,para,Pará,15,,-19.85,-44.616667
br,para,Pará,16,,-1.45,-48.483333
br,para,Pará,30,,-7.833333,-36.366667
br,parapeuna,Parapeúna,21,,-22.089167,-43.827222
br,parapitinga,Parapitinga,28,,-10.433333,-36.466667
br,parapouca,Parapouca,25,,4.4,-60.116667
br,parapouco,Parapouco,25,,4.616177,-60.110541
br,parapua,Parapuã,27,,-21.766667,-50.75
br,parapui,Parapuí,06,,-3.35,-40.183333
br,parari,Parari,17,,-7.316667,-36.65
br,para sempre,Para Sempre,06,,-4.983333,-40.1
br,parasinho,Parasinho,06,,-3.033333,-40.65
br,parasinho,Parasinho,22,,-5.233333,-35.85
br,paratari,Paratari,01,,-8.716667,-72.833333
br,parateca,Parateca,05,,-13.916667,-43.55
br,paratei,Paratei,27,,-23.233333,-46
br,paratibe,Paratibe,30,,-7.916667,-34.916667
br,paratigi,Paratigi,05,,-12.35,-39.416667
br,paratiji,Paratiji,05,,-12.416667,-39.5
br,parati-mirim,Parati-Mirim,21,,-23.233333,-44.633333
br,paratinga,Paratinga,05,10262,-12.7,-43.166667
br,parati,Parati,04,,-5.545833,-63.208056
br,parati,Parati,21,15118,-23.216667,-44.716667
br,parati,Parati,26,,-26.3692,-48.7221
br,paratipe,Paratipe,30,,-7.916667,-34.916667
br,paratory,Paratory,01,,-8.716667,-72.833333
br,paratubai,Paratubaí,11,,-20.183333,-56.266667
br,paratubal,Paratubal,11,,-19.45,-57.533333
br,paratubal,Paratubal,14,,-16.7,-57.733333
br,paratuba,Paratuba,04,,-2.308333,-61.078333
br,paratudai,Paratudai,14,,-15.616667,-56.65
br,paratudal,Paratudal,11,,-19.45,-57.533333
br,paratudal,Paratudal,14,,-16.7,-57.733333
br,paraty-mirim,Paraty-Mirim,21,,-23.233333,-44.633333
br,paraty,Paraty,04,,-5.545833,-63.208056
br,paraty,Paraty,21,,-23.216667,-44.716667
br,paraty,Paraty,26,,-26.3692,-48.7221
br,parauara,Parauará,04,,-3.066667,-67.883333
br,parauna,Paraúna,15,,-16.366667,-41.5
br,parauna,Paraúna,29,9731,-17.033333,-50.433333
br,parau,Paraú,22,,-5.776111,-37.101111
br,parazinho,Paràzinho,06,,-3.033333,-40.65
br,parazinho,Paràzinho,22,,-5.233333,-35.85
br,parceiro,Parceiro,16,,-7.816667,-54.816667
br,pardinho,Pardinho,27,,-23.1,-48.383333
br,pardiuva,Pardiuva,04,,.183333,-69.45
br,pardo,Pardo,26,,-26.2,-50.316667
br,pardos,Pardos,26,,-26.2,-50.316667
br,pareci novo,Pareci Novo,23,,-29.65,-51.4
br,parecis,Parecis,14,,-14.15,-56.933333
br,parecis,Parecis,24,,-12.183333,-61.6
br,parecy,Parecy,23,,-29.65,-51.4
br,paredao,Paredão,15,,-17.1,-45.433333
br,paredao,Paredão,18,,-25.677888,-50.691816
br,paredes de sapucahy,Paredes de Sapucahy,15,,-21.8,-45.716667
br,paredes do sapucai,Paredes do Sapucaí,15,,-21.8,-45.716667
br,paredes,Paredes,05,,-17.983333,-40
br,parelhas,Parelhas,06,,-5.5,-40.1
br,parelhas,Parelhas,13,,-8.45,-46.333333
br,parelhas,Parelhas,22,16377,-6.683333,-36.65
br,parelheiros,Parelheiros,27,,-23.8258,-46.73
br,parente,Parente,25,,.911667,-61.671667
br,pargue boa uniao,Pargue Boa União,21,,-22.293047,-42.913046
br,pariaso,Paríaso,21,,-22.494069,-42.910378
br,parica,Paricá,04,,-4.217222,-60.671111
br,paricas,Paricás,03,,.166667,-51.133333
br,paricatuba,Paricatuba,04,,-3.116667,-60.433333
br,paricatube,Paricatube,04,,-4.435556,-61.8725
br,pariconia,Paricônia,02,,-9.25,-38.016667
br,pari das pedras,Parí das Pedras,05,,-12.75,-44.783333
br,pari de pedras,Pari de Pedras,05,,-12.75,-44.783333
br,parijos,Parijós,30,,-7.816667,-35.566667
br,parintins,Parintins,04,64429,-2.6,-56.733333
br,pari,Pari,18,,-23.560539,-50.661183
br,pari,Pari,27,,-20.15,-47.616667
br,paripe,Paripe,05,,-12.833333,-38.466667
br,paripi,Paripi,04,,-5.699167,-64.420556
br,paripiranga,Paripiranga,05,6965,-10.683333,-37.866667
br,paripueira,Paripueira,02,,-9.466667,-35.55
br,paripueira,Paripueira,06,,-4.35,-37.933333
br,pariquera-acu,Pariquera-Açu,27,13436,-24.716667,-47.883333
br,pariquera assu,Pariquera Assú,27,,-24.716667,-47.883333
br,pariqueracu,Pariqueraçu,27,,-24.716667,-47.883333
br,pariquera-mirim,Pariquera-Mirim,27,,-24.733333,-47.816667
br,pariri,Pariri,04,,-6.808611,-62.595833
br,pariry,Pariry,04,,-6.808611,-62.595833
br,parisi,Parisi,27,,-20.3,-50.016667
br,parituabe,Parituabe,05,,-13.433333,-39.083333
br,park palace,Park Palace,21,,-23.002127,-43.369308
br,parlandim,Parlandim,31,,-6.666667,-48.1
br,parna do araguaia,Parna do Araguaia,31,,-10.591111,-50.149444
br,parnagua,Parnaguá,20,,-10.216667,-44.633333
br,parnahiba,Parnahiba,20,,-2.909167,-41.774722
br,parnahyba,Parnahyba,20,,-2.909167,-41.774722
br,parnahyba,Parnahyba,27,,-23.45,-46.916667
br,parnaiba,Parnaíba,05,,-12.25,-41.516667
br,parnaiba,Parnaíba,20,138011,-2.909167,-41.774722
br,parnaiba,Parnaíba,27,,-23.45,-46.916667
br,parnaioca,Parnaioca,21,,-23.183333,-44.25
br,parnaiuicava,Parnaiuicava,04,,.35,-69.083333
br,parnamirim,Parnamirim,22,150347,-5.916667,-35.25
br,parnamirim,Parnamirim,30,7928,-8.083333,-39.566667
br,parnarama,Parnarama,13,12202,-5.683333,-43.1
br,parnaso,Parnaso,13,,-4.283333,-43.45
br,parnaso,Parnaso,27,,-21.95,-50.416667
br,parobe,Parobé,23,48560,-29.633333,-50.833333
br,paromano,Paromano,05,,-12.8,-38.633333
br,parongaba,Parongaba,01,,-8.8,-70.6
br,parque acari,Parque Acari,21,,-22.822567,-43.345491
br,parque agrinco,Parque Agrinco,27,,-23.3771,-46.1043
br,parque alegria,Parque Alegria,21,,-22.88433,-43.231997
br,parque alvorada,Parque Alvorada,21,,-22.864321,-43.279329
br,parque anchieta,Parque Anchieta,21,,-22.827098,-43.415219
br,parque auto castro,Parque Auto Castro,21,,-22.885809,-43.526247
br,parque boa esperanca,Parque Boa Esperança,21,,-22.929407,-43.562639
br,parque boa ventura,Parque Boa Ventura,21,,-22.827546,-43.607097
br,parque bom jesus,Parque Bom Jesus,21,,-22.821456,-43.619061
br,parque campo alegre,Parque Campo Alegre,21,,-22.804679,-43.648069
br,parque campo lindo,Parque Campo Lindo,21,,-22.810078,-43.644493
br,parque columbia,Parque Columbia,21,,-22.813595,-43.3408
br,parque curicica,Parque Curicica,21,,-22.941184,-43.380334
br,parque das flores,Parque das Flores,27,,-23.263707,-46.61271
br,parque das gracas,Parque das Graças,27,,-23.7532,-46.6347
br,parque das laranjeiras,Parque das Laranjeiras,04,,-3.064722,-60.013611
br,parque das rosas,Parque das Rosas,21,,-23.002971,-43.349086
br,parque dinamarca,Parque Dinamarca,27,,-23.300977,-46.593429
br,parque do dick,Parque do Dick,21,,-22.803434,-43.321868
br,parque dois irmaos,Parque Dois Irmãos,21,,-22.950531,-43.393495
br,parque do lago,Parque do Lago,27,,-23.316883,-46.560412
br,parque dom bosco,Parque Dom Bosco,21,,-22.814565,-43.642039
br,parque dos coqueiros,Parque dos Coqueiros,21,,-22.782645,-43.569414
br,parque do votorantim,Parque do Votorantim,27,,-23.351624,-46.577638
br,parque duque de caxias,Parque Duque de Caxias,21,,-22.797962,-43.292944
br,parque engenho pequeno,Parque Engenho Pequeno,21,,-22.749297,-43.427334
br,parque esperanca,Parque Esperança,21,,-22.826141,-43.395381
br,parque estoril,Parque Estoril,21,,-22.923147,-43.631135
br,parque estoril,Parque Estoril,27,,-23.7698,-46.5171
br,parque fluminense,Parque Fluminense,21,,-22.735798,-43.334897
br,parque industrial,Parque Industrial,15,,-19.95,-44.016667
br,parque internacional,Parque Internacional,27,,-23.2061,-46.7451
br,parque ipiranga,Parque Ipiranga,21,,-22.794588,-43.571725
br,parque jacimar,Parque Jacimar,21,,-22.79893,-43.648981
br,parque jardim beiramar,Parque Jardim Beiramar,21,,-22.810833,-43.298345
br,parque joaninha,Parque Joaninha,21,,-22.82178,-43.606396
br,parque leopoldina,Parque Leopoldina,21,,-22.884101,-43.454417
br,parque licurgo,Parque Licurgo,21,,-22.866065,-43.330389
br,parque los angeles,Parque Los Angeles,27,,-23.7678,-46.6164
br,parque manaca,Parque Manaca,27,,-23.7866,-46.6372
br,parque marcilio dias,Parque Marcílio Dias,21,,-22.820974,-43.272288
br,parque marone,Parque Maroné,21,,-22.138611,-43.285278
br,parque mercurio,Parque Mercurio,21,,-22.811019,-43.341584
br,parque mundial,Parque Mundial,21,,-22.836428,-43.356803
br,parque nossa senhora de fatima,Parque Nossa Senhora de Fatima,21,,-22.892666,-43.462433
br,parque nubia,Parque Núbia,21,,-22.871489,-43.53675
br,parque olinda,Parque Olinda,21,,-22.818007,-43.610384
br,parque paraiso,Parque Paraíso,21,,-22.824151,-43.600468
br,parque peruche,Parque Peruche,27,,-23.497575,-46.658036
br,parque piaui,Parque Piauí,20,,-5.133333,-42.8
br,parque prados verdes,Parque Prados Verdes,21,,-22.842962,-43.613053
br,parque proletario da penha,Parque Proletario da Penha,21,,-22.846831,-43.283079
br,parque represa billings,Parque Represa Billings,27,,-23.8688,-46.6084
br,parque roquete pinto,Parque Roquete Pinto,21,,-22.843622,-43.247251
br,parque royal,Parque Royal,21,,-22.792965,-43.210134
br,parque santa amelia,Parque Santa Amélia,21,,-22.742673,-43.385497
br,parque sao carlos,Parque São Carlos,21,,-22.815259,-43.598097
br,parque sao francisco,Parque São Francisco,21,,-22.85048,-43.613432
br,parque sao jorge,Parque São Jorge,21,,-22.672778,-43.618333
br,parque sao jose,Parque São José,21,,-22.817684,-43.616205
br,parque sao luiz,Parque São Luiz,21,,-22.91078,-43.574093
br,parque sao pedro,Parque São Pedro,21,,-22.879947,-43.53611
br,parque sao vicente,Parque São Vicente,21,,-22.732097,-43.369236
br,parque suico,Parque Suíco,27,,-23.407005,-46.691001
br,parque sumare,Parque Sumaré,27,,-23.8641,-46.7435
br,parque tiete,Parque Tietê,21,,-22.782366,-43.337825
br,parque tiradentes,Parque Tiradentes,21,,-22.831706,-43.389816
br,parque turmalina,Parque Turmalina,27,,-23.845,-46.5847
br,parque veneza,Parque Veneza,21,,-22.722086,-43.335065
br,parque vermont,Parque Vermont,27,,-23.877473,-47.048728
br,parque vigario geral,Parque Vigário Geral,21,,-22.80538,-43.301178
br,parra,Parra,06,,-3.416667,-39.283333
br,parrapato,Parrapato,30,,-7.883333,-38.2
br,parreiras,Parreiras,02,,-9.383333,-38.05
br,parreiras,Parreiras,05,,-14.566667,-42.95
br,parreiras,Parreiras,15,,-21.933333,-46.383333
br,parteiro,Parteiro,04,,-4.513889,-59.365556
br,partenon,Partenon,23,,-30.05,-51.2
br,partidario,Partidário,15,,-20.366667,-45.05
br,paruje,Parujé,02,,-9.533333,-37.283333
br,paru,Paru,04,,-5.806389,-63.536944
br,paruru,Paruru,27,,-23.691738,-47.340531
br,parurus,Parurus,27,,-23.691738,-47.340531
br,paschoal,Paschoal,14,,-14.766667,-57.433333
br,pascoal,Pascoal,06,,-4.216667,-38.566667
br,pascoal,Pascoal,14,,-14.766667,-57.433333
br,pascom,Pascom,27,,-22.45,-47.55
br,pa serrada,Pá Serrada,13,,-3.207222,-43.014722
br,pasmado,Pasmado,30,,-7.766667,-34.933333
br,pasmados,Pasmados,30,,-7.766667,-34.933333
br,passa bem,Passa Bem,13,,-3.554722,-43.325556
br,passabem,Passabém,15,,-19.283333,-43.216667
br,passa-bem,Passa-Bem,24,,-9.766667,-63.65
br,passa bois,Passa Bois,26,,-26.833333,-50.416667
br,passa cinco,Passa Cinco,27,,-22.35,-47.833333
br,passa da patria,Passa da Patria,04,,-6.95,-64.583333
br,passa dez,Passa Dez,15,,-19.683333,-42.316667
br,passa-dois,Passa-Dois,18,,-25.795551,-49.787314
br,passa dois,Passa Dois,26,,-26.833333,-50.416667
br,passagem da areia,Passagem da Areia,20,,-8.883333,-45.866667
br,passagem da canoa,Passagem da Canoa,13,,-3.371667,-42.473889
br,passagem da conceicao,Passagem da Conceição,14,,-15.566667,-56.15
br,passagem da pedra,Passagem da Pedra,17,,-7.966667,-37.2
br,passagem da raiz,Passagem da Raiz,22,,-5.866667,-36.433333
br,passagem d'areia,Passagem d'Areia,05,,-10.866667,-45.166667
br,passagem da taboca,Passagem da Taboca,20,,-9.7,-45.833333
br,passagem de mariana,Passagem de Mariana,15,,-20.383333,-43.45
br,passagem de pedra,Passagem de Pedra,05,,-10.883333,-45.416667
br,passagem de pedra,Passagem de Pedra,06,,-7.516667,-38.833333
br,passagem de pedra,Passagem de Pedra,22,,-5.1425,-37.271944
br,passagem de pedras,Passagem de Pedras,05,,-10.883333,-45.416667
br,passagem de santo antonio,Passagem de Santo Antônio,20,,-5.4,-42.916667
br,passagem do bastiao,Passagem do Bastião,15,,-15.55,-41.95
br,passagem do caboclo,Passagem do Caboclo,22,,-5.616667,-35.8
br,passagem do gado,Passagem do Gado,13,,-3.1475,-42.984167
br,passagem do leite,Passagem do Leite,20,,-3.790833,-42.502222
br,passagem do magu,Passagem do Magu,13,,-3.091389,-42.303333
br,passagem do meio,Passagem do Meio,06,,-5.516667,-39.533333
br,passagem do meio,Passagem do Meio,22,,-6.25,-36.1
br,passagem do pajeu,Passagem do Pajeú,05,,-11.966667,-44.366667
br,passagem do rio verde,Passagem do Rio Verde,05,,-10.933333,-42.316667
br,passagem dos afogados,Passagem dos Afogados,30,,-7.75,-37.65
br,passagem dos cavalos,Passagem dos Cavalos,30,,-7.833333,-37.433333
br,passagem dos mocos,Passagem dos Moços,05,,-10.55,-43.1
br,passagem do sono,Passagem do Sono,05,,-14.816667,-42.183333
br,passagem dos porcos,Passagem dos Porcos,05,,-11.7,-41.85
br,passagem dos teixeiras,Passagem dos Teixeiras,05,,-12.733333,-38.433333
br,passagem dos texeiras,Passagem dos Texeiras,05,,-12.733333,-38.433333
br,passagem do vigario,Passagem do Vigário,02,,-9.533333,-36.533333
br,passagem franca,Passagem Franca,13,7376,-6.166667,-43.783333
br,passagem funda,Passagem Funda,05,,-9.966667,-38.716667
br,passagem funda,Passagem Funda,06,,-5.2,-39.933333
br,passagem funda,Passagem Funda,20,,-5.45,-41.55
br,passagem funda,Passagem Funda,22,,-5.583333,-37.666667
br,passagem fundo,Passagem Fundo,22,,-5.583333,-37.666667
br,passagem limpa,Passagem Limpa,20,,-6.3,-41.55
br,passagem nova,Passagem Nova,05,,-12.916667,-41.883333
br,passagem nova,Passagem Nova,06,,-3.066667,-39.666667
br,passagem nova,Passagem Nova,20,,-8.55,-42.133333
br,passagem,Passagem,02,,-9.433333,-37.633333
br,passagem,Passagem,05,,-10.066667,-42.433333
br,passagem,Passagem,06,,-3.116667,-41.183333
br,passagem,Passagem,13,,-1.55,-46.166667
br,passagem,Passagem,14,,-15.9,-57.083333
br,passagem,Passagem,15,,-19.283333,-43.216667
br,passagem,Passagem,16,,-4.366667,-56.383333
br,passagem,Passagem,17,,-6.533333,-36.066667
br,passagem,Passagem,20,,-5.966667,-42.083333
br,passagem,Passagem,22,,-6.033333,-37.666667
br,passagem,Passagem,26,,-28.466667,-48.983333
br,passagem,Passagem,30,,-8.1,-36.5
br,passagem rasa,Passagem Rasa,20,,-3.9075,-42.581667
br,passagem santo antonio,Passagem Santo Antônio,13,,-5.383333,-42.9
br,passagem velha,Passagem Velha,13,,-3.024444,-42.475
br,passagem velha,Passagem Velha,20,,-5.666667,-41.3
br,passagenzinha,Passagenzinha,20,,-9.45,-45.483333
br,passaje,Passaje,14,,-15.416667,-60
br,passamanes,Passamanes,17,,-7.233333,-38.216667
br,passamo,Passamo,17,,-7.383333,-37.916667
br,passa quatro,Passa Quatro,15,12765,-22.383333,-44.966667
br,passa quatro,Passa Quatro,18,,-25.95,-52.433333
br,passarao,Passarão,25,,3.216667,-60.6
br,passaredo,Passaredo,21,,-22.919041,-43.414242
br,passarinho,Passarinho,17,,-6.7,-38.133333
br,passarinho,Passarinho,26,,-27.15,-53.25
br,passarinhos,Passarinhos,26,,-27.15,-53.25
br,passaros,Passaros,14,,-16.6,-55.866667
br,passa-tempo,Passa-Tempo,11,,-21.116667,-55.15
br,passa tempo,Passa Tempo,13,,-5.45,-43.333333
br,passa tempo,Passa Tempo,15,,-20.666667,-44.5
br,passa-tres,Passa-Três,18,,-26.0724,-49.79
br,passa tres,Passa Três,21,,-22.7,-44
br,passa tres,Passa Três,27,,-22.883333,-46.666667
br,passa-tres,Passa-Três,27,,-23.462099,-47.875611
br,passa vinte,Passa Vinte,15,,-22.216667,-44.25
br,passaxunga,Passaxunga,17,,-7.366667,-36.2
br,passe-bem,Passe-Bem,13,,-2.466667,-45.216667
br,passe,Passé,05,,-12.716667,-38.516667
br,passicho,Passicho,23,,-30.033333,-50.383333
br,passinho,Passinho,23,,-30.033333,-50.383333
br,passinhos,Passinhos,18,,-25.45,-52.433333
br,passinhos,Passinhos,23,,-30.033333,-50.383333
br,passira,Passira,30,12664,-7.95,-35.633333
br,passo almeida,Passo Almeida,18,,-26.15,-51.216667
br,passo bormann,Passo Bormann,26,,-27.233333,-52.6
br,passo borman,Passo Borman,26,,-27.233333,-52.6
br,passo canoinhas,Passo Canoinhas,26,,-26.616667,-50.35
br,passoca,Passoca,14,,-16.566667,-56.266667
br,passoda figueira,Passoda Figueira,11,,-21.033333,-57.733333
br,passo da patria,Passo da Patria,04,,-6.95,-64.583333
br,passo da reserva,Passo da Reserva,23,,-29.75,-51.95
br,passo das antas,Passo das Antas,23,,-29.066667,-51.583333
br,passo das pedras,Passo das Pedras,23,,-31.383333,-52.133333
br,passo de camaragibe,Passo de Camaragibe,02,5523,-9.25,-35.433333
br,passo de camarajibe,Passo de Camarajibe,02,,-9.25,-35.433333
br,passo de pupo,Passo de Pupo,18,,-25.133333,-49.966667
br,passo de sao marcos,Passo de São Marcos,23,,-28.383333,-55.833333
br,passo de tomaz,Passo de Tomaz,18,,-25.54843,-50.42342
br,passo do alonso,Passo do Alonso,23,,-31.233333,-54.433333
br,passo do cacao,Passo do Cação,23,,-30.983333,-53.483333
br,passo do calcao,Passo do Calção,23,,-30.983333,-53.483333
br,passo do certao,Passo do Certão,26,,-29.216667,-49.8
br,passo do feijo,Passo do Feijó,23,,-30.016667,-51.083333
br,passo do gado,Passo do Gado,26,,-28.483333,-49
br,passo do gato,Passo do Gato,26,,-28.483333,-49
br,passo do guacu boi,Passo do Guaçu Boi,23,,-29.75,-56.25
br,passo do meio,Passo do Meio,18,,-25.9,-50.583333
br,passo do ourico,Passo do Ouriçó,23,,-29.9343,-50.9855
br,passo do potinga,Passo do Potinga,18,,-25.613097,-50.715723
br,passo do pupo,Passo do Pupo,18,,-25.133333,-49.966667
br,passo do sabao,Passo do Sabão,23,,-30.083333,-51.05
br,passo do sertao,Passo do Sertão,26,,-29.216667,-49.8
br,passo do sobrado,Passo do Sobrado,23,,-29.75,-52.283333
br,passo dos pupos,Passo dos Pupos,18,,-25.133333,-49.966667
br,passo do tio paulo,Passo do Tio Paulo,18,,-25.517251,-50.118283
br,passo do valo,Passo do Valo,18,,-26.1076,-49.7606
br,passo figueira,Passo Figueira,11,,-21.033333,-57.733333
br,passo fundo,Passo Fundo,18,,-25.582304,-50.177434
br,passo fundo,Passo Fundo,23,179532,-28.266667,-52.4
br,passo fundo,Passo Fundo,27,,-23.5033,-47.599
br,passo liso,Passo Liso,18,,-25.283333,-52.333333
br,passo nono,Passo Nono,23,,-29.683333,-55.533333
br,passo novo,Passo Novo,23,,-29.683333,-55.533333
br,passo,Passo,23,,-28.616667,-56.033333
br,passo quatro,Passo Quatro,15,,-22.383333,-44.966667
br,passo raso,Passo Raso,23,,-29.9093,-51.4793
br,passo sertao,Passo Sertão,26,,-29.216667,-49.8
br,passos,Passos,15,98753,-20.716667,-46.616667
br,passo torraca,Passo Torraca,11,,-22.316667,-55.033333
br,passo vermelho,Passo Vermelho,26,,-28.9,-49.466667
br,pasta,Pasta,06,,-5.116667,-39.383333
br,pastinha,Pastinha,05,,-13,-38.95
br,pastinho,Pastinho,05,,-13.083333,-41.6
br,pastinho,Pastinho,23,,-31.266667,-54.133333
br,pasto branco,Pasto Branco,23,,-30.45,-54.55
br,pasto da mata,Pasto da Mata,05,,-17.85,-39.866667
br,pasto de fora,Pasto de Fora,05,,-12.716667,-38.483333
br,pasto grande,Pasto Grande,04,,-7.906667,-62.903889
br,pastorador,Pastorador,22,,-5.65,-35.316667
br,pastora,Pastôra,05,,-11.95,-37.95
br,pastos bons,Pastos Bons,06,,-4.383333,-39.9
br,pastos bons,Pastos Bons,13,10469,-6.6,-44.083333
br,pasto velho,Pasto Velho,27,,-23.475974,-47.93547
br,pataiba,Pataíba,05,,-11.683333,-38.733333
br,patamute,Patamuté,05,,-9.416667,-39.466667
br,patanhaem,Patanhaém,06,,-3.966667,-38.466667
br,patas,Patas,17,,-7.566667,-36.266667
br,patau,Patau,05,,-13.266667,-41.883333
br,pateirao,Pateirão,05,,-15.433333,-40.583333
br,patiaba,Patiaba,05,,-13.283333,-39.716667
br,pati do alferes,Pati do Alferes,21,,-22.428056,-43.421944
br,patinhos de baixo,Patinhos de Baixo,18,,-25.130312,-48.893863
br,patinhos de cima,Patinhos de Cima,18,,-25.125791,-48.931236
br,patinhos,Patinhos,05,,-12.55,-39.783333
br,pati,Pati,05,,-12.233333,-38.25
br,pati,Patí,13,,-3.051667,-43.125
br,patis,Patis,15,,-16.079167,-44.080833
br,patis,Patis,20,,-3.7775,-42.108056
br,patis,Patis,21,,-22.616667,-42.633333
br,patizal,Patizal,31,,-11.883333,-49.15
br,pato bragado,Pato Bragado,18,,-24.616667,-54.216667
br,pato branco,Pato Branco,18,65754,-26.216667,-52.666667
br,pato,Pato,05,,-10.1,-43.45
br,pato,Pato,20,,-9.483333,-45.233333
br,pato,Pato,30,,-8.25,-37.55
br,patos de minas,Patos de Minas,15,126236,-18.583333,-46.533333
br,patos,Patos,05,,-10.1,-43.45
br,patos,Patos,06,,-3.033333,-39.7
br,patos,Patos,15,,-18.416667,-46.416667
br,patos,Patos,17,92577,-7.016667,-37.266667
br,patos,Patos,18,,-25.1871,-48.960961
br,patos,Patos,20,,-3.5275,-42.277222
br,patos,Patos,27,,-20.033333,-49.4
br,patos,Patos,28,,-9.75,-37.483333
br,patos velhos,Patos Velhos,18,,-25.366667,-50.966667
br,patrao mor,Patrão Mor,08,,-19.483333,-40.45
br,patriarca,Patriarca,06,,-3.583333,-40.25
br,patricio,Patrício,29,,-14.966667,-49.383333
br,patrimonio da capela,Patrimônio da Capela,11,,-18.45,-53.116667
br,patrimonio d'agua clara,Patrimonio d'Agua Clara,27,,-21.533333,-50.566667
br,patrimonio da luiziana,Patrimônio da Luiziana,27,,-21.683333,-50.283333
br,patrimonio da pedra da viuva,Patrimônio da Pedra da Viuva,08,,-18.2,-40.716667
br,patrimonio da penha,Patrimônio da Penha,08,,-18.583333,-40.416667
br,patrimonio da serra,Patrimônio da Serra,08,,-18.383333,-40.833333
br,patrimonio da viuva,Patrimônio da Viúva,08,,-18.2,-40.716667
br,patrimonio de entre rios,Patrimônio de Entre Rios,27,,-20.65,-51.383333
br,patrimonio de gracianopolis,Patrimônio de Gracianópolis,27,,-21.433333,-51.6
br,patrimonio de sao pedro,Patrimonio de São Pedro,27,,-22.016667,-51.066667
br,patrimonio divino,Patrimônio Divino,08,,-21,-41.6
br,patrimonio do cafe,Patrimônio do Café,18,,-23.890419,-50.185564
br,patrimonio do jaguarete,Patrimônio do Jaguaretê,27,,-22.55,-51.116667
br,patrimonio do jauru,Patrimônio do Jauru,11,,-18.583333,-54.316667
br,patrimonio do limoeiro,Patrimônio do Limoeiro,27,,-22.583333,-49.35
br,patrimonio do pinheiro,Patrimônio do Pinheiro,08,,-18.35,-40.283333
br,patrimonio do rato,Patrimônio do Rato,27,,-21.566667,-50.7
br,patrimonio do serro,Patrimônio do Sêrro,08,,-18.383333,-40.833333
br,patrimonio do taquari,Patrimônio do Taquari,14,,-17.833333,-53.283333
br,patrimonio ipiranga,Patrimônio Ipiranga,27,,-22.2,-51.75
br,patrimonio jaguarete,Patrimônio Jaguaretê,27,,-22.55,-51.116667
br,patrimonio marques dos reis,Patrimônio Marques dos Reis,18,,-23.007348,-49.911092
br,patrimonio,Patrimônio,08,,-18.2,-40.716667
br,patrimonio,Patrimônio,15,,-19.5,-48.483333
br,patrimonio,Patrimônio,18,,-23.883333,-51.75
br,patrimonio santa guilhermina,Patrimônio Santa Guilhermina,27,,-22.516667,-51.25
br,patrimonio sao jose,Patrimônio São José,27,,-22.183333,-49.583333
br,patrimonio sao pedro,Patrimônio São Pedro,27,,-23.3,-49.6
br,patrimonio sao sebastiao,Patrimônio São Sebastião,27,,-22.433333,-48
br,patrimonio uniao,Patrimônio União,11,,-23.083333,-55.216667
br,patrocinio do coite,Patrocinio do Coité,05,,-10.683333,-37.866667
br,patrocinio do muriae,Patrocínio do Muriaé,15,,-21.15,-42.2
br,patrocinio do muriahe,Patrocinio do Muriahé,15,,-21.15,-42.2
br,patrocinio do sapucahy,Patrocinio do Sapucahy,27,,-20.633333,-47.283333
br,patrocinio do sapucai,Patrocínio do Sapucaí,27,,-20.633333,-47.283333
br,patrocinio,Patrocínio,13,,-4.466667,-44.733333
br,patrocinio,Patrocínio,15,71964,-18.95,-46.983333
br,patrocinio,Patrocínio,20,,-6.833333,-40.616667
br,patrocinio,Patrocínio,23,,-30.866667,-52.25
br,patrocinio paulista,Patrocínio Paulista,27,,-20.633333,-47.283333
br,patrocinio sao martinho,Patrocínio São Martinho,27,,-21.566667,-50.266667
br,patrocinio sao vincente,Patrocínio São Vincente,27,,-22.016667,-49.083333
br,patundova,Patundova,27,,-22.383333,-48.633333
br,patu,Patu,22,8842,-6.1,-37.633333
br,paturi,Paturi,06,,-7.4,-38.783333
br,paturi,Paturi,27,,-22.776,-45.1446
br,paty do alferas,Paty do Alferas,21,,-22.428056,-43.421944
br,patys,Patys,15,,-16.079167,-44.080833
br,pau alto,Pau Alto,11,,-19.883333,-56.066667
br,pau amarelo,Pau Amarelo,30,,-9.133333,-36.283333
br,pau amarelo,Pau Amarelo,31,,-6.683333,-48.05
br,pau-a-pique,Pau-a-Pique,05,,-13.633333,-41.95
br,pauapixuna,Pauapixuna,04,,-2.75,-65.783333
br,pau branco,Pau Branco,05,,-11.816667,-39.45
br,pau branco,Pau Branco,06,,-3.533333,-38.933333
br,pau branco,Pau Branco,17,,-7.683333,-38.466667
br,pau branco,Pau Branco,30,,-8.533333,-35.266667
br,pau brasil,Pau Brasil,05,8136,-15.45,-39.65
br,pau brasil,Pau Brasil,08,,-19.85,-40.15
br,pau caido,Pau Caído,06,,-3.55,-40.183333
br,pau caido,Pau Caido,17,,-7.266667,-36.65
br,pau cedro,Pau Cedro,05,,-12.85,-39.333333
br,pau da embira,Pau da Embira,17,,-7.45,-36.016667
br,pau da fome,Pau da Fome,21,,-22.924944,-43.432736
br,pau-d'agua,Pau-d'Agua,13,,-3.413889,-42.249722
br,pau da legua,Pau da Legua,22,,-5.427222,-37.367222
br,pau-d'alho,Pau-d'Alho,06,,-3.666667,-41.35
br,pau d'alho,Pau d'Alho,08,,-20.883333,-40.95
br,pau-d'alho,Pau-d'Alho,18,,-23.3172,-50.2222
br,pau d'alho,Pau d'Alho,27,,-22.816667,-50.1
br,pau d'alho,Pau d'Alho,30,,-7.9,-35.166667
br,pau d'arco,Pau d'Arco,02,,-9.783333,-36.75
br,pau d'arco,Pau d'Arco,05,,-11.033333,-43.133333
br,pau d'arco,Pau d'Arco,06,,-5.416667,-39.5
br,pau d'arco,Pau d'Arco,13,,-3.157778,-43.094167
br,pau-d'arco,Pau-d'Arco,13,,-3.783056,-43.463333
br,pau d'arco,Pau d'Arco,17,,-6.916667,-38.6
br,pau-d'arco,Pau-d'Arco,20,,-3.419167,-42.022222
br,pau d'arco,Pau d'Arco,20,,-5.183333,-41.916667
br,pau d'arco,Pau d'Arco,22,,-5.329167,-37.054722
br,pau d'arco,Pau d'Arco,30,,-8.1,-37.733333
br,pau d'arco,Pau d'Arco,31,,-7.5075,-49.207778
br,pau d'arcos,Pau d'Arcos,20,,-7.15,-41.633333
br,pau da torta,Pau da Torta,14,,-15.366667,-59.783333
br,pau de canoa,Pau de Canoa,02,,-9.35,-37.616667
br,pau de casca,Pau de Casca,18,,-26.0306,-49.7665
br,pau de chapada i,Pau de Chapada I,20,,-5.35,-41.983333
br,pau de chapada,Pau de Chapada,20,,-6.033333,-41.95
br,pau de colher,Pau de Colher,05,,-11.016667,-40.95
br,pau de colher,Pau de Colher,30,,-8.5,-38.983333
br,pau de copa,Pau de Copa,05,,-15.7,-41.033333
br,pau de copas,Pau de Copas,05,,-15.7,-41.033333
br,pau de espinho,Pau de Espinho,05,,-14.183333,-43.2
br,pau-de-ferro,Pau-de-Ferro,20,,-3.661944,-42.286667
br,pau de fogo,Pau de Fogo,06,,-6.066667,-40.033333
br,pau de leite,Pau de Leite,17,,-7.033333,-37.6
br,pau de leite,Pau de Leite,22,,-5.552222,-36.202778
br,pau de linho,Pau de Linho,15,,-17.333333,-42.35
br,pau de pilao,Pau de Pilão,05,,-12.116667,-40.85
br,pau de pulga,Pau de Pulga,17,,-7.083333,-37.916667
br,pau doia,Pau Dóia,17,,-7.466667,-38.2
br,pau d'oleo,Pau d'Oleo,06,,-5.383333,-40.933333
br,pau do leo,Pau do Leo,08,,-20.616667,-40.633333
br,pau d'oleo,Pau d'Oleo,08,,-20.616667,-40.633333
br,pau do oleo,Pau do Óleo,22,,-5.766667,-35.7
br,pau dos ferros,Pau dos Ferros,06,,-5.8,-39.883333
br,pau dos ferros,Pau dos Ferros,22,25051,-6.116667,-38.166667
br,pauela de ferro,Pauela de Ferro,15,,-20.9,-41.966667
br,pau ferrado,Pau Ferrado,13,,-3.159167,-43.453889
br,pau ferrado,Pau Ferrado,20,,-3.951944,-42.234167
br,pau ferrado,Pau Ferrado,31,,-6.616667,-48.6
br,pau ferrinho,Pau Ferrinho,17,,-7.633333,-38.516667
br,pau ferro,Pau Ferro,05,,-11.616667,-39.133333
br,pau ferro,Pau Ferro,06,,-4.916667,-39.933333
br,pau ferro,Pau Ferro,17,,-7.083333,-35.416667
br,pau ferro,Pau Ferro,21,,-22.928383,-43.329753
br,pau ferro,Pau Ferro,30,,-7.633333,-37.6
br,pau fincado,Pau Fincado,23,,-29.916667,-54.316667
br,pau gigante,Pau Gigante,08,,-19.833333,-40.366667
br,pau grande,Pau Grande,24,,-10.483333,-65.4
br,pauini,Pauini,04,7633,-7.666667,-66.966667
br,paula candido,Paula Cândido,15,,-20.883333,-42.966667
br,paula freitas,Paula Freitas,18,,-26.2,-50.95
br,paula lima,Paula Lima,15,,-21.583333,-43.483333
br,paula,Paula,26,,-26.216667,-48.6
br,paula,Paula,30,,-8.833333,-36.216667
br,paula pereira,Paula Pereira,26,,-26.016667,-50.533333
br,paula ramos,Paula Ramos,26,,-26.7723,-49.0144
br,paulas,Paulas,26,,-26.216667,-48.6
br,pau lavrado,Pau Lavrado,13,,-3.243611,-42.243056
br,pau leite,Pau Leite,17,,-7.133333,-36.7
br,pauliceia,Paulicéia,08,,-21.116667,-41.35
br,pauliceia,Paulicéia,11,,-21.1,-55.483333
br,pauliceia,Paulicéia,27,,-21.283333,-51.85
br,paulina,Paulina,16,,-.65,-47.4
br,paulinia,Paulínia,27,65596,-22.75,-47.166667
br,paulino neves,Paulino Neves,13,,-2.716667,-42.55
br,paulino,Paulino,13,,-3.951944,-43.256944
br,paulino,Paulino,15,,-20.233333,-46.066667
br,paulino trindade,Paulino Trindade,23,,-29.6,-56.916667
br,paulista florida,Paulista Flórida,27,,-21.6,-51.2
br,paulistana,Paulistana,20,,-8.15,-41.15
br,paulistania,Paulistânia,27,,-22.6,-49.383333
br,paulista,Paulista,05,,-12.5,-43.1
br,paulista,Paulista,06,,-3.9,-38.5
br,paulista,Paulista,08,,-18.666667,-40.8
br,paulista,Paulista,14,,-15.95,-55.55
br,paulista,Paulista,17,3677,-6.583333,-37.616667
br,paulista,Paulista,20,,-7.3,-41.566667
br,paulista,Paulista,22,,-5.572778,-37.115278
br,paulista,Paulista,30,289977,-7.95,-34.883333
br,paulistas,Paulistas,08,,-18.666667,-40.8
br,paulistas,Paulistas,15,,-18.416667,-42.866667
br,paulo affonso,Paulo Affonso,02,,-9.111667,-37.7
br,paulo afonso,Paulo Afonso,02,,-9.111667,-37.7
br,paulo afonso,Paulo Afonso,05,85353,-9.35,-38.233333
br,paulo barros,Paulo Barros,11,,-19.333333,-56.583333
br,paulo be frontin,Paulo Be Frontin,21,,-22.549444,-43.683889
br,paulo bento,Paulo Bento,23,,-27.7,-52.416667
br,paulo cingel,Paulo Cingel,26,,-26.7604,-49.094
br,paulo de almeida,Paulo de Almeida,21,,-22.333333,-43.916667
br,paulo de faria,Paulo de Faria,27,,-20.033333,-49.4
br,paulo-de-frontin,Paulo-de-Frontin,18,,-26.033333,-50.85
br,paulo freitas,Paulo Freitas,18,,-26.2,-50.95
br,paulo frontin,Paulo Frontin,18,,-26.033333,-50.85
br,paulo jacinto,Paulo Jacinto,02,,-9.366667,-36.366667
br,paulo lopes,Paulo Lopes,14,,-15.266667,-56.816667
br,paulo lopes,Paulo Lopes,26,,-27.964444,-48.6825
br,paulo manuel,Paulo Manuel,27,,-23.847775,-47.060377
br,paulo mardes,Paulo Mardes,27,,-23.699488,-47.418773
br,paulo oliveira,Paulo Oliveira,18,,-23.8107,-50.3623
br,paulo,Paulo,03,,-.366667,-52.15
br,paulo,Paulo,13,,-3.960556,-43.239444
br,paulo,Paulo,17,,-7.516667,-38.6
br,paulo pinto,Paulo Pinto,18,,-25.266667,-53.25
br,paulopolis,Paulópolis,27,,-22.1,-50.25
br,paulo ramos,Paulo Ramos,13,8888,-4.216667,-45.183333
br,paulo saldanha,Paulo Saldanha,24,,-11.666667,-62.25
br,paulo sancho,Paulo Sancho,15,,-17.833333,-40.233333
br,paulos,Paulos,22,,-6.016667,-37.9
br,pau luis,Pau Luís,20,,-4.566667,-42.466667
br,paumaripe,Paumaripé,04,,-7.916667,-67.133333
br,pau mulatinho,Pau Mulatinho,05,,-12.733333,-39.183333
br,pau mulato,Pau Mulato,01,,-8.443333,-71.328056
br,pau,Pau,13,,-3.741667,-42.679167
br,pau,Pau,22,,-6.266667,-38.333333
br,pau pereira,Pau Pereira,06,,-4.35,-38.516667
br,pau pombo,Pau Pombo,05,,-12.15,-38.866667
br,pau preto,Pau Prêto,05,,-12.033333,-38.7
br,pau preto,Pau Preto,13,,-3.672778,-42.945833
br,pau preto,Pau Prêto,14,,-16.716667,-56.733333
br,pau quebrado,Pau Quebrado,13,,-3.323056,-43.493611
br,pau queimado,Pau Queimado,04,,-6.366667,-61.766667
br,pau real,Pau Real,13,,-4.45,-44.85
br,pau sangue,Pau Sangue,05,,-13.4,-43.033333
br,paus branco,Paus Branco,06,,-5.633333,-39.666667
br,paus brancos,Paus Brancos,22,,-5.373611,-37.479167
br,paus brancos,Paus Brancos,30,,-7.833333,-38.3
br,pau seco,Pau Sêco,02,,-9.283333,-37.766667
br,pau seco,Pau Sêco,05,,-14.133333,-39
br,pau seco,Pau Sêco,15,,-20.2,-45.55
br,paus grandes,Paus Grandes,30,,-7.55,-39.616667
br,paus,Paus,20,,-9.55,-44.683333
br,pau vermelho,Pau Vermelho,05,,-17.15,-39.45
br,pau vermelho,Pau Vermelho,20,,-8.266667,-41.9
br,pauxis,Pauxis,04,,-3.366667,-66.033333
br,pavao,Pavão,05,,-12.65,-38.766667
br,pavao,Pavão,06,,-7.05,-38.95
br,pavao,Pavão,13,,-2.366667,-44.6
br,pavao,Pavão,15,,-17.433333,-41.05
br,pavao,Pavão,27,,-24.643441,-48.786074
br,pavao-pavaozinho,Pavão-Pavaozinho,21,,-22.980145,-43.196622
br,paverama,Paverama,23,,-29.55,-51.766667
br,pavucu,Pavuçu,20,,-7.95,-43.2
br,pavuna,Pavuna,06,,-3.916667,-38.566667
br,pavuna,Pavuna,21,,-22.809335,-43.356377
br,paxinno,Paxinno,31,,-11.255278,-47.725556
br,paxiua,Paxiua,04,,.7,-67.5
br,paxiuba,Paxiuba,04,,-5.6525,-63.715556
br,paxiubinha,Paxiubinha,04,,-5.638889,-63.737778
br,paxua,Paxua,04,,.216667,-68.533333
br,paz,Paz,18,,-25.65,-52.116667
br,paz,Paz,22,,-5.466667,-35.383333
br,p do feliciano,P do Feliciano,23,,-29.9109,-50.8311
br,peabiru,Peabiru,18,12345,-23.9,-52.333333
br,peador,Peador,20,,-3.983333,-42.692222
br,peba,Peba,02,,-10.35,-36.283333
br,peba,Peba,13,,-6.033333,-43.316667
br,peba,Peba,17,,-7.033333,-36.083333
br,peba,Peba,31,,-7.533333,-48.166667
br,pebas,Pebas,06,,-7.633333,-38.866667
br,pebas,Pebas,20,,-7.7,-41.916667
br,pe branco,Pe Branco,17,,-6.733333,-38.6
br,pebra,Pebra,20,,-7.65,-41.9
br,pecanha,Peçanha,15,6903,-18.55,-42.566667
br,pecem,Pecém,06,,-3.533333,-38.866667
br,pechincha,Pechincha,21,,-22.922151,-43.352791
br,peco arara,Peço Arara,28,,-10.783333,-37.566667
br,pecone,Peconé,14,,-16.259722,-56.626944
br,peda alta,Peda Alta,18,,-25.776969,-49.883343
br,pedagio,Pedagio,27,,-23.7893,-46.5194
br,pe-da-ladeira,Pé-da-Ladeira,13,,-3.830278,-43.433611
br,pe da ladeira,Pé da Ladeira,20,,-6.883333,-41.983333
br,pe da pedra,Pé da Pedra,20,,-7.816667,-41.7
br,pe da serra do geraldo,Pé da Serra do Geraldo,22,,-6.133333,-37.866667
br,pe da serra,Pé da Serra,02,,-8.966667,-37.533333
br,pe da serra,Pé da Serra,05,,-12.116667,-41.183333
br,pe da serra,Pé da Serra,20,,-8.783333,-42.75
br,pe da serra,Pé da Serra,22,,-4.965278,-36.884444
br,pe-de-boi,Pe-de-Boi,28,,-11.1,-38.066667
br,pe de galinha,Pé de Galinha,05,,-14.916667,-40.866667
br,pe de jerimum,Pé de Jerimum,17,,-7.833333,-36.55
br,pe de ladeira,Pé de Ladeira,17,,-7.683333,-37.8
br,pe de lima,Pé de Lima,05,,-11.866667,-41.866667
br,pe de moco,Pé de Mocó,30,,-9.083333,-37.183333
br,pederneira,Pederneira,25,,2.383333,-60.85
br,pederneiras,Pederneiras,15,,-19.716667,-49.283333
br,pederneiras,Pederneiras,16,,-4.216667,-55.85
br,pederneiras,Pederneiras,18,,-25.141607,-48.383863
br,pederneiras,Pederneiras,23,,-30.033333,-52.5
br,pederneiras,Pederneiras,27,38020,-22.383333,-48.766667
br,pe de serra,Pé de Serra,02,,-8.966667,-37.533333
br,pe de serra,Pé de Serra,05,,-11.833333,-39.6
br,pe de serra,Pé de Serra,13,,-6.033333,-43.316667
br,pe de serra,Pé de Serra,17,,-7.583333,-38.133333
br,pe de serra,Pé de Serra,22,,-4.965278,-36.884444
br,pe de serra,Pé de Serra,30,,-8.383333,-35.933333
br,pe do alto,Pé do Alto,05,,-14.566667,-41.433333
br,pe do boi,Pé do Boi,28,,-11.1,-38.066667
br,pe do morro,Pé do Morro,05,,-12.016667,-42.766667
br,pe-do-morro,Pé-do-Morro,13,,-3.370278,-42.455278
br,pe do morro,Pé do Morro,15,,-22.333333,-44.95
br,pe do morro,Pé do Morro,16,,-4.666667,-54.133333
br,pe-do-morro,Pé-do-Morro,20,,-3.933333,-42.701667
br,pe do morro,Pé do Morro,20,,-5.416667,-42.483333
br,pe do morro,Pé do Morro,31,,-12.966667,-46.933333
br,pedra alta,Pedra Alta,05,,-11.133333,-39.1
br,pedra alta,Pedra Alta,17,,-7.766667,-36.266667
br,pedra angular,Pedra Angular,21,,-22.887606,-43.556487
br,pedra atravessada,Pedra Atravessada,30,,-7.833333,-37.516667
br,pedra azul,Pedra Azul,15,20899,-16.016667,-41.266667
br,pedra azul,Pedra Azul,18,,-25.769815,-50.05313
br,pedra bela,Pedra Bela,27,,-22.783333,-46.45
br,pedra bonita,Pedra Bonita,05,,-12.283333,-39.316667
br,pedra bonita,Pedra Bonita,15,,-20.516667,-42.333333
br,pedra branca de cima,Pedra Branca de Cima,22,,-5.767222,-36.079444
br,pedra branca do araraquara,Pedra Branca do Araraquara,18,,-25.9145,-48.9194
br,pedra branca,Pedra Branca,05,,-12.416667,-41.15
br,pedra branca,Pedra Branca,06,20072,-5.45,-39.716667
br,pedra branca,Pedra Branca,13,,-3.716667,-43.733333
br,pedra branca,Pedra Branca,15,,-20.183333,-45.9
br,pedra branca,Pedra Branca,17,,-6.983333,-37.9
br,pedra branca,Pedra Branca,18,,-25.03729,-48.963642
br,pedra branca,Pedra Branca,20,,-3.472222,-42.204444
br,pedra branca,Pedra Branca,22,,-5.198056,-37.440278
br,pedra branca,Pedra Branca,24,,-10.05,-62.116667
br,pedra branca,Pedra Branca,26,,-26.516667,-49.133333
br,pedra branca,Pedra Branca,27,,-22.949,-45.1459
br,pedra branca,Pedra Branca,30,,-7.866667,-36.333333
br,pedra branca,Pedra Branca,31,,-6.45,-48.583333
br,pedra brance,Pedra Brance,06,,-5.983333,-40.633333
br,pedra canga,Pedra Canga,11,,-20.666667,-55.816667
br,pedra canga,Pedra Canga,24,,-9.016667,-64.083333
br,pedra chata,Pedra Chata,18,,-25.145245,-48.370499
br,pedra comprida,Pedra Comprida,22,,-5.857778,-37.430556
br,pedra comprida,Pedra Comprida,30,,-8.466667,-36.45
br,pedra corrida,Pedra Corrida,15,,-19.116667,-42.166667
br,pedra da arara,Pedra da Arara,20,,-7.85,-41.633333
br,pedra da balisa,Pedra da Balisa,05,,-10.6275,-46.116944
br,pedra da baliza,Pedra da Baliza,05,,-10.6275,-46.116944
br,pedra da cuica,Pedra da Cuíca,30,,-8.716667,-38.85
br,pedra d'agua do umbuzeiro,Pedra d'Agua do Umbuzeiro,17,,-7,-36.5
br,pedra d'agua,Pedra d'Agua,05,,-9.266667,-38.283333
br,pedra d'agua,Pedra d'Agua,06,,-5.616667,-40.566667
br,pedra d'agua,Pedra d'Agua,17,,-6.5,-36.216667
br,pedra d'agua,Pedra d'Agua,20,,-7.616667,-41.15
br,pedra d'agua,Pedra d'Agua,21,,-21.466667,-41.416667
br,pedra d' agua,Pedra d' Agua,22,,-5.55,-35.85
br,pedra d'agua,Pedra d'Agua,28,,-9.716667,-37.85
br,pedra da mata,Pedra da Mata,27,,-22.616667,-47.016667
br,pedra da onca,Pedra da Onça,05,,-10.566667,-43.5
br,pedra de amolar,Pedra de Amolar,05,,-11.85,-45.216667
br,pedra de amolar,Pedra de Amolar,30,,-8.1,-38.766667
br,pedra de amolar,Pedra de Amolar,31,,-10.557222,-46.383056
br,pedra de fogo,Pedra de Fogo,02,,-9.416667,-36.283333
br,pedra de fogo,Pedra de Fogo,05,,-11.116667,-45.966667
br,pedra-de-fogo,Pedra-de-Fogo,13,,-3.781389,-42.769444
br,pedra de fogo,Pedra de Fogo,22,,-5.393611,-36.481389
br,pedra de fogo,Pedra de Fogo,30,,-8.35,-38.9
br,pedra de guaratiba,Pedra de Guaratiba,21,,-22.998593,-43.633326
br,pedra do amolar,Pedra do Amolar,31,,-10.557222,-46.383056
br,pedra do anta,Pedra do Anta,15,,-20.6,-42.716667
br,pedra do barco,Pedra do Barco,04,,-4.916667,-58.033333
br,pedra do buraco,Pedra do Buraco,04,,-4.916667,-58.033333
br,pedra do cajuru,Pedra do Cajuru,15,,-17.366667,-41.616667
br,pedra do cruzeiro,Pedra do Cruzeiro,15,,-22.5754,-45.5355
br,pedra do ilheo,Pedra do Ilhéo,05,,-10.8,-41.65
br,pedra do ilheu,Pedra do Ilhéu,05,,-10.8,-41.65
br,pedra do indaia,Pedra do Indaiá,15,,-20.25,-45.216667
br,pedra do rumo,Pedra do Rumo,13,,-4.233333,-45.35
br,pedra do salgado,Pedra do Salgado,05,,-12.4,-38.133333
br,pedra do sal,Pedra do Sal,20,,-2.804167,-41.730278
br,pedra dourada,Pedra Dourada,15,,-20.816667,-42.166667
br,pedra do vento,Pedra do Vento,08,,-20.383333,-40.6
br,pedra enfincada,Pedra Enfincada,20,,-6.816667,-40.633333
br,pedra ferrada,Pedra Ferrada,13,,-5.6,-46.7
br,pedra fina,Pedra Fina,26,,-26.2463,-49.9932
br,pedra fixa,Pedra Fixa,30,,-8.616667,-36.766667
br,pedra furada,Pedra Furada,02,,-9.9,-36.766667
br,pedra furada,Pedra Furada,20,,-9.716667,-45.283333
br,pedra furada,Pedra Furada,31,,-11.546944,-46.259722
br,pedra ganga,Pedra Ganga,11,,-20.666667,-55.816667
br,pedra grande,Pedra Grande,05,,-9.9,-39.55
br,pedra grande,Pedra Grande,13,,-3.408889,-43.315
br,pedra grande,Pedra Grande,15,,-15.983333,-40.883333
br,pedra grande,Pedra Grande,20,,-3.833889,-42.580556
br,pedra grande,Pedra Grande,22,,-5.15,-35.883333
br,pedra grande,Pedra Grande,27,,-22.783333,-46.45
br,pedra lavara,Pedra Lavara,17,,-6.75,-36.466667
br,pedra lavrada,Pedra Lavrada,17,,-6.75,-36.466667
br,pedral do sal,Pedral do Sal,20,,-2.804167,-41.730278
br,pedra lisa,Pedra Lisa,17,,-6.316667,-37.466667
br,pedra lisa,Pedra Lisa,18,,-25.697067,-50.012593
br,pedra lisa,Pedra Lisa,22,,-5.740278,-37.004167
br,pedral,Pedral,04,,-5.253056,-59.653889
br,pedral,Pedral,24,,-10.366667,-65.25
br,pedralva,Pedralva,15,,-22.233333,-45.466667
br,pedra marmore,Pedra Mármore,11,,-21.316667,-56.516667
br,pedra menina,Pedra Menina,15,,-18.133333,-43.1
br,pedra miuda,Pedra Miúda,20,,-3.710278,-42.419722
br,pedra mole,Pedra Mole,28,,-10.616667,-37.683333
br,pedranopolis,Pedranópolis,27,,-20.233333,-50.1
br,pedra nova,Pedra Nova,05,,-12.133333,-38.85
br,pedrao,Pedrão,02,,-9.466667,-37.966667
br,pedrao,Pedrão,05,,-12.15,-38.65
br,pedrao,Pedrão,30,,-9.15,-38.05
br,pedra,Pedra,02,,-9.383333,-37.983333
br,pedra,Pedra,05,,-11.2,-39.933333
br,pedra,Pedra,06,,-3.883333,-38.5
br,pedra,Pedra,13,,-3.134722,-43.333889
br,pedra,Pedra,17,,-7.266667,-37.05
br,pedra,Pedra,20,,-10,-45.35
br,pedra,Pedra,26,,-29,-49.833333
br,pedra,Pedra,27,,-21.2,-47.616667
br,pedra,Pedra,30,11197,-8.5,-36.95
br,pedra picada,Pedra Picada,17,,-7.383333,-37.883333
br,pedra pintada,Pedra Pintada,05,,-10.7,-41.116667
br,pedra preta,Pedra Preta,18,,-25.521451,-50.686526
br,pedra preta,Pedra Preta,20,,-9.016667,-45.95
br,pedra preta,Pedra Preta,22,,-5.583889,-36.104722
br,pedra preta,Pedra Preta,28,,-9.616667,-37.833333
br,pedra preta,Pedra Preta,31,,-11.333333,-47.633333
br,pedra preto,Pedra Prêto,17,,-6.9,-38.666667
br,pedra queimada,Pedra Queimada,05,,-14.5,-39.416667
br,pedra rachada,Pedra Rachada,06,,-4.683333,-41.066667
br,pedra rachada,Pedra Rachada,20,,-3.891944,-42.574722
br,pedra redonda,Pedra Redonda,03,,1.883333,-50.8
br,pedra redonda,Pedra Redonda,06,,-5.416667,-39.433333
br,pedra redonda,Pedra Redonda,17,,-7.1,-36.016667
br,pedraria,Pedraria,15,,-17.633333,-43.45
br,pedra roxa,Pedra Roxa,30,,-8.983333,-37.85
br,pedras altas,Pedras Altas,05,,-11.166667,-40.05
br,pedras altas,Pedras Altas,23,,-31.733333,-53.583333
br,pedra santa,Pedra Santa,31,,-7.233333,-48.466667
br,pedras brancas,Pedras Brancas,06,,-5.15,-38.816667
br,pedras brancas,Pedras Brancas,22,,-5.585278,-36.743333
br,pedras brancas,Pedras Brancas,23,,-29.0206,-51.0779
br,pedras das abelha,Pedras das Abelha,22,,-5.583333,-37.683333
br,pedras das abelhas,Pedras das Abelhas,22,,-5.583333,-37.683333
br,pedras de fogo,Pedras de Fogo,17,13894,-7.383333,-35.116667
br,pedras de maria da cruz,Pedras de Maria da Cruz,15,,-15.616667,-44.383333
br,pedras de maria de cruz,Pedras de Maria de Cruz,15,,-15.616667,-44.383333
br,pedras do ernesto,Pedras do Ernesto,05,,-10.4,-42.466667
br,pedras do salgado,Pedras do Salgado,05,,-12.4,-38.133333
br,pedra selada,Pedra Selada,21,,-22.3389,-44.3952
br,pedras grandes,Pedras Grandes,26,,-28.45,-49.183333
br,pedras molles,Pedras Molles,28,,-10.616667,-37.683333
br,pedras negras,Pedras Negras,24,,-12.85,-62.9
br,pedra solta,Pedra Solta,15,,-20.15,-41.633333
br,pedras,Pedras,04,,-2.796389,-57.280278
br,pedras,Pedras,05,,-10.6,-42.65
br,pedras,Pedras,06,,-3.1,-39.55
br,pedras,Pedras,08,,-19.366667,-40.516667
br,pedras,Pedras,11,,-19.166667,-57.216667
br,pedras,Pedras,13,,-3.066111,-42.199167
br,pedras,Pedras,14,,-14.566667,-55.933333
br,pedras,Pedras,15,,-16.266667,-41.883333
br,pedras,Pedras,20,,-10,-45.35
br,pedras,Pedras,21,,-22.351563,-42.865162
br,pedras,Pedras,22,,-5.236944,-36.713889
br,pedras,Pedras,23,,-30.166667,-52.85
br,pedras,Pedras,27,,-23.466667,-45.9
br,pedras,Pedras,28,,-10.483333,-37.116667
br,pedras,Pedras,29,,-16.5,-51.433333
br,pedras,Pedras,30,,-8.466667,-36.216667
br,pedras pretas,Pedras Pretas,05,,-12.983333,-39.2
br,pedra tapada,Pedra Tapada,30,,-7.95,-35.633333
br,pedra verde,Pedra Verde,06,,-5.85,-39.15
br,pedra vermelha,Pedra Vermelha,05,,-10.35,-39.516667
br,pedra vermelha,Pedra Vermelha,27,,-23.246111,-46.530278
br,pedra vermelha,Pedra Vermelha,30,,-8.516667,-38.8
br,pedre d'agua,Pedre d'Agua,17,,-7.05,-37.816667
br,pedre grande,Pedre Grande,22,,-4.966667,-36.85
br,pedregulho,Pedregulho,05,,-11.133333,-43.533333
br,pedregulho,Pedregulho,11,,-20.1,-56.366667
br,pedregulho,Pedregulho,27,11216,-20.266667,-47.483333
br,pedreira do boqueirao,Pedreira do Boqueirão,22,,-5.837778,-36.063333
br,pedreira itaguacu,Pedreira Itaguaçu,26,,-27.244037,-49.710555
br,pedreira,Pedreira,05,,-12.666667,-38.95
br,pedreira,Pedreira,13,,-5.383333,-43.483333
br,pedreira,Pedreira,16,,-1.033333,-46.966667
br,pedreira,Pedreira,26,,-26.2,-48.933333
br,pedreira,Pedreira,27,39199,-22.716667,-46.916667
br,pedreira,Pedreira,30,,-7.716667,-38.666667
br,pedreira santa luzia,Pedreira Santa Luzia,21,,-22.783255,-43.773014
br,pedreiras,Pedreiras,04,,-4.439722,-62.265
br,pedreiras,Pedreiras,05,,-12.666667,-38.95
br,pedreiras,Pedreiras,06,,-4.033333,-38.4
br,pedreiras,Pedreiras,08,,-20.4,-41
br,pedreiras,Pedreiras,13,,-5.383333,-43.483333
br,pedreiras,Pedreiras,16,,-1.033333,-46.966667
br,pedreiras,Pedreiras,20,33909,-4.566667,-44.65
br,pedreiras,Pedreiras,23,,-32.033333,-53.05
br,pedreiras,Pedreiras,26,,-26.833333,-48.666667
br,pedreiras,Pedreiras,27,,-22.716667,-46.916667
br,pedreiras,Pedreiras,28,,-11.05,-37.183333
br,pedreiro,Pedreiro,06,,-5.366667,-39.483333
br,pedrinha,Pedrinha,20,,-10.05,-44.266667
br,pedrinha,Pedrinha,26,,-27.0855,-49.571
br,pedrinhas,Pedrinhas,05,,-10.6,-42.183333
br,pedrinhas,Pedrinhas,06,,-3.066667,-39.983333
br,pedrinhas,Pedrinhas,13,,-3.290278,-42.308333
br,pedrinhas,Pedrinhas,18,,-25.888507,-49.810626
br,pedrinhas,Pedrinhas,20,,-3.695,-42.534444
br,pedrinhas,Pedrinhas,21,,-22.316667,-41.916667
br,pedrinhas,Pedrinhas,22,,-4.957222,-37.099167
br,pedrinhas,Pedrinhas,27,,-22.816667,-50.783333
br,pedrinhas,Pedrinhas,28,,-11.2,-37.683333
br,pedrinho,Pedrinho,22,,-5.233333,-36.116667
br,pedrinhos,Pedrinhos,20,,-9.05,-45.933333
br,pedrinopolis,Pedrinópolis,15,,-19.216667,-47.466667
br,pedro affonso,Pedro Affonso,31,,-8.988611,-48.021389
br,pedro afonso,Pedro Afonso,31,,-8.988611,-48.021389
br,pedro americo,Pedro Américo,11,,-23.683333,-55.283333
br,pedro angelo,Pedro Ângelo,15,,-20.783333,-46.35
br,pedro antonio,Pedro Antônio,17,,-7.333333,-37.666667
br,pedro augusto,Pedro Augusto,15,,-21.433333,-45.816667
br,pedro avelino,Pedro Avelino,22,,-5.520278,-36.383611
br,pedro barros,Pedro Barros,27,,-24.25,-47.366667
br,pedro canga,Pedro Canga,11,,-21.166667,-56.15
br,pedro carlos,Pedro Carlos,21,,-22.257222,-43.956944
br,pedro celestino,Pedro Celestino,11,,-20.383333,-55.033333
br,pedro chaves,Pedro Chaves,15,,-19.4,-50.066667
br,pedro cubas,Pedro Cubas,27,,-24.563352,-48.273745
br,pedro da costa,Pedro da Costa,17,,-7.5,-36.866667
br,pedro dantas,Pedro Dantas,14,,-12.833333,-56.183333
br,pedro de freitas,Pedro de Freitas,03,,2.15,-50.85
br,pedro de toledo,Pedro de Toledo,27,,-24.283333,-47.233333
br,pedro do rio,Pedro do Rio,21,,-22.331667,-43.134167
br,pedro dos reis,Pedro dos Reis,15,,-21.4,-46.333333
br,pedro felicio,Pedro Felício,15,,-20.416667,-45.2
br,pedro ferreira,Pedro Ferreira,15,,-16.166667,-40.383333
br,pedro funil,Pedro Funil,13,,-8.35,-46.333333
br,pedro gomes,Pedro Gomes,11,,-18.066667,-54.533333
br,pedro grande,Pedro Grande,15,,-17.1,-40.75
br,pedro ii,Pedro II,20,22039,-4.416667,-41.466667
br,pedro julio,Pedro Júlio,15,,-21.35,-45.766667
br,pedro ledesma,Pedro Ledesma,11,,-23.5,-54.566667
br,pedro leopoldo,Pedro Leopoldo,15,49262,-19.633333,-44.05
br,pedro ligeiro,Pedro Ligeiro,31,,-7.4,-49.283333
br,pedro lustosa,Pedro Lustosa,18,,-25.816667,-51.85
br,pedro lustoza,Pedro Lustoza,18,,-25.816667,-51.85
br,pedro maciel,Pedro Maciel,14,,-15.75,-55.1
br,pedro manuailer,Pedro Manuailer,11,,-23.233333,-54.866667
br,pedro manwailer,Pedro Manwailer,11,,-23.233333,-54.866667
br,pedro marinho,Pedro Marinho,15,,-18.75,-41.666667
br,pedro melo,Pedro Melo,15,,-21.516667,-46.383333
br,pedro neto,Pedro Neto,27,,-21.266667,-47.616667
br,pedro offonso,Pedro Offonso,31,,-8.988611,-48.021389
br,pedro,Pedro,04,,-4.359167,-70.911667
br,pedro,Pedro,05,,-13.216667,-38.966667
br,pedro,Pedro,24,,-10.116667,-63.766667
br,pedro,Pedro,30,,-8.766667,-38.833333
br,pedro pereira,Pedro Pereira,15,,-18.55,-43.8
br,pedro pinheiro,Pedro Pinheiro,05,,-16.5,-39.95
br,pedro rodrigues,Pedro Rodrigues,15,,-20.483333,-45.233333
br,pedro rodrigues,Pedro Rodrigues,20,,-3.678611,-42.235556
br,pedrosa,Pedrosa,13,,-3.016667,-44.883333
br,pedrosa,Pedrosa,15,,-19.983333,-47.366667
br,pedrosa,Pedrosa,27,,-23.648713,-47.457449
br,pedro segundo,Pedro Segundo,06,,-7.35,-39.05
br,pedro segundo,Pedro Segundo,20,,-4.416667,-41.466667
br,pedro severo,Pedro Severo,11,,-17.666667,-54.033333
br,pedrosilandia,Pedrosilândia,13,,-3.4,-42.783333
br,pedro silva,Pedro Silva,15,,-20.283333,-45.2
br,pedroso,Pedroso,15,,-19.983333,-47.366667
br,pedroso,Pedroso,18,,-25.9569,-50.144755
br,pedros,Pedros,27,,-23.191519,-47.905438
br,pedro teixeira,Pedro Teixeira,15,,-21.716667,-43.733333
br,pedro toledo,Pedro Toledo,27,,-24.283333,-47.233333
br,pedro velho,Pedro Velho,17,,-7.483333,-35.566667
br,pedro velho,Pedro Velho,22,6366,-6.433333,-35.233333
br,pedro versiani,Pedro Versiani,15,,-17.866667,-41.316667
br,pedro viana,Pedro Viana,15,,-21.55,-46.333333
br,pedro xavier,Pedro Xavier,11,,-21.216667,-56.25
br,pega bem,Pega Bem,15,,-19.333333,-41.716667
br,pega-bom,Pega-Bom,15,,-19.333333,-41.716667
br,pegado,Pegado,22,,-5.733333,-35.7
br,peiropolis,Peirópolis,15,,-19.733333,-47.75
br,peiroval,Peiroval,14,,-16.1,-56.433333
br,peixe-boi,Peixe-Boi,16,,-1.2,-47.3
br,peixe bravo,Peixe Bravo,15,,-19.583333,-44.5
br,peixe cru,Peixe Cru,15,,-17.116667,-42.95
br,peixe de couro,Peixe de Couro,14,,-17.366667,-55.333333
br,peixe gordo,Peixe Gordo,06,,-5.216667,-38.216667
br,peixe,Peixe,02,,-9.3,-35.666667
br,peixe,Peixe,05,,-12.65,-40.633333
br,peixe,Peixe,06,,-4.6,-41.083333
br,peixe,Peixe,13,,-6.15,-43.95
br,peixe,Peixe,20,,-3.983333,-42.633333
br,peixe,Peixe,31,,-12.05,-48.533333
br,peixinho,Peixinho,31,,-11.255278,-47.725556
br,peixoto,Peixoto,04,,-7.086111,-70.747778
br,peixoto,Peixoto,05,,-12.6,-39.6
br,peixoto,Peixoto,17,,-7.133333,-37.866667
br,peixoto,Peixoto,25,,3.55,-60.416667
br,pejeu,Pejeú,20,,-8.183333,-41.4
br,pejucara,Pejuçara,23,,-28.433333,-53.633333
br,pela-beico,Péla-Beiço,05,,-13.65,-40.866667
br,pelada,Pelada,06,,-4.116667,-38.95
br,pelada,Pelada,22,,-5.683333,-35.6
br,pelado,Pelado,22,,-6,-36.45
br,pelado,Pelado,28,,-9.883333,-37.933333
br,pelame,Pelame,18,,-23.966667,-50.383333
br,pelego,Pelêgo,22,,-6.116667,-37.65
br,pe leve,Pé Leve,02,,-9.8,-36.583333
br,pelonio,Pelônio,13,,-3.406944,-42.594722
br,pelo sinal,Pelo Sinal,06,,-5.666667,-39.7
br,pelo-sinal,Pelo-Sinal,16,,-1.683333,-52.566667
br,pelo sinal,Pelo Sinal,17,,-7.966667,-36.833333
br,pelo sinal,Pelo Sinal,30,,-7.616667,-37.616667
br,pelotas,Pelotas,01,,-10.066667,-66.866667
br,pelotas,Pelotas,23,320680,-31.766667,-52.333333
br,pena final,Pena Final,22,,-5.983333,-35.9
br,pena forte,Pena Forte,06,,-7.766667,-39
br,penalva,Penalva,13,17186,-3.3,-45.166667
br,penamar,Penamar,05,,-12.766667,-43.95
br,pena,Pena,16,,-2.016667,-49.25
br,penapolis,Penápolis,01,,-9.966667,-67.8
br,penapolis,Penápolis,27,54478,-21.4,-50.066667
br,penasco,Penasco,05,,-9.916667,-43.416667
br,pendanga,Pendanga,08,,-19.85,-40.4
br,pendanga,Pendanga,13,,-7.616667,-46.066667
br,pendencia,Pendência,06,,-6.65,-38.85
br,pendencia,Pendência,17,,-7.05,-37.783333
br,pendencia,Pendência,22,,-5.263333,-36.723056
br,pendencias,Pendências,22,9363,-5.263333,-36.723056
br,pendotiba,Pendotiba,21,,-22.895833,-43.033611
br,pendurao,Pendurão,02,,-9.3,-36.233333
br,penedia,Penedia,15,,-19.833333,-43.65
br,penedo,Penedo,02,42099,-10.283333,-36.6
br,penedo,Penedo,05,,-12.633333,-40.933333
br,penedo,Penedo,13,,-6.05,-43.083333
br,penedo,Penedo,15,,-20.516667,-46.116667
br,penedo,Penedo,16,,-5.266667,-56.7
br,penedo,Penedo,20,,-6.316667,-41.65
br,penedo,Penedo,21,,-21.566667,-41.75
br,peneiras,Peneiras,15,,-21.283333,-46.633333
br,penha circular,Penha Circular,21,,-22.834969,-43.291878
br,penha colorada,Penha Colorada,24,,-9.783333,-65.333333
br,penha colorida,Penha Colorida,24,,-9.783333,-65.333333
br,penha de franca,Penha de França,15,,-18.083333,-43.05
br,penha de franca,Penha de França,27,,-23.533333,-46.533333
br,penha de itapocoroy,Penha de Itapocoroy,26,,-26.766667,-48.65
br,penha do capim,Penha do Capim,15,,-19.666667,-41.25
br,penha do cassiano,Penha do Cassiano,15,,-18.883333,-42.25
br,penha do chalet,Penha do Chalet,15,,-20.016667,-41.583333
br,penha do coco,Penha do Côco,15,,-20.016667,-41.583333
br,penha do franca,Penha do França,15,,-18.083333,-43.05
br,penha do norte,Penha do Norte,15,,-19.116667,-41.416667
br,penha do tapaua,Penha do Tapauá,04,,-5.756389,-64.383333
br,penha longa,Penha Longa,15,,-22.055833,-43.085833
br,penha,Penha,05,,-12.016667,-39.05
br,penha,Penha,06,,-5.716667,-40.533333
br,penha,Penha,08,,-19.75,-41.033333
br,penha,Penha,15,,-18.966667,-42.466667
br,penha,Penha,17,,-7.166667,-34.8
br,penha,Penha,18,,-24.666667,-50.516667
br,penha,Penha,21,,-21.283333,-41.75
br,penha,Penha,26,20097,-26.766667,-48.65
br,penha,Penha,27,,-23.533333,-46.533333
br,penido,Penido,15,,-21.716667,-43.55
br,peninsula green,Península Green,21,,-22.988087,-43.352923
br,pennapolis,Pennapolis,27,,-21.4,-50.066667
br,pensamento,Pensamento,11,,-21.233333,-55.183333
br,pensamento,Pensamento,13,,-3.727778,-42.764167
br,pensamento,Pensamento,18,,-24.333333,-52.666667
br,pensamento,Pensamento,20,,-5.916667,-41.966667
br,pensao sao francisco,Pensão São Francisco,29,,-15.933333,-49.2
br,pensao sao miguel,Pensão São Miguel,29,,-15.2,-48.683333
br,pensao seca,Pensão Sêca,14,,-15.833333,-55.133333
br,pentagna,Pentagna,21,,-22.158611,-43.754444
br,pentanha,Pentanha,21,,-22.158611,-43.754444
br,penteado,Penteado,27,,-24.508297,-48.302166
br,pentecoste,Pentecoste,06,19681,-3.8,-39.283333
br,pepagaio,Pepagaio,05,,-13.45,-42.6
br,pepital,Pepital,13,,-2.35,-44.433333
br,pequeri,Pequeri,15,,-21.834444,-43.119167
br,pequery,Pequery,15,,-21.834444,-43.119167
br,pequia,Pequiá,04,,-1.766667,-66.066667
br,pequia,Pequiá,08,,-20.283333,-41.766667
br,pequi,Pequi,05,,-10.233333,-43.116667
br,pequi,Pequi,13,,-3.018611,-43.451111
br,pequi,Pequi,15,,-15.933333,-42.433333
br,pequiri,Pequiri,11,,-17.7,-54.15
br,pequizeiro,Pequizeiro,13,,-3.055,-43.028611
br,pequizeiro,Pequizeiro,20,,-3.768056,-42.620833
br,pequizeiro,Pequizeiro,31,,-8.542778,-48.824444
br,pequy,Pequy,15,,-19.633333,-44.666667
br,peral do sobrado,Peral do Sobrado,23,,-30.6575,-52.3858
br,peral,Peral,18,,-24.835835,-48.992416
br,percevejo,Percevejo,05,,-14.833333,-41.266667
br,percos,Percos,20,,-7.6,-43.366667
br,perdicao,Perdição,08,,-20.383333,-41.566667
br,perdicoes,Perdições,13,,-6.716667,-43.866667
br,perdido,Perdido,11,,-21.766667,-57.283333
br,perdigao,Perdigão,15,,-19.95,-45.066667
br,perdizes de baixo,Perdizes de Baixo,13,,-2.883333,-44.316667
br,perdizes,Perdizes,05,,-12.433333,-45.4
br,perdizes,Perdizes,11,,-18.033333,-56.15
br,perdizes,Perdizes,15,,-19.35,-47.283333
br,perdizes,Perdizes,26,,-27,-51.133333
br,perdizes,Perdizes,31,,-11.650278,-48.716944
br,perdoes,Perdões,15,17821,-21.083333,-45.083333
br,perdoes,Perdões,27,,-23.133333,-46.466667
br,pereba,Pereba,02,,-9.45,-36.316667
br,peregrino,Peregrino,15,,-19.75,-48.133333
br,pereira barreto,Pereira Barreto,27,22537,-20.633333,-51.116667
br,pereira fogaca,Pereira Fogaça,18,,-24.710238,-48.662643
br,pereirao,Pereirão,20,,-5.666667,-41.45
br,pereira,Pereira,05,,-13.616667,-41.116667
br,pereira,Pereira,06,,-2.979167,-40.898333
br,pereira,Pereira,13,,-3.541944,-43.24
br,pereira,Pereira,15,,-18.416667,-48.566667
br,pereira,Pereira,16,,-1.033333,-46.966667
br,pereira,Pereira,30,,-8.116667,-40.483333
br,pereiras,Pereiras,06,,-4.316667,-39.8
br,pereiras,Pereiras,15,,-22.550257,-45.698039
br,pereiras,Pereiras,17,,-7.55,-37.95
br,pereiras,Pereiras,20,,-3.83,-42.236389
br,pereiras,Pereiras,27,,-22.366667,-47.7
br,pereiras,Pereiras,30,,-7.983333,-37.883333
br,pereirinha,Pereirinha,16,,-8.15,-57.583333
br,pereiro,Pereiro,06,,-6.05,-38.466667
br,pereiro,Pereiro,17,,-6.933333,-38.05
br,pereiro,Pereiro,20,,-6.866667,-42.516667
br,pereiros,Pereiros,20,,-6.966667,-41.116667
br,pereiros,Pereiros,22,,-5.085556,-36.983333
br,pereiros,Pereiros,30,,-7.933333,-37.966667
br,pereque,Perequê,26,,-27.155,-48.573333
br,perico,Pericó,26,,-28.166667,-49.75
br,perigara,Perigara,14,,-16.983333,-56.433333
br,perigoso,Perigoso,05,,-17,-39.65
br,perimbo,Perimbó,26,,-27.533333,-49.7
br,peri-mirim,Peri-Mirim,13,,-2.633333,-44.9
br,peripa,Peripá,05,,-14.933333,-41.716667
br,periperi de pocoes,Periperi de Poções,05,,-14.65,-40.483333
br,periperi,Periperi,02,,-9.666667,-36.4
br,periperi,Periperi,05,,-12.483333,-38.333333
br,periperi,Periperí,20,,-4.266667,-41.783333
br,peri-peri,Peri-Peri,20,,-7.6,-43.033333
br,periperi,Periperi,20,,-8.133333,-42.783333
br,peri-peri,Perí-Perí,30,,-8.083333,-35.366667
br,periperi,Periperi,30,,-8.55,-36.866667
br,peripery,Peripery,20,,-4.266667,-41.783333
br,peripery,Peripery,30,,-8.083333,-35.366667
br,peripiri,Peripiri,20,,-8.133333,-42.783333
br,peripueira,Peripueira,06,,-4.35,-37.933333
br,periquara,Periquara,06,,-3.383333,-39.016667
br,periquito,Periquito,04,,-7.316667,-60.35
br,periquito,Periquito,05,,-12.016667,-38.783333
br,periquito,Periquito,13,,-3.66,-43.457778
br,periquito,Periquito,15,,-19.166667,-42.25
br,periquito,Periquito,16,,-6.45,-58.05
br,periquitos,Periquitos,24,,-10.083333,-65.283333
br,periseiro,Periseiro,14,,-16.183333,-58.233333
br,perises de baixo,Perises de Baixo,13,,-2.883333,-44.316667
br,perises,Perises,13,,-2.916667,-44.35
br,peritoro,Peritoró,04,,-3.229444,-62.81
br,peritoro,Peritoró,13,,-4.333333,-44.3
br,peritoro,Peritoró,31,,-8.768889,-47.6225
br,perixil,Perixil,26,,-28.366667,-48.8
br,perizes de baixo,Perizes de Baixo,13,,-2.883333,-44.316667
br,perizes,Perizes,13,,-2.916667,-44.35
br,pernambuco,Pernambuco,04,,-7.016667,-71.533333
br,pernambuco,Pernambuco,05,,-12.683333,-43.216667
br,pernambuco,Pernambuco,08,,-20.966667,-40.866667
br,pernambuco,Pernambuco,16,,-1.466667,-48.033333
br,pernambuco,Pernambuco,27,,-24.8801,-48.077
br,pernambuco,Pernambuco,30,,-8.05,-34.9
br,pernambuquinha,Pernambuquinha,06,,-3.05,-39.633333
br,pernambuquinho,Pernambuquinho,06,,-3.05,-39.633333
br,pernambuquinho,Pernambuquinho,22,,-4.95,-37.166667
br,perobal,Perobal,18,,-23.9,-53.4
br,perobal,Perobal,27,,-23.5919,-47.9016
br,peroba,Peroba,02,,-8.916667,-35.15
br,peroba,Peroba,16,,-1.15,-46.466667
br,peroba,Peroba,18,,-23.383333,-50.883333
br,peroba,Peroba,27,,-20.966667,-49.566667
br,perobas,Perobas,15,,-19.266667,-45.9
br,perocao,Peroção,08,,-20.633333,-40.466667
br,perola d'oeste,Perola d'Oeste,18,,-23.8,-53.666667
br,perola do oeste,Pérola do Oeste,18,,-23.8,-53.666667
br,perola,Peróla,23,,-28.533333,-52.15
br,perpetua,Perpétua,15,,-15.2,-46
br,perpetuo socorro,Perpétuo Socorro,01,,-10,-66.766667
br,perpetuo socorro,Perpétuo Socorro,30,,-8.55,-36.733333
br,perrexil,Perrexil,26,,-28.366667,-48.8
br,perro cansado,Perro Cansado,14,,-15.533333,-60.35
br,perr socorro,Perr Socôrro,01,,-10,-66.766667
br,perseveranca,Perseverança,04,,-4.033333,-59.116667
br,perseveranca,Perseverança,11,,-21.616667,-56.966667
br,perseveranca,Perseverança,16,,-.933333,-47.983333
br,perta da hora,Perta da Hora,06,,-7.666667,-39.283333
br,pertile,Pertile,23,,-29.916667,-53.033333
br,peruanos,Peruanos,24,,-10.666667,-63.1
br,peruhibe,Peruhibe,27,,-24.316667,-47
br,peruhybe,Peruhybe,27,,-24.316667,-47
br,peruhype,Peruhype,05,,-17.716667,-39.566667
br,peruibe,Peruíbe,27,63032,-24.316667,-47
br,peruipe,Peruípe,05,,-17.766667,-39.616667
br,peruje,Perujé,02,,-9.533333,-37.283333
br,peru,Peru,05,,-13.566667,-41.233333
br,peru,Peru,13,,-1.483333,-44.783333
br,perus,Perus,20,,-4.133333,-41.266667
br,perus,Perus,27,,-23.405843,-46.746279
br,pery-pery,Pery-Pery,02,,-9.666667,-36.4
br,pescadores,Pescadores,26,,-27.033333,-48.583333
br,pescador,Pescador,15,,-18.366667,-41.6
br,pescaria brava,Pescaria Brava,26,,-28.383333,-48.883333
br,pescoco,Pescoço,04,,-4.824167,-59.304167
br,peso duro,Pêso Duro,31,,-5.466667,-47.7
br,pesoe,Pesoé,14,,-15.133333,-60.466667
br,pesqueirao,Pesqueirão,16,,-7.116667,-57.75
br,pesqueira,Pesqueira,30,41896,-8.366667,-36.7
br,pesqueirinha,Pesqueirinha,16,,-7.116667,-57.75
br,pesqueirinho,Pesqueirinho,16,,-7.116667,-57.75
br,pesqueirinho,Pesqueirinho,25,,2.416667,-60.85
br,pesqueiro,Pesqueiro,06,,-2.980278,-40.566944
br,pesqueiro,Pesqueiro,13,,-6.483333,-44.333333
br,pesqueiro,Pesqueiro,18,,-24.116667,-49.7
br,pesqueiro,Pesqueiro,23,,-29.7,-50.933333
br,pessegueiro,Pessegueiro,15,,-21.066667,-46.583333
br,pessegueiro,Pessegueiro,23,,-27.9,-54.433333
br,pessoa anta,Pessoa Anta,06,,-3.366667,-41
br,pessoa,Pessoa,02,,-9.233333,-35.35
br,petim,Petim,05,,-12.7,-39.25
br,petitinga,Petitinga,22,,-5.383333,-35.333333
br,petonha,Petonha,30,,-8.916667,-37.416667
br,petrolandia,Petrolândia,30,20575,-9.083333,-38.3
br,petrolina de goias,Petrolina de Goiás,29,7710,-16.1,-49.333333
br,petrolina,Petrolina,04,,-2.6,-67.133333
br,petrolina,Petrolina,29,,-16.1,-49.333333
br,petrolina,Petrolina,30,194653,-9.4,-40.5
br,petropolis,Petrópolis,21,272694,-22.510833,-43.184444
br,petropolis,Petrópolis,22,,-5.782222,-35.201667
br,petropolis,Petrópolis,23,,-30.041667,-51.1875
br,petrovina,Petrovina,14,,-16.766667,-54.116667
br,petunia,Petúnia,15,,-21.016667,-46.4
br,pexinho,Pexinho,31,,-11.255278,-47.725556
br,philadelphia,Philadelphia,24,,-9.1,-61.666667
br,philadelphia,Philadelphia,31,,-7.327222,-47.366111
br,piabanha,Piabanha,05,,-14.216667,-39.416667
br,piabanha,Piabanha,08,,-20.95,-40.9
br,piabanha,Piabanha,31,,-9.542222,-48.228056
br,piabas,Piabas,05,,-12.7,-38.166667
br,piabas,Piabas,06,,-4.233333,-39.866667
br,piabas,Piabas,13,,-3.827778,-42.766667
br,piabas,Piabas,16,,-1.2,-46.9
br,piabas,Piabas,21,,-23.024793,-43.52163
br,piabas,Piabas,22,,-5.925,-36.057222
br,piabeta,Piabetá,21,,-22.614722,-43.168611
br,piacaba,Piaçaba,20,,-6.316667,-41.733333
br,piacabucu,Piaçabuçu,02,9862,-10.4,-36.416667
br,piacaguera,Piaçaguera,18,,-25.479486,-48.475783
br,piaca,Piacá,30,,-8.25,-36.366667
br,piaca,Piacá,31,,-7.7,-47.3
br,piacatuba,Piacatuba,15,,-21.483333,-42.783333
br,piacatu,Piacatu,27,,-21.633333,-50.5
br,piacava,Piacava,20,,-5.5,-42.983333
br,piacu,Piaçu,08,,-20.35,-41.4
br,piador,Piador,20,,-7.966667,-41.833333
br,piai,Piaí,27,,-23.779,-47.2165
br,pianco,Piancó,15,,-18.7,-44.933333
br,pianco,Piancó,17,10482,-7.2,-37.95
br,piao,Pião,15,,-18.966667,-44.15
br,piao,Pião,21,,-21.25,-41.333333
br,piao,Pião,27,,-23.083333,-46.233333
br,piapitangui,Piapitangui,08,,-20.35,-40.45
br,piarore,Piarore,14,,-14.183333,-56.2
br,piassabussu,Piassabussu,02,,-10.4,-36.416667
br,piassaguera,Piassagüera,18,,-25.479486,-48.475783
br,piassava,Piassava,05,,-12.116667,-41.35
br,piata,Piatã,05,,-13.15,-41.8
br,piato,Piató,22,,-5.523889,-37.0075
br,piaui de dentro,Piaui de Dentro,06,,-4.666667,-38.283333
br,piaui,Piauí,15,,-16.966667,-41.85
br,piauna,Piaúna,05,,-14.283333,-39.4
br,piau,Piau,02,,-9.5,-37.666667
br,piau,Piau,15,,-21.516667,-43.316667
br,piau,Piau,22,,-6.233333,-35.133333
br,piaus,Piaus,17,,-7.583333,-38.033333
br,piavore,Piavoré,14,,-14.183333,-56.2
br,picada da linha,Picada da Linha,22,,-5.233333,-35.633333
br,picada do maia,Picada do Maia,23,,-32.466667,-53.55
br,picada do mata,Picada do Mata,23,,-32.466667,-53.55
br,picada dos porcos,Picada dos Porcos,20,,-3.768056,-42.475
br,picada do zuza,Picada do Zuza,05,,-14.25,-43.133333
br,picada hartz,Picada Hartz,23,,-29.583333,-50.916667
br,picada nova,Picada Nova,06,,-2.919722,-41.110833
br,picadao da baia,Picadão da Baia,26,,-26.667363,-49.964219
br,picada,Picada,02,,-9.5,-36.433333
br,picada,Picada,05,,-10.7,-41.733333
br,picada,Picada,06,,-7.316667,-38.983333
br,picada,Picada,13,,-3.618056,-42.956944
br,picada,Picada,14,,-17.216667,-54.683333
br,picada,Picada,17,,-6.883333,-38.15
br,picada,Picada,20,,-8.65,-42.15
br,picada,Picada,22,,-5.271111,-37.376389
br,picada,Picada,23,,-28.866667,-50.483333
br,picada,Picada,30,,-8.25,-36
br,picada velha,Picada Velha,13,,-3.719167,-43.045278
br,picadinha,Picadinha,11,,-22.15,-55.066667
br,picado do zuza,Picado do Zuza,05,,-14.25,-43.133333
br,picado,Picado,05,,-12.3,-38.7
br,pica pau,Pica Pau,17,,-7.666667,-38.033333
br,pica pau,Pica Pau,22,,-5.916667,-35.983333
br,picaras,Piçaras,05,,-12.633333,-41.366667
br,picarra,Piçarra,20,,-3.685556,-42.5975
br,picarras,Piçarras,05,,-12.633333,-41.366667
br,picarras,Piçarras,26,,-26.766667,-48.666667
br,piche,Piche,11,,-18.416667,-54.966667
br,pichore de baixo,Pichoré de Baixo,22,,-5.772222,-36.575
br,pichore,Pichoré,22,,-5.788333,-36.543889
br,pichunas,Pichunas,21,,-22.787243,-43.174163
br,pichuri,Pichuri,13,,-5.383333,-43.266667
br,picinguaba,Picinguaba,27,,-23.366667,-44.833333
br,pico agudo,Pico Agudo,18,,-23.747953,-50.209668
br,pico branco,Pico Branco,22,,-6.166667,-37.916667
br,pico dos antonios,Pico dos Antônios,20,,-5.4,-42.916667
br,pico,Pico,13,,-9.85,-46.416667
br,picos,Picos,02,,-9.5,-37.766667
br,picos,Picos,05,,-8.95,-38.616667
br,picos,Picos,13,,-6.033333,-44.233333
br,picos,Picos,17,,-7.566667,-38.283333
br,picos,Picos,20,57496,-7.083333,-41.466667
br,picos,Picos,22,,-6.033333,-37.583333
br,picos,Picos,28,,-9.683333,-37.9
br,picoto,Picôto,17,,-7.583333,-36.383333
br,picuhy,Picuhy,17,,-6.516667,-36.35
br,picui,Picuí,17,10779,-6.516667,-36.35
br,pidu,Pidu,06,,-6.15,-40.766667
br,piedade da ponte nova,Piedade da Ponte Nova,15,,-20.233333,-42.733333
br,piedade do bagre,Piedade do Bagre,15,,-18.783333,-44.916667
br,piedade do paraopeba,Piedade do Paraopeba,15,,-20.166667,-44.016667
br,piedade do rio grande,Piedade do Rio Grande,15,,-21.466667,-44.2
br,piedade dos geraes,Piedade dos Geraes,15,,-20.466667,-44.233333
br,piedade dos gerais,Piedade dos Gerais,15,,-20.466667,-44.233333
br,piedade,Piedade,05,,-12.783333,-39.983333
br,piedade,Piedade,06,,-4.366667,-39.516667
br,piedade,Piedade,15,,-19.766667,-42.083333
br,piedade,Piedade,21,,-22.116667,-41.616667
br,piedade,Piedade,27,27913,-23.713098,-47.414578
br,piedade,Piedade,30,,-8.183333,-34.916667
br,piem,Piem,18,,-26.0998,-49.4275
br,pien,Piên,18,,-26.0998,-49.4275
br,pieropolis,Pierópolis,15,,-19.733333,-47.75
br,pigui,Pigui,13,,-6.7,-43.783333
br,pilao arcado,Pilão Arcado,05,6715,-10.15,-42.433333
br,pilao d'agua,Pilao d'Agua,05,,-12.183333,-41.233333
br,pilao deitado,Pilão Deitado,14,,-14.95,-57.616667
br,pilao de pedra,Pilão de Pedra,18,,-25.6031,-48.9516
br,pilao de pedra,Pilão de Pedra,20,,-3.771111,-42.523333
br,pilao do gato,Pilão do Gato,02,,-9.083333,-37.383333
br,pilao,Pilão,04,,-5.723333,-60.94
br,pilao,Pilão,05,,-13.183333,-40.2
br,pilao,Pilão,11,,-21.1,-55.95
br,pilao,Pilão,28,,-11.016667,-38.1
br,pilao,Pilão,29,,-17.683333,-52.216667
br,pilao,Pilão,30,,-8.75,-37.2
br,pilaozinho,Pilãozinho,30,,-7.8,-38.433333
br,pilar de goias,Pilar de Goiás,29,,-14.683333,-49.45
br,pilar do sul,Pilar do Sul,27,19107,-23.816667,-47.7
br,pilares,Pilares,21,,-22.88478,-43.294909
br,pilar,Pilar,02,30617,-9.6,-35.933333
br,pilar,Pilar,04,,-5.75,-63.766667
br,pilar,Pilar,05,,-12.366667,-40.716667
br,pilar,Pilar,06,,-5.7,-38.266667
br,pilar,Pilar,17,7588,-7.25,-35.266667
br,pilar,Pilar,27,,-23.816667,-47.7
br,pilar,Pilar,29,,-14.683333,-49.45
br,pilar,Pilar,30,,-7.75,-34.833333
br,piloes de dentro,Pilões de Dentro,17,,-6.866667,-35.6
br,piloes do maia,Pilões do Maia,17,,-6.8,-35.566667
br,piloes,Pilões,05,,-13.566667,-41.616667
br,piloes,Pilões,06,,-3.3,-40.083333
br,piloes,Pilões,17,,-6.7,-38.516667
br,piloes,Pilões,20,,-3.946389,-42.743889
br,piloes,Pilões,22,,-6.133333,-37.866667
br,piloes,Pilões,27,,-22.666667,-45.316667
br,piloes,Pilões,30,,-7.866667,-39.05
br,pimenta bueno,Pimenta Bueno,24,25785,-11.65,-61.2
br,pimental,Pimental,04,,-4.466389,-59.183056
br,pimental,Pimental,16,,-4.566667,-56.2
br,pimenta,Pimenta,05,,-12.45,-41.316667
br,pimenta,Pimenta,08,,-20.383333,-40.45
br,pimenta,Pimenta,13,,-1.216667,-46.2
br,pimenta,Pimenta,15,,-20.466667,-45.8
br,pimenta,Pimenta,16,,-4.566667,-56.2
br,pimenta,Pimenta,22,,-5.761944,-37.340278
br,pimenta,Pimenta,29,,-18.7,-51.416667
br,pimentas,Pimentas,05,,-13.65,-39.233333
br,pimentas,Pimentas,15,,-18.966667,-46.083333
br,pimenteiral,Pimenteiral,11,,-18.8,-57.566667
br,pimenteira,Pimenteira,05,,-13.45,-38.983333
br,pimenteira,Pimenteira,06,,-7.15,-39.883333
br,pimenteira,Pimenteira,11,,-18.1,-54.916667
br,pimenteira,Pimenteira,14,,-16.633333,-56.083333
br,pimenteira,Pimenteira,20,,-6.233333,-41.416667
br,pimenteiras,Pimenteiras,05,,-13.45,-38.983333
br,pimenteiras,Pimenteiras,20,3819,-6.233333,-41.416667
br,pimenteiras,Pimenteiras,21,,-22.415078,-42.982841
br,pimenteiras,Pimenteiras,24,,-13.416667,-61.116667
br,pimentel,Pimentel,04,,-4.466389,-59.183056
br,pimentel,Pimentel,13,,-3.716667,-45.5
br,pimentel,Pimentel,30,,-8.6,-36.35
br,pimento,Pimento,08,,-20.383333,-40.45
br,pina,Pina,30,,-8.1,-34.883333
br,pinare,Pinaré,05,,-13.866667,-39.1
br,pinare,Pinaré,18,,-25.933333,-51.1
br,pindahyval,Pindahyval,14,,-17.15,-56.083333
br,pindaiba,Pindaíba,14,,-14.966667,-52.316667
br,pindaiba,Pindaíba,15,,-21.2,-43.05
br,pindaiba,Pindaíba,20,,-10.55,-45.266667
br,pindaiba,Pindaíba,27,,-21.15,-47.316667
br,pindaibas,Pindaíbas,15,,-15.016667,-44.233333
br,pindai,Pindaí,05,,-14.483333,-42.683333
br,pindaiuval,Pindaiuval,14,,-15.683333,-58.733333
br,pindaival,Pindaival,14,,-15.683333,-58.733333
br,pindamonhangaba,Pindamonhangaba,27,132220,-22.916667,-45.466667
br,pinda,Pindá,14,,-17,-55.883333
br,pindare-mirim,Pindaré-Mirim,13,,-3.616667,-45.35
br,pindare,Pindare,06,,-4.533333,-40.35
br,pindare,Pindaré,15,,-19.7,-44.05
br,pindauva do meio,Pindaúva do Meio,27,,-24.894,-48.0482
br,pindobacu,Pindobaçu,05,17242,-10.733333,-40.35
br,pindoba grande,Pindoba Grande,02,,-9.466667,-36.2
br,pindobal,Pindobal,04,,-6.314444,-61.798056
br,pindobal,Pindobal,16,,-3.228056,-48.359167
br,pindoba,Pindoba,02,,-9.466667,-36.2
br,pindoba,Pindoba,06,,-3.95,-41.066667
br,pindoba,Pindoba,08,,-20.4,-41.15
br,pindoba,Pindoba,13,,-4.3,-44.683333
br,pindoba,Pindoba,22,,-5.846111,-36.911944
br,pindobas,Pindobas,05,,-12.616667,-38.533333
br,pindobassu,Pindobassú,05,,-10.733333,-40.35
br,pindoguaba,Pindoguaba,06,,-3.75,-41.133333
br,pindo,Pindó,11,,-22.95,-54.983333
br,pindoral,Pindoral,04,,-4.516667,-57.5
br,pindorama do goias,Pindorama do Goias,31,,-11.171389,-47.473333
br,pindorama do tocantins,Pindorama do Tocantins,31,,-11.171389,-47.473333
br,pindorama,Pindorama,05,,-11.433333,-40.4
br,pindorama,Pindorama,23,,-28.3,-53.5
br,pindorama,Pindorama,27,12248,-21.2,-48.916667
br,pindorama,Pindorama,30,,-8.7,-36.45
br,pindorama,Pindorama,31,,-11.171389,-47.473333
br,pindoretama,Pindoretama,06,,-4.033333,-38.3
br,pindotiba,Pindotiba,26,,-28.4,-49.216667
br,pindoval,Pindoval,04,,-4.516667,-57.5
br,pindurao,Pindurão,17,,-7.866667,-36.65
br,pindurao,Pindurão,30,,-7.833333,-36.283333
br,pinduri,Pinduri,04,,-5.589167,-61.009722
br,pineiros,Pineiros,18,,-23.844347,-50.139206
br,pingador,Pingador,14,,-15.066667,-55.8
br,pingador,Pingador,26,,-27,-51.833333
br,pinga fogo,Pinga Fogo,30,,-7.733333,-37.633333
br,pinga,Pinga,06,,-6.116667,-40.816667
br,pinga,Pinga,20,,-7.266667,-41.116667
br,pinhais,Pinhais,15,,-19.716667,-43.833333
br,pinhalao,Pinhalão,18,,-23.791305,-50.057482
br,pinhal da serra,Pinhal da Serra,23,,-27.866667,-51.15
br,pinhal grande,Pinhal Grande,23,,-29.35,-53.266667
br,pinhalito,Pinhalito,18,,-24.95,-52.716667
br,pinhal,Pinhal,15,,-21.233333,-45.35
br,pinhal,Pinhal,18,,-23.4,-50.3
br,pinhal,Pinhal,23,,-27.866667,-51.15
br,pinhal,Pinhal,27,,-22.2,-46.75
br,pinhal preto,Pinhal Prêto,18,,-25.616667,-52.45
br,pinhal ralo,Pinhal Ralo,18,,-25.433333,-52.6
br,pinhalzinho,Pinhalzinho,15,,-22.633333,-45.916667
br,pinhalzinho,Pinhalzinho,18,,-24.133333,-52.8
br,pinhalzinho,Pinhalzinho,23,,-27.566667,-51.95
br,pinhalzinho,Pinhalzinho,26,,-26.8,-52.95
br,pinhalzinho,Pinhalzinho,27,,-22.766667,-46.6
br,pinhao grande,Pinhão Grande,05,,-9.433333,-39.85
br,pinhao,Pinhão,02,,-9.283333,-37.2
br,pinhao,Pinhão,05,,-9.366667,-39.516667
br,pinhao,Pinhão,17,,-6.583333,-38.3
br,pinhao,Pinhão,18,15141,-25.716667,-51.633333
br,pinhao,Pinhão,22,,-5.5225,-37.216944
br,pinhao,Pinhão,28,,-10.566667,-37.733333
br,pinhaozeiro,Pinhãozeiro,02,,-9.266667,-37.183333
br,pinhaozinho,Pinhãozinho,02,,-9.266667,-37.183333
br,pinhaozinho,Pinhãozinho,18,,-24.5,-53.15
br,pinheiral de baixo,Pinheiral de Baixo,18,,-25.480833,-50.101389
br,pinheiral de cima,Pinheiral de Cima,18,,-25.512799,-50.091022
br,pinheiral,Pinheiral,21,19469,-22.516667,-43.983333
br,pinheiral,Pinheiral,26,,-27.416667,-49.1
br,pinheira,Pinheira,06,,-7.283333,-38.633333
br,pinheira,Pinheira,26,,-27.887222,-48.588611
br,pinheiras,Pinheiras,27,,-22.533333,-44.9
br,pinheirinho baixo,Pinheirinho Baixo,26,,-28.95,-49.783333
br,pinheirinho,Pinheirinho,18,,-23.765447,-50.121622
br,pinheirinho,Pinheirinho,23,,-29.466667,-54.416667
br,pinheirinho,Pinheirinho,27,,-22.716667,-47.483333
br,pinheirinhos,Pinheirinhos,15,,-22.433333,-44.983333
br,pinheirinhos,Pinheirinhos,18,,-24.983333,-50.366667
br,pinheirinhos,Pinheirinhos,27,,-22.4,-47.933333
br,pinheiro chagas,Pinheiro Chagas,15,,-21.05,-44.1
br,pinheiro de baixo,Pinheiro de Baixo,05,,-14.716667,-42.283333
br,pinheiro machado,Pinheiro Machado,23,11176,-31.566667,-53.383333
br,pinheiro marcado,Pinheiro Marcado,23,,-28.283333,-53.05
br,pinheiro,Pinheiro,05,,-12.583333,-38.55
br,pinheiro,Pinheiro,06,,-4.933333,-40.533333
br,pinheiro,Pinheiro,13,38894,-2.516667,-45.083333
br,pinheiro,Pinheiro,15,,-18.7,-43.05
br,pinheiro,Pinheiro,16,,-1.3,-48.466667
br,pinheiro,Pinheiro,18,,-24.905756,-48.826069
br,pinheiro,Pinheiro,21,,-22.516667,-43.983333
br,pinheiro,Pinheiro,27,,-20.983333,-47.183333
br,pinheiro preto,Pinheiro Prêto,26,,-27.05,-51.2
br,pinheiros altos,Pinheiros Altos,15,,-20.566667,-43.266667
br,pinheiros de baixo,Pinheiros de Baixo,05,,-14.716667,-42.283333
br,pinheiro seco,Pinheiro Sêco,18,,-24.733333,-49.566667
br,pinheiros,Pinheiros,13,,-2.516667,-45.083333
br,pinheiros,Pinheiros,15,,-18.083333,-43.633333
br,pinheiros,Pinheiros,18,,-23.454747,-49.753292
br,pinheiros,Pinheiros,23,,-29.783333,-52.733333
br,pinheiros,Pinheiros,26,,-26.4131,-48.6441
br,pinheiros,Pinheiros,27,,-20.983333,-47.183333
br,pinhel,Pinhel,16,,-2.916667,-55.233333
br,pinhe,Pinhé,11,,-19.7,-54.316667
br,pinho de baixo,Pinho de Baixo,18,,-25.3855,-50.6959
br,pinho de cima,Pinho de Cima,18,,-25.3951,-50.7441
br,pinhoes,Pínhões,06,,-3.866667,-38.883333
br,pinhoes,Pinhões,15,,-19.716667,-43.833333
br,pinhoes,Pinhões,20,,-7.466667,-41.783333
br,pinhoes,Pinhões,22,,-5.7,-35.733333
br,pinho,Pinho,18,,-25.366667,-50.733333
br,pinhotiba,Pinhotiba,15,,-20.966667,-42.183333
br,pintada,Pintada,05,,-11.85,-42.7
br,pintada,Pintada,13,,-3.905,-42.738333
br,pintada,Pintada,15,,-15.483333,-42.333333
br,pintada,Pintada,20,,-6.35,-43.7
br,pintada,Pintada,23,,-30.033333,-51.25
br,pintada,Pintada,30,,-8.966667,-36.516667
br,pintadas,Pintadas,05,,-11.816667,-39.933333
br,pintadas,Pintadas,20,,-3.333333,-42.133333
br,pintadinha,Pintadinha,17,,-7.933333,-36.666667
br,pintadinha,Pintadinha,30,,-7.9,-39.633333
br,pintado,Pintado,30,,-7.966667,-37.416667
br,pinta,Pinta,13,,-3.166667,-44.8
br,pinto bandeira,Pinto Bandeira,23,,-29.1,-51.45
br,pinto,Pinto,15,,-18.416667,-48.066667
br,pinto,Pinto,20,,-3.603333,-42.489444
br,pintos negreiro,Pintos Negreiro,15,,-22.3,-45.216667
br,pintos negreiros,Pintos Negreiros,15,,-22.3,-45.216667
br,pintos,Pintos,06,,-7.666667,-39.183333
br,pintos,Pintos,15,,-22.6379,-45.5185
br,pintos,Pintos,27,,-22.9,-47.316667
br,pintos,Pintos,28,,-10.966667,-37.2
br,pio anastacio,Pio Anastácio,15,,-21.116667,-46.7
br,pioes,Piões,20,,-6.85,-41.25
br,pio ix,Pio IX,20,4973,-6.833333,-40.616667
br,pioneiros,Pioneiros,27,,-20.5,-47.833333
br,pio nono,Pio Nôno,20,,-6.833333,-40.616667
br,pio xii,Pio XII,13,14773,-3.883333,-45.283333
br,pio x,Pio X,06,,-6.633333,-38.783333
br,pipa,Pipa,22,,-6.233333,-35.05
br,pipeiras,Pipeiras,21,,-21.8,-41.133333
br,pipinuque,Pipinuque,08,,-18.666667,-40.466667
br,pipipa,Pipipã,30,,-8.466667,-38.1
br,pipoco,Pipôco,22,,-5.895278,-37.153611
br,piquara,Piquara,05,,-13.6,-38.966667
br,piquera,Piquera,27,,-23.84388,-47.24302
br,piquerobi,Piquerobi,27,,-21.883333,-51.733333
br,piqueroby,Piqueroby,27,,-21.883333,-51.733333
br,piquet carneiro,Piquet Carneiro,06,,-5.8,-39.416667
br,piquete,Piquete,02,,-8.983333,-35.866667
br,piquete,Piquete,27,13845,-22.6,-45.183333
br,piquete velho,Piquete Velho,18,,-24.916667,-50.766667
br,piquet velho,Piquet Velho,18,,-24.916667,-50.766667
br,piquia,Piquiá,04,,-1.766667,-66.066667
br,piqui,Piqui,05,,-10.233333,-43.116667
br,piqui,Piqui,13,,-6.7,-43.783333
br,piqui,Piqui,20,,-6.85,-43.05
br,piquira,Piquira,27,,-23.236413,-47.523991
br,piquiri,Piquiri,11,,-17.7,-54.15
br,piquiri,Piquiri,14,,-17.166667,-56.566667
br,piquiri,Piquirí,18,,-24.95,-51.933333
br,piquiri,Piquiri,22,,-5.090278,-37.191389
br,piquizeiro,Piquizeiro,13,,-3.616667,-43.583333
br,piquizeiro,Piquizeiro,20,,-9.633333,-44.85
br,piquizeiro,Piquizeiro,31,,-8.542778,-48.824444
br,pirabeiraba,Pirabeiraba,26,,-26.2,-48.933333
br,pirabibu,Pirabibu,06,,-5.033333,-39.35
br,piracaia,Piracaia,27,26076,-23.05,-46.35
br,piracaiba,Piracaíba,15,,-18.483333,-48.433333
br,piracanjuba,Piracanjuba,29,16736,-17.3,-49.016667
br,piracaua,Piracaua,16,,-3.15,-47.983333
br,piracema,Piracema,08,,-20.183333,-41.183333
br,piracema,Piracema,15,,-20.516667,-44.483333
br,piracema,Piracema,18,,-22.933333,-52.616667
br,piracema,Piracema,21,,-22.066667,-43.15
br,piracicaba,Piracicaba,15,,-18.483333,-48.433333
br,piracicaba,Piracicaba,27,342216,-22.716667,-47.633333
br,piracununga,Piraçununga,27,,-21.983333,-47.416667
br,piracuruca,Piracuruca,20,18852,-3.933333,-41.7
br,piragiba,Piragiba,05,,-12.2,-43.85
br,piraguara,Piraguara,15,,-20.8,-43.333333
br,piraguara,Piraguara,18,,-25.433333,-49.066667
br,piragutanga,Piragutanga,11,,-19.3,-57.583333
br,pirahy,Pirahy,18,,-24.516667,-49.933333
br,pirahy,Pirahy,21,,-22.627778,-43.901944
br,piraiauara,Piraiauara,04,,-4.533333,-62.066667
br,pirai do norte,Piraí do Norte,05,,-13.75,-39.366667
br,pirai do sul,Piraí do Sul,18,16409,-24.516667,-49.933333
br,pirai-mirim,Piraí-Mirim,18,,-24.516667,-49.933333
br,piraim,Piraim,14,,-16.183333,-56.016667
br,pirainha,Pirainha,11,,-20.166667,-55.75
br,pirai,Piraí,18,,-24.516667,-49.933333
br,pirai,Piraí,21,19105,-22.627778,-43.901944
br,pirai,Piraí,23,,-28.6,-51.783333
br,pirai,Piraí,27,,-23.2,-45.583333
br,piraiuara,Piraiuara,04,,.783333,-67.533333
br,pirajai,Pirajaí,27,,-22.466667,-49.333333
br,piraja,Pirajá,05,,-12.25,-41.15
br,piraja,Pirajá,06,,-6.266667,-40.6
br,piraja,Pirajá,20,,-8.983333,-44.666667
br,piraja,Pirajá,27,,-20.933333,-49.65
br,pirajiba,Pirajiba,05,,-12.2,-43.85
br,pirajuba,Pirajuba,15,,-19.9,-48.7
br,pirajuhia,Pirajuhia,05,,-12.966667,-38.8
br,pirajuhy,Pirajuhy,27,,-21.983333,-49.483333
br,pirajuia,Pirajuia,05,,-12.966667,-38.8
br,pirajui,Pirajuí,27,17503,-21.983333,-49.483333
br,piraju,Pirajú,18,,-23.754693,-50.595667
br,piraju,Piraju,27,25271,-23.2,-49.383333
br,piramboia,Pirambóia,27,,-22.916667,-48.15
br,pirambu,Pirambu,28,,-10.733333,-36.866667
br,piranema,Piranema,21,,-22.83733,-43.711348
br,pirangai,Pirangaí,21,,-22.566667,-44.616667
br,piranga,Piranga,15,,-20.683333,-43.3
br,pirangi do norte,Pirangi do Norte,22,,-5.966667,-35.133333
br,pirangi do sul,Pirangi do Sul,22,,-5.983333,-35.116667
br,pirangi,Pirangi,05,,-14.683333,-39.366667
br,pirangi,Pirangi,06,,-4.583333,-38.35
br,pirangi,Pirangi,27,,-21.083333,-48.65
br,piranguassu,Piranguassú,15,,-22.516667,-45.5
br,pirangucu,Piranguçu,15,,-22.516667,-45.5
br,piranguinho,Piranguinho,15,,-22.4,-45.533333
br,pirangussu,Pirangussu,15,,-22.516667,-45.5
br,pirangy do sul,Pirangy do Sul,22,,-5.983333,-35.116667
br,pirangy,Pirangy,27,,-21.083333,-48.65
br,piranha,Piranha,02,,-9.816667,-37.016667
br,piranha,Piranha,05,,-12.8,-41.183333
br,piranha,Piranha,13,,-3.067778,-42.208056
br,piranha,Piranha,17,,-6.583333,-37.616667
br,piranha,Piranha,18,,-23.494634,-50.06424
br,piranhaquara,Piranhaquara,16,,-4.154722,-52.621111
br,piranhas,Piranhas,02,1170,-9.45,-37.766667
br,piranhas,Piranhas,04,,-2.416667,-65.466667
br,piranhas,Piranhas,05,,-12.8,-41.183333
br,piranhas,Piranhas,06,,-4.75,-41.1
br,piranhas,Piranhas,13,,-2.2,-45.75
br,piranhas,Piranhas,20,,-7,-40.9
br,piranhas,Piranhas,22,,-6.1,-37.75
br,piranhas,Piranhas,29,9887,-16.516667,-51.85
br,piranhas velhas,Piranhas Velhas,17,,-7.033333,-38.483333
br,piranji do norte,Piranji do Norte,22,,-5.966667,-35.133333
br,piranji do sul,Piranji do Sul,22,,-5.983333,-35.116667
br,piranji,Piranji,06,,-4.583333,-38.35
br,piranji,Piranji,27,,-21.083333,-48.65
br,piranj,Piranj,05,,-14.683333,-39.366667
br,pirao,Pirao,04,,-4.746389,-62.299167
br,pirapama,Pirapama,15,,-19.016667,-44.016667
br,pirapanema,Pirapanema,15,,-21.066667,-42.5
br,pirapema,Pirapema,13,,-2.333333,-44.4
br,pirapemas,Pirapemas,13,6441,-3.716667,-44.233333
br,pirapetinga do bom jesus,Pirapetinga do Bom Jesus,21,,-21.083333,-41.783333
br,pirapetinga,Pirapetinga,04,,-7.033333,-62.866667
br,pirapetinga,Pirapetinga,15,,-20.133333,-42.3
br,pirapetinga,Pirapetinga,24,,-9.466667,-64.166667
br,pira,Pirá,04,,.066667,-67.533333
br,pira,Pira,05,,-10.85,-43.2
br,pirapiringa,Pirapiringa,04,,-7.033333,-62.866667
br,pirapitanga,Pirapitanga,11,,-19.3,-57.583333
br,pirapitangui,Pirapitangui,08,,-20.35,-40.45
br,pirapitinga,Pirapitinga,04,,-7.033333,-62.866667
br,pirapitinga,Pirapitinga,18,,-23.128152,-52.219595
br,pirapitingui,Pirapitingui,27,,-23.366667,-47.333333
br,pirapitinguy,Pirapitinguy,27,,-23.366667,-47.333333
br,pirapituba,Pirapituba,15,,-21.666667,-46.516667
br,pirapo,Pirapó,18,,-23.4,-51.533333
br,pirapo,Pirapó,23,,-28.033333,-55.25
br,pirapora do bom jesus,Pirapora do Bom Jesus,27,14690,-23.4,-47
br,pirapora,Pirapora,01,,-8.448056,-72.821389
br,pirapora,Pirapora,15,51657,-17.35,-44.933333
br,pirapora,Pirapora,27,,-23.093325,-47.660215
br,pirapora,Pirapóra,30,,-7.783333,-39.183333
br,piraporinha,Piraporinha,27,,-23.638,-47.5136
br,pirapozinho,Pirapòzinho,27,21711,-22.25,-51.5
br,pirapucu,Pirapucu,04,,-4.206389,-65.108333
br,piraputanga,Piraputanga,11,,-20.433333,-55.533333
br,piraputangas,Piraputangas,11,,-19.3,-57.583333
br,piraputangas,Piraputangas,14,,-16.3,-56.133333
br,piraquara,Piraquara,15,,-20.8,-43.333333
br,piraquara,Piraquara,18,41162,-25.433333,-49.066667
br,piraquara,Piraquara,21,,-22.880412,-43.424854
br,piraque,Piraque,31,,-6.756944,-48.159167
br,pirara,Pirará,25,,3.05,-61.15
br,pirarema,Pirarema,04,,-5.255833,-60.252778
br,pirarucu,Pirarucu,04,,-3.057222,-61.626667
br,pirassinunga,Pirassinunga,27,,-21.983333,-47.416667
br,pirassununga,Pirassununga,27,60414,-21.983333,-47.416667
br,pirataba,Pirataba,23,,-29.25,-49.866667
br,piratininga,Piratininga,11,,-17.85,-56.366667
br,piratininga,Piratininga,21,,-22.95,-43.083333
br,piratininga,Piratininga,27,,-22.383333,-49.15
br,piratini,Piratini,11,,-22.866667,-54.833333
br,piratini,Piratini,23,,-31.45,-53.1
br,piratiny,Piratiny,23,,-31.45,-53.1
br,pirat,Pirat,23,,-28.6,-51.783333
br,piratuba,Piratuba,26,,-27.45,-51.8
br,piratuba,Piratuba,27,,-23.65274,-47.333525
br,piraua,Pirauá,17,,-7.6,-35.583333
br,pirauba,Piraúba,15,,-21.283333,-43.033333
br,pirauna,Piraúna,05,,-14.283333,-39.4
br,pirenopolis,Pirenópolis,29,13615,-15.85,-48.95
br,pires de albuquerque,Pires de Albuquerque,15,,-16.916667,-43.733333
br,pires de baixo,Pires de Baixo,27,,-22.590833,-47.321944
br,pires de cima,Pires de Cima,27,,-22.558611,-47.360278
br,pires do meio,Pires do Meio,27,,-22.572222,-47.341944
br,pires do rio,Pires do Rio,29,24823,-17.3,-48.283333
br,pires e albuquerque,Pires e Albuquerque,15,,-16.916667,-43.733333
br,pires ferreira,Pires Ferreira,06,,-4.25,-40.633333
br,pires ferreiva,Pires Ferreiva,06,,-4.25,-40.633333
br,pires morais,Pires Morais,15,,-20.8,-45.366667
br,pires,Pires,03,,.433333,-52.166667
br,pires,Pires,14,,-15.466667,-55.95
br,pires,Pires,15,,-20.433333,-43.85
br,pires,Pires,27,,-22.133333,-47.233333
br,pirianito,Pirianito,18,,-23.2,-50.816667
br,piria,Piriá,16,,-1.666667,-50.033333
br,piri grande,Piri Grande,16,,.066667,-50
br,pirina ii,Pirinã II,13,,-3.080278,-43.380556
br,pirina i,Pirinã I,13,,-3.469167,-43.272222
br,pirina,Pirinã,13,,-3.694722,-43.421667
br,piripa,Piripá,05,,-14.933333,-41.716667
br,piriperi,Piriperi,05,,-12.483333,-38.333333
br,piriperi,Piriperi,20,,-7.6,-43.033333
br,piri,Piri,05,,-9.65,-41.433333
br,piripiri,Piripiri,05,,-12.866667,-38.466667
br,piripiri,Piripiri,20,44866,-4.266667,-41.783333
br,piripiri,Piripiri,27,,-23.056491,-47.761903
br,piririca,Piririca,27,,-24.557459,-48.443055
br,piritiba,Piritiba,05,16230,-11.733333,-40.566667
br,piritoro,Piritoró,31,,-8.768889,-47.6225
br,pirituba,Pirituba,27,,-23.489824,-46.732203
br,pirituba,Pirituba,30,,-8.083333,-35.366667
br,pirizal,Pirizal,14,,-16.266667,-56.383333
br,pirizeiro,Pirizeiro,14,,-16.183333,-58.233333
br,pirpirituba,Pirpirituba,17,8355,-6.766667,-35.5
br,pirracao,Pirracao,15,,-20.433333,-42.716667
br,piscamba,Piscamba,15,,-20.433333,-42.716667
br,pitanga,Pitanga,05,,-12.666667,-38.55
br,pitanga,Pitanga,06,,-3.816667,-40.966667
br,pitanga,Pitanga,08,,-20.166667,-40.283333
br,pitanga,Pitanga,15,,-15.166667,-44.366667
br,pitanga,Pitanga,18,18652,-24.766667,-51.733333
br,pitanga,Pitanga,21,,-22.116667,-41.316667
br,pitanga,Pitanga,23,,-27.533333,-54.383333
br,pitangas,Pitangas,21,,-22.116667,-41.316667
br,pitangueira,Pitangueira,11,,-20.883333,-56.7
br,pitangueira,Pitangueira,15,,-21.283333,-45.416667
br,pitangueiras,Pitangueiras,11,,-20.883333,-56.7
br,pitangueiras,Pitangueiras,18,,-23.2,-51.583333
br,pitangueiras,Pitangueiras,21,,-22.817442,-43.179756
br,pitangueiras,Pitangueiras,23,,-29.833333,-50.516667
br,pitangueiras,Pitangueiras,27,28541,-21.033333,-48.216667
br,pitangui,Pitangui,02,,-9.083333,-35.266667
br,pitangui,Pitangui,15,18859,-19.666667,-44.9
br,pitangui,Pitangui,22,,-5.633333,-35.233333
br,pitanguy,Pitanguy,15,,-19.666667,-44.9
br,pitimbu da cruz,Pitimbu da Cruz,22,,-5.916667,-35.333333
br,pitimbu,Pitimbu,17,7862,-7.466667,-34.8
br,pitimbu,Pitimbu,22,,-5.916667,-35.3
br,pitingao,Pitingão,06,,-3.566667,-39.683333
br,pitinga,Pitinga,05,,-12.666667,-38.55
br,pititinga,Pititinga,22,,-5.383333,-35.333333
br,pito aceso,Pito Aceso,27,,-22.083333,-50.416667
br,pitombas,Pitombas,05,,-9.416667,-43.216667
br,pitombas,Pitombas,17,,-8.166667,-37.05
br,pitombeira de baixo,Pitombeira de Baixo,13,,-3.638889,-43.366389
br,pitombeira dos alves,Pitombeira dos Alves,13,,-3.719722,-43.423333
br,pitombeira ii,Pitombeira II,13,,-3.649167,-43.367778
br,pitombeira,Pitombeira,05,,-13.483333,-41.6
br,pitombeira,Pitombeira,06,,-3.766667,-39.416667
br,pitombeira,Pitombeira,13,,-3.310278,-42.348333
br,pitombeira,Pitombeira,17,,-6.516667,-38.016667
br,pitombeira,Pitombeira,20,,-3.420556,-42.047778
br,pitombeira,Pitombeira,22,,-5.786111,-37.355556
br,pitombeira,Pitombeira,30,,-7.833333,-39.65
br,pitombeiras,Pitombeiras,06,,-2.883333,-40.166667
br,pitombeiras,Pitombeiras,13,,-3.835,-42.805
br,pitombeiras,Pitombeiras,20,,-4.75,-41.216667
br,pitombos,Pitombos,17,,-8.166667,-37.05
br,pituba,Pituba,05,,-13,-38.45
br,pituba,Pituba,22,,-5.983333,-35.416667
br,pituba,Pituba,27,,-21.966667,-46.833333
br,pituna,Pituna,04,,.033333,-67.5
br,piui,Piuí,15,,-20.466667,-45.966667
br,piuma,Piúma,08,17634,-20.833333,-40.716667
br,pium de cima,Pium de Cima,22,,-5.983333,-35.216667
br,piumhy,Piumhy,15,,-20.466667,-45.966667
br,pium,Pium,22,,-5.933333,-35.15
br,pium,Pium,25,,2.967185,-59.982582
br,pium,Pium,31,,-10.45,-49.095278
br,piunzinho,Piunzinho,31,,-10.387222,-49.200278
br,piuva grande,Piúva Grande,14,,-16.433333,-57.066667
br,piuval,Piuval,14,,-16.333333,-57.8
br,piuva,Piúva,11,,-18.883333,-57.633333
br,piuva,Piúva,14,,-13.483333,-56.1
br,piva,Piva,18,,-26.047778,-53.725556
br,pixaim,Pixaim,06,,-3.1,-39.55
br,pixaim,Pixaim,14,,-16.735833,-56.837222
br,pixe,Pixe,11,,-18.416667,-54.966667
br,pixo,Pixo,11,,-18.416667,-54.966667
br,pizunha,Pizunha,06,,-2.95,-40.216667
br,placa de piedade,Placa de Piedade,30,,-7.283333,-37.25
br,placa dois,Placa Dois,18,,-23.257269,-52.590323
br,placa paraiso,Placa Paraíso,20,,-5.716667,-42.6
br,placa,Placa,20,,-5.716667,-42.6
br,placa,Placa,30,,-7.416667,-39.883333
br,placas,Placas,13,,-3.567778,-42.686111
br,placido de castro,Plácido de Castro,01,11950,-10.333333,-67.183333
br,placido silveira,Plácido Silveira,23,,-30.866667,-54.35
br,placina,Placina,18,,-23.3134,-50.0088
br,planaltina do parana,Planaltina do Paraná,18,,-23.016667,-52.966667
br,planaltina,Planaltina,07,88855,-15.616667,-47.666667
br,planalto do sul,Planalto do Sul,27,,-22.3,-52.216667
br,planalto,Planalto,15,,-16.833333,-40.933333
br,planalto,Planalto,23,,-27.333333,-53.05
br,planalto,Planalto,27,,-21.05,-49.916667
br,planalto,Planalto,31,,-11.933333,-47.25
br,planchao,Planchão,14,,-14.616667,-56.133333
br,planeta,Planeta,04,,-3.016667,-67.866667
br,plano alto,Plano Alto,23,,-29.783333,-56.533333
br,planura,Planura,15,,-20.133333,-48.7
br,plataforma,Plataforma,05,,-12.883333,-38.483333
br,plataform,Plataform,05,,-12.883333,-38.483333
br,platina,Platina,18,,-23.3134,-50.0088
br,platina,Platina,27,,-22.633333,-50.233333
br,plinio silveira,Plínio Silveira,21,,-21.166667,-41.666667
br,p. lopes,P. Lopes,11,,-21.833333,-53.6
br,poaca,Poacá,23,,-29.983333,-52.366667
br,poacos,Poacos,30,,-7.85,-39.916667
br,poaia,Poaia,15,,-18.316667,-42.2
br,poa,Poá,27,107434,-23.533333,-46.333333
br,pobre,Pobre,20,,-7.266667,-42.466667
br,pocao de pedra,Poção de Pedra,13,,-4.75,-44.933333
br,pocao de pedras,Poção de Pedras,13,12337,-4.75,-44.933333
br,pocao de pedro,Pocão de Pedro,13,,-4.75,-44.933333
br,pocao,Poção,02,,-9.666667,-36.616667
br,pocao,Poção,04,,-6.016667,-61.6
br,pocao,Poção,05,,-18.1,-39.916667
br,pocao,Poção,11,,-20.383333,-54.45
br,pocao,Poção,13,,-3.851667,-43.3225
br,pocao,Poção,15,,-18.883333,-45.333333
br,pocao,Poção,16,,-1.383333,-48.666667
br,pocao,Poção,17,,-7.183333,-37.55
br,pocao,Poção,20,,-10.466667,-45.116667
br,pocao,Poção,27,,-20.433333,-49.266667
br,pocao,Poção,30,,-8.183333,-36.7
br,pocas,Poças,05,,-11.783333,-37.533333
br,pocete,Pocête,22,,-5.645278,-36.869722
br,pochica,Pochica,13,,-2.8,-42.35
br,pocidonio muniz,Pocidônio Muniz,15,,-16.983333,-40.983333
br,pocinho de cima,Pocinho de Cima,17,,-7.116667,-37.966667
br,pocinho,Pocinho,11,,-21.816667,-57.45
br,pocinho,Pocinho,14,,-15.983333,-56.033333
br,pocinho,Pócinho,17,,-7.033333,-37.616667
br,pocinho,Pocinho,26,,-26.510502,-49.567778
br,pocinho,Pocinho,30,,-7.566667,-37.533333
br,pocinhos de cima,Poçinhos de Cima,20,,-7.15,-40.816667
br,pocinhos do rio verde,Pocinhos do Rio Verde,15,,-21.933333,-46.416667
br,pocinhos,Pocinhos,06,,-4.016667,-38.866667
br,pocinhos,Pocinhos,17,7803,-7.066667,-36.05
br,pocinhos,Poçinhos,20,,-7.133333,-40.816667
br,poco azul,Poço Azul,14,,-15.983333,-54.466667
br,poco baixo,Poço Baixo,30,,-7.8,-37.166667
br,poco bonito,Poço Bonito,18,,-25.634197,-50.635822
br,poco branco,Poço Branco,02,,-8.933333,-37.816667
br,poco branco,Poço Branco,22,7112,-5.633333,-35.666667
br,poco cabeco preto,Poço Cabeço Prêto,22,,-5.416667,-35.983333
br,poco caldas,Poço Caldas,15,,-21.8,-46.566667
br,poco central,Poço Central,05,,-14.383333,-39.6
br,poco cercado,Poço Cercado,06,,-6.083333,-40.633333
br,poco cercado,Poço Cercado,17,,-6.566667,-38.35
br,poco cercado,Poço Cercado,30,,-8.083333,-39.783333
br,poco comprido,Poço Comprido,02,,-9.133333,-37.483333
br,poco comprido,Poço Comprido,05,,-12.366667,-40.816667
br,poco comprido,Poço Comprido,06,,-3.216667,-39.783333
br,poco comprido,Poço Comprido,20,,-5.05,-41.183333
br,poco comprido,Poco Comprido,22,,-5.666667,-35.383333
br,poco comprido,Poço Comprido,30,,-9.05,-36.4
br,pococs,Pocõcs,31,,-11.983333,-47.6
br,poco da abelha,Poço da Abelha,02,,-9.6,-36.616667
br,poco da agua,Poço da Água,05,,-12.866667,-41.25
br,poco da anta,Poço da Anta,20,,-8.883333,-42.283333
br,poco da cajazeira,Poço da Cajàzeira,17,,-6.766667,-38.266667
br,poco da colher,Poço da Colher,30,,-9.2,-38.116667
br,poco da cruz,Poço da Cruz,06,,-7.166667,-40.416667
br,poco da cruz,Poco da Cruz,17,,-6.266667,-37.383333
br,poco da cruz,Poço da Cruz,30,,-8.333333,-37.716667
br,poco da draga,Poço da Draga,06,,-3.719444,-38.518056
br,poco d'agua,Poco d'Agua,05,,-12.866667,-41.25
br,poco d'agua,Poco d'Agua,20,,-6.35,-41.866667
br,poco da ilha,Poço da Ilha,04,,-3.079167,-63.144444
br,poco da isabel,Poço da Isabel,05,,-12.666667,-40.45
br,poco da jiboia,Poço da Jibóia,15,,-20.716667,-45.883333
br,poco da julia,Poço da Júlia,02,,-9.683333,-36.633333
br,poco d'anta,Poco d'Anta,05,,-13.033333,-43.75
br,poco d'anta,Poco d'Anta,08,,-20.916667,-41.516667
br,poco d'anta,Poco d'Anta,20,,-6.183333,-42.783333
br,poco danta,Poço Danta,20,,-7.85,-41.133333
br,poco d'anta,Poco d'Anta,21,,-22.583333,-42.283333
br,poco d'antas,Poco d'Antas,05,,-12.066667,-38.216667
br,poco dantas,Poço Dantas,05,,-13.766667,-40.066667
br,poco dantas,Poço Dantas,17,,-6.45,-38.466667
br,poco dantas,Poço Dantas,20,,-7.85,-41.133333
br,poco d'antas,Poco d'Antas,23,,-29.45,-51.666667
br,poco da onca,Poço da Onça,02,,-9.116667,-37.433333
br,poco da onca,Poço da Onça,05,,-9.733333,-40.233333
br,poco da onca,Poço da Onça,06,,-5.216667,-40.266667
br,poco da pedra,Poço da Pedra,05,,-12.2,-40.8
br,poco da pedra,Poço da Pedra,06,,-3.416667,-41.4
br,poco da pedra,Poço da Pedra,17,,-6.65,-38.216667
br,poco da pedra,Poço da Pedra,20,,-7.7,-41.766667
br,poco da pedra,Poço da Pedra,22,,-6.25,-38.05
br,poco da pedra,Poço da Pedra,30,,-8.316667,-38.116667
br,poco da porta,Poço da Porta,05,,-12.266667,-44.733333
br,poco da porta,Poço da Porta,30,,-8.416667,-38.516667
br,poco da prefeitura,Poço da Prefeitura,22,,-5.483333,-37.75
br,poco d'arco,Poco d'Arco,05,,-12.866667,-39.533333
br,poco da roca,Poço da Roça,05,,-12.166667,-39.216667
br,poco da roca,Poço da Roça,30,,-8.816667,-38.666667
br,poco das antas,Poço das Antas,23,,-29.45,-51.666667
br,poco das eguas,Poço das Éguas,13,,-3.904722,-42.89
br,poco das pedras,Poço das Pedras,06,,-5.15,-38.183333
br,poco das pedras,Poço das Pedras,20,,-7.666667,-41.7
br,poco das pedras,Poço das Pedras,22,,-5.191389,-37.235556
br,poco das trincheiras,Poço das Trincheiras,02,1775,-9.3,-37.266667
br,poco de alexandra,Poço de Alexandra,30,,-8.666667,-37.85
br,poco de arroz,Poço de Arroz,20,,-8.516667,-41.233333
br,poco de baixo,Poço de Baixo,05,,-12.516667,-39.4
br,poco de baixo,Poço de Baixo,06,,-6,-40.016667
br,poco de boi,Poço de Boi,30,,-8.433333,-37.65
br,poco de embira,Poço de Embira,05,,-12.116667,-42.5
br,poco de fora,Poço de Fora,05,,-9.616667,-39.783333
br,poco de fumo,Poço de Fumo,30,,-8.15,-39.733333
br,poco de pato,Poço de Pato,30,,-8.316667,-36.616667
br,poco de pau,Poço de pau,06,,-7.55,-38.833333
br,poco de pedra,Poço de Pedra,05,,-10.233333,-43.466667
br,poco de pedra,Poço de Pedra,06,,-4.7,-39.6
br,poco de pedra,Poco de Pedra,17,,-7.083333,-36.633333
br,poco de pedra,Poço de Pedra,20,,-9.9,-44.583333
br,poco de pedra,Poço de Pedra,30,,-8.333333,-38.916667
br,poco de pedras,Poço de Pedras,05,,-9.783333,-38.866667
br,poco de pedras,Poço de Pedras,13,,-3.859722,-43.234167
br,poco de pedras,Poço de Pedras,21,,-23.027344,-43.561588
br,poco do acude,Poço do Açude,17,,-6.416667,-38.2
br,poco do alexandre,Poço do Alexandre,30,,-8.666667,-37.85
br,poco do arco,Poço do Arco,05,,-12.866667,-39.533333
br,poco do arroz,Poço do Arroz,20,,-8.516667,-41.233333
br,poco do banco,Poço do Banco,13,,-5.15,-43.266667
br,poco do boi,Poco do Boi,17,,-7.566667,-36.983333
br,poco do boi,Poço do Boi,20,,-7.583333,-41.066667
br,poco do boi,Poço do Boi,30,,-8.433333,-37.65
br,poco do cachorro,Poço do Cachorro,17,,-7.516667,-38.05
br,poco do cavalo,Poço do Cavalo,20,,-7.05,-40.666667
br,poco do cavalo,Poço do Cavalo,30,,-8.216667,-36.683333
br,poco doce,Poço Doce,06,,-3.433333,-39.1
br,poco doce,Poco Doce,17,,-7.516667,-36.183333
br,poco do contrabando,Poço do Contrabando,23,,-30.566667,-56.25
br,poco do couro,Poço do Couro,06,,-6.116667,-40.016667
br,poco do ferro,Poço do Ferro,06,,-6.65,-39.45
br,poco do girau,Poço do Giraú,20,,-10.133333,-43.85
br,poco do ininga,Poço do Ininga,20,,-5.483333,-41.483333
br,poco do jirau,Poço do Jirau,20,,-10.133333,-43.85
br,poco do joa,Poço do Joá,06,,-3.2,-40.35
br,poco do jua,Poco do Juá,17,,-7.133333,-36.3
br,poco do juazeiro,Poço do Juazeiro,20,,-7.016667,-40.666667
br,poco do luciano,Poço do Luciano,06,,-4.883333,-41.133333
br,poco do mato,Poço do Mato,05,,-12.633333,-44.15
br,poco do meio,Poço do Meio,05,,-12.433333,-44.266667
br,poco do meio,Poço do Meio,22,,-5.448333,-37.3775
br,poco do pato,Poço do Pato,30,,-8.316667,-36.616667
br,poco do porco,Poço do Porco,30,,-7.566667,-39.533333
br,poco dos antas,Poço dos Antas,23,,-29.45,-51.666667
br,poco dos cavalos,Poço dos Cavalos,06,,-3.366667,-39.316667
br,poco dos cavalos,Poço dos Cavalos,17,,-6.883333,-38.033333
br,poco do umbuzeiro,Poco do Umbuzeiro,30,,-7.733333,-38.35
br,poco escuro,Poco Escuro,06,,-4.183333,-38.616667
br,poco escuro,Poço Escuro,17,,-7.1,-37.766667
br,pocoes,Poções,05,35255,-14.516667,-40.35
br,pocoes,Poções,13,,-3.466389,-43.408056
br,pocoes,Poções,20,,-10.466667,-45.116667
br,pocoes,Pocões,29,,-16.65,-50.15
br,pocoes,Poções,31,,-11.983333,-47.6
br,poco ferreira,Poço Ferreira,25,,1.883333,-61.016667
br,poco fundo,Poço Fundo,15,,-21.8,-45.966667
br,poco fundo,Poço Fundo,20,,-10.133333,-44.2
br,poco fundo,Poco Fundo,30,,-7.95,-36.333333
br,poco gordo,Poço Gordo,21,,-21.816667,-41.233333
br,poco grande,Poço Grande,06,,-4.983333,-39.916667
br,poco grande,Poço Grande,14,,-15.683333,-56.083333
br,poco grande,Poço Grande,18,,-24.916667,-49.05
br,poco grande,Poço Grande,27,,-24.521231,-48.508474
br,poco imperial,Poço Imperial,06,,-2.983333,-41.133333
br,poco iriruba,Poço Iriruba,25,,1.55,-60.683333
br,poco limpo,Poço Limpo,22,,-5.816667,-35.55
br,poco longe,Poço Longe,05,,-12.083333,-40.583333
br,pocone,Poconé,14,21485,-16.259722,-56.626944
br,poco novo,Poço Nôvo,17,,-7.4,-37.9
br,poco novo,Poço Nôvo,22,,-5.2,-37.583333
br,poco perdido,Poço Perdido,22,,-5.183333,-37.6
br,poco,Poço,05,,-10.5,-40.4
br,poco,Poço,06,,-3.8,-38.716667
br,poco,Poço,14,,-15.066667,-56.5
br,poco,Poço,15,,-16.083333,-40.033333
br,poco,Poço,17,,-6.566667,-38.516667
br,poco,Poço,18,,-24.583333,-50.566667
br,poco,Poço,20,,-6.683333,-40.933333
br,poco,Poço,27,,-20.416667,-47.866667
br,poco,Poço,30,,-8.916667,-37.083333
br,poco preto,Poço Prêto,06,,-6.35,-40.716667
br,poco preto,Poço Prêto,26,,-26.283333,-50.883333
br,poco redondo,Poço Redondo,05,,-11.066667,-38.85
br,poco redondo,Poço Redondo,06,,-4.933333,-37.95
br,poco redondo,Poço Redondo,13,,-3.543333,-42.691667
br,poco redondo,Poco Redondo,22,,-5.966667,-36.183333
br,poco redondo,Poço Redondo,28,,-9.816667,-37.683333
br,poco rico,Poço Rico,14,,-14.9,-56.633333
br,poco salgado,Poço Salgado,02,,-9.333333,-37.233333
br,poco salgado,Poço Salgado,06,,-3.35,-40.283333
br,pocos de caldas,Poços de Caldas,15,146590,-21.8,-46.566667
br,poco seguro,Poço Seguro,06,,-5.45,-39.216667
br,pocos,Poços,02,,-9.416667,-37.45
br,pocos,Poços,05,,-12.016667,-43.066667
br,pocos,Pocos,06,,-4.4,-38.7
br,pocos,Poços,13,,-3.563333,-43.066389
br,pocos,Poços,14,,-16.05,-56.466667
br,pocos,Poços,17,,-7.633333,-38.166667
br,pocos,Poços,20,,-3.511111,-42.504444
br,pocos,Pocos,22,,-5.466667,-35.45
br,pocos,Poços,30,,-7.85,-38.5
br,poco triste,Poço Triste,05,,-13.533333,-41.616667
br,poco verde,Poço Verde,06,,-3.45,-39.633333
br,poco verde,Poço Verde,13,,-3.933611,-42.884444
br,poco verde,Poço Verde,22,,-5.486944,-37.3025
br,poco verde,Poço Verde,26,,-28.833333,-49.666667
br,poco verde,Poço Verde,28,12167,-10.7,-38.183333
br,poco-verde,Poço-Verde,30,,-7.65,-40.116667
br,poco verde,Poço Verde,30,,-7.833333,-39.766667
br,pocrane,Pocrane,15,,-19.616667,-41.616667
br,podimirim,Podimirim,06,,-7.3,-38.95
br,poeirama,Poeirama,02,,-9.416667,-36.566667
br,poeira,Poeira,04,,-7.199722,-70.860278
br,poeira,Poeira,05,,-9.616667,-40.033333
br,poeira,Poeira,11,,-20.383333,-56.316667
br,poeiras,Poeiras,11,,-20.383333,-56.316667
br,poimro,Poimró,16,,1.1,-54.666667
br,poiri,Poiri,05,,-14.333333,-39.333333
br,poiso alto,Poiso Alto,15,,-22.183333,-44.966667
br,poiungu,Poiungu,04,,-3.816667,-69.4
br,pojuca,Pojuca,05,25102,-12.35,-38.333333
br,pojuca,Pojuca,30,,-8.4,-35.066667
br,pojuquinha,Pojuquinha,05,,-12.6,-38.05
br,pojuquinhas,Pojuquinhas,05,,-12.6,-38.05
br,pojuquinhos,Pojuquinhos,05,,-12.6,-38.05
br,pokhrane,Pokhrane,15,,-19.616667,-41.616667
br,polaquia,Polaquia,26,,-26.9369,-49.2108
br,policarpo duarte,Policarpo Duarte,23,,-30.65,-55.583333
br,policarpo,Policarpo,16,,-5.283333,-56.016667
br,polidoro,Polidoro,23,,-28.366667,-52.25
br,polinopolis,Polinópolis,18,,-23.283333,-52.016667
br,poli velho,Poli Velho,20,,-5.033333,-42.833333
br,poloni,Poloni,27,,-20.766667,-49.8
br,polo verde,Polo Verde,20,,-7.3,-40.733333
br,polungu,Polungu,04,,-3.816667,-69.4
br,polvora,Pólvora,11,,-18.15,-53.966667
br,polycarpo,Polycarpo,16,,-5.283333,-56.016667
br,pombal,Pombal,04,,-6.733333,-62.366667
br,pombal,Pombal,05,,-10.833333,-38.533333
br,pombal,Pombal,16,,-2.35,-52
br,pombal,Pombal,17,21751,-6.766667,-37.783333
br,pombal,Pombal,21,,-22.5,-44.25
br,pombal,Pombal,27,,-23.866667,-47.75
br,pomba,Pomba,06,,-5.766667,-40.75
br,pomba,Pomba,15,,-21.283333,-43.183333
br,pombas,Pombas,05,,-12.916667,-40.416667
br,pombas,Pombas,14,,-15.933333,-54.7
br,pombas,Pombas,17,,-7.316667,-36.65
br,pombas,Pombas,18,,-25.180921,-48.962151
br,pombas,Pombas,23,,-30.316667,-51.016667
br,pombeira,Pombeira,15,,-19.15,-48.266667
br,pombinhas,Pombinhas,13,,-3.816667,-44.583333
br,pombinhas,Pombinhas,18,,-25.033333,-50.25
br,pombinhas,Pombinhas,20,,-5.533333,-42.95
br,pombinhas,Pombinhas,26,,-27.25,-50
br,pombinho,Pombinho,17,,-7.433333,-38.316667
br,pombinhos,Pombinhos,13,,-3.816667,-44.583333
br,pombo,Pombo,05,,-12,-39.05
br,pombos,Pombos,13,,-6,-43.3
br,pombos,Pombos,20,,-6.166667,-41.716667
br,pombos,Pombos,30,15895,-8.15,-35.4
br,pomeranos,Pomeranos,26,,-26.8159,-49.238
br,pomeranos santo antonio,Pomeranos Santo Antônio,26,,-26.761,-49.2351
br,pomeranos sao roque,Pomeranos São Roque,26,,-26.7781,-49.2465
br,pomerode,Pomerode,26,21898,-26.75,-49.183333
br,pompa,Pompa,11,,-21.8,-54.716667
br,pompeia,Pompéia,17,,-6.583333,-38.25
br,pompeia,Pompéia,27,18015,-22.133333,-50.166667
br,pompeiro,Pompeiro,04,,-7.133333,-69.616667
br,pompeo,Pompéo,15,,-19.2,-44.983333
br,pompeu,Pompeu,11,,-19.416667,-57.483333
br,pompeu,Pompeu,15,25278,-19.166667,-45.1
br,pompeu,Pompeu,16,,-7.283333,-57.866667
br,pompeu velho,Pompeu Velho,15,,-19.35,-44.883333
br,pompilio marques,Pompílio Marques,07,,-15.566667,-47.766667
br,pompuanas,Pompuanas,04,,-5.393056,-62.801389
br,pompunhas,Pompunhas,04,,-5.393056,-62.801389
br,ponagua,Ponagua,20,,-6.633333,-41.95
br,ponciana,Ponciana,22,,-5.324167,-36.780278
br,ponciano,Ponciano,01,,-7.883333,-72.75
br,ponciano,Ponciano,02,,-9.916667,-36.833333
br,poncianos,Poncianos,15,,-19.9,-48.2
br,ponde,Pondé,05,,-11.883333,-38.166667
br,pongahy,Pongahy,27,,-21.75,-49.383333
br,pongai,Pongaí,27,,-21.75,-49.383333
br,ponta aguda,Ponta Aguda,05,,-12.716667,-39.666667
br,ponta alegre,Ponta Alegre,04,,-4.568056,-59.862778
br,ponta alegre,Ponta Alegre,05,,-13.116667,-38.783333
br,ponta alegre,Ponta Alegre,16,,-6.316667,-57.8
br,ponta alegre,Ponta Alegre,30,,-8.733333,-36.683333
br,ponta alto,Ponta Alto,21,,-21.083333,-41.9
br,ponta cal,Ponta Cal,11,,-22.616667,-55.283333
br,ponta curua,Ponta Curuá,03,,.733333,-50.25
br,ponta da arara,Ponta da Arara,04,,-4.149167,-60.915278
br,ponta da areia,Ponta da Areia,05,,-12.9,-38.666667
br,ponta da areia,Ponta da Areia,21,,-22.975138,-43.633391
br,ponta da cruz,Ponta da Cruz,05,,-13.066667,-38.683333
br,ponta da divisao,Ponta da Divisão,14,,-8.9,-58.5
br,ponta da fruta,Ponta da Fruta,08,,-20.516667,-40.433333
br,ponta d'agua,Ponta d'Agua,05,,-10.9,-43.35
br,ponta-d'agua,Ponta-d'Agua,20,,-3.971667,-42.675833
br,ponta d'agua,Ponta d'Agua,20,,-6.416667,-41.333333
br,ponta d'agua,Ponta d'Agua,31,,-11.916667,-48.85
br,ponta da mata,Ponta da Mata,27,,-20.8,-47.916667
br,ponta da pita,Ponta da Pita,18,,-25.4565,-48.69
br,ponta d'areia,Ponta d'Areia,05,,-17.733333,-39.233333
br,ponta da serra,Ponta da Serra,05,,-11.766667,-43.066667
br,ponta da serra,Ponta da Serra,17,,-6.533333,-37.616667
br,ponta da serra,Ponta da Serra,20,,-6.133333,-41.816667
br,ponta da serra,Ponta da Serra,22,,-5.736667,-36.120278
br,ponta da serra,Ponta da Serra,27,,-21.116667,-47.65
br,ponta da serra,Ponta da Serra,29,,-13.166667,-47.05
br,ponta da serra,Ponta da Serra,31,,-11.316667,-48.633333
br,ponta da vargem,Ponta da Vargem,30,,-8.6,-37.316667
br,ponta de aratuba,Ponta de Aratuba,05,,-13.083333,-38.733333
br,ponta de nossa senhora,Ponta de Nossa Senhora,05,,-12.816667,-38.65
br,ponta de pedra,Ponta de Pedra,05,,-12.25,-39.75
br,ponta de pedras,Ponta de Pedras,16,,-1.383333,-48.866667
br,ponta de pedras,Ponta de Pedras,30,,-7.633333,-34.8
br,ponta de ramos,Ponta de Ramos,16,,-.75,-47.8
br,ponta do anel,Ponta do Anel,20,,-2.9,-41.45
br,ponta do campo,Ponta do Campo,14,,-16.216667,-56.133333
br,ponta do flechal,Ponta do Flechal,16,,-6.933333,-58.233333
br,ponta do funil,Ponta do Funil,30,,-7.683333,-34.833333
br,ponta do lanco,Ponta do Lanço,18,,-25.325704,-48.409024
br,ponta do largo,Ponta do Largo,05,,-17.516667,-39.45
br,ponta do leone,Ponta do Leone,05,,-12.966667,-38.95
br,ponta do malhado,Ponta do Malhado,05,,-14.75,-39.033333
br,ponta do mangue,Ponta do Mangue,02,,-8.933333,-35.166667
br,ponta do mangue,Ponta do Mangue,13,,-2.583333,-42.75
br,ponta do mel,Ponta do Mel,22,,-4.95,-36.883333
br,ponta do morro,Ponta do Morro,13,,-6.666667,-43.25
br,ponta do morro,Ponta do Morro,20,,-5.366667,-42.416667
br,ponta do muta,Ponta do Mutá,05,,-13.866667,-38.933333
br,ponta do paraguacu,Ponta do Paraguaçu,05,,-12.85,-38.8
br,ponta do pasto,Ponta do Pasto,18,,-25.426975,-48.418842
br,ponta do peixoto,Ponta do Peixoto,04,,-3.253333,-62.908611
br,ponta do ramo,Ponta do Ramo,05,,-14.6,-39.05
br,ponta do ramos,Ponta do Ramos,16,,-.75,-47.8
br,ponta do rei,Ponta do Rei,26,,-26.3883,-48.614
br,ponta dos indios,Ponta dos Índios,03,,4.066667,-51.633333
br,ponta grande,Ponta Grande,04,,-4.458056,-62.238056
br,ponta grossa dos fidalgos,Ponta Grossa dos Fidalgos,21,,-21.933333,-41.333333
br,ponta grossa,Ponta Grossa,05,,-13.016667,-38.7
br,ponta grossa,Ponta Grossa,18,292179,-25.083333,-50.15
br,ponta grossa,Ponta Grossa,26,,-28.283333,-48.783333
br,pontais,Pontais,17,,-7.416667,-38.366667
br,pontal da barra,Pontal da Barra,02,,-10.5,-36.4
br,pontal de sao joao da barra,Pontal de São João da Barra,05,,-14.8125,-39.033333
br,pontal do cururipe,Pontal do Cururipe,02,,-10.166667,-36.133333
br,pontal do itarare,Pontal do Itararé,18,,-25.866667,-48.95
br,pontal do parana,Pontal do Paraná,18,14969,-25.58,-48.354167
br,pontal do peba,Pontal do Peba,02,,-10.35,-36.283333
br,pontal dos ilheus,Pontal dos Ilhéus,05,,-14.833333,-39.016667
br,pont' alegre,Pont' Alegre,22,,-6.033333,-38
br,pontalete,Pontalete,15,,-21.45,-45.666667
br,pontalina,Pontalina,29,13640,-17.516667,-49.45
br,pontalinda,Pontalinda,27,,-20.45,-50.5
br,pontal,Pontal,02,,-10.166667,-36.133333
br,pontal,Pontal,05,,-11.533333,-38.85
br,pontal,Pontal,11,,-19.683333,-52.816667
br,pontal,Pontal,15,,-16.766667,-42.033333
br,pontal,Pontal,22,,-6.083333,-38.05
br,pontal,Pontal,26,,-26.166667,-48.6
br,pontal,Pontal,27,32567,-21.05,-48.083333
br,pontal,Pontal,29,,-17.783333,-50.216667
br,pontal,Pontal,31,,-5.933333,-47.683333
br,ponta mofina,Ponta Mofina,02,,-10.366667,-36.55
br,ponta mufina,Ponta Mufina,02,,-10.366667,-36.55
br,ponta natal,Ponta Natal,04,,-5.551667,-60.786111
br,ponta negra,Ponta Negra,22,,-5.883333,-35.166667
br,ponta nossa senhora,Ponta Nossa Senhora,05,,-12.816667,-38.65
br,pontao,Pontão,01,,-9.816667,-67.333333
br,pontao,Pontão,05,,-12.866667,-38.3
br,pontao,Pontão,23,,-27.916667,-51.533333
br,ponta,Ponta,05,,-13.983333,-38.983333
br,ponta,Ponta,16,,-1.55,-47.883333
br,ponta,Ponta,27,,-21.466667,-46.683333
br,ponta,Ponta,30,,-8.933333,-37.4
br,ponta pora,Ponta Porã,11,55765,-22.533333,-55.716667
br,ponta rasa,Ponta Rasa,26,,-28.316667,-48.75
br,pontas de pedra,Pontas de Pedra,30,,-7.633333,-34.8
br,ponta seca,Ponta Sêca,13,,-1.583333,-45.116667
br,ponte alegre,Ponte Alegre,04,,-8.95,-67.833333
br,ponte alta de cima,Ponte Alta de Cima,26,,-27.133333,-50.466667
br,ponte alta do bom jesus,Ponte Alta do Bom Jesus,31,,-12.142222,-46.401944
br,ponte alta do norte,Ponte Alta do Norte,26,,-27.133333,-50.466667
br,ponte alta do norte,Ponte Alta do Norte,31,,-10.773611,-47.4075
br,ponte alta do tocantins,Ponte Alta do Tocantins,31,,-10.773611,-47.4075
br,ponte alta,Ponte Alta,14,,-15.416667,-55.283333
br,ponte alta,Ponte Alta,15,,-20.083333,-41.716667
br,ponte alta,Ponte Alta,18,,-25.468083,-48.857524
br,ponte alta,Ponte Alta,21,,-21.083333,-41.9
br,ponte alta,Ponte Alta,26,,-27.133333,-50.466667
br,ponte alta,Ponte Alta,27,,-22.433333,-47.1
br,ponte alta,Ponte Alta,31,,-10.773611,-47.4075
br,ponte alto de cima,Ponte Alto de Cima,26,,-27.133333,-50.466667
br,ponte bella,Ponte Bella,01,,-7.866667,-73.483333
br,ponte branca,Ponte Branca,14,,-16.45,-52.666667
br,ponte caida,Ponte Caída,15,,-19.033333,-43.8
br,ponte coberta,Ponte Coberta,21,,-22.673611,-43.816667
br,ponte da grama,Ponte da Grama,21,,-22.2,-42.133333
br,ponte d'agua,Ponte d'Agua,05,,-10.166667,-42.066667
br,ponte das araras,Ponte das Araras,15,,-19.15,-42.766667
br,ponte das carrolhos,Ponte das Carrolhos,30,,-8.233333,-34.966667
br,ponte da tabua,Ponte da Tábua,15,,-21.416667,-45.366667
br,ponte de itabapoana,Ponte de Itabapoana,08,,-21.2,-41.466667
br,ponte de pedra,Ponte de Pedra,14,,-13.583333,-57.35
br,ponte de pedra,Ponte de Pedra,15,,-20.95,-45.15
br,ponte de pedras,Ponte de Pedras,14,,-17.1,-54.383333
br,ponte de ramas,Ponte de Ramas,16,,-.75,-47.8
br,ponte do cigano,Ponte do Cigano,15,,-16.521667,-44.286667
br,ponte do palmito,Ponte do Palmito,08,,-20.816667,-41.5
br,ponte do parauna,Ponte do Paraúna,15,,-18.633333,-44.083333
br,ponte dos carvalhos,Ponte dos Carvalhos,30,,-8.233333,-34.966667
br,ponte dos ciganos,Ponte dos Ciganos,15,,-16.521667,-44.286667
br,ponte dos jesuitas,Ponte dos Jesuítas,21,,-22.873315,-43.676076
br,ponte dos leites,Ponte dos Leites,21,,-22.9,-42.366667
br,ponte do souza,Ponte do Souza,21,,-22.2674,-44.3942
br,ponte e lacerda,Ponte e Lacerda,14,,-15.2,-59.366667
br,ponte falsa,Ponte Falsa,14,,-15.516667,-55.366667
br,ponte firme,Ponte Firme,15,,-18.066667,-46.416667
br,ponte funda,Ponte Funda,21,,-22.209167,-43.717778
br,ponte funda,Ponte Funda,29,,-16.8,-48.45
br,ponte gestal,Ponte Gestal,27,,-20.15,-49.683333
br,ponte grande,Ponte Grande,15,,-20.516667,-46.766667
br,ponte guayra,Ponte Guayra,27,,-20.383333,-48.483333
br,ponteira,Ponteira,29,,-17.366667,-52.65
br,ponte lavrada,Ponte Lavrada,27,,-23.583215,-47.098349
br,ponte limpa,Ponte Limpa,21,,-22.736667,-43.733333
br,ponte nova,Ponte Nova,05,,-12.266667,-41.183333
br,ponte nova,Ponte Nova,11,,-18.933333,-54.416667
br,ponte nova,Ponte Nova,15,48188,-20.4,-42.9
br,ponte nova,Ponte Nova,16,,-2.933333,-52.066667
br,ponte nova,Ponte Nova,18,,-23.7026,-49.7775
br,ponte nova,Ponte Nova,21,,-21.716667,-41.933333
br,ponte nova,Ponte Nova,27,,-23.1017,-47.9822
br,ponte,Ponte,05,,-11.6,-37.516667
br,ponte,Ponte,13,,-5.216667,-42.983333
br,ponte,Ponte,14,,-15.25,-56.683333
br,ponte,Ponte,16,,-1.55,-47.883333
br,pontes altas,Pontes Altas,26,,-27.483333,-50.383333
br,pontes de lacerda,Pontes de Lacerda,14,,-15.2,-59.366667
br,pontes do upamaroti,Pontes do Upamaroti,23,,-31.25,-55.15
br,pontes e lacerda,Pontes e Lacerda,14,29383,-15.2,-59.366667
br,ponte serrada,Ponte Serrada,26,,-26.866667,-51.966667
br,ponte serrado,Ponte Serrado,26,,-26.866667,-51.966667
br,pontes gestal,Pontes Gestal,27,,-20.15,-49.683333
br,pontes lacerda,Pontes Lacerda,14,,-15.2,-59.366667
br,pontes,Pontes,05,,-11.883333,-37.65
br,pontes,Pontes,13,,-4.833333,-43.366667
br,pontes,Pontes,14,,-15.3,-57.733333
br,pontes,Pontes,15,,-22.433333,-46.466667
br,ponte torta,Ponte Torta,18,,-25.698322,-50.186477
br,ponte velha,Ponte Velha,14,,-15.283333,-56.6
br,ponte velha,Ponte Velha,15,,-17.95,-40.3
br,ponte velha,Ponte Velha,22,,-5.9,-35.233333
br,ponte vermelha,Ponte Vermelha,11,,-19.483333,-54.416667
br,ponte vermelho,Ponte Vermelho,11,,-19.483333,-54.416667
br,pontevila,Pontevila,15,,-20.516667,-45.616667
br,pontezinha,Pontezinha,14,,-14.683333,-56.466667
br,pontezinha,Pontezinha,30,,-8.216667,-34.966667
br,pontina,Pontina,17,,-7.166667,-35.6
br,pontinha,Pontinha,05,,-13.166667,-38.866667
br,pontinha,Pontinha,14,,-15.016667,-55.966667
br,pontinha,Pontinha,17,,-7.533333,-34.833333
br,pontinhas,Pontinhas,17,,-7.533333,-34.833333
br,ponto alegre,Ponto Alegre,04,,-8.95,-67.833333
br,ponto alegre,Ponto Alegre,05,,-14.016667,-39.45
br,ponto alegre,Ponto Alegre,11,,-21.55,-56.85
br,ponto alegre,Ponto Alegre,27,,-22.433333,-52.466667
br,ponto cacau pireira,Ponto Cacau Pireira,04,,-3.166944,-60.083611
br,ponto central,Ponto Central,05,,-13.5,-40.183333
br,ponto certo,Ponto Certo,05,,-13.133333,-39.283333
br,ponto chique,Ponto Chique,05,,-14.55,-39.933333
br,ponto da divisao,Ponto da Divisão,14,,-8.9,-58.5
br,ponto da matriz,Ponto da Matriz,21,,-22.985714,-43.572055
br,ponto da santa cruz,Ponto da Santa Cruz,27,,-22.15,-51.8
br,ponto do leone,Ponto do Léone,05,,-12.966667,-38.95
br,pontoes,Pontões,08,,-20.2,-41.066667
br,pontoes,Pontões,15,,-20.366667,-42.116667
br,pontoes,Pontões,21,,-23.006164,-43.431019
br,ponto norte,Ponto Norte,05,,-15.2,-40.1
br,ponto novo,Ponto Novo,05,7141,-10.866667,-40.133333
br,ponto novo,Ponto Novo,16,,-2.933333,-52.066667
br,ponto obrigado,Ponto Obrigado,05,,-13.333333,-39.883333
br,pontos brancos,Pontos Brancos,02,,-9.483333,-36.933333
br,ponto sessenta,Ponto Sessenta,05,,-12.133333,-39.416667
br,populina,Populina,27,,-19.966667,-50.533333
br,popunhas,Popunhas,04,,-5.393056,-62.801389
br,poramana,Poramana,05,,-12.8,-38.633333
br,porangaba,Porangaba,01,,-8.664722,-72.816389
br,porangaba,Porangaba,02,,-9.55,-36.15
br,porangaba,Porangaba,06,,-3.75,-38.55
br,porangaba,Porangaba,27,,-20.9,-47.883333
br,poranga,Poranga,06,,-4.733333,-40.916667
br,poranga,Poranga,08,,-18.6,-40.883333
br,porangatu,Porangatu,29,32758,-13.433333,-49.166667
br,porao,Porão,06,,-3.366667,-39.45
br,porcas,Porcas,14,,-14.6,-55.983333
br,porciuncula,Porciúncula,21,12511,-20.966667,-42.033333
br,porcos,Porcos,05,,-12.666667,-44.35
br,porcos,Porcos,20,,-3.352778,-42.022778
br,porcos,Porcos,22,,-6.233333,-37.916667
br,porcos,Porcos,31,,-10.9,-47.3
br,porecatu,Porecatu,18,11390,-22.716667,-51.4
br,poreiros,Poreiros,20,,-6.966667,-41.116667
br,por-enquanto,Por-Enquanto,20,,-8.616667,-45.666667
br,pore,Pore,22,,-5.601944,-37.288333
br,porfirio,Porfírio,14,,-14.516667,-57.416667
br,porfirio,Porfírio,15,,-14.583333,-44.35
br,pori,Pori,05,,-14.333333,-39.333333
br,porongaba,Porongaba,01,,-8.192778,-72.922222
br,porongos,Porongos,23,,-28.45,-53.316667
br,pororoca,Pororoca,14,,-15.583333,-56.55
br,pororoca,Pororoca,22,,-5.366667,-35.7
br,porre,Porre,25,,3.133333,-60.366667
br,porta d'agua,Porta d'Agua,22,,-5.9425,-36.273889
br,portalegre,Portalegre,22,,-6.033333,-38
br,portal,Portal,05,,-12.366667,-41.65
br,portao,Portão,05,,-12.2,-38.416667
br,portao,Portão,23,21051,-29.7,-51.25
br,portao sao lourenco,Portão São Lourenço,26,,-26.1198,-49.8682
br,portaozinho,Portãozinho,18,,-25.810111,-49.22966
br,porteira correia,Porteira Correia,11,,-22.016667,-57.033333
br,porteira do pinhal,Porteira do Pinhal,23,,-27.966667,-51.216667
br,porteira ortiz,Porteira Ortiz,11,,-22.483333,-55.733333
br,porteira,Porteira,05,,-12.683333,-38.266667
br,porteira,Porteira,06,,-4.633333,-37.8
br,porteira,Porteira,11,,-22.016667,-57.033333
br,porteira,Porteira,14,,-15.9,-56.75
br,porteira,Porteira,15,,-20.233333,-44.4
br,porteira,Porteira,16,,-1.083333,-57.066667
br,porteira,Porteira,17,,-7.666667,-36.433333
br,porteira,Porteira,30,,-7.95,-38.283333
br,porteira,Porteira,31,,-11.383333,-48.616667
br,porteiras,Porteiras,06,,-3.35,-39.416667
br,porteiras,Porteiras,13,,-3.127222,-42.180556
br,porteiras,Porteiras,15,,-17.25,-44.816667
br,porteiras,Porteiras,20,,-4.883333,-41.45
br,porteiras,Porteiras,23,,-27.966667,-51.783333
br,porteiras,Porteiras,30,,-8.283333,-37.733333
br,porteirinha,Porteirinha,13,,-3.268333,-42.286944
br,porteirinha,Porteirinha,14,,-15.966667,-56.45
br,porteirinha,Porteirinha,15,14144,-15.733333,-43.033333
br,porteirinha,Porteirinha,23,,-30.633333,-55.266667
br,porteirinhas,Porteirinhas,15,,-21.716667,-44.466667
br,porteiro,Porteiro,18,,-25.8302,-48.8933
br,portela,Portela,13,,-3.976667,-42.888889
br,portela,Portela,21,,-21.633333,-41.983333
br,portela,Portela,23,,-27.6,-52.816667
br,portella,Portella,21,,-21.633333,-41.983333
br,portella,Portella,23,,-27.6,-52.816667
br,portel,Portel,16,21315,-1.95,-50.816667
br,portinha,Portinha,14,,-15.016667,-55.966667
br,porto 15 de agosto,Pôrto 15 de Agosto,11,,-21.966667,-53.816667
br,porto 15 de agosto,Pôrto 15 de Agosto,14,,-15.216667,-59.45
br,porto 15 de novembre,Pôrto 15 de Novembre,11,,-21.783333,-52.166667
br,porto 15 de novembre,Pôrto 15 de Novembre,24,,-10.716667,-62.783333
br,porto 15 novembro,Pôrto 15 Novembro,11,,-21.783333,-52.166667
br,porto 1 de fevereiro,Pôrto 1 de Fevereiro,24,,-11.3,-63.35
br,porto 1 de fevreiro,Pôrto 1 de Fevreiro,24,,-11.3,-63.35
br,porto 2 de novembro,Pôrto 2 de Novembro,24,,-8.85,-62.283333
br,porto 3 morrinhos,Porto 3 Morrinhos,18,,-22.866667,-53.5
br,porto 7 de setembro,Pôrto 7 de Setembro,11,,-22.216667,-52.516667
br,porto acre,Pôrto Acre,01,,-9.587778,-67.535556
br,porto afonso camargo,Pôrto Afonso Camargo,27,,-22.6,-51.783333
br,porto afonso de camargo,Pôrto Afonso de Camargo,27,,-22.633333,-51.733333
br,porto albuquerque,Pôrto Albuquerque,11,,-19.383333,-57.433333
br,porto alcidia,Pôrto Alcídia,27,,-22.216667,-52.5
br,porto alegre do tocantins,Porto Alegre do Tocantins,31,,-11.676667,-46.985833
br,porto alegre,Pôrto Alegre,01,,-8.2,-72.766667
br,porto alegre,Porto Alegre,04,,-5.903056,-64.395556
br,porto alegre,Pôrto Alegre,05,,-13.2,-43.716667
br,porto alegre,Pôrto Alegre,11,,-17.633333,-56.966667
br,porto alegre,Porto Alegre,13,,-5.15,-43.483333
br,porto alegre,Pôrto Alegre,14,,-14.783333,-56.1
br,porto alegre,Pôrto Alegre,15,,-16.616667,-41.783333
br,porto alegre,Pôrto Alegre,16,,-4.350278,-52.737778
br,porto alegre,Porto Alegre,18,,-25.0974,-53.9614
br,porto alegre,Pôrto Alegre,20,,-3.466667,-42.366667
br,porto alegre,Porto Alegre,23,1372763,-30.033333,-51.2
br,porto alegre,Porto Alegre,25,,-.886389,-61.925278
br,porto alemao,Pôrto Alemão,11,,-22.183333,-54.3
br,porto alica,Porto Alica,18,,-24.516667,-54.333333
br,porto almeida,Pôrto Almeida,18,,-26.15,-51.216667
br,porto alonso,Pôrto Alonso,04,,-2.466667,-66.5
br,porto alvorada do sul,Pôrto Alvorada do Sul,27,,-22.733333,-51.2
br,porto alvorada,Porto Alvorada,18,,-22.783333,-51.183333
br,porto alvorada,Pôrto Alvorada,27,,-22.733333,-51.2
br,porto amarante,Pôrto Amarante,14,,-12.983333,-60.2
br,porto amazonas,Porto Amazonas,18,,-25.5481,-49.8931
br,porto a. mendes,Pôrto A. Mendes,18,,-25.366667,-54.566667
br,porto andira,Porto Andirá,18,,-23.533333,-52.333333
br,porto angelica,Pôrto Angélica,11,,-22.083333,-53.716667
br,porto antigo,Pôrto Antigo,14,,-14.683333,-60.05
br,porto antonio prado,Pôrto Antônio Prado,27,,-20.166667,-48.8
br,porto antunes,Pôrto Antunes,04,,-2.916667,-67.116667
br,porto antunes,Pôrto Antunes,27,,-20.133333,-48.5
br,porto araia,Pôrto Araia,11,,-20.3,-55.9
br,porto arari,Pôrto Arari,03,,.283333,-51.15
br,porto aroeira,Porto Aroeira,11,,-21.683333,-54.416667
br,porto arraia,Pôrto Arraia,11,,-20.3,-55.9
br,porto arrepiado,Pôrto Arrepiado,29,,-18.35,-48.7
br,porto artaza,Pôrto Artaza,18,,-24.516667,-54.333333
br,porto arthur,Porto Arthur,14,,-13.6,-55.35
br,porto artur,Pôrto Artur,14,,-13.6,-55.35
br,porto aurora,Pôrto Aurora,04,,-3.366667,-67.85
br,porto ausencia,Porto Ausência,04,,-5.616111,-63.229167
br,porto badeco,Pôrto Badeco,11,,-17.616667,-54.95
br,porto baguari,Pôrto Baguari,11,,-18.416667,-57.366667
br,porto barra do batatal,Porto Barra do Batatal,27,,-24.586279,-48.270775
br,porto barra do ivinheima,Pôrto Barra do Ivinheima,11,,-22.966667,-53.666667
br,porto barreirao,Pôrto Barreirão,31,,-12.7,-48.266667
br,porto barreiras,Porto Barreiras,31,,-12.7,-48.266667
br,porto barreiro,Pôrto Barreiro,14,,-16.083333,-58.083333
br,porto barreiros,Pôrto Barreiros,15,,-18.383333,-48.483333
br,porto baston,Porto Baston,14,,-15.1,-59.95
br,porto bastos,Pôrto Bastos,14,,-15.1,-59.95
br,porto batalha,Pôrto Batalha,27,,-22.7,-51.216667
br,porto batatal,Porto Batatal,27,,-24.586279,-48.270775
br,porto batista,Pôrto Batista,23,,-29.9,-51.516667
br,porto bela vista,Pôrto Bela Vista,14,,-17.6,-56.983333
br,porto bela vista,Pôrto Bela Vista,18,,-25.433333,-54.583333
br,porto bello,Porto Bello,26,,-27.1575,-48.539722
br,porto belo,Porto Belo,26,14722,-27.1575,-48.539722
br,porto benedito,Pôrto Benedito,14,,-16.716667,-56.45
br,porto bicentenario,Pôrto Bicentenário,24,,-11.766667,-63.283333
br,porto biguacal,Porto Biguacal,14,,-16.483333,-56.3
br,porto boi so,Pôrto Boi Só,30,,-8.533333,-35.033333
br,porto bom jardim,Pôrto Bom Jardim,14,,-16.05,-58.083333
br,porto bom jesus do livramento,Porto Bom Jesus do Livramento,04,,-5.631944,-64.15
br,porto braga,Pôrto Braga,11,,-20.866667,-57.833333
br,porto braga,Porto Braga,21,,-21.6,-41.483333
br,porto branco,Pôrto Branco,11,,-21.9,-54.766667
br,porto branco,Pôrto Branco,13,,-5.666667,-43.85
br,porto brasilia,Pôrto Brasília,18,,-22.866667,-53.5
br,porto brejauva,Pôrto Brejaúva,27,,-19.966667,-49.316667
br,porto brilhante,Pôrto Brilhante,11,,-21.883333,-54.5
br,porto britania,Pôrto Britânia,18,,-24.65,-54.316667
br,porto bugre,Pôrto Bugre,23,,-27.6,-54.833333
br,porto buriti,Pôrto Buriti,15,,-17.283333,-46.466667
br,porto buritirana,Pôrto Buritirana,14,,-15.133333,-59.666667
br,porto byington,Pôrto Byington,18,,-23.95,-54.016667
br,porto cabral,Pôrto Cabral,27,,-22.283333,-52.633333
br,porto cachoeira,Pôrto Cachoeira,11,,-21.566667,-53.216667
br,porto cafe,Pôrto Café,11,,-21.883333,-54.683333
br,porto cajueiro,Pôrto Cajueiro,14,,-11.05,-55.883333
br,porto cajuru,Pôrto Cajuru,27,,-20.6,-48.333333
br,porto caleano,Pôrto Caleano,11,,-20.033333,-52.133333
br,porto calvo,Pôrto Calvo,02,17347,-9.066667,-35.4
br,porto camargo,Pôrto Camargo,18,,-23.35,-53.716667
br,porto cambara,Porto Cambará,18,,-23.628425,-50.083629
br,porto cambira,Pôrto Cambira,11,,-22.333333,-54.883333
br,porto caneca,Pôrto Caneca,14,,-16.666667,-56.466667
br,porto caneco,Pôrto Caneco,14,,-13.6,-55.35
br,porto canoas,Pôrto Canoas,14,,-14.45,-57.283333
br,porto cape,Pôrto Capé,11,,-21.883333,-54.683333
br,porto capim,Pôrto Capim,27,,-22.65,-51.333333
br,porto caracara,Pôrto Caracará,14,,-17.866667,-57.45
br,porto carreiros,Porto Carreiros,15,,-18.383333,-48.483333
br,porto carrito,Pôrto Carrito,15,,-20.95,-46.066667
br,porto casa nova,Pôrto Casa Nova,27,,-22.783333,-51.016667
br,porto cassange,Pôrto Cassange,14,,-16.566667,-56.6
br,porto castilho,Pôrto Castilho,27,,-22.25,-52.516667
br,porto castro alves,Pôrto Castro Alves,05,,-12.516667,-39.2
br,porto cavalheiro,Pôrto Cavalheiro,29,,-17.216667,-48.066667
br,porto cecilio-cue,Pôrto Cecílio-cuê,11,,-22.133333,-53.666667
br,porto cecilio,Pôrto Cecílio,11,,-22.133333,-53.666667
br,porto cedro,Pôrto Cedro,11,,-18.283333,-55.033333
br,porto cedro,Pôrto Cedro,27,,-22.916667,-50.116667
br,porto central,Pôrto Central,04,,-7.533333,-70.716667
br,porto chalana,Pôrto Chalana,26,,-27.183333,-52.766667
br,porto chane,Pôrto Chané,11,,-18.15,-57.366667
br,porto cinco de maio,Pôrto Cinco de Maio,11,,-22.55,-53.566667
br,porto ciriaco,Pôrto Ciríaco,11,,-19.7,-56.266667
br,porto colimbiano,Pôrto Colimbiano,04,,-2.633333,-65.783333
br,porto columbiano,Pôrto Columbiano,04,,-2.633333,-65.783333
br,porto conceicao do aruma,Porto Conceição do Arumã,04,,-5.643889,-63.771667
br,porto conceicao,Pôrto Conceição,14,,-17.15,-57.383333
br,porto copacabana do norte,Pôrto Copacabana do Norte,18,,-23.533333,-52.333333
br,porto coqueirinha,Pôrto Coqueirinha,11,,-21.6,-53.016667
br,porto coqueirinho,Pôrto Coqueirinho,11,,-21.6,-53.016667
br,porto coqueiro,Porto Coqueiro,14,,-17.333333,-55.666667
br,porto correia,Porto Correia,04,,-3.612222,-62.998056
br,porto corupa,Pôrto Corupá,11,,-23.75,-54.533333
br,porto cristalino,Pôrto Cristalino,11,,-22.383333,-53.55
br,porto cuiaba,Pôrto Cuiabá,04,,-2.533333,-66.383333
br,porto curupahy,Porto Curupahy,11,,-23.183333,-54.4
br,porto curupai,Pôrto Curupaí,11,,-22.833333,-53.883333
br,porto cyriaco,Porto Cyriaco,11,,-19.7,-56.266667
br,porto da aldeia do manduri,Pôrto da Aldeia do Manduri,14,,-16.916667,-56.2
br,porto da aldeia pirizal,Pôrto da Aldeia Pirizal,14,,-16.833333,-56.133333
br,porto da aroeira,Porto da Aroeira,11,,-21.683333,-54.416667
br,porto da barca,Pôrto da Barca,16,,-5.033333,-52.133333
br,porto da barra,Pôrto da Barra,11,,-21.633333,-52.966667
br,porto da boca,Pôrto da Bôca,02,,-9.933333,-36.116667
br,porto da chatana,Porto da Chatana,26,,-27.183333,-52.766667
br,porto da conceicao,Porto da Conceição,14,,-17.15,-57.383333
br,porto da espada,Pôrto da Espada,05,,-13.1,-38.966667
br,porto da farra,Pôrto da Farra,11,,-21.633333,-52.966667
br,porto da fazenda das palmeiras,Pôrto da Fazenda das Palmeiras,11,,-19.033333,-57.216667
br,porto da fazenda santa maria do poborereu,Porto da Fazenda Santa Maria do Poborereu,14,,-16.95,-56.216667
br,porto da fazenda santa maria do poboreu,Pôrto da Fazenda Santa Maria do Poboreu,14,,-16.95,-56.216667
br,porto da folha,Pôrto da Fôlha,02,,-9.933333,-36.116667
br,porto da folha,Pôrto da Fôlha,28,9420,-9.916667,-37.283333
br,porto da fora,Porto da Fóra,14,,-16.116667,-55.85
br,porto da fotografia,Pôrto da Fotografia,14,,-15.2,-59.466667
br,porto da gabarra,Pôrto da Gabarra,13,,-3.116667,-44.566667
br,porto da galinha,Pôrto da Galinha,15,,-16.9,-45.416667
br,porto da gloria,Pôrto da Glória,15,,-20.65,-46.5
br,porto da lama,Pôrto da Lama,30,,-8.533333,-35.016667
br,porto da lontra,Pôrto da Lontra,16,,-4.8,-52.316667
br,porto da maloca,Pôrto da Maloca,04,,2.033333,-63.166667
br,porto da manga,Porto da Manga,23,,-29.9501,-51.4556
br,porto da melancia,Porto da Melancia,13,,-3.436667,-42.277778
br,porto da olaria,Pôrto da Olaria,15,,-18.85,-48.116667
br,porto da photographia,Porto da Photographia,14,,-15.2,-59.466667
br,porto da praia,Pôrto da Praia,16,,-.666667,-47.2
br,porto da reparticao,Pôrto da Repartição,13,,-3.683333,-42.683333
br,porto das barcas,Pôrto das Barcas,20,,-2.909167,-41.774722
br,porto das cabras,Pôrto das Cabras,28,,-10.833333,-36.95
br,porto das caixas,Pôrto das Caixas,21,,-22.7,-42.883333
br,porto das canoas,Pôrto das Canoas,14,,-14.45,-57.283333
br,porto das canoas,Pôrto das Canoas,15,,-19.183333,-42.8
br,porto das cruzes,Pôrto das Cruzes,21,,-21.716667,-42.233333
br,porto das eguas,Pôrto das Éguas,11,,-19.816667,-56.033333
br,porto das flores,Porto das Flores,15,,-22.079167,-43.556667
br,porto das flores,Porto das Flores,21,,-22.085,-43.558611
br,porto das gabarras,Pôrto das Gabarras,13,,-3.116667,-44.566667
br,porto das gaivotas,Porto das Gaivotas,04,,-5.61,-63.439167
br,porto das galinhas,Pôrto das Galinhas,30,,-8.516667,-35.016667
br,porto das marrecas,Pôrto das Marrecas,27,,-21.35,-51.866667
br,porto das melancias,Pôrto das Melancias,15,,-18.5,-45.283333
br,porto das pedras,Pôrto das Pedras,11,,-19.383333,-52.533333
br,porto das pedras,Pôrto das Pedras,14,,-16.416667,-56.316667
br,porto das pombas,Pôrto das Pombas,23,,-30.316667,-51.016667
br,porto da sul,Porto da Sul,14,,-13.283333,-53.533333
br,porto das vargens,Porto das Vargens,20,,-3.46,-42.291944
br,porto da telha,Pôrto da Telha,14,,-15.416667,-60
br,porto de areia e pedras,Porto de Areia e Pedras,27,,-24.522685,-48.133092
br,porto de aterada,Pôrto de Aterada,14,,-17.016667,-56.6
br,porto de aterrado,Pôrto de Aterrado,14,,-17.016667,-56.6
br,porto de atterada,Porto de Atterada,14,,-17.016667,-56.6
br,porto de cariacica,Pôrto de Cariacica,08,,-20.283333,-40.4
br,porto de cima,Pôrto de Cima,14,,-14.866667,-55.916667
br,porto de cima,Porto de Cima,18,,-25.436027,-48.87566
br,porto de fora,Pôrto de Fora,14,,-16.116667,-55.85
br,porto de guanhaes,Pôrto de Guanhães,15,,-18.883333,-43.1
br,porto de indio,Pôrto de Indio,14,,-11.5,-55.616667
br,porto de indios,Pôrto de Índios,14,,-11.5,-55.616667
br,porto de itatuba,Porto de Itatuba,04,,-5.683333,-63.410556
br,porto dejesado,Pôrto Dejesado,11,,-22.383333,-54.75
br,porto de manga,Pôrto de Manga,15,,-18.283333,-44.3
br,porto de massacas,Porto de Massacas,24,,-12.433333,-61.033333
br,porto de mos,Pôrto de Mós,16,,-1.75,-52.233333
br,porto de moz,Pôrto de Moz,16,9912,-1.75,-52.233333
br,porto de pedra,Pôrto de Pedra,11,,-21.2,-52.966667
br,porto de pedras,Pôrto de Pedras,02,,-9.166667,-35.283333
br,porto de pedras,Pôrto de Pedras,05,,-10.133333,-42.433333
br,porto de pedras,Pôrto de Pedras,16,,-.8,-47.133333
br,porto de pimenteira,Pôrto de Pimenteira,13,,-4.3,-42.983333
br,porto-de-santa-cruz,Pôrto-de-Santa-Cruz,05,,-15.183333,-41.35
br,porto de santa cruz,Pôrto de Santa Cruz,05,,-15.5,-41.316667
br,porto de santa cruz,Porto de Santa Cruz,15,,-17.433333,-41.05
br,porto de santana,Pôrto de Santana,03,,-.05,-51.183333
br,porto de santana,Pôrto de Santana,08,,-21.233333,-41.133333
br,porto de santo antonio,Pôrto de Santo Antonio,15,,-21.316667,-42.866667
br,porto de sao domingos,Porto de São Domingos,15,,-19.216667,-50.75
br,porto de sao francisco dos casaes,Pôrto de São Francisco dos Casaes,23,,-30.033333,-51.2
br,porto de sao francisco,Pôrto de São Francisco,11,,-18.383333,-57.366667
br,porto de sauipe,Pôrto de Sauípe,05,,-12.4,-37.916667
br,porto desejado,Porto Desejado,11,,-22.383333,-54.75
br,porto desejado,Pôrto Desejado,15,,-17.033333,-42.8
br,porto de tapes,Porto de Tapes,23,,-30.666667,-51.383333
br,porto de zelandia,Porto de Zelandia,13,,-8.516667,-45.766667
br,porto diamante,Pôrto Diamante,15,,-17.833333,-46.3
br,porto do acai,Pôrto do Açaí,14,,-15.216667,-59.516667
br,porto do angico,Pôrto do Angico,14,,-14.8,-54.7
br,porto do antunes,Porto do Antunes,27,,-20.133333,-48.5
br,porto do aratingauba,Porto do Aratingauba,26,,-28.3,-48.866667
br,porto do assahy,Porto do Assahy,14,,-15.216667,-59.516667
br,porto do badeco,Pôrto do Badeco,11,,-17.616667,-54.95
br,porto do barco,Porto do Barco,06,,-2.9,-39.883333
br,porto do barracao,Pôrto do Barracão,15,,-16.916667,-45.383333
br,porto do barreiro,Pôrto do Barreiro,14,,-16.083333,-58.083333
br,porto do boi morto,Pôrto do Boi Morto,14,,-15.583333,-57.45
br,porto do bugres,Pôrto do Bugres,14,,-15.5,-57.683333
br,porto do buri,Pôrto do Buri,15,,-17.283333,-46.466667
br,porto do buriti,Pôrto do Buriti,15,,-17.283333,-46.466667
br,porto do buritizal,Pôrto do Buritizal,14,,-15.133333,-59.666667
br,porto do burity,Porto do Burity,15,,-17.283333,-46.466667
br,porto do buritysal,Porto do Buritysal,14,,-15.133333,-59.666667
br,porto do campo,Pôrto do Campo,14,,-15.7,-57.716667
br,porto do capeta,Pôrto do Capeta,11,,-20.083333,-56.533333
br,porto do carregador,Porto do Carregador,14,,-16.016667,-58.35
br,porto do cassange,Pôrto do Cassange,14,,-16.566667,-56.6
br,porto do catepa,Pôrto do Catepa,11,,-20.083333,-56.533333
br,porto do caubi,Porto do Caubí,05,,-14.2,-39.033333
br,porto do cedro,Pôrto do Cedro,27,,-22.916667,-50.116667
br,porto do ceu,Pôrto do Céu,03,,.033333,-51.233333
br,porto do cima,Porto do Cima,14,,-14.2,-55.083333
br,porto do cocaual,Pôrto do Cocaual,16,,-3.266667,-51.316667
br,porto do conde,Pôrto do Conde,23,,-29.966667,-51.8
br,porto do coqueiro,Pôrto do Coqueiro,14,,-17.333333,-55.666667
br,porto do costa,Pôrto do Costa,05,,-13.466667,-38.916667
br,porto do cubiculo,Pôrto do Cubículo,31,,-12.683333,-46.65
br,porto do engenho da pedra,Porto do Engenho da Pedra,21,,-22.833333,-43.266667
br,porto do estacio,Pôrto do Estácio,23,,-29.383333,-49.8
br,porto do faxanda da baia dos passaros,Pôrto do Faxanda da Baía dos Pássaros,14,,-16.7,-55.8
br,porto do fazenda santa maria,Porto do Fazenda Santa Maria,14,,-16.95,-56.216667
br,porto do ferreiras,Porto do Ferreiras,15,,-21.033333,-45.333333
br,porto do fora,Porto do Fora,14,,-16.116667,-55.85
br,porto do frio,Pôrto do Frio,13,,-5.666667,-43.85
br,porto do galinha,Pôrto do Galinha,15,,-16.9,-45.416667
br,porto dois de novembre,Porto Dois de Novembre,24,,-8.85,-62.283333
br,porto do jatai,Pôrto do Jataí,11,,-22.166667,-54.716667
br,porto do jatoba,Porto do Jatoba,14,,-16.066667,-58.15
br,porto do jeronimo,Pôrto do Jerónimo,29,,-18.683333,-50.25
br,porto do limao,Porto do Limão,03,,.683333,-51.433333
br,porto do mangue,Porto do Mangue,22,,-5.068333,-36.780278
br,porto do massaca,Pôrto do Massaca,24,,-12.433333,-61.033333
br,porto do massacas,Pôrto do Massacás,24,,-12.433333,-61.033333
br,porto do meio,Pôrto do Meio,05,,-12.916667,-38.816667
br,porto domingos,Pôrto Domingos,11,,-23.75,-55.3
br,porto do padeiro,Pôrto do Padeiro,27,,-24.133333,-46.883333
br,porto do palhal,Pôrto do Palhal,04,,-5.405,-59.745833
br,porto do palmital,Pôrto do Palmital,26,,-26.033333,-48.816667
br,porto do papagaio,Pôrto do Papagaio,14,,-13.466667,-58.35
br,porto do papagente,Porto do Papagente,05,,-12.516667,-39.2
br,porto do pilao,Porto do Pilão,22,,-5.114722,-36.787778
br,porto do prado,Porto do Prado,23,,-27.133333,-53.4
br,porto do praiao,Porto do Praião,15,,-18.616667,-49.6
br,porto do prelado,Pôrto do Prelado,27,,-24.616667,-47.3
br,porto do rei,Porto do Rei,26,,-26.3883,-48.614
br,porto do reparticao,Pôrto do Repartição,13,,-3.683333,-42.683333
br,porto do retiro de sao rafael,Pôrto do Retiro de São Rafael,14,,-16.766667,-56.066667
br,porto do riachao,Porto do Riachão,20,,-8.166667,-45.583333
br,porto do rio verde,Porto do Rio Verde,05,,-10.933333,-42.316667
br,porto do roucinho,Pôrto do Roucinho,05,,-13.666667,-44.483333
br,porto do rouxinho,Porto do Rouxinho,05,,-13.666667,-44.483333
br,porto do salto,Pôrto do Salto,15,,-20.833333,-46
br,porto do sao borja,Porto do São Borja,23,,-28.616667,-56.033333
br,porto do sape,Pôrto do Sapé,27,,-20.133333,-49.016667
br,porto do sarandi,Pôrto do Sarandi,21,,-21.8,-42.45
br,porto do sara,Pôrto do Sará,14,,-17.7,-57.05
br,porto do sauipe,Porto do Sauipe,05,,-12.4,-37.916667
br,porto dos bugres,Pôrto dos Bugres,14,,-15.5,-57.683333
br,porto dos cabritos,Porto dos Cabritos,21,,-23.000704,-43.323054
br,porto dos garruchos,Pôrto dos Garruchos,23,,-28.183333,-55.65
br,porto dos gauchos,Pôrto dos Gaúchos,14,,-11.483333,-57.366667
br,porto dos indios,Porto dos Índios,15,,-22.076667,-43.712222
br,porto dos indios,Pôrto dos Índios,18,,-25.3,-52.583333
br,porto dos massacas,Porto dos Massacás,24,,-12.433333,-61.033333
br,porto dos mehinaco,Porto dos Mehinaco,14,,-12.55,-53.116667
br,porto dos meinaco,Porto dos Meinaco,14,,-12.55,-53.116667
br,porto dos meinacos,Pôrto dos Meinacos,14,,-12.55,-53.116667
br,porto dos melancios,Pôrto dos Melancios,15,,-18.5,-45.283333
br,porto dos mendes,Pôrto dos Mendes,15,,-21.033333,-45.333333
br,porto dos meninaco,Porto dos Meninaco,14,,-12.55,-53.116667
br,porto do soldado,Pôrto do Soldado,14,,-15.116667,-59.7
br,porto dos pachecos,Pôrto dos Pachecos,29,,-17.75,-47.583333
br,porto dos santos,Pôrto dos Santos,05,,-12.916667,-38.616667
br,porto dos tinguis,Porto dos Tinguis,20,,-3.821389,-42.0175
br,porto do sul,Pôrto do Sul,14,,-13.283333,-53.533333
br,porto do surubi,Pôrto do Surubi,21,,-21.8,-42.45
br,porto do taboado,Porto do Taboado,11,,-20.183333,-51.05
br,porto do taboado,Porto do Taboado,27,,-20.216667,-51.033333
br,porto do tapiropoan,Porto do Tapiropoãn,14,,-14.85,-57.75
br,porto do tonico,Porto do Tonico,14,,-15.416667,-57.7
br,porto do triumpho,Porto do Triumpho,24,,-12.9,-60.8
br,porto do triunfo,Pôrto do Triunfo,11,,-17.766667,-57.083333
br,porto do triunfo,Pôrto do Triunfo,14,,-17.766667,-57.183333
br,porto do una,Pôrto do Una,27,,-24.433333,-47.083333
br,porto do uniao,Pôrto do Uniao,26,,-26.25,-51.083333
br,porto dourado,Pôrto Dourado,11,,-23.8,-54.366667
br,porto doutor ceravolo,Pôrto Doutor Ceravolo,27,,-22.6,-51.766667
br,porto edite,Pôrto Edite,01,,-10.25,-67.083333
br,porto embira,Pôrto Embira,01,,-8.5,-70.533333
br,porto emilio,Porto Emílio,24,,-9.716667,-65.8
br,porto epitacio,Pôrto Epitácio,23,,-29.383333,-49.8
br,porto erequeira,Pôrto Erequeira,14,,-16.866667,-56.166667
br,porto esperanca,Pôrto Esperança,11,,-17.783333,-57.116667
br,porto esperanca,Pôrto Esperança,14,,-14.15,-56.1
br,porto esperanca,Pôrto Esperança,24,,-12.816667,-60.85
br,porto esperanza,Porto Esperanza,11,,-19.616667,-57.45
br,porto esperediao,Porto Esperedião,14,,-15.85,-58.466667
br,porto esperidao,Pôrto Esperidão,14,,-15.85,-58.466667
br,porto esperidiao,Pôrto Esperidião,14,,-15.85,-58.466667
br,porto espiridao,Porto Espiridao,14,,-15.85,-58.466667
br,porto espiridiao,Porto Espiridião,14,,-15.85,-58.466667
br,portoes,Portões,15,,-20.2266,-43.776
br,porto estanhado,Pôrto Estanhado,20,,-3.95,-42.766667
br,porto estrela,Pôrto Estrêla,14,,-15.333333,-57.233333
br,porto estrela,Porto Estrela,23,,-31.25,-51.75
br,porto euclides da cunha,Pôrto Euclides da Cunha,27,,-22.566667,-52.6
br,porto faria,Pôrto Faria,15,,-17.8,-44.65
br,porto faustino lemos,Pôrto Faustino Lemos,15,,-17.166667,-47.266667
br,porto felicidade,Pôrto Felicidade,11,,-22.966667,-54.616667
br,porto feliz,Pôrto Feliz,15,,-19.066667,-50.5
br,porto feliz,Porto Feliz,18,,-25.784819,-50.247107
br,porto feliz,Porto Feliz,27,41016,-23.213333,-47.523056
br,porto ferrao,Pôrto Ferrão,27,,-21.683333,-49.233333
br,porto ferreca,Pôrto Ferreca,11,,-22.583333,-53.766667
br,porto ferreira,Pôrto Ferreira,27,49128,-21.85,-47.466667
br,porto ferreiro,Porto Ferreiro,27,,-21.85,-47.466667
br,porto firme,Pôrto Firme,15,,-20.666667,-43.1
br,porto firmino,Pôrto Firmino,27,,-22.633333,-51.733333
br,porto flores,Pôrto Flores,11,,-21.766667,-57.883333
br,porto formoso,Porto Formoso,13,,-3.45,-42.373611
br,porto frances,Porto Francês,02,,-9.833333,-35.833333
br,porto franco,Pôrto Franco,01,,-10.116667,-67.816667
br,porto franco,Pôrto Franco,03,,1.883333,-50.783333
br,porto franco,Pôrto Franco,04,,-6.75,-69.95
br,porto franco,Pôrto Franco,13,14874,-6.333333,-47.4
br,porto franco,Pôrto Franco,16,,-1.1,-49.216667
br,porto franco,Pôrto Franco,26,,-27.216667,-49.083333
br,porto franco,Porto Franco,31,,-8.310278,-49.056944
br,porto fundacao,Pôrto Fundação,14,,-13.983333,-55.3
br,porto fundo,Pôrto Fundo,16,,-4.933333,-52.216667
br,porto galeano,Pôrto Galeano,11,,-20.033333,-52.133333
br,porto galvao,Pôrto Galvão,27,,-22.95,-50.5
br,porto gato preto,Pôrto Gato Prêto,11,,-22.333333,-53.516667
br,porto general meira,Pôrto General Meira,18,,-25.566667,-54.583333
br,porto giovani,Pôrto Giovani,27,,-22.95,-50.8
br,porto goio en,Porto Goio En,26,,-27.283333,-52.683333
br,porto gois,Pôrto Góis,27,,-23.216667,-47.233333
br,porto goyo en,Porto Goyo En,26,,-27.283333,-52.683333
br,porto grande,Pôrto Grande,03,,.7,-51.4
br,porto grande,Pôrto Grande,13,,-6.933333,-44.183333
br,porto guaira,Porto Guaira,18,,-24.066667,-54.25
br,porto guaira,Pôrto Guaíra,27,,-20.383333,-48.483333
br,porto guanandi,Pôrto Guanandi,11,,-20.483333,-55.75
br,porto guarani,Pôrto Guarani,11,,-22.3,-53.583333
br,porto guarei,Pôrto Guareí,11,,-22.666667,-53.566667
br,porto guasca,Pôrto Guasca,27,,-20.383333,-48.483333
br,porto guavira,Pôrto Guavirá,11,,-23.4,-54.2
br,porto gurupai,Pôrto Gurupaí,11,,-23.183333,-54.4
br,porto gurupay,Porto Gurupay,11,,-23.183333,-54.4
br,porto imburi,Pôrto Imburi,21,,-21.6,-41.483333
br,porto independencia,Pôrto Independência,27,,-20.966667,-51.7
br,porto iolanda,Pôrto Iolanda,24,,-13.216667,-62.1
br,porto ipiranga,Pôrto Ipiranga,18,,-23.216667,-52.9
br,porto ipora,Pôrto Iporã,11,,-23.566667,-54.033333
br,porto isabel,Pôrto Isabel,11,,-23.95,-54.2
br,porto itacora,Pôrto Itacorá,18,,-25.116667,-54.433333
br,porto italiano,Pôrto Italiano,05,,-16.016667,-39.916667
br,porto italo,Pôrto Ítalo,18,,-25.333333,-48.766667
br,porto itaparica,Pôrto Itaparica,27,,-22.666667,-51.583333
br,porto itaperiu,Porto Itaperiú,26,,-26.5639,-48.7485
br,porto itapopo,Pôrto Itapopó,11,,-23.783333,-54.316667
br,porto itu,Pôrto Itu,04,,-2.95,-69.216667
br,porto jacare,Pôrto Jacaré,15,,-15.083333,-44.116667
br,porto jatai,Pôrto Jatai,11,,-22.166667,-54.716667
br,porto jatoba,Pôrto Jatobá,14,,-16.066667,-58.15
br,porto jejui,Pôrto Jejuí,18,,-24.783333,-54.4
br,porto jejuy,Pôrto Jejuy,18,,-24.783333,-54.4
br,porto joana,Pôrto Joana,15,,-20.316667,-47
br,porto joao alfredo,Pôrto João Alfredo,27,,-22.666667,-47.75
br,porto joaquim antunes,Pôrto Joaquim Antunes,27,,-20.433333,-48.433333
br,porto joaquim justino,Pôrto Joaquim Justino,27,,-20.433333,-48.433333
br,porto joffre,Porto Joffre,14,,-17.333333,-56.8
br,porto jofre,Pôrto Jofre,14,,-17.333333,-56.8
br,porto jose coroa,Porto José Coroa,14,,-14.3,-54.7
br,porto justino,Pôrto Justino,27,,-20.433333,-48.433333
br,porto kiki,Pôrto Kiki,11,,-21.95,-54.283333
br,porto labirinto,Pôrto Labirinto,27,,-21.166667,-51.883333
br,porto laguna,Pôrto Laguna,11,,-23.233333,-54.2
br,porto lambari,Pôrto Lambari,11,,-21.783333,-54.1
br,porto leopoldina,Pôrto Leopoldina,27,,-22.933333,-50.25
br,porto lescano cue,Pôrto Lescano Cuê,11,,-23.45,-53.983333
br,porto liberal,Pôrto Liberal,11,,-23.166667,-54.083333
br,porto limoeiro,Pôrto Limoeiro,11,,-17.75,-57.05
br,porto limoeiro,Porto Limoeiro,14,,-16.483333,-56.233333
br,porto lindo,Pôrto Lindo,11,,-23.65,-54.5
br,porto loreto,Pôrto Loreto,11,,-22.583333,-53.766667
br,porto lorito,Pôrto Lorito,11,,-22.583333,-53.766667
br,porto lucas,Pôrto Lucas,23,,-27.3,-52.25
br,porto lucena,Pôrto Lucena,23,,-27.85,-55.016667
br,porto luiza,Pôrto Luiza,11,,-23.133333,-54.216667
br,porto luiz ferreira,Pôrto Luiz Ferreira,11,,-22.583333,-53.766667
br,porto macuapanim,Porto Macuapanim,04,,-2.533333,-65.5
br,porto manduri,Pôrto Manduri,14,,-16.916667,-56.2
br,porto manga,Pôrto Manga,11,,-19.233333,-57.216667
br,porto manuel nunes,Pôrto Manuel Nunes,29,,-19.2,-50.75
br,porto mao de pao,Porto Mão de Pãó,29,,-18.366667,-47.783333
br,porto mao de pau,Pôrto Mão de Pau,29,,-18.366667,-47.783333
br,porto mapis novo,Porto Mapis Novo,04,,-7.170833,-71.811389
br,porto mapis velho,Porto Mapis Velho,04,,-7.154722,-71.796944
br,porto maquapanim,Pôrto Maquapanim,04,,-2.533333,-65.5
br,porto maraca,Porto Maracá,14,,-13.4,-55.583333
br,porto marcondes,Pôrto Marcondes,27,,-22.533333,-52.033333
br,porto marcos pereira,Pôrto Marcos Pereira,27,,-21.133333,-50.233333
br,porto mariante,Porto Mariante,23,,-29.7,-51.966667
br,porto maria,Pôrto Maria,27,,-22.466667,-52.883333
br,porto marinho,Pôrto Marinho,21,,-21.716667,-42.266667
br,porto marinho,Pôrto Marinho,27,,-22.916667,-50.35
br,porto marques,Pôrto Marques,11,,-22.116667,-53.6
br,porto marques,Pôrto Marquês,24,,-12.35,-59.966667
br,porto marrecas,Pôrto Marrecas,27,,-21.35,-51.866667
br,porto martinho,Porto Martinho,11,,-21.733333,-54.183333
br,porto martins,Pôrto Martins,27,,-22.666667,-48.366667
br,porto mascarenhas,Porto Mascarenhas,08,,-19.5,-40.9
br,porto matarazzo,Pôrto Matarazzo,27,,-22.933333,-50.7
br,porto maua,Pôrto Mauá,23,,-27.583333,-54.666667
br,porto mbocaia,Pôrto Mbocaia,11,,-21.983333,-54.533333
br,porto meira,Pôrto Meira,18,,-25.566667,-54.583333
br,porto mendes goncalves,Pôrto Mendes Gonçalves,18,,-24.5,-54.333333
br,porto mendes,Pôrto Mendes,18,,-24.5,-54.333333
br,porto menezes,Pôrto Menezes,27,,-21.066667,-50.35
br,porto mercedes,Pôrto Mercedes,11,,-22.333333,-55.016667
br,porto militao,Pôrto Militão,27,,-19.933333,-49.95
br,porto monoco,Pôrto Monoco,14,,-13.4,-55.583333
br,porto moroco,Pôrto Morocó,14,,-13.4,-55.583333
br,porto mororo,Pôrto Mororó,14,,-13.4,-55.583333
br,porto morrinho,Pôrto Morrinho,14,,-16.633333,-57.816667
br,porto morrinhos,Pôrto Morrinhos,15,,-14.866667,-43.933333
br,porto murtinho,Pôrto Murtinho,11,12672,-21.7,-57.866667
br,porto nacional,Porto Nacional,31,40862,-10.708056,-48.308333
br,porto nazare,Pôrto Nazaré,24,,-10.083333,-62.3
br,porto nazareth,Pôrto Nazareth,24,,-10.083333,-62.3
br,porto nho-nho morais,Pôrto Nhô-Nhô Morais,18,,-22.616667,-52.166667
br,porto nobrega,Pôrto Nóbrega,27,,-24.166667,-47.333333
br,porto noticia,Pôrto Notícia,11,,-23.8,-54.366667
br,porto novo,Pôrto Novo,01,,-10.116667,-66.916667
br,porto novo,Pórto Novo,05,,-10.866667,-40.133333
br,porto novo,Pôrto Novo,08,,-20.3,-40.366667
br,porto novo,Pôrto Novo,11,,-17.766667,-57.083333
br,porto novo,Pôrto Novo,14,,-16.816667,-56.583333
br,porto novo,Pôrto Novo,15,,-21.883333,-42.7
br,porto novo,Pôrto Novo,18,,-24.05,-54.166667
br,porto novo,Porto Novo,21,,-22.816667,-43.083333
br,porto novo,Porto Novo,23,,-32.041667,-52.083333
br,porto novo,Pôrto Novo,24,,-9.516667,-63.116667
br,porto nunes,Pôrto Nunes,29,,-19.2,-50.75
br,porto occulto,Porto Occulto,11,,-23.8,-54.8
br,porto ocoi,Pôrto Ocoí,18,,-25.216667,-54.466667
br,porto ocoy,Porto Ocoy,18,,-25.216667,-54.466667
br,porto oculto,Pôrto Oculto,11,,-23.183333,-54.116667
br,porto oeoi,Porto Oeoi,18,,-25.216667,-54.466667
br,porto otavio,Pôrto Otávio,14,,-8.616667,-57.983333
br,porto palmira,Pôrto Palmira,27,,-22.966667,-50.75
br,porto palmital,Pôrto Palmital,26,,-26.033333,-48.816667
br,porto pantanal,Pôrto Pantanal,11,,-21.95,-57.933333
br,porto papagaio,Pôrto Papagaio,11,,-22.366667,-53.55
br,porto paraguaia,Pôrto Paraguaia,11,,-22.366667,-53.55
br,porto paraiso,Porto Paraiso,18,,-23.319971,-52.65714
br,porto pardo,Porto Pardo,01,,-9.4,-72.7
br,porto passo cue,Pôrto Passo Cuê,18,,-25.3,-54.516667
br,porto pequeri,Pôrto Pequeri,18,,-24.4,-53.15
br,porto peroba,Pôrto Perobá,11,,-22.9,-53.633333
br,porto pinduva,Pôrto Pinduva,27,,-24.55,-47.5
br,porto pinheiro,Pôrto Pinheiro,26,,-27.283333,-52.683333
br,porto pio prado,Pôrto Pio Prado,27,,-21.05,-50.466667
br,porto piquiri,Pôrto Piquiri,18,,-24.4,-53.15
br,porto pirabebe,Pôrto Pirabebe,11,,-22.316667,-53.566667
br,porto pirai,Pôrto Piraí,11,,-23.733333,-54.516667
br,porto platon,Pôrto Platon,03,,.7,-51.45
br,porto poet,Pôrto Poet,03,,1.783333,-54.65
br,porto porobeu,Pôrto Porobeu,14,,-16.95,-56.216667
br,porto,Pôrto,01,,-7.766667,-73.35
br,porto,Pôrto,03,,-.05,-51.183333
br,porto,Pôrto,05,,-10.933333,-42.833333
br,porto,Pôrto,11,,-19.35,-52.4
br,porto,Pôrto,16,,-1.033333,-46.883333
br,porto,Pôrto,20,6535,-3.9,-42.7
br,porto,Pôrto,23,,-27.183333,-53.733333
br,porto,Porto,27,,-21.35,-51.866667
br,porto,Pôrto,29,,-17.283333,-48.183333
br,porto presidente vargas,Porto Presidente Vargas,27,,-20.216667,-51.033333
br,porto primavera,Pôrto Primavera,11,,-22.5,-53.016667
br,porto primeiro de fevereiro,Pôrto Primeiro de Fevereiro,24,,-11.3,-63.35
br,porto primeiro,Porto Priméiro,11,,-22.633333,-54.8
br,porto quebra-canoas,Pôrto Quebra-Canoas,27,,-22.916667,-50.583333
br,porto quebracho,Pôrto Quebracho,11,,-21.833333,-57.883333
br,porto quebrado,Pôrto Quebrado,11,,-21.833333,-57.883333
br,porto querencia,Pôrto Querência,18,,-22.966667,-53.6
br,porto quijarro,Pôrto Quijarro,11,,-19,-57.716667
br,porto quinze de agosto,Pôrto Quinze de Agôsto,11,,-21.966667,-53.816667
br,porto quinze de agosto,Pôrto Quinze de Agôsto,14,,-15.216667,-59.45
br,porto quinze de novembro,Pôrto Quinze de Novembro,11,,-21.783333,-52.166667
br,porto quinze de novembro,Pôrto Quinze de Novembro,24,,-10.716667,-62.783333
br,porto quinze,Porto Quinze,14,,-15.216667,-59.45
br,porto quiqui,Pôrto Quiqui,11,,-21.95,-54.283333
br,porto real da sao francisco,Porto Real da São Francisco,15,,-20.166667,-45.7
br,porto real de sao francisco,Pôrto Real de São Francisco,15,,-20.166667,-45.7
br,porto real do colegio,Pôrto Real do Colégio,02,6001,-10.183333,-36.816667
br,porto real do collegio,Porto Real do Collegio,02,,-10.183333,-36.816667
br,porto real,Pôrto Real,15,,-20.166667,-45.7
br,porto real,Porto Real,21,12061,-22.4172,-44.2861
br,porto real,Porto Real,31,,-9.295556,-47.778056
br,porto ribeirao vermelho,Pôrto Ribeirão Vermelho,27,,-22.7,-51.366667
br,porto ribeiro,Pôrto Ribeiro,27,,-22.45,-48.65
br,porto rico,Pôrto Rico,02,,-8.9,-35.616667
br,porto rico,Pôrto Rico,04,,-7.066667,-71.716667
br,porto rico,Pôrto Rico,06,,-4.266667,-38.85
br,porto rico,Pôrto Rico,18,,-22.766667,-53.25
br,porto rio amambai,Pôrto Rio Amambaí,11,,-23.333333,-53.85
br,porto rio iguatemi,Pôrto Rio Iguatemi,11,,-23.933333,-54.166667
br,porto roberto,Pôrto Roberto,14,,-13.8,-60.466667
br,porto rode,Pôrto Rode,26,,-27.166667,-53.616667
br,porto rolon,Pôrto Rolon,11,,-22.233333,-53.583333
br,porto roseira,Porto Roseira,11,,-22.966667,-54.616667
br,porto sabauma,Pôrto Sabauma,27,,-24.816667,-47.75
br,porto sabauna,Porto Sabaúna,27,,-24.816667,-47.75
br,porto salva,Porto Salva,16,,-.95,-48.15
br,porto salvo,Pôrto Salvo,16,,-.95,-48.15
br,porto santa barbara,Pôrto Santa Bárbara,11,,-22.5,-53.533333
br,porto santa helena,Pôrto Santa Helena,18,,-24.933333,-54.383333
br,porto santa maria,Porto Santa Maria,14,,-16.95,-56.216667
br,porto santa maria,Pôrto Santa Maria,18,,-25.716667,-52.283333
br,porto santana,Pôrto Santana,03,,-.05,-51.183333
br,porto santana,Pôrto Santana,18,,-25.666667,-52.483333
br,porto santa rosa,Pôrto Santa Rosa,11,,-20.983333,-57.8
br,porto santo antonio,Pôrto Santo Antônio,23,,-27.466667,-54.35
br,porto santo cruz,Porto Santo Cruz,05,,-15.183333,-41.35
br,porto sao bento,Pôrto São Bento,11,,-22.016667,-53.716667
br,porto sao carlos,Porto São Carlos,18,,-23.36329,-52.524268
br,porto sao domingos,Pôrto São Domingos,14,,-10.95,-51.366667
br,porto sao domingos,Pôrto São Domingos,15,,-19.216667,-50.75
br,porto sao domingos,Pôrto São Domingos,18,,-24.583333,-54.3
br,porto sao francisco,Pôrto São Francisco,11,,-22.6,-53.116667
br,porto sao jeronimo,Pôrto São Jerônimo,29,,-18.683333,-50.25
br,porto sao jeronymo,Pôrto São Jeronymo,29,,-18.683333,-50.25
br,porto sao joao evangelico,Porto São João Evangelico,11,,-18.65,-56.816667
br,porto sao joao,Pôrto São João,11,,-22.633333,-53.133333
br,porto sao jose,Pôrto São José,11,,-17.366667,-56.8
br,porto sao jose,Pôrto São José,18,,-22.716667,-53.166667
br,porto sao jose velho,Pôrto São José Velho,11,,-17.366667,-56.8
br,porto sao martinho,Pôrto São Martinho,11,,-21.733333,-54.183333
br,porto sao paulo novo,Pôrto São Paulo Novo,27,,-21.983333,-52.3
br,porto sao pedro,Pôrto São Pedro,18,,-22.75,-53.216667
br,porto sape,Pôrto Sapé,11,,-21.883333,-54.683333
br,porto sapucahy,Pôrto Sapucahy,15,,-22.25,-45.7
br,porto sassora,Pôrto Sassorá,11,,-23.566667,-54.766667
br,porto sassoro,Pôrto Sassoró,11,,-23.566667,-54.766667
br,porto sauipe,Pôrto Sauípe,05,,-12.4,-37.916667
br,porto seguro,Porto Seguro,04,,-5.554444,-60.890556
br,porto seguro,Pôrto Seguro,05,123196,-16.433333,-39.083333
br,porto seguro,Porto Seguro,13,,-6.7,-43.783333
br,porto seguro,Porto Seguro,15,,-20.666667,-43.1
br,porto seguro,Pôrto Seguro,16,,-1.033333,-47.416667
br,porto seguro,Pôrto Seguro,20,,-6.733333,-43.783333
br,porto seguro,Pôrto Seguro,21,,-21.683333,-42.166667
br,porto seguro,Pôrto Seguro,25,,3.45,-60.166667
br,porto seguro,Pôrto Seguro,27,,-22.9,-50.433333
br,porto sete de setembro,Pôrto Sete de Setembro,11,,-22.216667,-52.516667
br,porto sete de setembro,Pôrto Sete de Setembro,18,,-25.183333,-54.45
br,porto sinop,Pôrto Sinop,18,,-24.083333,-53.983333
br,porto snope,Pôrto Snope,18,,-24.083333,-53.983333
br,porto soares,Porto Soares,11,,-22.383333,-54.75
br,porto sol de maio,Pôrto Sol de Maio,18,,-25.05,-54.466667
br,porto subauma,Porto Subauma,27,,-24.816667,-47.75
br,porto taboado,Pôrto Taboado,11,,-20.183333,-51.05
br,porto tabuado,Pôrto Tabuado,11,,-20.183333,-51.05
br,porto tagacaba,Pôrto Tagaçaba,18,,-25.216667,-48.466667
br,porto taquarucu,Pôrto Taquaruçu,27,,-22.6,-51.883333
br,porto teixeira,Porto Teixeira,27,,-22.916667,-50.583333
br,porto tenente marques,Pôrto Tenente Marques,24,,-12.35,-59.966667
br,porto tibagi,Pôrto Tibagi,27,,-22.783333,-51.016667
br,porto tibirica,Pôrto Tibiriçá,27,,-21.816667,-52.166667
br,porto tiburcio de meio,Pôrto Tibúrcio de Meio,27,,-24.05,-49.416667
br,porto tiburcio de melo,Pôrto Tibúrcio de Melo,27,,-24.05,-49.416667
br,porto tonico,Pôrto Tonico,14,,-15.416667,-57.7
br,porto tritona,Pôrto Tritona,11,,-23.766667,-54.7
br,porto triunfo,Pôrto Triunfo,24,,-12.9,-60.8
br,porto uere,Pôrto Uerê,11,,-21.7,-52.483333
br,porto una,Pôrto Una,27,,-24.433333,-47.083333
br,porto uniao,Pôrto União,26,28907,-26.25,-51.083333
br,porto unicao,Porto Unicão,26,,-26.25,-51.083333
br,porto urbano,Pôrto Urbano,14,,-16.383333,-55.966667
br,porto valter,Porto Valter,01,,-8.261111,-72.738889
br,porto vanilha,Pôrto Vanilha,11,,-23.566667,-54.033333
br,porto veado,Pôrto Veado,25,,2.25,-60.933333
br,porto velho da cunha,Porto Velho da Cunha,21,,-21.833333,-42.533333
br,porto velho do cunha,Pôrto Velho do Cunha,21,,-21.833333,-42.533333
br,porto velho ii,Porto Velho II,13,,-3.241389,-43.417778
br,porto velho i,Porto Velho I,13,,-3.228611,-43.410556
br,porto velho,Pôrto Velho,05,,-13.6,-41.083333
br,porto velho,Pôrto Velho,11,,-17.766667,-57.083333
br,porto velho,Pôrto Velho,14,,-10.783333,-51
br,porto velho,Pôrto Velho,17,,-6.99,-34.875
br,porto velho,Porto Velho,18,,-24.692258,-48.783855
br,porto velho,Porto Velho,23,,-32.033333,-52.091667
br,porto velho,Pôrto Velho,24,306206,-8.766667,-63.9
br,porto velho,Pôrto Velho,27,,-21.833333,-52.166667
br,porto verde,Pôrto Verde,11,,-23.783333,-54.75
br,porto victoria,Porto Victoria,11,,-22.3,-54.516667
br,porto vila nova,Pôrto Vila Nova,27,,-22.466667,-52.883333
br,porto vista alegre,Pôrto Vista Alegre,29,,-17.333333,-47.466667
br,porto vitoria,Pôrto Vitória,11,,-22.3,-54.516667
br,porto vitoria,Pôrto Vitória,16,,-2.85,-52
br,porto vitoria,Pôrto Vitória,18,,-26.15,-51.216667
br,porto walter,Pôrto Walter,01,1816,-8.261111,-72.738889
br,porto xavier,Pôrto Xavier,23,,-27.9,-55.133333
br,porto zinico,Pôrto Zinico,27,,-20.233333,-48.533333
br,porto zizico,Pôrto Zizico,27,,-20.233333,-48.533333
br,porto zulmira,Porto Zulmira,18,,-26.166667,-51.133333
br,portugal,Portugal,16,,-5.866667,-57.1
br,portugal velho,Portugal Velho,16,,-5.883333,-57.1
br,portuguesa,Portuguêsa,21,,-22.266667,-41.95
br,portugueses,Portugueses,27,,-23.277877,-47.976058
br,poruquara,Poruquara,18,,-25.271133,-48.26872
br,porvir novo,Porvir Novo,01,,-10.866667,-68.6
br,porvir,Porvir,01,,-10.916667,-68.616667
br,posangue,Posangue,02,,-9.366667,-36.583333
br,posse de ressaca,Posse de Ressaca,27,,-22.6,-46.916667
br,posse do meio,Posse do Meio,21,,-21.283333,-41.516667
br,posse dos coutinhos,Posse dos Coutinhos,21,,-22.816667,-42.75
br,posse,Posse,05,,-13.116667,-39.983333
br,posse,Posse,21,,-22.253056,-43.075
br,posse,Posse,27,,-22.6,-46.916667
br,posse,Posse,29,20003,-14.083333,-46.366667
br,posses,Posses,15,,-20.216667,-46.683333
br,posses,Posses,23,,-29.483333,-51.866667
br,posses,Posses,29,,-18.283333,-49
br,posto alto manissaua,Pôsto Alto Manissaua,14,,-11.3,-54.7
br,posto bodoco,Pôsto Bodocó,30,,-7.433333,-39.983333
br,posto branco,Pôsto Branco,23,,-30.45,-54.55
br,posto carvalho,Pôsto Carvalho,26,,-26.533333,-49.6
br,posto central,Pôsto Central,05,,-16.166667,-39.283333
br,posto cocraimoro,Pôsto Cocraimoro,16,,-7.216667,-52.6
br,posto curua,Pôsto Curua,16,,-6.416667,-54.833333
br,posto de monta,Pôsto de Monta,18,,-23.1,-51.016667
br,posto de pescana,Pôsto de Pescana,18,,-25.583333,-54.383333
br,posto de saude,Pôsto de Saude,20,,-5.916667,-42.616667
br,posto diuarum,Pôsto Diuarum,14,,-11.2,-53.233333
br,posto dos indios,Pôsto dos Índios,18,,-25.3,-52.583333
br,posto duque de caxias,Pôsto Duque de Caxias,26,,-26.85,-49.716667
br,posto esso,Pôsto Esso,05,,-12.466667,-39.233333
br,posto fiscal macuricana,Pôsto Fiscal Macuricanã,04,,-2.25,-56.483333
br,posto fiscal,Posto Fiscal,18,,-25.084666,-48.59989
br,posto fiscal,Pôsto Fiscal,20,,-7.583333,-40.716667
br,posto fiscal,Pôsto Fiscal,24,,-12.483333,-63.633333
br,posto fiscal rolim de moura,Pôsto Fiscal Rolim de Moura,24,,-13.083333,-62.266667
br,posto florestal,Posto Florestal,27,,-23.9855,-46.7418
br,posto indigena batovi,Pôsto Indígena Batovi,14,,-14.066667,-54.216667
br,posto indigena do criacao simoes lopes,Posto Indigena do Criação Simões Lopes,14,,-14.233333,-54.683333
br,posto indigena presidente alves de barro,Pôsto Indígena Presidente Alves de Barro,11,,-20.433333,-56.966667
br,posto monta,Pôsto Monta,18,,-23.1,-51.016667
br,posto paraguacu,Pôsto Paraguaçu,05,,-15.183333,-39.75
br,posto paraguassu,Pôsto Paraguassú,05,,-15.183333,-39.75
br,posto piai,Posto Piai,23,,-29.228,-51.0369
br,posto simoes lopes,Pôsto Simões Lopes,14,,-14.233333,-54.683333
br,posto wauso,Posto Wauso,14,,-13.569444,-59.604167
br,posto ypiranga,Posto Ypiranga,04,,-2.931944,-69.695
br,potengi pequeno,Potengi Pequeno,22,,-5.916667,-35.833333
br,potengi,Potengi,06,,-7.1,-40
br,potengi,Potengi,22,,-5.85,-35.516667
br,potengy,Potengy,22,,-5.916667,-35.75
br,potenji,Potenji,06,,-7.1,-40
br,pote,Poté,15,,-17.816667,-41.816667
br,pote,Pote,20,,-6.25,-41.883333
br,pote,Poté,21,,-22.416667,-41.95
br,pote seco,Pote Seco,20,,-3.505833,-42.4775
br,potiguara,Potiguara,23,,-29.683333,-51.133333
br,potinga,Potinga,18,,-25.234824,-48.53762
br,potinha,Potinha,17,,-7.533333,-34.833333
br,poti,Poti,06,,-5.083333,-40.8
br,poti,Poti,20,,-5.033333,-42.833333
br,potiragua,Potiraguá,05,,-15.6,-39.883333
br,potira,Potira,17,,-7.733333,-36.316667
br,potirendaba,Potirendaba,27,,-21.066667,-49.383333
br,potiretama,Potiretama,06,,-5.716667,-38.15
br,potiri,Potiri,08,,-20.05,-40.3
br,poti velho,Poti Velho,20,,-5.033333,-42.833333
br,potreirito,Potreirito,11,,-22.533333,-55.516667
br,potreiro de julho,Potreiro de Julho,11,,-22.683333,-55.6
br,potreiro,Potreiro,11,,-20.416667,-56.583333
br,potreiro,Potreiro,27,,-20.75,-47.383333
br,potunduva,Potunduva,27,,-22.383333,-48.633333
br,poty,Poty,06,,-5.083333,-40.8
br,potyrendaba,Potyrendaba,27,,-21.066667,-49.383333
br,pouca conta,Pouca Conta,05,,-12.95,-39.7
br,pousada do engenho,Pousada do Engenho,21,,-22.909107,-43.389855
br,pousa,Pousa,22,,-5.633333,-35.733333
br,pouso alegre,Pouso Alegre,04,,-4.323333,-59.688333
br,pouso alegre,Pouso Alegre,05,,-12.833333,-39.133333
br,pouso alegre,Pouso Alegre,08,,-20.016667,-41.133333
br,pouso alegre,Pouso Alegre,11,,-20.783333,-55.366667
br,pouso alegre,Pouso Alegre,14,,-11.733333,-57.316667
br,pouso alegre,Pouso Alegre,15,115203,-22.216667,-45.933333
br,pouso alegre,Pouso Alegre,18,,-25.116667,-53.016667
br,pouso alegre,Pouso Alegre,27,,-23.2589,-46.2406
br,pouso alto,Pouso Alto,06,,-4.7,-39.866667
br,pouso alto,Pouso Alto,11,,-19.416667,-54.133333
br,pouso alto,Pouso Alto,15,,-17.166667,-44.166667
br,pouso alto,Pouso Alto,27,,-24.728635,-48.140982
br,pouso alto,Pouso Alto,29,,-17.3,-49.016667
br,pouso cabral,Pouso Cabral,14,,-15.5,-55.8
br,pouso das pindaibas,Pouso das Pindaíbas,15,,-19.283333,-47.383333
br,pouso de passageiros,Pouso de Passageiros,16,,-7.366667,-57.833333
br,pouso do campo,Pouso do Campo,15,,-22.233333,-45.833333
br,pouso dos indios,Pouso dos Índios,04,,.883333,-67.466667
br,pouso feio,Pouso Feio,18,,-24.833333,-51.966667
br,pouso frio,Pouso Frio,15,,-21.083333,-45.2
br,pouso grande,Pouso Grande,16,,-4.666667,-56.25
br,pouso novo,Pouso Novo,23,,-29.166667,-52.2
br,pouso,Pouso,16,,-1.733333,-46.516667
br,pouso redondo,Pouso Redondo,26,,-27.25,-49.95
br,pouso seco,Pouso Sêco,21,,-22.683333,-44.166667
br,pouso separacao,Pouso Separação,18,,-24.916667,-53.583333
br,pousos,Pousos,16,,-1.866667,-46.316667
br,pousso redondo,Pousso Redondo,26,,-27.25,-49.95
br,poveado toldo,Poveado Toldo,23,,-27.75,-52.166667
br,povinho,Povinho,18,,-25.883333,-49.966667
br,povoacao benedito quintino,Povoação Benedito Quintino,15,,-18.783333,-40.983333
br,povoacao,Povoação,08,,-20.466667,-41.166667
br,povoacao,Povoação,20,,-6.883333,-40.75
br,povoacoes,Povoações,05,,-12.6,-39.45
br,povoado de guajara,Povoado de Guajará,04,,-7.566667,-72.6
br,povoado de sao simao,Povoado de São Simão,15,,-20.133333,-45.5
br,povoado dos miler,Povoado dos Miler,27,,-21.483333,-49.016667
br,povoan,Povoan,18,,-23.419622,-52.699973
br,povo novo,Povo Novo,23,,-31.933333,-52.316667
br,poxim do sul,Poxim do Sul,05,,-15.45,-39
br,poxim,Poxim,02,,-10.033333,-36.05
br,poxim,Poxim,05,,-15.45,-39
br,poxoreu,Poxoreu,14,,-15.833333,-54.383333
br,praca da bandeira,Práça da Bandeira,21,,-22.911934,-43.214805
br,praca da serra,Praça da Serra,18,,-25.308135,-48.947271
br,praca do carmo,Praça do Carmo,21,,-22.836477,-43.298427
br,praca do jatoba,Praça do Jatobá,05,,-11.3,-40.783333
br,praca,Praça,05,,-11.266667,-40.75
br,praca seca,Praça Seca,21,,-22.899526,-43.347727
br,praceiro,Praceiro,16,,-7.816667,-54.816667
br,pracinha,Pracinha,27,,-21.85,-51.083333
br,pradinia,Pradínia,27,,-21.766667,-49.233333
br,pradopolis,Pradópolis,27,13193,-21.366667,-48.066667
br,prado,Prado,05,15466,-17.35,-39.216667
br,prado,Prado,06,,-5.583333,-38.416667
br,prado,Prado,23,,-27.133333,-53.4
br,prado,Prado,27,,-20.166667,-48.8
br,pradoso,Pradoso,05,,-14.833333,-40.95
br,prados,Prados,15,,-21.05,-44.083333
br,praia chata,Praia Chata,13,,-5.25,-47.866667
br,praia chico,Praia Chico,16,,-5,-56.65
br,praia da bandeira,Praia da Bandeira,21,,-22.810272,-43.180639
br,praia da conceicao,Praia da Conceição,30,,-7.883333,-34.833333
br,praia de aracatiba,Praia de Araçatiba,21,,-23.1,-44.25
br,praia de sao lourenco,Praia de São Lourenço,27,,-23.816667,-46.05
br,praia do leste,Praia do Leste,18,,-25.691667,-48.466667
br,praia do peixe,Praia do Peixe,18,,-24.691748,-48.698201
br,praia dos carneiros,Praia dos Carneiros,30,,-8.7,-35.1
br,praia dos namorados,Praia dos Namorados,27,,-22.703889,-47.274167
br,praia dourada,Praia Dourada,04,,-3.029167,-60.098333
br,praia do vinte e oito,Praia do Vinte e Oito,04,,-.7,-61.483333
br,praia formosa,Praia Formosa,21,,-22.903757,-43.205258
br,praia grande,Praia Grande,04,,-6.783333,-60.283333
br,praia grande,Praia Grande,05,,-11.466667,-38.066667
br,praia grande,Praia Grande,18,,-24.808024,-48.996249
br,praia grande,Praia Grande,26,,-26.333333,-48.583333
br,praia grande,Praia Grande,27,250032,-24,-46.4
br,praial,Praial,14,,-16.616667,-56.45
br,praia norte,Praia Norte,31,,-5.359444,-47.609167
br,praiao,Praião,15,,-18.616667,-49.6
br,praia,Praia,13,,-6.716667,-43.116667
br,praia,Praia,15,,-21.016667,-44.316667
br,praia,Praia,21,,-22.433333,-41.866667
br,praia redonda,Praia Redonda,26,,-28.166667,-48.966667
br,praia rica,Praia Rica,14,,-14.85,-55.55
br,praia seca,Praia Sêca,21,,-22.933333,-42.333333
br,praiba,Praíba,30,,-9.083333,-36.65
br,prainha da ponta do uva,Prainha da Ponta do Uvá,18,,-25.411487,-48.420781
br,prainha do andrade,Prainha do Andrade,16,,-4.966667,-56.6
br,prainha,Prainha,04,,-4.237778,-62.311389
br,prainha,Prainha,06,,-3.9,-38.35
br,prainha,Prainha,16,6481,-1.8,-53.483333
br,prainha,Prainha,18,,-25.5675,-48.313333
br,prainha,Prainha,21,,-23.038055,-43.506529
br,prainha,Prainha,27,,-24.283333,-47.466667
br,prainhas,Prainhas,16,,-1.783333,-51.666667
br,prainnha,Prainnha,18,,-25.457392,-48.609617
br,pranchada,Pranchada,23,,-27.45,-54.3
br,pranchado,Pranchado,23,,-27.45,-54.3
br,pranchao,Pranchão,14,,-14.616667,-56.133333
br,pranchita,Pranchita,18,,-26.020556,-53.738333
br,praseras,Praseras,05,,-10.785278,-46.085278
br,prata do piaui,Prata do Piauí,20,,-5.666667,-42.2
br,prata dos aredos,Prata dos Aredos,21,,-22.413903,-42.901635
br,prata iii,Prata III,13,,-3.331944,-43.414444
br,prata ii,Prata II,13,,-3.085278,-43.354444
br,prata i,Prata I,13,,-3.795,-43.206944
br,pratania,Pratânia,27,,-22.816667,-48.65
br,pratapolis,Pratápolis,15,,-20.75,-46.866667
br,prata,Prata,05,,-11.8,-45.6
br,prata,Prata,06,,-2.933333,-40.266667
br,prata,Prata,08,,-18.283333,-40.966667
br,prata,Prata,13,,-2.766667,-43.533333
br,prata,Prata,14,,-16.833333,-53.866667
br,prata,Prata,15,19896,-19.3,-48.916667
br,prata,Prata,16,,-1.3,-47.6
br,prata,Prata,17,,-6.633333,-38.016667
br,prata,Prata,18,,-23.066667,-51.25
br,prata,Prata,20,,-5.616667,-42.966667
br,prata,Prata,21,,-20.85,-41.75
br,prata,Prata,23,,-28.783333,-51.6
br,prata,Prata,27,,-20.283333,-47.866667
br,prata,Prata,29,,-13.166667,-46.8
br,prata,Prata,30,,-8.7,-36.316667
br,pratas,Pratas,05,,-15.2,-39.433333
br,prates,Prates,08,,-20.916667,-41.016667
br,pratigipe,Pratigipe,05,,-13.016667,-38.95
br,pratigi,Pratigi,05,,-13.516667,-38.916667
br,pratijipe,Pratijipe,05,,-13.016667,-38.95
br,pratinha,Pratinha,08,,-20.65,-41.633333
br,pratinha,Pratinha,15,,-19.766667,-46.4
br,pratinha,Pratinha,23,,-28.733333,-51.633333
br,pratinha,Pratinha,25,,2.7,-61.033333
br,pratinha,Pratinha,27,,-21.433333,-47.533333
br,pratis,Pratis,21,,-22.331444,-42.894296
br,prato certo,Prato Certo,20,,-6.9,-40.716667
br,prato fino,Prato Fino,05,,-10.95,-43.483333
br,prato raso,Prato Raso,05,,-9.683333,-43.35
br,pratos,Pratos,23,,-27.5,-54.5
br,prazeiro,Prazeiro,16,,-7.816667,-54.816667
br,prazeras,Prazeras,30,,-8.166667,-34.933333
br,prazer da vida,Prazer da Vida,31,,-6.583333,-48.6
br,prazeres,Prazeres,02,,-9.883333,-37.233333
br,prazeres,Prazeres,05,,-10.785278,-46.085278
br,prazeres,Prazeres,06,,-7.1,-38.683333
br,prazeres,Prazeres,15,,-17.816667,-41.6
br,prazeres,Prazeres,20,,-3.940556,-42.085833
br,prazeres,Prazeres,25,,-3.233333,-61.133333
br,prazeres,Prazeres,30,,-7.816667,-38.466667
br,prea,Preá,06,,-4.533333,-37.9
br,prego,Prego,16,,-1.033333,-48.233333
br,pregos,Pregos,15,,-21.766667,-42.9
br,preguica,Preguiça,15,,-20.583333,-41.983333
br,preguica,Preguiça,28,,-10.883333,-37.516667
br,preguicas,Preguiças,13,,-3.116667,-45.183333
br,prensa,Prensa,06,,-3.216667,-40
br,prensa,Prensa,17,,-6.383333,-37.9
br,prensa,Prensa,18,,-25.6,-49.25
br,prequeiro,Prequeiro,06,,-4.433333,-38.933333
br,prequicosa,Prequiçosa,06,,-6.016667,-40.7
br,presidente afonso pena,Presidente Afonso Pena,24,,-10.866667,-61.95
br,presidente alves,Presidente Alves,27,,-22.083333,-49.45
br,presidente bernardes,Presidente Bernardes,15,,-20.766667,-43.2
br,presidente bernardes,Presidente Bernardes,27,12954,-22.05,-51.55
br,presidente dutra,Presidente Dutra,02,30330,-5.25,-44.5
br,presidente dutra,Presidente Dutra,18,,-26.081944,-53.564167
br,presidente dutra,Presidente Dutra,29,,-18.9,-50.5
br,presidente epistacio,Presidente Epistacio,27,,-21.766667,-52.1
br,presidente epitacio,Presidente Epitácio,27,38742,-21.766667,-52.1
br,presidente epitaclo,Presidente Epitãclo,27,,-21.766667,-52.1
br,presidente figueiredo,Presidente Figueiredo,04,,-2.05,-60.05
br,presidente getulio,Presidente Getúlio,26,,-27.0448,-49.6224
br,presidente hermes,Presidente Hermes,24,,-11.283333,-61.916667
br,presidente juncelino,Presidente Juncelino,21,,-22.767532,-43.439764
br,presidente juscelino,Presidente Juscelino,21,,-22.767532,-43.439764
br,presidente kennedy,Presidente Kennedy,31,,-8.489722,-48.389722
br,presidente marques,Presidente Marques,24,,-9.7,-65.383333
br,presidente medici,Presidente Médici,24,11923,-11.283333,-61.916667
br,presidente murtinho,Presidente Murtinho,14,,-15.65,-53.9
br,presidente olegario,Presidente Olegário,15,13587,-18.416667,-46.416667
br,presidente pena,Presidente Pena,15,,-17.683333,-40.883333
br,presidente pena,Presidente Pena,26,,-26.7,-51.05
br,presidente penna,Presidente Penna,15,,-17.683333,-40.883333
br,presidente penna,Presidente Penna,24,,-10.866667,-61.95
br,presidente,Presidente,24,,-11.283333,-61.916667
br,presidente prudente,Presidente Prudente,27,209507,-22.116667,-51.366667
br,presidente soares,Presidente Soares,15,,-20.416667,-41.966667
br,presidente tibirica,Presidente Tibiriça,27,,-22.233333,-49.25
br,presidente vargas,Presidente Vargas,08,,-20.733333,-41.116667
br,presidente vargas,Presidente Vargas,13,,-1.283333,-45.766667
br,presidente vargas,Presidente Vargas,15,,-19.616667,-43.216667
br,presidente vargas,Presidente Vargas,27,,-20.216667,-51.033333
br,presidente venceslau,Presidente Venceslau,27,34026,-21.866667,-51.833333
br,presidente wenceslau,Presidente Wenceslaú,27,,-21.866667,-51.833333
br,presidio,Presídio,05,,-11.6,-41.566667
br,presidio,Presídio,13,,-5.066667,-46.233333
br,presidio,Presídio,21,,-22.906111,-43.311111
br,preta mina,Preta Mina,16,,-1.683333,-46.6
br,preta,Preta,02,,-9.85,-36.583333
br,preta,Preta,05,,-13.4,-39.083333
br,preta,Preta,15,,-19.166667,-45.95
br,prevenido,Prevenido,20,,-3.55,-41.733333
br,pricilio,Pricílio,05,,-13.983333,-40.583333
br,primavera de santo antonio,Primavera de Santo Antônio,30,,-8.35,-35.366667
br,primavera,Primavera,02,,-9.45,-36.183333
br,primavera,Primavera,04,,-.433333,-65.316667
br,primavera,Primavera,05,,-12.416667,-38.466667
br,primavera,Primavera,06,,-3.133333,-39.683333
br,primavera,Primavera,11,,-19.433333,-55.816667
br,primavera,Primavera,13,,-4.4,-44.916667
br,primavera,Primavera,14,,-15.683333,-54.366667
br,primavera,Primavera,16,,-.933333,-47.1
br,primavera,Primavera,18,,-24.35,-52.933333
br,primavera,Primavera,20,,-6.166667,-41.883333
br,primavera,Primavera,22,,-5.666667,-35.933333
br,primavera,Primavera,24,,-9.666667,-62.35
br,primavera,Primavera,27,,-21.983333,-49.983333
br,primavera,Primavera,30,,-8.35,-35.366667
br,primavera,Primavera,31,,-7.566667,-48.416667
br,primeira alianca,Primeira Aliança,27,,-21.016667,-51.116667
br,primeira cruz,Primeira Cruz,13,,-2.5,-43.433333
br,primeira ilha,Primeira Ilha,05,,-17.983333,-40
br,primeira lagoa,Primeira Lagoa,22,,-5.683333,-35.516667
br,primeiro campo,Primeiro Campo,04,,-2.8,-57.6
br,primeiro campo,Primeiro Campo,13,,-3.62,-43.2875
br,primeiro de maio,Primeiro de Maio,18,,-22.8,-51.016667
br,primeiro faxinal dos castilhos,Primeiro Faxinal dos Castilhos,18,,-25.8085,-49.9143
br,primor,Primor,24,,-8.433333,-63.483333
br,princesa d'oeste,Princesa d'Oeste,27,,-20.9,-49.383333
br,princesa isabel,Princesa Isabel,17,12616,-7.733333,-38
br,princesa isabel,Princesa Isabel,23,,-27.7,-52.066667
br,princesa isabel,Princesa Isabel,26,,-26.95,-51.1
br,princesa izabel,Princesa Izabel,23,,-27.7,-52.066667
br,princesa,Princesa,08,,-20.716667,-40.916667
br,princesa,Princesa,17,,-7.733333,-38
br,princess isabel,Princess Isabel,17,,-7.733333,-38
br,princeza,Princeza,17,,-7.733333,-38
br,principe da beira,Príncipe da Beira,24,,-12.416667,-64.416667
br,principe imperial,Príncipe Imperial,04,,-7.566667,-72.566667
br,principe imperial,Príncipe Imperial,06,,-5.166667,-40.666667
br,principe,Príncipe,08,,-20.333333,-41.833333
br,principe,Príncipe,31,,-11.976111,-47.543056
br,procopio carvalho,Procópio Carvalho,27,,-21.733333,-47.533333
br,procopio,Procópio,03,,1.016667,-50.783333
br,procos,Procos,31,,-10.9,-47.3
br,producao,Produção,05,,-13.25,-40.033333
br,professor sousa,Professor Sousa,21,,-22.5,-42.133333
br,professor sperber,Professor Sperber,15,,-19.983333,-41.666667
br,profeta,Profeta,01,,-7.716667,-72.616667
br,progresso,Progresso,01,,-8.183333,-72.05
br,progresso,Progresso,05,,-16.433333,-39.35
br,progresso,Progresso,23,,-29.25,-52.3
br,projeto,Projeto,20,,-10.233333,-45.25
br,promissao,Promissão,02,,-9.233333,-37.566667
br,promissao,Promissão,11,,-18.65,-55.7
br,promissao,Promissão,27,27032,-21.533333,-49.866667
br,propria,Propriá,28,23787,-10.216667,-36.85
br,prosela,Prosela,04,,-2.716667,-66.783333
br,prosperidade,Prosperidade,08,,-20.666667,-41.066667
br,prosperidade,Prosperidade,15,,-20.283333,-41.966667
br,prosperidade,Prosperidade,21,,-22.05,-41.483333
br,protasio alves,Protásio Alves,23,,-28.766667,-51.483333
br,protecao,Proteção,05,,-12.783333,-38.95
br,protecao,Proteção,11,,-19.55,-55.316667
br,protestantes,Protestantes,15,,-22.733333,-46.3
br,protogenes,Protógenes,14,,-15.733333,-55.8
br,provazzi,Provazzi,27,,-23.211265,-47.741748
br,providencia,Providência,01,,-9.733333,-68.25
br,providencia,Providência,04,,-.316667,-63.966667
br,providencia,Providência,15,,-21.666667,-42.583333
br,providencia,Providência,16,,-2.016667,-49.833333
br,providencia,Providencia,24,,-9.116667,-63.25
br,providencia,Providência,25,,-3.733333,-60.5
br,providencia,Providência,28,,-10.133333,-37.1
br,provisao,Provisão,05,,-13.933333,-40
br,prudencio de morais,Prudêncio de Morais,27,,-20.533333,-50.45
br,prudente de morais,Prudente de Morais,06,,-5.35,-39.316667
br,prudente de morais,Prudente de Morais,15,,-19.483333,-44.166667
br,prudentes,Prudentes,27,,-23.173823,-47.985727
br,prudentopolis,Prudentópolis,18,19611,-25.2,-50.95
br,puba,Puba,06,,-3.083333,-40.3
br,pubas,Pubas,20,,-6.133333,-42.366667
br,pucalpa,Pucalpa,01,,-7.85,-72.716667
br,puca,Puca,04,,-7.217778,-70.881389
br,puca,Puçá,13,,-3.145833,-42.234722
br,puca,Puçá,20,,-8.4,-44.4
br,pucazeiro,Puçàzeiro,13,,-9.383333,-46.016667
br,pucuma,Pucumã,13,,-5.7,-44.366667
br,pucurina,Pucurina,03,,3.733333,-51.566667
br,pucuriua,Pucuriua,03,,3.733333,-51.566667
br,pucuriu,Pucuriu,03,,3.733333,-51.566667
br,puei,Puei,23,,-30.116667,-56.416667
br,puerto itacora,Puerto Itacora,18,,-25.116667,-54.433333
br,puerto lucena,Puerto Lucena,23,,-27.85,-55.016667
br,puerto mendes,Puerto Mendes,18,,-24.5,-54.333333
br,puerto mendez,Puerto Méndez,18,,-24.5,-54.333333
br,puerto novo,Puerto Novo,01,,-10.116667,-66.916667
br,puerto ocoi,Puerto Ocoi,18,,-25.216667,-54.466667
br,puga,Puga,11,,-19.666667,-57.516667
br,pugas de cima,Pugas de Cima,18,,-25.45,-49.966667
br,pug mill,Pug Mill,31,,-10.417778,-48.803333
br,puiracu,Puiraçu,30,,-8.9,-35.15
br,puirassu,Puirassú,30,,-8.9,-35.15
br,puiu,Puiú,30,,-8.616667,-37.466667
br,pulador,Pulador,11,,-19.05,-54.816667
br,pulador,Pulador,23,,-28.8,-52.05
br,pulga,Pulga,15,,-18.633333,-42.45
br,pulgas,Pulgas,22,,-6.366667,-38.033333
br,pulinopolis,Pulinópolis,18,,-23.283333,-52.016667
br,pumba,Pumba,05,,-12.683333,-39.2
br,punau,Punau,22,,-5.35,-35.416667
br,pune,Pune,16,,1.966667,-54.916667
br,pungare,Pungaré,18,,-25.9187,-49.4822
br,punta da serra,Punta da Serra,13,,-6.316667,-42.916667
br,pupunha,Pupunha,04,,-5.1,-67.2
br,pupunhas,Pupunhas,04,,-5.1,-67.2
br,pupuri,Pupuri,04,,-7.483333,-65.366667
br,pupury,Pupury,04,,-7.483333,-65.366667
br,pureza,Pureza,21,,-21.583333,-41.833333
br,pureza,Pureza,22,,-5.466667,-35.55
br,purilandia,Purilândia,21,,-20.933333,-41.95
br,purma campi,Purma Campi,04,,-4.386944,-70.935
br,purma,Purma,04,,-2.931944,-69.695
br,purus,Purús,01,,-9.066667,-68.666667
br,puruzinho,Puruzinho,04,,-5.885556,-64.409444
br,pussazeiro,Pussazeiro,13,,-9.383333,-46.016667
br,putinga,Putinga,23,,-29,-52.15
br,putiri,Putiri,08,,-20.05,-40.3
br,puxinana,Puxinanã,02,,-9.5,-37.05
br,puxinana,Puxinanã,17,3210,-7.15,-35.966667
br,pyrenopolis,Pyrenopolis,29,,-15.85,-48.95
br,quadrada,Quadrada,30,,-7.7,-39.933333
br,quadra,Quadra,22,,-5.135278,-36.890278
br,quadra,Quadra,27,,-23.3,-48.05
br,quadro novo,Quadro Novo,26,,-26.944282,-49.67921
br,quadro,Quadro,05,,-13.483333,-38.9
br,quaitiba,Quaitiba,05,,-13.266667,-39.933333
br,quajara,Quajará,04,,-5.533333,-59.55
br,quandu,Quandu,02,,-9.233333,-37.233333
br,quandus,Quandus,13,,-3.878889,-43.447222
br,quantigua,Quantigua,18,,-23.5698,-49.9116
br,quaraci,Quaraci,05,,-14.633333,-39.533333
br,quaracu,Quaraçu,05,,-15.183333,-41.35
br,quarador,Quarador,06,,-5.833333,-39.783333
br,quarahim,Quarahim,23,,-30.216667,-57.55
br,quarahy,Quarahy,23,,-30.383333,-56.45
br,quarai,Quaraí,23,23229,-30.383333,-56.45
br,quarany,Quarany,01,,-10.116667,-67.8
br,quarenta,Quarenta,21,,-22.233333,-41.8
br,quarepoti,Quarepoti,23,,-28.466667,-54.716667
br,quaresma,Quaresma,06,,-7.133333,-40.033333
br,quari,Quarí,04,,-4.109444,-63.138889
br,quarta legua,Quarta Légua,23,,-29.2444,-51.1402
br,quarteirao dos pampas,Quarteirão dos Pampas,05,,-12.183333,-39.733333
br,quarteis,Quartéis,15,,-18.016667,-43.783333
br,quarteis,Quartéis,21,,-22.466667,-42.3
br,quartel geral,Quartel Geral,15,,-19.3,-45.55
br,quartel,Quartel,13,,-2.783333,-43.966667
br,quartel sao joao,Quartel São João,15,,-19.233333,-45.766667
br,quarto de onca,Quarto de Onça,05,,-16.166667,-39.866667
br,quata,Quatá,27,10370,-22.266667,-50.7
br,quatiba,Quatiba,17,,-6.966667,-37.933333
br,quaticaba,Quatiçaba,29,,-13.983333,-46.516667
br,quatiguaba,Quatiguaba,06,,-3.1,-39.566667
br,quatigua,Quatiguá,18,,-23.5698,-49.9116
br,quatiguaua,Quatiguaua,06,,-3.1,-39.566667
br,quatipi,Quatipi,23,,-28.533333,-51.9
br,quatipuru,Quatipuru,16,,-.866667,-46.983333
br,quati,Quati,04,,-5.655278,-63.523333
br,quati,Quati,05,,-13.35,-39.666667
br,quati,Quati,11,,-21.05,-56.233333
br,quati,Quati,15,,-17.016667,-41.833333
br,quati,Quati,17,,-8.15,-36.7
br,quati,Quati,22,,-6.35,-38.35
br,quati,Quati,30,,-8.15,-36.233333
br,quatis gramado,Quatis Gramado,27,,-24.610862,-48.861323
br,quatis,Quatis,05,,-13.233333,-40.333333
br,quatis,Quatis,21,10289,-22.4099,-44.2594
br,quatis,Quatis,27,,-21.233333,-47.35
br,quatituba,Quatituba,15,,-19.4,-41.25
br,quatoquara,Quatoquará,16,,-5.45,-56.866667
br,quatorze de maio,Quatorze de Maio,11,,-22.533333,-54.35
br,quatorze,Quatorze,11,,-22.533333,-54.35
br,quatro barras,Quatro Barras,18,17526,-25.366667,-49.083333
br,quatro bocas,Quatro Bôcas,16,,-1.3,-47.383333
br,quatro buritis,Quatro Buritis,20,,-5,-42.383333
br,quatro e meio,Quatro e Meio,27,,-23.952985,-47.213879
br,quatro irmaos,Quatro Irmãos,18,,-25.933333,-52.766667
br,quatro irmaos,Quatro Irmãos,23,,-27.833333,-52.433333
br,quatro pontes,Quatro Pontes,18,,-24.583333,-53.966667
br,quebo,Quebó,14,,-14.6,-56.066667
br,quebra anzol,Quebra Anzol,13,,-3.074722,-42.764167
br,quebra-canela,Quebra-Canela,14,,-14.483333,-56.6
br,quebra-cangalha,Quebra-Cangalha,05,,-13.1,-41.616667
br,quebra carro,Quebra Carro,21,,-22.96908,-43.620527
br,quebracho,Quebracho,23,,-31.366667,-53.966667
br,quebra-coco,Quebra-Coco,13,,-3.744722,-42.979722
br,quebrada,Quebrada,06,,-5.816667,-40.583333
br,quebradas,Quebradas,05,,-13.916667,-42.333333
br,quebra-dente,Quebra-Dente,27,,-22.766667,-47.5
br,quebra dentes,Quebra Dentes,26,,-27.683333,-49.216667
br,quebra joelho,Quebra Joelho,18,,-25.958881,-49.393287
br,quebra-junta,Quebra-Junta,04,,-3.116944,-63.086667
br,quebra-mar,Quebra-Mar,18,,-25.8484,-48.5454
br,quebrangulo,Quebrângulo,02,6587,-9.333333,-36.483333
br,quebra-pote,Quebra-Pote,13,,-2.683333,-44.216667
br,quebra prato,Quebra Prato,11,,-21.516667,-57.883333
br,quebra unha,Quebra Unha,30,,-7.883333,-38.55
br,quecaba,Queçaba,26,,-27.733333,-48.933333
br,queda,Quedá,11,,-18.883333,-55.65
br,queimacao,Queimação,17,,-7.866667,-36.933333
br,queimada da onca,Queimada da Onça,30,,-8.35,-37.033333
br,queimada de tomas,Queimada de Tomás,22,,-6.1,-36.033333
br,queimada do andre,Queimada do André,30,,-8.883333,-36.666667
br,queimada do curral,Queimada do Curral,05,,-11.416667,-39.35
br,queimada do milho,Queimada do Milho,05,,-9.583333,-39.2
br,queimada do tapuio,Queimada do Tapuio,17,,-6.966667,-36.416667
br,queimada grande,Queimada Grande,05,,-10.3,-40.466667
br,queimada grande,Queimada Grande,06,,-6.2,-40.733333
br,queimada grande,Queimada Grande,13,,-2.666667,-43.183333
br,queimada grande,Queimada Grande,20,,-7.7,-41.466667
br,queimada grande,Queimada Grande,30,,-7.7,-39.45
br,queimada ii,Queimada II,13,,-3.058889,-43.420556
br,queimada i,Queimada I,13,,-3.224167,-43.386667
br,queimada nova,Queimada Nova,02,,-9.616667,-37.483333
br,queimada nova,Queimada Nova,05,,-11.033333,-42.066667
br,queimada nova,Queimada Nova,20,,-8.583333,-41.416667
br,queimada,Queimada,03,,1.95,-50.783333
br,queimada,Queimada,04,,-7.083333,-69.683333
br,queimada,Queimada,05,,-10.616667,-42.6
br,queimada,Queimada,06,,-4.85,-40.016667
br,queimada,Queimada,13,,-2.3,-45.266667
br,queimada,Queimada,15,,-22.45,-45.15
br,queimada,Queimada,16,,-2.266667,-49.75
br,queimada,Queimada,17,,-7.35,-35.916667
br,queimada,Queimada,20,,-8.233333,-41.716667
br,queimada,Queimada,24,,-9.4,-62.433333
br,queimada,Queimada,30,,-8.266667,-38.066667
br,queimadas dos cavalos,Queimadas dos Cavalos,20,,-4.833333,-41.533333
br,queimadas,Queimadas,05,10439,-10.966667,-39.633333
br,queimadas,Queimadas,06,,-3.45,-41.4
br,queimadas,Queimadas,13,,-2.3,-45.266667
br,queimadas,Queimadas,17,20446,-7.35,-35.916667
br,queimadas,Queimadas,18,,-24.2,-50.916667
br,queimadas,Queimadas,20,,-5.766667,-41.816667
br,queimadas,Queimadas,22,,-5.366667,-35.883333
br,queimadas,Queimadas,24,,-9.4,-62.433333
br,queimadas,Queimadas,30,,-7.466667,-37.266667
br,queimade grande,Queimade Grande,30,,-7.8,-37.65
br,queimadinha,Queimadinha,05,,-10.366667,-42.433333
br,queimadinhas,Queimadinhas,05,,-13.05,-40.75
br,queimadinhas,Queimadinhas,18,,-25.464,-50.5607
br,queimado de cima,Queimado de Cima,18,,-26.0146,-49.3624
br,queimado,Queimado,05,,-16.566667,-39.333333
br,queimado,Queimado,08,,-20.166667,-40.383333
br,queimado,Queimado,11,,-22.083333,-57.266667
br,queimado,Queimado,17,,-6.616667,-37.55
br,queimador,Queimador,27,,-23.430728,-47.83192
br,queimados,Queimados,05,,-13.783333,-40.083333
br,queimados,Queimados,06,,-4.766667,-40.416667
br,queimados,Queimados,15,,-22.45,-45.15
br,queimados,Queimados,21,135742,-22.722897,-43.556316
br,queimados,Queimados,24,,-9.4,-62.433333
br,queimasangue,Queimasangue,21,,-22.190833,-43.251944
br,queimondo,Queimondo,15,,-22.45,-45.15
br,queiros,Queirós,27,,-21.816667,-50.216667
br,queiroz,Queiroz,05,,-13.933333,-41.283333
br,queiroz,Queiroz,11,,-20.3,-51.45
br,queiroz,Queiroz,27,,-21.816667,-50.216667
br,queirs,Queirs,21,,-22.338132,-42.832844
br,queixada,Queixada,15,,-17.133333,-42
br,queixada,Queixada,17,,-7.366667,-38.45
br,queixada,Queixada,20,,-6,-40.916667
br,queixadas,Queixadas,15,,-17.133333,-42
br,queluzita,Queluzita,15,,-20.733333,-43.883333
br,queluzito,Queluzito,15,,-20.733333,-43.883333
br,queluz,Queluz,27,,-22.533333,-44.766667
br,quem diria,Quem Diria,04,,-3.783333,-58.383333
br,quenta-sol,Quenta-Sol,15,,-20.133333,-47.116667
br,querema,Querema,02,,-10.083333,-36.516667
br,querencia do norte,Querência do Norte,18,,-23,-53.466667
br,querencia,Querência,18,,-22.966667,-53.6
br,querencia,Querência,23,,-32.2,-52.183333
br,querendo,Querendo,21,,-20.983333,-41.85
br,querera,Quererá,05,,-11.35,-38.816667
br,queres,Queres,20,,-3.916944,-42.407778
br,querida,Querida,06,,-4.033333,-39.833333
br,querino franca,Querino França,11,,-18.7,-54.25
br,queto,Queto,06,,-5.2,-40.1
br,quevedos,Quevedos,23,,-29.35,-54.066667
br,quexados,Quexados,15,,-17.133333,-42
br,quiandeua,Quiandeua,16,,-2.6,-47.866667
br,quicaba,Quiçaba,26,,-27.733333,-48.933333
br,quicama,Quiçamã,21,,-22.1,-41.466667
br,quicama,Quiçamã,28,,-10.9,-37.183333
br,quicamar,Quiçamar,05,,-12.2,-38.766667
br,quidombo,Quidombo,05,,-12.383333,-38.9
br,quieto,Quieto,06,,-4.7,-39.9
br,quieto,Quieto,18,,-25.966667,-52.666667
br,quijingue,Quijingue,05,4293,-10.75,-39.2
br,quilmado,Quilmado,03,,1.95,-50.783333
br,quilombo,Quilombo,05,,-12.4,-40.933333
br,quilombo,Quilombo,13,,-3.373889,-42.544722
br,quilombo,Quilombo,14,,-15.716667,-57.033333
br,quilombo,Quilombo,15,,-18.8,-43.166667
br,quilombo,Quilombo,23,,-31.533333,-52.466667
br,quilombo,Quilombo,26,,-26.783333,-52.75
br,quilombo,Quilombo,27,,-21.966667,-49.05
br,quilombo,Quilombo,30,,-8.533333,-36.083333
br,quilometro 41,Quilômetro 41,05,,-14.85,-39.55
br,quilometro cinco,Quilometro Cinco,27,,-24.539789,-48.79339
br,quilometro oitenta e quatro,Quilômetro Oitenta e Quatro,21,,-22.579167,-43.973333
br,quilometro onze,Quilômetro Onze,27,,-20.8,-51.1
br,quilometro quatorze,Quilômetro Quatorze,18,,-25.31,-50.572
br,quilometro quinze,Quilômetro Quinze,18,,-24.740474,-48.988859
br,quilometro quinze,Quilômetro Quinze,26,,-26.333333,-50.716667
br,quilometro sete,Quilômetro Sete,27,,-22.033333,-50.466667
br,quimami,Quimami,06,,-7.166667,-39.066667
br,quinca sant'ana,Quinca Sant'Ana,11,,-17.333333,-55.366667
br,quincas,Quincas,05,,-13.316667,-43.333333
br,quinca-tua,Quinca-Tua,15,,-16.133333,-40.283333
br,quincoe,Quincoê,06,,-6.233333,-39.416667
br,quincos,Quincos,06,,-6.033333,-38.516667
br,quincunca,Quincuncá,06,,-6.866667,-39.616667
br,quindiua,Quindiua,13,,-2.333333,-44.766667
br,quingo,Quingo,05,,-9.566667,-38.066667
br,quinin,Quinin,06,,-5.25,-39.2
br,quiniporo,Quiniporo,06,,-5.183333,-38.966667
br,quinquelere,Quinquelere,06,,-7.033333,-40.05
br,quinta da boa vista,Quinta da Boa Vista,21,,-22.905717,-43.224724
br,quinta da cantareira,Quinta da Cantareira,27,,-23.398427,-46.684559
br,quinta do itanhanga,Quinta do Itanhanga,21,,-22.976407,-43.323919
br,quinta do sol,Quinta do Sol,18,,-23.8,-52.116667
br,quinta do sol,Quinta do Sol,27,,-23.28767,-46.548732
br,quinta do sul,Quinta do Sul,18,,-23.8,-52.116667
br,quinta legua,Quinta Légua,23,,-29.2238,-51.1732
br,quintana,Quintana,27,,-22.05,-50.3
br,quinta,Quinta,08,,-20.616667,-40.45
br,quinta,Quinta,23,,-32.083333,-52.283333
br,quintas do rio,Quintas do Rio,21,,-22.985555,-43.382808
br,quintas,Quintas,05,,-13.25,-39
br,quintaus,Quintaús,06,,-6.866667,-39.083333
br,quintino bocaiuva,Quintino Bocaiúva,21,,-22.885842,-43.317296
br,quintino,Quintino,04,,1.5,-67.2
br,quintino,Quintino,06,,-7.033333,-39.466667
br,quintinos,Quintinos,15,,-18.833333,-46.083333
br,quinze de novembro,Quinze de Novembro,18,,-26.1575,-53.504167
br,quinze de novembro,Quinze de Novembro,23,,-28.75,-53.1
br,quinzinho,Quinzinho,15,,-21.233333,-45.583333
br,quinzopolis,Quinzópolis,18,,-23.016667,-50.566667
br,quiobal,Quiobal,06,,-4.016667,-38.6
br,quipapa,Quipapá,30,11533,-8.833333,-36.033333
br,quipa,Quipá,05,,-9.383333,-40.366667
br,quiquara,Quiquara,13,,-5.883333,-43.416667
br,quirambu,Quirambu,22,,-6.066667,-35.333333
br,quiriba,Quiriba,02,,-9.4,-37.65
br,quiri d'alho,Quiri d'Alho,30,,-8.583333,-37.433333
br,quiri do alho,Quiri do Alho,30,,-8.583333,-37.433333
br,quirimbuquer,Quirimbuquer,22,,-5.708611,-36.870278
br,quirim,Quirim,27,,-23.033333,-45.633333
br,quirina,Quirina,13,,-3.091667,-43.446944
br,quirinopolis,Quirinópolis,29,32104,-18.533333,-50.5
br,quirino,Quirino,05,,-9.483333,-38.9
br,quirino,Quirino,21,,-22.298056,-43.685556
br,quirino,Quirino,29,,-18.7,-51.816667
br,quiririm,Quiririm,27,,-23.033333,-45.633333
br,quiriri,Quiriri,26,,-26.133333,-49.016667
br,quiriritiua,Quiriritiua,13,,-2.383333,-44.65
br,quissaman,Quissamãn,21,,-22.1,-41.466667
br,quissama,Quissamã,21,,-22.1,-41.466667
br,quissama,Quissamã,28,,-10.9,-37.183333
br,quissamar,Quissamar,05,,-12.2,-38.766667
br,quitaius,Quitaiús,06,,-6.866667,-39.1
br,quitandinha,Quitandinha,18,,-25.8712,-49.4982
br,quiteria,Quiteria,05,,-12.366667,-40.033333
br,quiteria,Quitéria,23,,-30.433333,-52.066667
br,quitimbu,Quitimbu,30,,-7.9,-37.566667
br,quitite,Quitite,21,,-22.955264,-43.32879
br,quitumba,Quitumba,05,,-13.533333,-38.966667
br,quitungo,Quitungo,05,,-14.183333,-39.083333
br,quixaba da cobranca,Quixaba da Cobranca,22,,-5.095278,-36.517222
br,quixaba do felix,Quixabá do Felix,22,,-6.283333,-37.083333
br,quixaba,Quixaba,05,,-10.766667,-41.7
br,quixaba,Quixaba,06,,-4.566667,-37.65
br,quixaba,Quixaba,17,,-6.333333,-38.333333
br,quixaba,Quixaba,24,,-10.683333,-63.8
br,quixaba,Quixaba,30,,-7.716667,-37.85
br,quixaba velha,Quixaba Velha,17,,-7.016667,-37.083333
br,quixabeira,Quixabeira,05,,-12.6,-39.116667
br,quixabeira,Quixabeira,17,,-7.216667,-38.366667
br,quixabeira,Quixabeira,22,,-5.2,-35.833333
br,quixabeira,Quixabeira,30,,-7.866667,-36.4
br,quixabeirinha,Quixábeirinha,22,,-5.291389,-37.010556
br,quixabeiru sozinha,Quixabeiru Sozinha,22,,-5.603611,-37.355
br,quixabera,Quixabera,31,,-11.888056,-48.763889
br,quixabinha,Quixabinha,30,,-7.966667,-38.383333
br,quixada,Quixadá,01,,-8.433333,-72.85
br,quixada,Quixadá,06,49328,-4.966667,-39.016667
br,quixada,Quixadá,24,,-10.683333,-63.8
br,quixada,Quixadá,30,,-9.016667,-37.283333
br,quixara,Quixará,06,,-6.916667,-39.566667
br,quixariu,Quixariú,06,,-6.8,-40.283333
br,quixatu,Quixatu,06,,-5.383333,-39.066667
br,quixelo,Quixelô,06,,-4.833333,-38.383333
br,quixeramobim,Quixeramobim,01,,-8.466667,-72.033333
br,quixeramobim,Quixeramobim,06,34322,-5.2,-39.283333
br,quixeramobim,Quixeramobim,17,,-7.05,-38.683333
br,quixere,Quixeré,06,11258,-5.083333,-37.983333
br,quixoa,Quixoá,06,,-6.45,-39.366667
br,quixoba,Quixoba,05,,-9.983333,-41.516667
br,quixobeira,Quixobeira,17,,-7.633333,-38.333333
br,quixudi,Quixudi,17,,-7.033333,-36.433333
br,quizaba,Quizaba,05,,-11.8,-43.183333
br,quizol,Quizol,18,,-24.083333,-49.916667
br,rabeca,Rabeca,13,,-1.933333,-44.65
br,rabeca,Rabeca,20,,-9.366667,-44.516667
br,rabelo,Rabelo,15,,-21.85,-46.533333
br,rabicho,Rabicho,14,,-15.783333,-56.916667
br,rabicho,Rabicho,15,,-15.866667,-46.333333
br,raca,Raça,30,,-8.316667,-40.733333
br,rachado,Rachado,17,,-6.85,-37.55
br,radiador,Radiador,25,,3.633333,-61.566667
br,rafael bandeira,Rafael Bandeira,11,,-23.85,-54.316667
br,rafael fernandes,Rafael Fernandes,22,,-6.2,-38.216667
br,rafael i,Rafael I,26,,-27.0171,-49.5464
br,rafael,Rafael,05,,-17.333333,-40.4
br,rafael,Rafael,30,,-8.166667,-35.966667
br,rafael segundo,Rafael Segundo,26,,-26.980321,-49.549107
br,rafard,Rafard,27,,-23.011389,-47.526111
br,raimundo agostinho,Raimundo Agostinho,22,,-5.1625,-37.086944
br,raimundo goncalves,Raimundo Gonçalves,16,,-1.433333,-51.233333
br,raimundo gonsalves,Raimundo Gonsalves,16,,-1.433333,-51.233333
br,raimundo martins,Raimundo Martins,06,,-4.65,-40.066667
br,raimundo nonato,Raimundo Nonato,20,,-9.016667,-42.7
br,raimundo,Raimundo,01,,-11,-68.566667
br,raimundo,Raimundo,02,,-9.05,-37.566667
br,raimundo,Raimundo,14,,-7.9,-58.05
br,raimundo,Raimundo,16,,-1.116667,-56.033333
br,raimundo,Raimundo,25,,2.816667,-60.116667
br,rainha isabel,Rainha Isabel,30,,-9.25,-36.866667
br,rainha,Rainha,26,,-26.5162,-48.7184
br,raizal,Raizal,31,,-7.066667,-48.316667
br,raizama,Raizama,11,,-17.85,-54.466667
br,raizama,Raizama,14,,-14.966667,-56.483333
br,raiz da serra,Raiz da Serra,21,,-22.780078,-43.791267
br,raizinha,Raizinha,14,,-15.916667,-54.616667
br,raizinhas,Raizinhas,14,,-15.916667,-54.616667
br,raiz,Raiz,02,,-9.316667,-35.65
br,raiz,Raiz,06,,-6.216667,-40.283333
br,raiz,Raiz,13,,-3.268333,-43.36
br,rajada,Rajada,17,,-7.516667,-37.866667
br,rajada,Rajada,20,,-5.116667,-42.533333
br,rajada,Rajada,22,,-6.533333,-36.633333
br,rajada,Rajada,30,,-8.8,-40.833333
br,rajadinha,Rajadinha,07,,-15.733333,-47.666667
br,rajado,Rajado,17,,-6.2,-37.483333
br,rajedo do carrapicho,Rajedo do Carrapicho,30,,-8.466667,-36.716667
br,ramada,Ramada,06,,-3.3,-39.366667
br,ramada,Ramada,20,,-6.266667,-41.533333
br,ramada,Ramada,22,,-5.563333,-36.028056
br,ramada,Ramada,23,,-28.066667,-53.7
br,ramada,Ramada,30,,-8.783333,-36.883333
br,ramadinha,Ramadinha,06,,-5.05,-40.216667
br,ramadinha,Ramadinha,22,,-5.483333,-37.55
br,ramaiana,Ramaiana,15,,-16.7,-40.816667
br,ramalhete,Ramalhete,15,,-18.45,-42.3
br,ramalhete,Ramalhete,20,,-8.1,-41.216667
br,ramalhete,Ramalhete,30,,-8.75,-40.516667
br,ramalho,Ramalho,05,,-14.033333,-44.2
br,ramalho,Ramalho,06,,-4.783333,-37.883333
br,ramalho,Ramalho,15,,-15.783333,-45.633333
br,ramalho,Ramalho,30,,-8.783333,-36.6
br,ramao,Ramão,23,,-32.833333,-52.7
br,rama-rama,Rama-Rama,24,,-9.333333,-62.016667
br,ramiro ramos,Ramiro Ramos,23,,-30.066667,-53.2
br,ramona,Ramona,23,,-31.133333,-54.15
br,ramos,Ramos,13,,-5.416667,-45.25
br,ramos,Ramos,16,,-1.3,-53.05
br,ramos,Ramos,21,,-22.849002,-43.260536
br,rampa,Rampa,13,,-2.616667,-43.533333
br,ranchao,Ranchão,14,,-12.883333,-59.016667
br,rancharia,Rancharia,11,,-18.916667,-55.7
br,rancharia,Rancharia,15,,-21.75,-43.95
br,rancharia,Rancharia,20,,-6.716667,-42.033333
br,rancharia,Rancharia,27,25531,-22.25,-50.916667
br,rancharia,Rancharia,30,,-7.7,-39.683333
br,rancheiro,Rancheiro,06,,-6.85,-38.966667
br,ranchinho,Ranchinho,08,,-18.8,-39.766667
br,ranchinho,Ranchinho,11,,-17.783333,-57.116667
br,ranchinho,Ranchinho,18,,-25.520138,-50.157686
br,rancho alegre,Rancho Alegre,05,,-12.75,-38.2
br,rancho alegre,Rancho Alegre,11,,-18.316667,-55.35
br,rancho alegre,Rancho Alegre,18,,-23.083333,-50.916667
br,rancho alegre,Rancho Alegre,27,,-22.6915,-45.5205
br,rancho da casca,Rancho da Casca,22,,-5.117778,-37.434167
br,rancho da pamonha,Rancho da Pamonha,27,,-23.3655,-46.2249
br,rancho das vacas,Rancho das Vacas,02,,-9.683333,-37.2
br,rancho da velha,Rancho da Velha,22,,-5.480556,-37.336111
br,rancho de caca dos tapaiuna,Rancho de Caça dos Tapaiuna,14,,-10.8,-55.95
br,rancho de caca dos tapiunas,Rancho de Caça dos Tapiúnas,14,,-10.8,-55.95
br,rancho de mendes,Rancho de Mendes,20,,-7.633333,-43.7
br,rancho do limeira,Rancho do Limeira,15,,-20.133333,-46.7
br,rancho do povo,Rancho do Povo,06,,-4.733333,-37.833333
br,rancho do povo,Rancho do Povo,17,,-6.316667,-37.716667
br,rancho do povo,Rancho do Povo,22,,-5.3,-37.766667
br,rancho dos bugres,Rancho dos Bugres,26,,-28.5,-49.283333
br,rancho dos negros,Rancho dos Negros,17,,-7.75,-37.033333
br,rancho dos patos,Rancho dos Patos,20,,-5.333333,-41.55
br,rancho feijao sem sal,Rancho Feijão Sem Sal,14,,-15.383333,-57.7
br,rancho grande,Rancho Grande,26,,-26.6,-50.25
br,rancho grande,Rancho Grande,27,,-23.183333,-47.5
br,rancho pimenteira,Rancho Pimenteira,11,,-18.8,-57.566667
br,rancho prola do vale,Rancho Prola do Vale,27,,-23.4019,-46.0143
br,rancho queimado,Rancho Queimado,11,,-22.083333,-57.266667
br,rancho queimado,Rancho Queimado,21,,-22.198889,-43.227222
br,rancho queimado,Rancho Queimado,26,,-27.683333,-49.033333
br,rancho quemado,Rancho Quemado,26,,-27.683333,-49.033333
br,rancho,Rancho,11,,-23.1,-54.766667
br,rancho,Rancho,15,,-21.483333,-45.05
br,rancho,Rancho,30,,-8.083333,-40.216667
br,rancho sao francisco,Rancho São Francisco,11,,-21.483333,-53.5
br,rancho velho,Rancho Velho,23,,-30.15,-50.4
br,rancho verde,Rancho Verde,14,,-15.466667,-57.966667
br,randolfo melo,Randolfo Melo,15,,-16.583333,-41.4
br,rapador,Rapador,15,,-21.333333,-44.316667
br,rapadura,Rapadura,15,,-20,-41.85
br,rapa queijo,Rapa Queijo,21,,-22.175556,-43.591667
br,rape,Rapé,22,,-5.9,-37.766667
br,raposa,Raposa,06,,-3.583333,-40.183333
br,raposa,Raposa,13,11883,-6.516667,-44.183333
br,raposas,Raposas,15,,-19.95,-43.8
br,raposo,Raposo,05,,-12.683333,-38.2
br,raposo,Rapôso,06,,-5.35,-38.316667
br,raposo,Raposo,15,,-20.2,-45.2
br,raposos,Raposos,15,13263,-19.95,-43.8
br,rapouse,Rapouse,13,,-5.15,-43.433333
br,rasgadinho,Rasgadinho,18,,-25.7432,-48.7558
br,rasgado,Rasgado,18,,-25.793792,-48.76958
br,rasgao,Rasgão,27,,-23.383333,-47.033333
br,raso,Raso,05,,-11.333333,-38.95
br,raspador,Raspador,15,,-21.333333,-44.316667
br,rasteira,Rasteira,06,,-3.85,-40.2
br,rateio,Rateio,02,,-9.833333,-35.966667
br,ratones,Ratones,26,,-27.5,-48.466667
br,rato,Rato,06,,-4.083333,-38.866667
br,rato,Rato,20,,-7.083333,-40.616667
br,ratos,Ratos,05,,-13.916667,-41.9
br,raul goncalves,Raul Gonçalves,29,,-17.85,-48.183333
br,raul soares,Raul Soares,15,13210,-20.083333,-42.366667
br,ravena,Ravena,15,,-19.783333,-43.75
br,raymundo lobo,Raymundo Lobo,16,,-8.583333,-49.666667
br,realengo,Realengo,21,,-22.88169,-43.432177
br,realeza,Realeza,06,,-6.316667,-40.783333
br,realeza,Realeza,15,,-20.233333,-42.15
br,realeza,Realeza,18,10389,-25.783333,-53.516667
br,realeza,Realeza,20,,-6.133333,-41.95
br,realeza,Realeza,24,,-9.5,-63.783333
br,realeza,Realeza,25,,3.516667,-61.25
br,real,Real,05,,-13.866667,-41.533333
br,rebentao,Rebentão,20,,-3.445278,-42.243611
br,rebojinho,Rebojinho,16,,-5.433333,-49.1
br,rebojo,Rebojo,11,,-18.5,-56.483333
br,rebojo,Rebojo,14,,-17.033333,-56.6
br,rebojo,Rebojo,27,,-22.333333,-51.65
br,rebojo,Rebojo,31,,-6.166667,-48.333333
br,reboucas,Rebouças,18,,-25.622368,-50.693124
br,reboucas,Rebouças,27,,-22.8,-47.283333
br,recanto amarelo,Recanto Amarelo,27,,-23.3027,-46.0635
br,recanto campestre,Recanto Campestre,27,,-23.3424,-46.0822
br,recanto campo belo do alto,Recanto Campo Belo do Alto,27,,-23.792,-46.7391
br,recanto campo belo,Recanto Campo Belo,27,,-23.798164,-46.739892
br,recanto da umburana,Recanto da Umburana,20,,-7.233333,-41.8
br,recanto do ceu azul,Recanto do Céu Azul,27,,-23.318139,-46.541012
br,recanto dos sabugueiros,Recanto dos Sabugueiros,27,,-23.9587,-47.0656
br,recanto pingol,Recanto Pingol,27,,-23.3192,-46.094
br,recanto,Recanto,02,,-9.3,-36.233333
br,recanto,Recanto,05,,-12.583333,-39.55
br,recanto,Recanto,06,,-3.6,-40.166667
br,recanto,Recanto,17,,-6.9,-37.4
br,recanto,Recanto,20,,-5.7,-43.066667
br,recanto,Recanto,22,,-5.63,-37.481944
br,recanto,Recanto,26,,-27.433333,-48.45
br,recanto,Recanto,30,,-7.65,-39.55
br,recanto santa ana,Recanto Santa Ana,27,,-23.2975,-46.0512
br,recanto sao pedro,Recanto São Pedro,27,,-23.818231,-46.746487
br,recanto sete estrelas,Recanto Sete Estrelas,27,,-23.3479,-46.24
br,recanto so jos,Recanto So Jos,27,,-23.3859,-46.061
br,recanto tanaka,Recanto Tanaka,27,,-23.2956,-46.0619
br,recanto taor mina,Recanto Taor Mina,27,,-23.3435,-46.0805
br,recanto trapia,Recanto Trapia,22,,-5.862778,-36.276389
br,recanto trs marias,Recanto Trs Marias,27,,-23.3622,-46.2159
br,recife,Recife,04,,-6.879167,-71.063056
br,recife,Recife,05,,-11.6,-41.9
br,recife,Recife,16,,-1.166667,-46.333333
br,recife,Recife,30,1478118,-8.05,-34.9
br,recompensa,Recompensa,04,,-7.566667,-72.516667
br,recordacao,Recordação,01,,-7.6,-72.833333
br,recordacao,Recordação,11,,-21.533333,-55.2
br,recreio atininga,Recreio Atininga,04,,-5.610278,-60.981111
br,recreio de sao domingos,Recreio de São Domingos,04,,-5.707778,-63.558611
br,recreio dos bandeirantes,Recreio dos Bandeirantes,21,,-23.017108,-43.465631
br,recreio quality residences,Recreio Quality Residences,21,,-23.002774,-43.481159
br,recreio,Recreío,01,,-8.486944,-71.41
br,recreio,Recreio,04,,-3.483333,-68.5
br,recreio,Recreio,05,,-11.466667,-43.216667
br,recreio,Recreio,06,,-5.6,-38.133333
br,recreio,Recreio,08,,-20.933333,-41.316667
br,recreio,Recreio,11,,-17.65,-56.75
br,recreio,Recreio,13,,-2.05,-44.55
br,recreio,Recreio,14,,-16.95,-58.233333
br,recreio,Recreio,15,8882,-21.533333,-42.466667
br,recreio,Recreio,16,,-1.016667,-48.95
br,recreio,Recreio,17,,-6.266667,-37.683333
br,recreio,Recreio,20,,-7.516667,-41.716667
br,recreio,Recreio,21,,-21.783333,-41.85
br,recreio,Recreio,22,,-5.25,-37.616667
br,recreio,Recreio,23,,-29.133333,-56.05
br,recreio,Recreio,25,,2.85,-60.716667
br,recreio,Recreio,27,,-21.8,-46.683333
br,recreiro,Recreiro,06,,-5.1,-40.333333
br,recuperado,Recuperado,11,,-23.566667,-54.55
br,recursolandia,Recursolândia,31,,-8.696389,-47.081944
br,recurso,Recurso,02,,-9.6,-37.316667
br,recurso,Recurso,13,,-3.381389,-43.432778
br,recurso,Recurso,20,,-8.016667,-42.65
br,recusa,Recusa,20,,-8.016667,-42.65
br,redempcao,Redempção,01,,-8.916667,-71.583333
br,redempcao,Redempção,04,,-4.957778,-62.581667
br,redempcao,Redempção,06,,-4.216667,-38.716667
br,redempcao,Redempção,27,,-23.266667,-45.55
br,redencao da serra,Redenção da Serra,27,,-23.266667,-45.55
br,redencao,Redenção,01,,-8.351111,-72.753611
br,redencao,Redenção,03,,1.066667,-50.7
br,redencao,Redenção,04,,-4.957778,-62.581667
br,redencao,Redenção,05,,-10.25,-43.716667
br,redencao,Redenção,06,14174,-4.216667,-38.716667
br,redencao,Redenção,20,,-9.5,-44.6
br,redencao,Redenção,23,,-27.666667,-53.65
br,redencao,Redenção,27,,-23.266667,-45.55
br,redentora,Redentora,23,,-27.666667,-53.65
br,redinha,Redinha,22,,-5.733333,-35.2
br,redonda,Redonda,06,,-4.651389,-37.470278
br,redonda,Redonda,22,,-4.933333,-36.966667
br,redondo,Redondo,05,,-13.033333,-44.083333
br,redondo,Redondo,15,,-19.25,-47.383333
br,redoval,Redoval,06,,-5.6,-39.666667
br,redregulho,Redregulho,06,,-6.35,-38.916667
br,reducao de santo inacio,Redução de Santo Inácio,18,,-22.683333,-51.816667
br,reducao,Redução,20,,-9.5,-44.6
br,reducto,Reducto,22,,-5.116667,-35.683333
br,reduto,Reduto,15,,-20.233333,-41.983333
br,reduto,Reduto,22,,-5.116667,-35.683333
br,reeve,Reeve,08,,-20.766667,-41.466667
br,reforma,Reforma,01,,-8.466667,-72.84
br,reforma,Reforma,22,,-5.379167,-37.377778
br,reforma,Reforma,25,,3.866667,-59.6
br,refugiado,Refugiado,23,,-28.666667,-50.916667
br,refugio da serra,Refúgio da Serra,27,,-23.401508,-46.65406
br,refugio,Refúgio,13,,-2.85,-45.25
br,refugio,Refúgio,21,,-22.3,-42.416667
br,regalia,Regalia,20,,-6.183333,-41.8
br,regalo,Regalo,13,,-8.1,-45.616667
br,regalo,Regalo,15,,-20.333333,-46.05
br,regalo,Regalo,20,,-9.794167,-45.038889
br,regame,Regamê,21,,-22.833333,-42.4
br,regencia augusta,Regencia Augusta,08,,-19.6,-39.816667
br,regencia,Regência,08,,-19.6,-39.816667
br,regeneracao,Regeneração,20,13608,-6.25,-42.683333
br,regente feijo,Regente Feijó,27,17219,-22.25,-51.333333
br,regina,Regina,03,,2.583333,-51.75
br,regina,Regina,18,,-22.9,-53.416667
br,regina vilela,Regina Vilela,15,,-20.65,-45.666667
br,reginopolis,Reginópolis,27,,-21.916667,-49.25
br,regis-cue,Regis-cuê,11,,-23.3,-54.733333
br,registro do araguaia,Registro do Araguaia,14,,-15.716667,-51.85
br,registro do araguaia,Registro do Araguaia,29,,-15.733333,-51.833333
br,registro do araguaya,Registro do Araguaya,29,,-15.733333,-51.833333
br,registro do jauru,Registro do Jauru,14,,-15.75,-58.55
br,registro,Registro,14,,-15.75,-58.55
br,registro,Registro,26,,-26.6,-52.35
br,registro,Registro,27,45698,-24.5,-47.833333
br,registro,Registro,29,,-15.733333,-51.833333
br,reichart,Reichart,26,,-26.333333,-50.616667
br,reinado,Reinado,30,,-8.083333,-36.116667
br,reinaldo scopeli,Reinaldo Scopeli,23,,-29.0787,-51.0562
br,reis,Reis,18,,-23.6,-51.383333
br,reliquia,Relíquia,05,,-13.233333,-39.716667
br,relogio do sol,Relógio do Sol,16,,-6.25,-54.133333
br,relogio,Relógio,08,,-20.133333,-40.416667
br,relogio,Relógio,18,,-25.266667,-51.1
br,relvado,Relvado,23,,-29.116667,-52.066667
br,remanco,Remanço,04,,-5.654444,-61.270833
br,remansao,Remansão,16,,-4.416667,-49.566667
br,remansinho,Remansinho,16,,-4.433333,-49.566667
br,remanso grande,Remanso Grande,04,,-6.033333,-58.8
br,remanso,Remanso,01,,-8.438889,-72.980833
br,remanso,Remanso,04,,-5.654444,-61.270833
br,remanso,Remanso,05,22780,-9.683333,-42.066667
br,remanso,Remanso,06,,-3.15,-40.366667
br,remanso,Remanso,11,,-20.85,-55.333333
br,remanso,Remanso,13,,-3.458333,-42.445
br,remanso,Remanso,20,,-5.216667,-42.8
br,remanso,Remanso,25,,-1.3,-61.7
br,remanso,Remanso,27,,-20.366667,-47.833333
br,remansu,Remansu,25,,-1.3,-61.7
br,remate de males,Remate de Males,04,,-4.332222,-70.208611
br,remdios,Remdios,27,,-23.3217,-46.0904
br,remedio da gameleira,Remédio da Gameleira,05,,-12.35,-39.083333
br,remedio,Remédio,04,,-5.956667,-64.377222
br,remedio,Remédio,13,,-2.05,-44.95
br,remedios de gamelleira,Remedios de Gamelleira,05,,-12.35,-39.083333
br,remedios,Remédios,05,,-12.8,-42.2
br,remedios,Remedios,06,,-3.6,-40.3
br,remedios,Remedios,15,,-21.033333,-43.583333
br,remedios,Remédios,27,,-23.066667,-45.5
br,remigio,Remígio,17,9659,-6.933333,-35.783333
br,remonta,Remonta,23,,-29.95,-54.95
br,remune,Remune,16,,1.883333,-54.95
br,renascenca,Renascença,04,,-3.833333,-66.35
br,renascenca,Renascença,18,,-26.133333,-53.016667
br,renascenca,Renascença,21,,-21.85,-41.966667
br,renascenca,Renascença,24,,-12.166667,-64.533333
br,renascensa,Renascensa,18,,-26.133333,-53.016667
br,renascer,Renascer,21,,-22.803606,-43.314868
br,rendinha,Rendinha,06,,-6.416667,-39.033333
br,renescenca,Renescença,24,,-12.166667,-64.533333
br,reparticao,Repartição,13,,-3.683333,-42.683333
br,reparticao,Repartição,16,,-4.733333,-56.566667
br,reparticao,Repartição,20,,-3.683333,-42.666667
br,repartimento,Repartimento,04,,-2.168333,-60.690556
br,repartimento,Repartimento,13,,-2.55,-44.733333
br,repartimento,Repartimento,16,,-1.25,-50.133333
br,repartimento,Repartimento,24,,-9.083333,-62.433333
br,represa,Represa,05,,-13.183333,-39.433333
br,represa,Represa,27,,-23.151205,-47.797888
br,republica,República,01,,-7.433333,-73.433333
br,republica,República,04,,-5.2,-62.8
br,republica,República,14,,-13.5,-60.5
br,republica,República,27,,-22.25,-47.45
br,requeijao,Requeijão,15,,-16.5,-41.583333
br,rera,Rera,25,,4.5,-60.166667
br,rerituba,Rerituba,26,,-27.516667,-48.516667
br,reriutaba,Reriutaba,06,12076,-4.166667,-40.583333
br,resende costa,Resende Costa,15,,-20.916667,-44.233333
br,resende,Resende,21,111515,-22.4679,-44.4575
br,reserva estrema,Reserva Estrema,01,,-10.666667,-70.1
br,reserva extrema,Reserva Extrema,01,,-10.666667,-70.1
br,reserva,Reserva,15,,-21.066667,-46.066667
br,reserva,Reserva,18,11097,-24.633333,-50.866667
br,reserva,Reserva,21,,-21.316667,-42.016667
br,reserva,Reserva,23,,-29.2,-53.55
br,reserva,Reserva,27,,-22.4,-47.2
br,reserva,Reserva,31,,-11.75,-47.05
br,resfriado,Resfriado,27,,-20.833333,-47.833333
br,resgate de umburanas,Resgate de Umburanas,05,,-12.433333,-39.1
br,resgates de umburanas,Resgates de Umburanas,05,,-12.433333,-39.1
br,residencial eldorado,Residencial Eldorado,27,,-23.3068,-46.2143
br,residencial girassol,Residencial Girassol,21,,-22.863221,-43.556709
br,residencia,Residência,20,,-4.45,-41.833333
br,residencia,Residencia,22,,-5.808889,-36.48
br,resolvido,Resolvido,14,,-17.5,-54.433333
br,resplandes,Resplandes,13,,-6.283333,-45.216667
br,resplendes,Resplendes,13,,-6.283333,-45.216667
br,resplendor,Resplendor,15,15131,-19.333333,-41.25
br,ressaca do botija,Ressaca do Botija,04,,-3.981389,-62.866389
br,ressaca,Ressaca,04,,-2.833333,-57.916667
br,ressaca,Ressaca,05,,-13.1,-41.8
br,ressaca,Ressaca,11,,-20.8,-56.533333
br,ressaca,Ressaca,13,,-5.666667,-47.45
br,ressaca,Ressaca,14,,-14.783333,-56.583333
br,ressaca,Ressaca,15,,-21.95,-45.5
br,ressaca,Ressaca,27,,-20.616667,-47.266667
br,ressaguinha,Ressaguinha,15,,-21.066667,-43.766667
br,ressaquinha,Ressaquinha,15,,-21.066667,-43.766667
br,restauracao,Restauração,01,,-9.216667,-72.233333
br,restauracao,Restauração,03,,1.1,-50.6
br,restauracao,Restauração,04,,-7.05,-62.883333
br,restauraco,Restauraço,04,,-5.635278,-61.057222
br,restinga de itapeba,Restinga de Itapeba,21,,-23.010556,-43.446111
br,restinga de jacarepagua,Restinga de Jacarepaguá,21,,-23.003056,-43.383056
br,restinga,Restinga,02,,-9.8,-37.283333
br,restinga,Restinga,18,,-25.15,-50.516667
br,restinga,Restinga,27,,-20.6,-47.483333
br,restinga,Restinga,31,,-12.766667,-46.866667
br,restinga seca,Restinga Sêca,23,,-29.816667,-53.383333
br,restinga secca,Restinga Secca,23,,-29.816667,-53.383333
br,restingua,Restingua,27,,-20.6,-47.483333
br,retencao,Retenção,11,,-22.066667,-56.45
br,retirada da esplanada,Retirada da Esplanada,15,,-19.316667,-48.35
br,retira da piuva,Retira da Piuva,14,,-16.433333,-57.066667
br,retirada,Retirada,05,,-12.05,-38.783333
br,retira da sentinella,Retira da Sentinella,14,,-16.5,-57.2
br,retire,Retire,20,,-6.633333,-42.333333
br,retirinho,Retirinho,11,,-19.866667,-56.05
br,retirinho,Retirinho,14,,-16.033333,-58.916667
br,retirinho,Retirinho,15,,-20.716667,-45.266667
br,retiro alegre,Retiro Alegre,11,,-22.066667,-57.733333
br,retiro alegria,Retiro Alegria,11,,-19.683333,-55.65
br,retiro al soria,Retiro Al Soria,11,,-19.683333,-55.65
br,retiro anhumas,Retiro Anhumas,11,,-21.8,-57.65
br,retiro aquidauana,Retiro Aquidauana,11,,-19.766667,-54.783333
br,retiro arara,Retiro Arara,11,,-19.75,-56.233333
br,retiro baia bonita,Retiro Baía Bonita,11,,-19.783333,-56.866667
br,retiro campina,Retiro Campina,04,,-4.966944,-62.733333
br,retiro capivara,Retiro Capivara,14,,-16.683333,-56.7
br,retiro caranda,Retiro Carandá,11,,-21.783333,-57.583333
br,retiro carrapatinho,Retiro Carrapatinho,11,,-19.833333,-56.416667
br,retiro central,Retiro Central,11,,-19.933333,-55.65
br,retiro corcunda,Retiro Corcunda,11,,-19.983333,-56.45
br,retiro curral velho,Retiro Curral Velho,14,,-15.583333,-51.716667
br,retiro da boa esperanca,Retiro da Boa Esperança,20,,-3.9,-42.233333
br,retiro da campina,Retiro da Campina,04,,-4.966944,-62.733333
br,retiro da contagem,Retiro da Contagem,15,,-19.833333,-44.133333
br,retiro da fazenda galera,Retiro da Fazenda Galera,14,,-14.476389,-59.568056
br,retiro da formiga,Retiro da Formiga,14,,-16.8,-56.083333
br,retiro da formosa,Retiro da Formosa,14,,-16.533333,-56.65
br,retiro da piuva,Retiro da Piuva,14,,-16.433333,-57.066667
br,retiro da ponte,Retiro da Ponte,27,,-20.8,-47.8
br,retiro da sentinela,Retiro da Sentinela,14,,-16.5,-57.2
br,retiro da serra,Retiro da Serra,27,,-23.599941,-47.047387
br,retiro das formigas,Retiro das Formigas,14,,-16.8,-56.083333
br,retiro das pedras,Retiro das Pedras,15,,-20.0874,-43.9885
br,retiro das piranhas,Retiro das Piranhas,11,,-18.15,-57.366667
br,retiro das piranhas,Retiro das Piranhas,29,,-16.366667,-51.8
br,retiro da volta grande,Retiro da Volta Grande,14,,-17.133333,-56.933333
br,retiro de aquidauana,Retiro de Aquidaúana,11,,-19.766667,-54.783333
br,retiro de joao de morais,Retiro de João de Morais,11,,-17.55,-55.35
br,retiro do aquidauana,Retiro do Aquidauana,11,,-19.766667,-54.783333
br,retiro do buriti,Retiro do Buriti,14,,-16.733333,-54.65
br,retiro do castanhal,Retiro do Castanhal,04,,-6.538611,-62.359722
br,retiro do cervo,Retiro do Cervo,11,,-19.866667,-56.383333
br,retiro do coronel barros,Retiro do Coronel Barros,11,,-18.65,-56.783333
br,retiro do curral velho,Retiro do Curral Velho,14,,-15.583333,-51.716667
br,retiro do formigueiro,Retiro do Formigueiro,11,,-19.066667,-57.316667
br,retiro do inga,Retiro do Ingá,11,,-19.8,-56.566667
br,retiro do joao moraes,Retiro do João Moraes,11,,-17.55,-55.35
br,retiro do malheiros,Retiro do Malheiros,11,,-19.8,-57.7
br,retiro do muriae,Retiro do Muriaé,21,,-21.183333,-42.016667
br,retiro do paratubal,Retiro do Paratubal,11,,-18.55,-57.283333
br,retiro do paratudo,Retiro do Paratudo,11,,-18.55,-57.283333
br,retiro do presidente,Retiro do Presidente,14,,-16.716667,-57.783333
br,retiro dos cabritos,Retiro Dos Cabritos,15,,-22.577,-45.5128
br,retiro dos cochos,Retiro dos Cochos,11,,-20.816667,-53.25
br,retiro dos velhos,Retiro dos Velhos,11,,-21.866667,-56.75
br,retiro estrela do sul,Retiro Estrêla do Sul,11,,-18.4,-53.6
br,retiro felipe,Retiro Felipe,11,,-20.2,-55.383333
br,retiro galera,Retiro Galera,14,,-14.476389,-59.568056
br,retiro grande,Retiro Grande,06,,-4.633333,-37.533333
br,retiro guarani,Retiro Guarani,11,,-19.9,-55.8
br,retiro lajeado,Retiro Lajeado,11,,-20.616667,-53.95
br,retirolandia,Retirolândia,05,,-11.566667,-39.316667
br,retiro largao,Retiro Largão,11,,-20.266667,-56.85
br,retiro mateira,Retiro Mateira,11,,-20.933333,-53.066667
br,retiro monte belo,Retiro Monte Belo,11,,-21.316667,-53.533333
br,retiro novo,Retiro Novo,11,,-19.833333,-56.266667
br,retiro novo,Retiro Novo,14,,-16.366667,-56.3
br,retiro progresso,Retiro Progresso,11,,-21.816667,-57.8
br,retiro quarany,Retiro Quarany,11,,-19.9,-55.8
br,retiro,Retiro,02,,-10.383333,-36.466667
br,retiro,Retiro,04,,-2.7,-67.083333
br,retiro,Retiro,05,,-10.283333,-41.05
br,retiro,Retiro,06,,-3.816667,-39.5
br,retiro,Retiro,07,,-15.7,-47.333333
br,retiro,Retiro,11,,-20.7,-57.666667
br,retiro,Retiro,13,,-3.166667,-45.3
br,retiro,Retiro,14,,-14.95,-55.916667
br,retiro,Retiro,15,,-15.366667,-42.616667
br,retiro,Retiro,16,,-1.116667,-49.383333
br,retiro,Retiro,17,,-6.9,-37.983333
br,retiro,Retiro,18,,-25.433333,-52.033333
br,retiro,Retiro,20,,-10.05,-44.266667
br,retiro,Retiro,21,,-22.271404,-42.84487
br,retiro,Retiro,22,,-5.688889,-37.381944
br,retiro,Retiro,23,,-28.883333,-50.083333
br,retiro,Retiro,26,,-28.633333,-49.05
br,retiro,Retiro,27,,-23.272224,-47.760185
br,retiro,Retiro,29,,-16.533333,-51.7
br,retiro,Retiro,30,,-7.45,-39.816667
br,retiro,Retiro,31,,-11.05,-48.6
br,retiro sao domingos,Retiro São Domingos,11,,-19.7,-56.45
br,retiro sao francisco,Retiro São Francisco,05,,-15.433333,-39.316667
br,retiro sao jose,Retiro São José,11,,-19.783333,-55.866667
br,retiro sao jose,Retiro São José,20,,-6.816667,-43.383333
br,retiro sao manoel,Retiro São Manoel,11,,-20.766667,-53
br,retiro sao rafael,Retiro São Rafael,14,,-16.766667,-56.066667
br,retiro saudoso,Retiro Saudoso,21,,-21.7,-41.883333
br,retiro segura,Retiro Segura,11,,-18.2,-56.75
br,retiro seguro,Retiro Seguro,11,,-18.2,-56.75
br,retiro sucuri,Retiro Sucuri,11,,-21.283333,-56.583333
br,retiro taruna,Retiro Tarunã,11,,-21.316667,-56.216667
br,retiro triunfo,Retiro Triunfo,11,,-21.5,-57.366667
br,retiro velho,Retiro Velho,11,,-20.216667,-55.8
br,retiro volta grande,Retiro Volta Grande,14,,-17.133333,-56.933333
br,reuniao,Reunião,04,,-3.049444,-61.5725
br,revedor,Revedor,06,,-3.983333,-41.233333
br,revencia,Revencia,17,,-6.666667,-37.8
br,reverdito,Reverdito,11,,-20.9,-57.75
br,reversa,Reversa,23,,-31.3,-52.2
br,revessa,Revessa,27,,-24.570479,-48.388492
br,revolta,Revolta,06,,-6.016667,-40.1
br,revolta,Revolta,15,,-16.333333,-40.483333
br,revolta,Revolta,21,,-20.983333,-41.966667
br,revolve,Revolve,30,,-8.95,-36.15
br,rezende costa,Rezende Costa,15,,-20.916667,-44.233333
br,rezende,Rezende,21,,-22.4679,-44.4575
br,riachao das neves,Riachão das Neves,05,11236,-11.766667,-44.933333
br,riachao da touceira,Riachão da Touceira,05,,-13.483333,-39.45
br,riachao de cima,Riachão de Cima,06,,-5.05,-40.283333
br,riachao de trapiu,Riachão de Trapiu,02,,-9.566667,-36.816667
br,riachao do bacamarte,Riachão do Bacamarte,17,,-7.25,-35.683333
br,riachao do banabuiu,Riachão do Banabuiú,06,,-5.433333,-39.983333
br,riachao do dantas,Riachão do Dantas,28,4615,-11.066667,-37.733333
br,riachao do jacuhype,Riachão do Jacuhype,05,,-11.8,-39.35
br,riachao do jacuipe,Riachão do Jacuípe,05,16911,-11.8,-39.35
br,riachao do panta,Riachão do Panta,06,,-4.266667,-38.833333
br,riachao do traipu,Riachão do Traipu,02,,-9.566667,-36.816667
br,riachao do utinga,Riachão do Utinga,05,,-12.033333,-41.166667
br,riachao d'utinga,Riachao d'Utinga,05,,-12.033333,-41.166667
br,riachao,Riachão,02,,-9.333333,-36.4
br,riachao,Riachão,05,,-11.333333,-40.4
br,riachao,Riachão,06,,-3.333333,-40.533333
br,riachao,Riachão,13,12428,-7.366667,-46.616667
br,riachao,Riachão,17,,-6.533333,-37.733333
br,riachao,Riachão,20,,-5.366667,-41.8
br,riachao,Riachão,22,,-5.833333,-38.033333
br,riachao,Riachão,28,,-11.066667,-37.733333
br,riachao,Riachão,30,,-7.983333,-38.083333
br,riachao,Riachão,31,,-12.533333,-46.416667
br,riachao teixeiras,Riachão Teixeiras,13,,-3.116667,-42.366667
br,riachaozinho,Riachãozinho,05,,-12.15,-41.35
br,riachaq,Riachaq,13,,-7.366667,-46.616667
br,riach doc,Riach Doc,06,,-2.8,-40.45
br,riachinho,Riachinho,05,,-10.233333,-43.2
br,riachinho,Riachinho,06,,-4.233333,-38.6
br,riachinho,Riachinho,13,,-3.116944,-43.389444
br,riachinho,Riachinho,22,,-5.138056,-37.423056
br,riachinho,Riachinho,30,,-8.533333,-37.116667
br,riachinho,Riachinho,31,,-6.433333,-48.133333
br,riacho agreste,Riacho Agreste,17,,-6.466667,-37.483333
br,riacho alegre,Riacho Alegre,05,,-13.583333,-39.9
br,riacho catole,Riacho Catolê,17,,-6.466667,-37.566667
br,riacho claro,Riacho Claro,05,,-12.433333,-38.433333
br,riacho da areia,Riacho da Areia,05,,-12.55,-39.833333
br,riacho da areia,Riacho da Areia,13,,-9.385278,-46.449444
br,riacho da areia,Riacho da Areia,15,,-19.533333,-44.383333
br,riacho da barra,Riacho da Barra,06,,-6.583333,-40.316667
br,riacho da barra,Riacho da Barra,17,,-7.2,-38.083333
br,riacho da brava,Riacho da Brava,30,,-8.9,-36.75
br,riacho da cachoaia,Riacho da Cachoaia,22,,-6.516667,-37.266667
br,riacho da cruz,Riacho da Cruz,13,,-3.616667,-43.65
br,riacho da cruz,Riacho da Cruz,15,,-15.333333,-44.3
br,riacho da cruz,Riacho da Cruz,22,,-5.916667,-35.683333
br,riacho da forquilha,Riacho da Forquilha,06,,-5.716667,-39.366667
br,riacho d'agua,Riacho d'Agua,02,,-9.583333,-37.266667
br,riacho da guia,Riacho da Guia,05,,-11.95,-38.383333
br,riacho da lagoa,Riacho da Lagoa,20,,-8.866667,-44.966667
br,riacho da luzia,Riacho da Luzia,30,,-8.633333,-36.85
br,riacho da mata,Riacho da Mata,06,,-4.933333,-40.733333
br,riacho dantas,Riacho Dantas,05,,-12.2,-40.65
br,riacho da oiticica,Riacho da Oiticica,22,,-5.961944,-37.2375
br,riacho da onca,Riacho da Onça,05,,-11.233333,-39.733333
br,riacho da onca,Riacho da Onca,17,,-7.6,-36.983333
br,riacho da onca,Riacho da Onca,22,,-5.85,-35.9
br,riacho da onca,Riacho da Onça,30,,-8.383333,-37.566667
br,riacho da palha,Riacho da Palha,06,,-5.65,-39.65
br,riacho da pedra,Riacho da Pedra,05,,-13.916667,-40.15
br,riacho da pedra,Riacho da Pedra,22,,-5.033333,-37.253889
br,riacho da porta,Riacho da Porta,22,,-5.853611,-36.773056
br,riacho da praia,Riacho da Praia,05,,-13.65,-40.016667
br,riacho da prata,Riacho da Prata,06,,-2.966667,-40.266667
br,riacho das almas,Riacho das Almas,30,,-8.133333,-35.866667
br,riacho das antas,Riacho das Antas,28,,-9.75,-37.533333
br,riacho da sela,Riacho da Sela,06,,-3.683333,-39.333333
br,riacho da sella,Riacho da Sella,06,,-3.683333,-39.333333
br,riacho da serra,Riacho da Serra,13,,-6.2,-43.116667
br,riacho da serra,Riacho da Serra,30,,-8.566667,-38.9
br,riacho das furnas,Riacho das Furnas,30,,-8.583333,-36.4
br,riacho das pedras,Riacho das Pedras,05,,-13.85,-40.883333
br,riacho das porteiras,Riacho das Porteiras,06,,-5.783333,-39.85
br,riacho da telha,Riacho da Telha,22,,-5.816667,-35.616667
br,riacho da torre,Riacho da Tôrre,05,,-13.366667,-39.75
br,riacho de boi,Riacho de Boi,17,,-7.05,-37.816667
br,riacho de cima,Riacho de Cima,22,,-6.316667,-38
br,riacho de fora,Riacho de Fora,17,,-7.333333,-36.733333
br,riacho de fora,Riacho de Fora,22,,-6.716667,-37.083333
br,riacho de meic,Riacho de Meic,06,,-7.166667,-38.85
br,riacho de melc,Riacho de Melc,06,,-7.166667,-38.866667
br,riacho de pedro,Riacho de Pedro,17,,-6.733333,-37.966667
br,riacho de santana,Riacho de Santana,05,12658,-13.616667,-42.95
br,riacho de santana,Riacho de Santana,22,,-6.266667,-38.316667
br,riacho de sant'anna,Riacho de Sant'Anna,05,,-13.616667,-42.95
br,riacho de santo antonio,Riacho de Santo Antônio,17,,-7.683333,-36.15
br,riacho do atalho,Riacho do Atalho,17,,-7.2,-36.783333
br,riacho do balaio,Riacho do Balaio,05,,-13.25,-41.45
br,riacho do barro,Riacho do Barro,17,,-6.716667,-38.066667
br,riacho do boi,Riacho do Boi,06,,-7.516667,-38.716667
br,riacho do boi,Riacho do Boi,20,,-6.933333,-40.816667
br,riacho do bonito,Riacho do Bonito,05,,-13.883333,-41.283333
br,riacho do brejo,Riacho do Brejo,02,,-9.083333,-36.233333
br,riacho do buraco,Riacho do Buraco,17,,-7.716667,-36.75
br,riacho do burro,Riacho do Burro,15,,-19.5,-45.15
br,riacho do cabelo,Riacho do Cabelo,22,,-5.142222,-36.131389
br,riacho do caboclo,Riacho do Caboclo,17,,-7.033333,-38.55
br,riacho do caldeirao,Riacho do Caldeirão,05,,-13.866667,-40.466667
br,riacho do cedro,Riacho do Cedro,05,,-11.683333,-42.616667
br,riacho doce,Riacho Doce,02,,-9.566667,-35.65
br,riacho doce,Riacho Doce,05,,-18.216667,-39.633333
br,riacho doce,Riacho Doce,30,,-8.133333,-36.066667
br,riacho do cipo,Riacho do Cipó,05,,-12.35,-39.3
br,riacho do cipo,Riacho do Cipó,17,,-7.333333,-36.533333
br,riacho do cipo,Riacho do Cipo,22,,-6.666667,-37.15
br,riacho do correia,Riacho do Correia,05,,-12.116667,-39.116667
br,riacho do couro,Riacho do Couro,30,,-8.583333,-36.716667
br,riacho do curral,Riacho do Curral,05,,-13.683333,-40.566667
br,riacho do estevao,Riacho do Estevao,17,,-7.316667,-36.583333
br,riacho do fogo,Riacho do Fogo,15,,-16.783333,-43.716667
br,riacho do gado,Riacho do Gado,06,,-4.766667,-38.583333
br,riacho do garimpo,Riacho do Garimpo,11,,-18.683333,-54.766667
br,riacho do guimaraes,Riacho do Guimarães,06,,-3.883333,-40.383333
br,riacho do macaco,Riacho do Macaco,06,,-4.566667,-39.566667
br,riacho do mate,Riacho do Mate,05,,-8.783333,-39.183333
br,riacho do mato,Riacho do Mato,05,,-8.783333,-39.183333
br,riacho do mato,Riacho do Mato,06,,-5.983333,-40.35
br,riacho do mato,Riacho do Mato,30,,-8.866667,-35.716667
br,riacho do meio,Riacho do Meio,05,,-11.866667,-40.683333
br,riacho do meio,Riacho do Meio,06,,-3.416667,-39.366667
br,riacho do meio,Riacho do Meio,13,,-3.060556,-42.681667
br,riacho do meio,Riacho do Meio,17,,-7.016667,-38.6
br,riacho do meio,Riacho do Meio,22,,-5.733333,-35.433333
br,riacho do meio,Riacho do Meio,30,,-7.533333,-37.366667
br,riacho do mel,Riacho do Mel,02,,-9.4,-36.933333
br,riacho do mendes,Riacho do Mendes,20,,-7.633333,-43.7
br,riacho do norte,Riacho do Norte,05,,-13.85,-39.483333
br,riacho do ouro,Riacho do Ouro,31,,-11.616667,-47.133333
br,riacho do padre,Riacho do Padre,20,,-7.333333,-40.916667
br,riacho do pasto,Riacho do Pasto,05,,-13.8,-41.133333
br,riacho do pintor,Riacho do Pintor,05,,-11.65,-45.033333
br,riacho do poco,Riacho do Poço,05,,-12.6,-40.283333
br,riacho do porco,Riacho do Porco,20,,-7.933333,-43.2
br,riacho do prato,Riacho do Prato,22,,-5.675,-36.635
br,riacho do saco,Riacho do Saco,05,,-8.8,-38.866667
br,riacho do saco,Riacho do Saco,30,,-8.783333,-36.833333
br,riacho do sangue,Riacho do Sangue,06,,-5.616667,-38.766667
br,riacho dos barreiros,Riacho dos Barreiros,30,,-7.916667,-38.033333
br,riacho dos bois,Riacho dos Bois,06,,-5.9,-39.4
br,riacho dos bois,Riacho dos Bois,20,,-6.766667,-40.5
br,riacho dos cavalos,Riacho dos Cavalos,06,,-5.383333,-39.416667
br,riacho dos cavalos,Riacho dos Cavalos,17,,-6.433333,-37.666667
br,riacho dos currais,Riacho dos Currais,17,,-6.866667,-37.75
br,riacho dose,Riacho Dose,30,,-7.816667,-36.116667
br,riacho do sertao,Riacho do Sertão,02,,-9.55,-37
br,riacho dos gatos,Riacho dos Gatos,17,,-6.85,-38.2
br,riacho do sitio,Riacho do Sítio,17,,-6.5,-37.9
br,riacho dos machados,Riacho dos Machados,15,,-15.983333,-43.05
br,riacho dos matos,Riacho dos Matos,20,,-5.3,-41.966667
br,riacho dos negros,Riacho dos Negros,05,,-12.433333,-40.95
br,riacho dos negros,Riacho dos Negros,20,,-5.766667,-43.066667
br,riacho dos negros,Riacho dos Negros,30,,-9.033333,-37.283333
br,riacho do sobrado,Riacho do Sobrado,05,,-9.266667,-40.75
br,riacho do sol,Riacho do Sol,02,,-9.85,-36.866667
br,riacho do sol,Riacho do Sol,30,,-8.7,-36.55
br,riacho dos paulos,Riacho dos Paulos,20,,-8.283333,-44.816667
br,riacho dos paus,Riacho dos Paus,22,,-5.716667,-35.75
br,riacho dos piloes,Riacho dos Pilões,17,,-7.016667,-37.233333
br,riacho dos porcos,Riacho dos Porcos,05,,-12.8,-43.25
br,riacho dos porcos,Riacho dos Porcos,17,,-7.333333,-37.083333
br,riacho dos portos,Riacho dos Portos,05,,-12.8,-43.25
br,riacho d'ouro,Riacho d'Ouro,31,,-11.616667,-47.133333
br,riacho espera,Riacho Espera,30,,-8.866667,-36.516667
br,riacho esquerdo,Riacho Esquerdo,30,,-7.916667,-36.433333
br,riacho fechado,Riacho Fechado,06,,-5.15,-40.483333
br,riacho fechado,Riacho Fechado,17,,-6.7,-38.05
br,riacho fechado,Riacho Fechado,22,,-5.65,-35.8
br,riacho feio ii,Riacho Feio II,13,,-3.861111,-43.28
br,riacho feio i,Riacho Feio I,13,,-3.9375,-43.091944
br,riacho fresco,Riacho Fresco,20,,-10.616667,-44.616667
br,riacho frio,Riacho Frio,05,,-12.4,-42.9
br,riacho frio,Riacho Frio,20,,-10.083333,-44.983333
br,riacho fundo,Riacho Fundo,05,,-12.283333,-39.316667
br,riacho fundo,Riacho Fundo,06,,-5.2,-38.783333
br,riacho fundo,Riacho Fundo,13,,-7.066667,-44.733333
br,riacho fundo,Riacho Fundo,15,,-15.016667,-43.583333
br,riacho fundo,Riacho Fundo,17,,-6.916667,-38.45
br,riacho fundo,Riacho Fundo,20,,-3.968056,-42.215278
br,riacho fundo,Riacho Fundo,22,,-5.6,-35.833333
br,riacho fundo,Riacho Fundo,30,,-8.666667,-37.133333
br,riacho grande,Riacho Grande,02,,-9.466667,-37.45
br,riacho grande,Riacho Grande,05,,-9.433333,-39.85
br,riacho grande,Riacho Grande,06,,-7.133333,-39.95
br,riacho grande,Riacho Grande,13,,-3.892778,-42.893889
br,riacho grande,Riacho Grande,17,,-6.933333,-37.783333
br,riacho grande,Riacho Grande,20,,-10.25,-45.05
br,riacho grande,Riacho Grande,22,,-5.33,-36.571667
br,riacho grande,Riacho Grande,27,,-23.778606,-46.530275
br,riacho largo,Riacho Largo,28,,-9.85,-37.683333
br,riacho outeiro,Riacho Outeiro,05,,-13.166667,-39.433333
br,riacho pedras,Riacho Pedras,05,,-12.733333,-41.066667
br,riacho pequeno,Riacho Pequeno,30,,-8.433333,-39.05
br,riacho pompeu,Riacho Pompeu,06,,-5.966667,-39.7
br,riacho riachao,Riacho Riachão,06,,-6.916667,-40.1
br,riacho,Riacho,02,,-9.25,-35.383333
br,riacho,Riacho,05,,-10.883333,-43.283333
br,riacho,Riacho,08,,-19.75,-40.05
br,riacho,Riacho,15,,-17.2,-42.333333
br,riacho,Riacho,20,,-6.466667,-41.75
br,riacho,Riacho,22,,-5.43,-36.131389
br,riacho,Riacho,26,,-28.6,-48.966667
br,riacho,Riacho,30,,-9.016667,-40.033333
br,riacho salgado,Riacho Salgado,17,,-7.316667,-36.433333
br,riacho salgado,Riacho Salgado,22,,-5.743889,-36.471667
br,riacho salina,Riacho Salina,22,,-5.801389,-36.786111
br,riacho seco,Riacho Sêco,02,,-9.4,-37.85
br,riacho seco,Riacho Sêco,05,,-13.05,-39.75
br,riacho seco,Riacho Sêco,06,,-5.683333,-40.733333
br,riacho seco,Riacho Seco,13,,-3.3075,-43.398889
br,riacho seco,Riacho Sêco,17,,-6.516667,-37.866667
br,riacho seco,Riacho Sêco,22,,-5.483333,-35.566667
br,riacho seco,Riacho Sêco,30,,-8.366667,-37.266667
br,riacho velho,Riacho Velho,17,,-7.35,-38.083333
br,riacho verde,Riacho Verde,06,,-5.366667,-39.6
br,riacho verde,Riacho Verde,13,,-3.519444,-43.055278
br,riacho verde,Riacho Verde,17,,-7.1,-38.266667
br,riacho verde,Riacho Verde,22,,-5.866667,-35.733333
br,riacho verde,Riacho Verde,30,,-7.916667,-38.983333
br,riachuello,Riachuello,05,,-10.95,-40.583333
br,riachuelo,Riachuelo,02,,-9.85,-36.233333
br,riachuelo,Riachuelo,04,,-5.6625,-61.2425
br,riachuelo,Riachuelo,05,,-10.95,-40.583333
br,riachuelo,Riachuelo,06,,-3.683333,-39.333333
br,riachuelo,Riachuelo,13,,-1.933333,-44.783333
br,riachuelo,Riachuelo,20,,-9.433333,-45.6
br,riachuelo,Riachuelo,21,,-22.899049,-43.25537
br,riachuelo,Riachuelo,22,,-5.783333,-35.766667
br,riachuelo,Riachuelo,27,,-20.533333,-47.95
br,riachuelo,Riachuelo,28,,-10.733333,-37.183333
br,rialma,Rialma,29,9270,-15.3,-49.566667
br,rialmas,Rialmas,29,,-15.3,-49.566667
br,rialto,Rialto,21,,-22.583333,-44.266667
br,rianapolis,Rianápolis,29,,-15.483333,-49.466667
br,rianopolis,Rianôpolis,29,,-15.483333,-49.466667
br,ribamar,Ribamar,04,,-5.646667,-61.156389
br,ribamar,Ribamar,13,,-2.55,-44.05
br,ribas do rio pardo,Ribas do Rio Pardo,11,11935,-20.45,-53.766667
br,ribas,Ribas,18,,-25.873364,-50.036651
br,ribeira de cima,Ribeira de Cima,05,,-16.2,-39.833333
br,ribeira do pau grande,Ribeira do Páu Grande,05,,-11.05,-38.433333
br,ribeira do pombal,Ribeira do Pombal,05,28236,-10.833333,-38.533333
br,ribeirao amarelo,Ribeirão Amarelo,18,,-25.1,-48.833333
br,ribeirao areado,Ribeirão Areado,26,,-27.0786,-49.5334
br,ribeirao azul,Ribeirão Azul,13,,-5.95,-43.083333
br,ribeirao bonito,Ribeirão Bonito,18,,-24.842277,-48.726141
br,ribeirao bonito,Ribeirão Bonito,27,10877,-22.066667,-48.166667
br,ribeirao branco,Ribeirão Branco,26,,-26.9213,-49.1527
br,ribeirao branco,Ribeirão Branco,27,9718,-24.216667,-48.783333
br,ribeirao chelter,Ribeirão Chelter,26,,-26.8577,-49.1814
br,ribeirao claro,Ribeirão Claro,11,,-21.05,-53.633333
br,ribeirao claro,Ribeirão Claro,18,,-23.196799,-49.756736
br,ribeirao claro,Ribeirão Claro,27,,-20.833333,-49.216667
br,ribeirao corrente,Ribeirão Corrente,27,,-20.45,-47.583333
br,ribeirao da anta,Ribeirão da Anta,18,,-23.881522,-50.004666
br,ribeirao da baixa,Ribeirão da Baixa,05,,-13.25,-41.9
br,ribeirao da batata,Ribeirão da Batata,27,,-24.910604,-48.09038
br,ribeirao da divisa,Ribeirão da Divisa,21,,-22.4509,-44.3024
br,ribeirao da ilha,Ribeirão da Ilha,26,,-27.716667,-48.583333
br,ribeirao da laje,Ribeirão da Laje,26,,-26.913,-49.61514
br,ribeirao da onca,Ribeirão da Onça,27,,-23.19317,-47.954643
br,ribeirao da prata,Ribeirão da Prata,14,,-15.066667,-56.116667
br,ribeirao da serra,Ribeirão da Serra,27,,-24.266667,-47.95
br,ribeirao das frutas,Ribeirão das Frutas,26,,-26.763314,-49.824484
br,ribeirao das neves,Ribeirão das Neves,15,406840,-19.783333,-44.1
br,ribeirao das pedra,Ribeirão das Pedra,15,,-18.916667,-48.4
br,ribeirao das pedras,Ribeirão das Pedras,14,,-14.566667,-55.933333
br,ribeirao das pedras,Ribeirão das Pedras,15,,-18.916667,-48.4
br,ribeirao das pedras,Ribeirão das Pedras,18,,-24.897448,-48.954584
br,ribeirao das pedras,Ribeirão das Pedras,26,,-26.9126,-49.2382
br,ribeirao de baixo,Ribeirão de Baixo,18,,-25.371667,-50.305
br,ribeirao de cima,Ribeirão de Cima,05,,-13.216667,-41.916667
br,ribeirao de cima,Ribeirão de Cima,08,,-19.716667,-40.333333
br,ribeirao de cima,Ribeirão de Cima,18,,-25.384444,-50.344444
br,ribeirao de dentro,Ribeirão de Dentro,27,,-23.1582,-47.864217
br,ribeirao de sao domingos,Ribeirão de São Domingos,15,,-20.466667,-42.283333
br,ribeirao de sao joaquim,Ribeirão de São Joaquim,21,,-22.283333,-44.183333
br,ribeirao do cafe,Ribeirão do Café,18,,-23.95,-49.983333
br,ribeirao do carariau,Ribeirão do Carariaú,02,,-9.05,-36.133333
br,ribeirao do cruzeiro,Ribeirão do Cruzeiro,08,,-19.666667,-40.133333
br,ribeirao do espinho,Ribeirão do Espinho,26,,-26.998,-49.2101
br,ribeirao do ferro,Ribeirão do Ferro,26,,-27.0885,-49.6812
br,ribeirao do largo,Ribeirão do Largo,05,,-15.45,-40.716667
br,ribeirao do meio,Ribeirão do Meio,05,,-13.233333,-41.9
br,ribeirao do meio,Ribeirão do Meio,08,,-19.7,-40.316667
br,ribeirao do meio,Ribeirão do Meio,18,,-23.347,-49.8612
br,ribeirao do meio,Ribeirão do Meio,27,,-22.166667,-47.333333
br,ribeirao do mono,Ribeirão do Mono,26,,-26.920534,-49.696084
br,ribeirao do ouro,Ribeirão do Ouro,26,,-27.2,-49.15
br,ribeirao do pinhal,Ribeirão do Pinhal,18,11275,-23.4,-50.3
br,ribeirao do pote,Ribeirão do Pote,27,,-23.6,-45.833333
br,ribeirao do salto,Ribeirão do Salto,05,,-15.816667,-40.233333
br,ribeirao do salto,Ribeirão do Salto,26,,-27.1214,-49.5518
br,ribeirao dos indios,Ribeirão dos Índios,27,,-21.816667,-51.616667
br,ribeirao dos pintos,Ribeirão dos Pintos,27,,-22.783333,-49.916667
br,ribeirao dos porcos,Ribeirão dos Porcos,27,,-24.720922,-48.319378
br,ribeirao do tigre,Ribeirão do Tigre,18,,-25.315067,-48.970373
br,ribeirao do tucano,Ribeirão do Tucano,26,,-27.0813,-49.6441
br,ribeirao fidelis,Ribeirão Fidelis,26,,-26.8444,-49.0678
br,ribeirao fundo,Ribeirão Fundo,15,,-21.95,-46.216667
br,ribeirao fundo,Ribeirão Fundo,27,,-23.020849,-47.678415
br,ribeirao galinha,Ribeirão Galinha,08,,-19.666667,-40.25
br,ribeirao grande,Ribeirão Grande,14,,-14.9,-56.666667
br,ribeirao grande,Ribeirão Grande,18,,-25.102454,-48.807441
br,ribeirao grande,Ribeirão Grande,26,,-26.983333,-50
br,ribeirao grande,Ribeirão Grande,27,,-22.8,-45.45
br,ribeirao grieseback,Ribeirão Grieseback,26,,-26.902373,-49.64689
br,ribeirao herdt,Ribeirão Herdt,26,,-26.7784,-49.1769
br,ribeirao kelmann,Ribeirão Kelmann,26,,-26.8525,-49.1945
br,ribeirao lima,Ribeirão Lima,26,,-26.706338,-49.523794
br,ribeirao luebke,Ribeirão Luebke,26,,-26.8371,-49.1757
br,ribeirao marreco,Ribeirão Marreco,26,,-26.951328,-49.756655
br,ribeirao pequeno,Ribeirão Pequeno,26,,-28.45,-48.866667
br,ribeirao pires,Ribeirão Pires,27,111890,-23.716667,-46.416667
br,ribeirao preto,Ribeirão Prêto,27,551278,-21.166667,-47.8
br,ribeirao,Ribeirão,05,,-13.233333,-41.9
br,ribeirao,Ribeirão,08,,-19.666667,-40.25
br,ribeirao,Ribeirão,13,,-5.466667,-43.4
br,ribeirao,Ribeirão,14,,-15.316667,-56.666667
br,ribeirao,Ribeirão,15,,-16.783333,-43.65
br,ribeirao,Ribeirão,21,,-22.2,-42.4
br,ribeirao,Ribeirão,24,,-10.25,-65.266667
br,ribeirao,Ribeirão,26,,-27.716667,-48.583333
br,ribeirao,Ribeirão,27,,-23.167,-46.5716
br,ribeirao,Ribeirão,29,,-16.816667,-49.533333
br,ribeirao,Ribeirão,30,29819,-8.516667,-35.383333
br,ribeirao rigo,Ribeirão Rigo,26,,-26.745463,-49.523533
br,ribeirao souto,Ribeirão Souto,26,,-26.8154,-49.1781
br,ribeirao uru,Ribeirão Uru,26,,-27.0056,-49.6858
br,ribeirao vermelho do sul,Ribeirão Vermelho do Sul,27,,-23.816667,-49.45
br,ribeirao vermelho,Ribeirão Vermelho,15,,-21.183333,-45.05
br,ribeirao vermelho,Ribeirão Vermelho,18,,-25.123802,-48.86347
br,ribeirao vermelho,Ribeirão Vermelho,27,,-23.816667,-49.45
br,ribeiraozinho,Ribeirãozinho,05,,-13.733333,-41.2
br,ribeiraozinho,Ribeirãozinho,08,,-18.2,-40.866667
br,ribeiraozinho,Ribeirãozinho,18,,-25.980364,-49.330813
br,ribeiraozinho,Ribeirãozinho,26,,-26.1217,-49.9256
br,ribeiraozinho,Ribeirãozinho,27,,-23.5291,-47.921
br,ribeiraozinnho,Ribeirãozinnho,14,,-16.45,-52.666667
br,ribeira,Ribeira,06,,-3.966667,-38.433333
br,ribeira,Ribeira,13,,-2.716667,-44.033333
br,ribeira,Ribeira,15,,-15.833333,-40.4
br,ribeira,Ribeira,17,,-7.416667,-36.366667
br,ribeira,Ribeira,21,,-22.822963,-43.167197
br,ribeira,Ribeira,22,,-5.776667,-35.205
br,ribeira,Ribeira,26,,-26.3368,-48.6782
br,ribeira,Ribeira,27,,-24.666667,-49.016667
br,ribeira,Ribeira,28,,-10.866667,-37.183333
br,ribeirinha,Ribeirinha,18,,-24.916667,-49.416667
br,ribeiro do amparo,Ribeiro do Amparo,05,,-11.05,-38.433333
br,ribeiro dos santos,Ribeiro dos Santos,27,,-20.6,-48.933333
br,ribeiro do vale,Ribeiro do Vale,27,,-21.083333,-50.716667
br,ribeiro goncalves,Ribeiro Gonçalves,20,,-7.533333,-45.233333
br,ribeiro junqueira,Ribeiro Junqueira,15,,-21.466667,-42.516667
br,ribeiro machado,Ribeiro Machado,15,,-20.1124,-43.7739
br,ribeiropolis,Ribeirópolis,27,,-23.45,-49.416667
br,ribeiropolis,Ribeirópolis,28,11215,-10.533333,-37.433333
br,ribeiro,Ribeiro,05,,-12.05,-41.333333
br,ribeiro,Ribeiro,13,,-3.458056,-42.482222
br,ribeiro,Ribeiro,15,,-21.983333,-45.583333
br,ribeiro,Ribeiro,18,,-24.7892,-48.5549
br,ribeiro,Ribeiro,23,,-29.283333,-54.3
br,ribeiros de baixo,Ribeiros de Baixo,15,,-20.25,-44.7
br,ribeiros de cima,Ribeiros de Cima,15,,-20.266667,-44.683333
br,ribeiros,Ribeiros,15,,-21.983333,-45.583333
br,riberalta,Riberalta,24,,-13.583333,-60.666667
br,ricardinho,Ricardinho,15,,-16.2,-40.4
br,ricardo de albuquerque,Ricardo de Albuquerque,21,,-22.839094,-43.405413
br,ricardo,Ricardo,15,,-15.766667,-43.866667
br,ricardo santos,Ricardo Santos,23,,-29.9,-56.216667
br,riconada,Riconada,11,,-22.2,-56.766667
br,rifaina,Rifaina,27,,-20.083333,-47.433333
br,rinare,Rinaré,06,,-5.4,-39.033333
br,rincao da estrela,Rincão da Estrêla,23,,-29.15,-53.15
br,rincao da panela,Rincão da Panela,23,,-30.6198,-52.3359
br,rincao del rei,Rincão del Rei,23,,-29.9,-52.383333
br,rincao d'el rey,Rincao d'El Rey,23,,-29.9,-52.383333
br,rincao de s. joao,Rincão de S. João,23,,-29.8213,-50.8078
br,rincao do inferninho,Rincão do Inferninho,23,,-30.133333,-53.55
br,rincao do julio,Rincão do Júlio,11,,-22.683333,-55.6
br,rincao dos cabrais,Rincão dos Cabrais,23,,-29.733333,-52.95
br,rincao dos coxos,Rinção dos Coxos,18,,-25.392778,-50.174722
br,rincao dos kroeff,Rincão dos Kroeff,23,,-29.45,-50.416667
br,rincao gaucho,Rincão Gaúcho,21,,-22.332898,-42.939594
br,rincao,Rincão,15,,-19.9,-46.15
br,rincao,Rincão,22,,-5.183333,-37.283333
br,rincao,Rincão,26,,-28.833333,-49.25
br,rincao,Rincão,27,,-21.583333,-48.083333
br,rinconada,Rinconada,11,,-22.2,-56.766667
br,rinopolis,Rinópolis,27,,-21.7,-50.716667
br,rio 2,Rio 2,21,,-22.969344,-43.384971
br,rio abaixo,Rio Abaixo,05,,-13.75,-41.816667
br,rio abaixo,Rio Abaixo,27,,-23.315389,-46.604549
br,rio acima,Rio Acima,15,,-20.0859,-43.7903
br,rio acima,Rio Acima,26,,-28.75,-49.216667
br,rio acima,Rio Acima,27,,-23.966667,-47.866667
br,rio afonso,Rio Afonso,27,,-23.233333,-45.45
br,rio afonsos,Rio Afonsos,27,,-23.233333,-45.45
br,rio alegre,Rio Alegre,05,,-13.833333,-44.466667
br,rio alegre,Rio Alegre,14,,-16.8925,-56.720833
br,rio alegre,Rio Alegre,18,,-25.8191,-48.5829
br,rio azeite,Rio Azeite,27,,-24.7819,-48.174
br,rio azul,Rio Azul,18,,-25.716667,-50.783333
br,rio azul,Rio Azul,23,,-27.383333,-52.433333
br,rio baio primeiro,Rio Baio Primeiro,18,,-25.65988,-50.37012
br,rio baio segundo,Rio Baio Segundo,18,,-25.659149,-50.387574
br,rio baio terceiro,Rio Baio Terceiro,18,,-25.65387,-50.40514
br,rio bananal,Rio Bananal,08,4814,-19.266667,-40.333333
br,rio bananal,Rio Bananal,27,,-24.72334,-48.159136
br,rio bom,Rio Bom,18,,-23.766667,-51.416667
br,rio bonita,Rio Bonita,26,,-27.133333,-51.216667
br,rio bonito,Rio Bonito,18,,-24.416667,-51.5
br,rio bonito,Rio Bonito,21,35997,-22.716667,-42.616667
br,rio bonito,Rio Bonito,26,,-26.133333,-48.9
br,rio bonito,Rio Bonito,29,,-16.95,-51.816667
br,rio branco do sul,Rio Branco do Sul,18,26441,-25.166667,-49.3
br,rio branco,Rio Branco,01,257645,-9.966667,-67.8
br,rio branco,Rio Branco,05,,-12.016667,-45.033333
br,rio branco,Rio Branco,11,,-21.666667,-53.9
br,rio branco,Rio Branco,15,,-21.016667,-42.833333
br,rio branco,Rio Branco,18,,-24.35,-51.333333
br,rio branco,Rio Branco,20,,-6.95,-42.9
br,rio branco,Rio Branco,23,,-28.433333,-53.633333
br,rio branco,Rio Branco,24,,-10.15,-64.066667
br,rio branco,Rio Branco,26,,-27.083333,-52.133333
br,rio branco,Rio Branco,27,,-24.9044,-48.0121
br,rio branco,Rio Branco,30,,-8.416667,-37.066667
br,rio brilhante,Rio Brilhante,11,18837,-21.8,-54.55
br,rio bruno,Rio Bruno,26,,-26.746583,-49.801975
br,rio cacador,Rio Caçador,26,,-26.783333,-51
br,rio cacatu,Rio Cacatu,18,,-25.318836,-48.752212
br,rio cachorros,Rio Cachorros,26,,-27.4,-50.483333
br,rio calcado,Rio Calçado,08,,-20.55,-40.566667
br,rio capinzal,Rio Capinzal,26,,-27.333333,-51.6
br,rio carolina,Rio Carolina,26,,-28.133333,-49.05
br,rio cartente,Rio Cartente,15,,-19.016667,-42.116667
br,rio casca,Rio Casca,14,,-15.45,-55.35
br,rio casca,Rio Casca,15,11769,-20.216667,-42.65
br,rio cedro medio,Rio Cedro Médio,26,,-28.716667,-49.583333
br,rio cinzas,Rio Cinzas,18,,-23.45,-50.283333
br,rio claro do sul,Rio Claro do Sul,18,,-25.933333,-50.683333
br,rio claro,Rio Claro,14,,-16.666667,-56.8
br,rio claro,Rio Claro,15,,-22.416667,-45.266667
br,rio claro,Rio Claro,18,,-23.65,-52.216667
br,rio claro,Rio Claro,21,12620,-22.716667,-44.15
br,rio claro,Rio Claro,27,180151,-22.4,-47.55
br,rio claro,Rio Claro,29,,-16.3,-50.9
br,rio comprido,Rio Comprido,21,,-22.923276,-43.204466
br,rio corrente dos pedrosos,Rio Corrente dos Pedrosos,18,,-25.540559,-50.739138
br,rio corrente primeiro,Rio Corrente Primeiro,18,,-25.510484,-50.729649
br,rio corrente segundo,Rio Corrente Segundo,18,,-25.4959,-50.7155
br,rio correntes,Rio Correntes,26,,-27.083333,-50.633333
br,rio crespo,Rio Crespo,24,,-9.75,-62.883333
br,rio curupahy,Rio Curupahy,11,,-22.833333,-53.883333
br,rio da areia,Rio da Areia,05,,-13.066667,-39.3
br,rio da areia,Rio da Areía,18,,-25.464444,-50.388889
br,rio da areia,Rio da Areia,26,,-26.35,-50.633333
br,rio da barra,Rio da Barra,30,,-8.166667,-37.483333
br,rio da caixa,Rio da Caixa,05,,-13.35,-41.983333
br,rio da conceicao,Rio da Conceição,31,,-11.468889,-46.7825
br,rio da dona,Rio da Dona,05,,-12.966667,-39.333333
br,rio da pedra,Rio da Pedra,26,,-29,-49.833333
br,rio da praia,Rio da Praia,18,,-25.9476,-48.5911
br,rio da prata,Rio da Prata,14,,-13.216667,-55.25
br,rio da prata,Rio da Prata,18,,-25.983333,-48.716667
br,rio da prata,Rio da Prata,21,,-22.923044,-43.516273
br,rio da prata,Rio da Prata,26,,-26.820338,-49.991722
br,rio d'areia,Rio d'Areia,18,,-25.464444,-50.388889
br,rio das almas,Rio das Almas,05,,-13.683333,-39.483333
br,rio das almas,Rio das Almas,18,,-25.35,-50.416667
br,rio das antas,Rio das Antas,05,,-14.333333,-42.416667
br,rio das antas,Rio das Antas,18,,-24.916667,-53.533333
br,rio das antas,Rio das Antas,26,,-26.5,-50.233333
br,rio das cobras,Rio das Cobras,26,,-27.1103,-49.6204
br,rio da serra,Rio da Serra,26,,-26.533333,-50.3
br,rio das flores,Rio das Flores,05,,-13.666667,-40.183333
br,rio das flores,Rio das Flores,21,,-22.166667,-43.585278
br,rio das laranjeiras,Rio das Laranjeiras,27,,-23.859873,-47.130732
br,rio das minas,Rio das Minas,27,,-24.9922,-48.1232
br,rio das mortes,Rio das Mortes,15,,-21.183333,-44.333333
br,rio das ostras,Rio das Ostras,21,46619,-22.533333,-41.95
br,rio das palmeiras,Rio das Palmeiras,05,,-14.633333,-42.3
br,rio das pedras,Rio das Pedras,15,,-18.683333,-48.516667
br,rio das pedras,Rio das Pedras,21,,-22.971727,-43.332854
br,rio das pedras,Rio das Pedras,26,,-27.416667,-49.25
br,rio das pedras,Rio das Pedras,27,23722,-22.833333,-47.6
br,rio das pratas,Rio das Pratas,05,,-13.516667,-39.833333
br,rio das trainhas,Rio das Trainhas,23,,-28.85,-50.45
br,rio das vacas,Rio das Vacas,02,,-9.683333,-37.2
br,rio das vacas,Rio das Vacas,28,,-11.016667,-37.566667
br,rio da varzea,Rio da Várzea,18,,-25.958,-49.3312
br,rio da varzea,Rio da Várzea,27,,-24.5,-49.216667
br,rio de areia,Rio de Areia,05,,-15.733333,-40.55
br,rio de contas,Rio de Contas,05,,-13.6,-41.8
br,rio de janeiro,Rio de Janeiro,21,6023742,-22.9,-43.233333
br,rio deneke ii,Rio Deneke II,26,,-26.7974,-49.823
br,rio deneke i,Rio Deneke I,26,,-26.7799,-49.7841
br,rio de pedras,Rio de Pedras,05,,-9.966667,-39.2
br,rio deserto,Rio Deserto,26,,-28.55,-49.366667
br,rio do amaro,Rio do Amaro,05,,-13.533333,-38.983333
br,rio do antonio,Rio do Antônio,05,,-14.4,-42.083333
br,rio do bidelho,Rio do Bidelho,08,,-20.816667,-40.95
br,rio do braco,Rio do Braço,05,,-14.65,-39.266667
br,rio do cacho,Rio do Cacho,18,,-25.7841,-49.4932
br,rio do campo,Rio do Campo,26,,-26.966667,-50.15
br,rio do cedro medio,Rio do Cedro Médio,26,,-28.716667,-49.583333
br,rio do cedro,Rio do Cedro,18,,-25.067011,-48.585376
br,rio doce,Rio Doce,08,,-21.1,-41.533333
br,rio doce,Rio Doce,15,,-20.25,-42.9
br,rio doce,Rio Doce,30,,-7.95,-34.833333
br,rio do cordeiro,Rio do Cordeiro,30,,-8.85,-36.95
br,rio d'oeste,Rio d'Oeste,26,,-27.2,-49.8
br,rio do fogo,Rio do Fogo,22,,-5.266667,-35.383333
br,rio dois paus,Rio Dois Paus,13,,-3.142222,-43.476111
br,rio dois,Rio Dois,21,,-22.969344,-43.384971
br,rio do julio,Rio do Júlio,26,,-26.283333,-49.116667
br,rio do liso,Rio do Liso,26,,-26.483333,-50.366667
br,rio do mato,Rio do Mato,18,,-25.966667,-53.083333
br,rio do meio,Rio do Meio,05,,-15.066667,-39.983333
br,rio do meio,Rio do Meio,18,,-25.335001,-48.759221
br,rio do meio,Rio do Meio,22,,-5.688056,-36.732778
br,rio do moreira,Rio do Moreira,06,,-7.066667,-40.066667
br,rio do nunes,Rio do Nunes,18,,-25.344565,-48.76767
br,rio do ouro,Rio do Ouro,21,,-22.659444,-43.529444
br,rio do peixe,Rio do Peixe,05,,-11.1,-39.5
br,rio do peixe,Rio do Peixe,08,,-20.183333,-41.183333
br,rio do peixe,Rio do Peixe,13,,-2.15,-44.833333
br,rio do peixe,Rio do Peixe,15,,-19.566667,-44.866667
br,rio do peixe,Rio do Peixe,17,,-6.55,-38.466667
br,rio do peixe,Rio do Peixe,26,,-26.6875,-48.7388
br,rio do pinhal,Rio do Pinhal,18,,-25.35,-49.033333
br,rio do pires,Rio do Pires,05,,-13.116667,-42.3
br,rio do pito,Rio do Pito,27,,-24.692357,-48.193519
br,rio do poco,Rio do Poço,18,,-25.370902,-48.97699
br,rio do pouso,Rio do Pouso,26,,-28.416667,-49.116667
br,rio do prado,Rio do Prado,15,,-16.583333,-40.566667
br,rio do sal,Rio do Sal,02,,-9.85,-36.866667
br,rio do sal,Rio do Sal,05,,-9.45,-38.183333
br,rio do salto,Rio do Salto,26,,-28.833333,-49.633333
br,rio dos anjos,Rio dos Anjos,05,,-10.983333,-38.183333
br,rio dos bois,Rio dos Bois,31,,-9.295556,-48.4025
br,rio dos bugres,Rio dos Bugres,26,,-27.516667,-49.516667
br,rio dos cachorros,Rio dos Cachorros,26,,-27.4,-50.483333
br,rio dos canoas,Rio dos Canoas,18,,-25.224014,-48.353846
br,rio dos cedros,Rio dos Cedros,26,,-26.733333,-49.266667
br,rio dos indios,Rio dos Índios,23,,-27.316667,-52.883333
br,rio dos pardos,Rio dos Pardos,26,,-26.333333,-50.616667
br,rio dos patos,Rio dos Patos,18,,-25.2369,-48.1817
br,rio dos paus,Rio dos Paus,05,,-13.2,-38.95
br,rio dos porcos,Rio dos Porcos,05,,-11.966667,-38.866667
br,rio dos porcos,Rio dos Porcos,26,,-28.9,-49.4
br,rio dos porcos,Rio dos Porcos,27,,-24.725292,-48.329664
br,rio dos tabocos,Rio dos Tabocos,05,,-13.666667,-39.5
br,rio do sul,Rio do Sul,26,51945,-27.2181,-49.6436
br,rio dos veados,Rio dos Veados,18,,-24.830598,-48.869355
br,rio do testo,Rio do Testo,26,,-26.75,-49.183333
br,rio do tigre,Rio do Tigre,18,,-24.433333,-51.3
br,rio do toldo,Rio do Toldo,26,,-26.700247,-49.702457
br,rio dourado,Rio Dourado,21,,-22.466667,-42.066667
br,rio douro,Rio Douro,21,,-22.659444,-43.529444
br,rio do veado,Rio do Veado,26,,-26.690848,-49.796967
br,rio d'una,Rio d'Una,26,,-28.133333,-48.766667
br,rio espera,Rio Espera,15,,-20.85,-43.483333
br,rio estiva,Rio Estiva,26,,-26.283333,-50.083333
br,rio forcacao,Rio Forcação,26,,-26.742619,-49.573393
br,rio formoso,Rio Formoso,30,15518,-8.666667,-35.15
br,rio fortuna,Rio Fortuna,26,,-28.1,-49.116667
br,rio fundo,Rio Fundo,05,,-12.416667,-38.6
br,rio fundo,Rio Fundo,08,,-20.433333,-40.733333
br,rio gelo,Rio Gelo,18,,-25.9528,-48.811
br,rio grande da serra,Rio Grande da Serra,27,38162,-23.8,-46.333333
br,rio grande do piaui,Rio Grande do Piauí,20,,-7.783333,-43.133333
br,rio grande dos lopes,Rio Grande dos Lopes,13,,-3.234722,-42.970833
br,rio grande do sul,Rio Grande do Sul,23,,-32.033333,-52.083333
br,rio grande,Rio Grande,05,,-12.616667,-41.5
br,rio grande,Rio Grande,08,,-20.65,-40.65
br,rio grande,Rio Grande,13,,-1.916667,-44.633333
br,rio grande,Rio Grande,20,,-7.783333,-43.133333
br,rio grande,Rio Grande,21,,-22.183333,-42.5
br,rio grande,Rio Grande,23,187842,-32.033333,-52.083333
br,rio grande,Rio Grande,27,,-23.8214,-46.5454
br,rio grande,Rio Grande,30,,-8.016667,-37.166667
br,riograndina,Riograndina,21,,-22.183333,-42.5
br,rio guaraquecaba,Rio Guaraqueçaba,18,,-25.226774,-48.278946
br,rio ivai,Rio Ivaí,16,,-1.366667,-52.166667
br,rio krauel ii,Rio Krauel II,26,,-27.006165,-49.647024
br,riolandia,Riolândia,27,,-19.983333,-49.666667
br,rio largo,Rio Largo,02,63389,-9.483333,-35.85
br,rio limpo,Rio Limpo,05,,-11.783611,-45.977222
br,rio maina,Rio Maina,26,,-28.683333,-49.45
br,rio manso,Rio Manso,14,,-14.683333,-56.25
br,rio manso,Rio Manso,15,,-20.266667,-44.316667
br,rio manso,Rio Manso,21,,-22.336389,-43.315
br,rio manso,Rio Manso,27,,-23.366667,-45.4
br,rio mar,Rio Mar,16,,-7.25,-53.7
br,rio mar,Rio Mar,21,,-22.997001,-43.405439
br,rio morto,Rio Morto,22,,-5.178611,-37.3075
br,rio mundel,Rio Mundel,18,,-25.103171,-48.746334
br,rio negra,Rio Negra,23,,-31.4,-53.883333
br,rio negrinho,Rio Negrinho,26,41915,-26.239449,-49.499857
br,rio negro,Rio Negro,11,,-19.45,-54.966667
br,rio negro,Rio Negro,15,,-17.25,-40.933333
br,rio negro,Rio Negro,18,23007,-26.0934,-49.7895
br,rio negro,Rio Negro,21,,-21.9,-42.266667
br,rio negro,Rio Negro,23,,-31.4,-53.883333
br,rio negro,Rio Negro,26,,-28.933333,-49.433333
br,rio noronha,Rio Noronha,14,,-12.2,-58.183333
br,rio novinho,Rio Novinho,14,,-16.6,-57.05
br,rio novo de baixo,Rio Nôvo de Baixo,22,,-5.802778,-36.03
br,rio novo do sul,Rio Novo do Sul,08,6717,-20.866667,-40.933333
br,rio novo,Rio Novo,05,,-14.133333,-39.733333
br,rio novo,Rio Novo,08,,-19.066667,-41.016667
br,rio novo,Rio Novo,11,,-21.333333,-56.75
br,rio novo,Rio Novo,14,,-14.233333,-55.516667
br,rio novo,Rio Novo,15,6258,-21.483333,-43.133333
br,rio novo,Rio Novo,18,,-22.916667,-53.5
br,rio novo,Rio Nôvo,22,,-5.825,-36.040556
br,rio novo,Rio Novo,23,,-27.4,-52.316667
br,rio novo,Rio Novo,26,,-26.45,-50.3
br,rio palma,Rio Palma,08,,-19.416667,-40.333333
br,rio paranahyba,Rio Paranahyba,15,,-19.2,-46.25
br,rio paranaiba,Rio Paranaíba,15,,-19.2,-46.25
br,rio pardinho,Rio Pardinho,23,,-29.6,-52.5
br,rio pardo de minas,Rio Pardo de Minas,15,9540,-15.616667,-42.55
br,rio pardo,Rio Pardo,08,,-20.35,-41.533333
br,rio pardo,Rio Pardo,11,,-20.45,-53.766667
br,rio pardo,Rio Pardo,15,,-15.616667,-42.55
br,rio pardo,Rio Pardo,23,26999,-29.983333,-52.366667
br,rio peixe,Rio Peixe,05,,-11.1,-39.5
br,rio pequeno,Rio Pequeno,18,,-25.23529,-48.689734
br,rio pequeno,Rio Pequeno,21,,-22.917677,-43.437392
br,rio pequeno,Rio Pequeno,26,,-28.15,-49.216667
br,rio pequeno,Rio Pequeno,27,,-23.8134,-46.5047
br,rio piracicaba,Rio Piracicaba,15,10439,-19.916667,-43.183333
br,rio pomba,Rio Pomba,15,13707,-21.283333,-43.183333
br,rio preto do sul,Rio Prêto do Sul,26,,-26.216567,-49.604935
br,rio preto ii,Rio Preto II,13,,-3.658889,-43.001111
br,rio preto i,Rio Preto I,13,,-3.820556,-43.036389
br,rio preto,Rio Prêto,05,,-11,-44.533333
br,rio preto,Rio Prêto,08,,-18.716667,-40.333333
br,rio preto,Rio Prêto,15,,-18.3,-47.5
br,rio preto,Rio Prêto,18,,-24.083333,-50.266667
br,rio preto,Rio Prêto,21,,-22.089167,-43.827222
br,rio preto,Rio Prêto,26,,-26.216567,-49.604935
br,rio preto,Rio Preto,27,,-20.8,-49.383333
br,rio primeiro,Rio Primeiro,11,,-22.633333,-54.8
br,rio putiu,Rio Putiú,06,,-4.35,-38.916667
br,rio quatorze,Rio Quatorze,11,,-22.533333,-54.35
br,rio quieto,Rio Quieto,18,,-25.966667,-52.666667
br,rio quinze,Rio Quinze,18,,-24.683333,-51.933333
br,rio rafael braco grande,Rio Rafael Braço Grande,26,,-26.944704,-49.53916
br,rio real,Rio Real,05,24006,-11.466667,-37.933333
br,rio,Rio,21,,-22.9,-43.233333
br,rio rufino,Rio Rufino,26,,-27.866667,-49.783333
br,rio sagrado,Rio Sagrado,18,,-25.5327,-48.7754
br,rio santo,Rio Santo,05,,-14.066667,-39.366667
br,rio scharlach,Rio Scharlach,26,,-26.943346,-49.593402
br,rio seco,Rio Sêco,05,,-12.35,-38.8
br,rio seco,Rio Sêco,21,,-22.766667,-42.666667
br,rio sinho,Rio Sinho,04,,-9.483333,-66.8
br,riosinho,Riosinho,18,,-25.535033,-50.65262
br,riosinho,Riosinho,23,,-29.65,-50.45
br,rio sono,Rio Sono,31,,-9.341944,-47.744167
br,rio sul,Rio Sul,26,,-27.2181,-49.6436
br,rio tavares,Rio Tavares,26,,-27.65,-48.5
br,rio tinto,Rio Tinto,17,11804,-6.8,-35.083333
br,rio toldo,Rio Tôldo,23,,-27.75,-52.166667
br,rio tromahy,Rio Tromahy,16,,-1.283333,-46.3
br,rio turvo,Rio Turvo,27,,-22.716667,-49.416667
br,rio uaca,Rio Uaçá,03,,3.75,-51.366667
br,rio verde de mato grosso,Rio Verde de Mato Grosso,11,16613,-18.933333,-54.866667
br,rio verde do sul,Rio Verde do Sul,11,,-22.9,-55.45
br,rio verde,Rio Verde,05,,-14.866667,-42.75
br,rio verde,Rio Verde,06,,-5.433333,-40.433333
br,rio verde,Rio Verde,11,,-18.933333,-54.866667
br,rio verde,Rio Verde,18,,-25.143889,-48.247778
br,rio verde,Rio Verde,23,,-29.25,-49.866667
br,rio verde,Rio Verde,27,,-23.5029,-47.5722
br,rio verde,Rio Verde,29,,-17.216667,-51.55
br,rio vermelho,Rio Vermelho,05,,-13.016667,-38.5
br,rio vermelho,Rio Vermelho,15,,-18.3,-43
br,rio vermelho,Rio Vermelho,21,,-22.733333,-42.55
br,rio vermelho,Rio Vermelho,26,,-26.283333,-49.333333
br,rio vermelho,Rio Vermelho,27,,-24.9616,-48.5156
br,riozinho de baixo,Riozinho de Baixo,18,,-25.572434,-50.677328
br,riozinho dos anciute,Riozinho dos Anciute,18,,-25.53906,-50.629748
br,riozinho dos santos,Riozinho dos Santos,18,,-25.602367,-50.648912
br,riozinho,Riozinho,04,,-9.483333,-66.8
br,riozinho,Riozinho,11,,-18.25,-56.233333
br,riozinho,Riozinho,13,,-9.733333,-46.25
br,riozinho,Riozinho,18,,-23.862055,-50.810627
br,riozinho,Riozinho,23,,-29.65,-50.45
br,riozinho,Riozinho,24,,-11.5,-61.3
br,ripeira,Ripeira,20,,-3.910556,-42.343056
br,riqueza,Riqueza,05,,-13.683333,-46.083333
br,riqueza,Riqueza,18,,-26.033333,-53.616667
br,risada,Risada,28,,-9.883333,-37.866667
br,riserva uno,Riserva Uno,21,,-23.000814,-43.40254
br,rita,Rita,11,,-18.416667,-54.9
br,rita,Rita,14,,-16.313611,-56.590278
br,rita,Rita,16,,-4.501389,-52.653333
br,rita velha,Rita Velha,11,,-17.8,-57.25
br,rivaliza,Rivaliza,01,,-7.8,-72.633333
br,rive,Rive,08,,-20.766667,-41.466667
br,riviera del fiori,Riviera del Fiori,21,,-23.002271,-43.342078
br,roberto,Roberto,27,,-21.266667,-48.966667
br,roca de caraubas,Roça de Caraúbas,17,,-7.75,-36.483333
br,roca de dentro,Roça de Dentro,30,,-7.716667,-37.716667
br,roca de milho,Roça de Milho,20,,-7.833333,-42.233333
br,rocadinho,Roçadinho,02,,-8.95,-35.966667
br,roca do arroz,Roça do Arroz,05,,-12.616667,-43.366667
br,roca do bruno,Roça do Bruno,16,,-1.966667,-46.433333
br,rocado grande,Roçado Grande,05,,-12.433333,-39.266667
br,rocado grande,Roçado Grande,22,,-5.566667,-37.219444
br,roca do mato,Roça do Mato,15,,-15.3,-41.833333
br,roca do meio,Roça do Meio,05,,-14.3,-41.083333
br,rocado,Roçado,06,,-4.866667,-41.133333
br,rocado,Roçado,13,,-6.666667,-44.316667
br,rocado,Rocado,20,,-7.466667,-43.216667
br,rocados,Roçados,05,,-14.1,-41.416667
br,roca grande,Roça Grande,05,,-11.85,-41.016667
br,roca grande,Roça Grande,13,,-3.95,-45.066667
br,roca grande,Roça Grande,15,,-21.6,-42.966667
br,roca nova,Roça Nova,17,,-6.533333,-38.166667
br,roca nova,Roça Nova,20,,-7.383333,-43.983333
br,roca nova,Roça Nova,30,,-8.183333,-38.366667
br,roca,Roça,15,,-22.5062,-45.6697
br,roca,Roça,20,,-4.45,-41.533333
br,roca,Roça,22,,-5.677778,-36.877778
br,roca sales,Roca Sales,23,,-29.283333,-51.866667
br,rocas novas,Roças Novas,15,,-19.75,-43.633333
br,rocas,Roças,22,,-4.989722,-36.916667
br,roca velha,Roça Velha,05,,-12.483333,-40.566667
br,roca velha,Roça Velha,13,,-3.390278,-42.6
br,roca velha,Roça Velha,17,,-7.9,-36.766667
br,roca velha,Roça Velha,20,,-3.5525,-42.278056
br,roca velha,Roça Velha,30,,-8.666667,-38.183333
br,rocca salles,Rocca Salles,23,,-29.283333,-51.866667
br,roceira,Roceira,02,,-9.883333,-36.35
br,rocha cavalcante,Rocha Cavalcante,02,,-9.1,-36.066667
br,rocha leao,Rocha Leão,21,,-22.433333,-42.016667
br,rocha miranda,Rocha Miranda,21,,-22.852805,-43.358412
br,rocha ribeiro,Rocha Ribeiro,21,,-22.867222,-43.3575
br,rocha,Rocha,06,,-3.016667,-40.366667
br,rocha,Rocha,15,,-21.466667,-45.816667
br,rocha,Rocha,21,,-22.894829,-43.248948
br,rocha sobrinho,Rocha Sobrinho,21,,-22.779424,-43.413007
br,rocha velha,Rocha Velha,05,,-12.45,-40.15
br,rochedinho,Rochedinho,11,,-20.233333,-54.55
br,rochedo de minas,Rochedo de Minas,15,,-21.633333,-43.016667
br,rochedo,Rochedo,05,,-11.566667,-41.966667
br,rochedo,Rochedo,11,,-19.95,-54.866667
br,rochedo,Rochedo,15,,-21.633333,-43.016667
br,rochedo,Rochedo,23,,-29.533333,-50.75
br,rochedo,Rochedo,30,,-8.533333,-38.183333
br,rocheira,Rocheira,02,,-9.583333,-36.583333
br,rochoso,Rochoso,06,,-4.95,-40.4
br,rocinha,Rocinha,05,,-12.783333,-41.8
br,rocinha,Rocinha,18,,-25.116667,-52.85
br,rocinha,Rocinha,21,,-22.990975,-43.249924
br,rocinha,Rocinha,27,,-22.533333,-47.733333
br,rodagem,Rodagem,21,,-22.183333,-41.616667
br,roda velha,Roda Velha,05,,-12.7,-45.833333
br,rodeador,Rodeador,05,,-14.583333,-45.733333
br,rodeador,Rodeador,06,,-3.333333,-40.133333
br,rodeador,Rodeador,15,,-15.466667,-44.25
br,rodeador,Rodeador,20,,-5.716667,-42.166667
br,rodeador,Rodeador,22,,-6.066667,-37.766667
br,rodeador,Rodeador,30,,-7.833333,-37.75
br,rodeieiro,Rodeieiro,05,,-10.633333,-41.433333
br,rodeio bonito,Rodeio Bonito,23,,-27.466667,-53.166667
br,rodeio chato,Rodeio Chato,26,,-27.166667,-52.583333
br,rodeio doze,Rodeio Doze,26,,-26.85,-49.333333
br,rodeio,Rodeio,08,,-20.716667,-40.916667
br,rodeio,Rodeio,18,,-24.934338,-48.821851
br,rodeio,Rodeio,21,,-22.549444,-43.683889
br,rodeio,Rodeio,26,,-26.85,-49.333333
br,rodeio,Rodeio,27,,-22.7485,-45.72009
br,rodeiro,Rodeiro,15,,-21.2,-42.866667
br,rodelas,Rodelas,05,,-8.833333,-38.766667
br,rodeleiro,Rodeleiro,05,,-10.633333,-41.433333
br,rodellas,Rodellas,05,,-8.833333,-38.766667
br,rodiador,Rodiador,05,,-12.05,-38.85
br,rodoleiro,Rodoleiro,05,,-10.633333,-41.433333
br,rodolfo fernandes,Rodolfo Fernandes,22,,-5.8,-38.066667
br,rodolfo goncalves,Rodolfo Gonçalves,11,,-19.233333,-54.266667
br,rodonopolis,Rodonópolis,14,,-16.466667,-54.633333
br,rodovalho,Rodovalho,29,,-13.983333,-48.733333
br,rodrigada,Rodrigada,27,,-22.166667,-47.433333
br,rodrigo mendes,Rodrigo Mendes,11,,-20.566667,-56.116667
br,rodrigo peixoto,Rodrigo Peixoto,11,,-20.166667,-55.75
br,rodrigues alves,Rodrigues Alves,24,3827,-11.9,-65
br,rodrigues mendes,Rodrigues Mendes,20,,-6.366667,-42.7
br,rodrigues,Rodrigues,04,,-6.533333,-73.25
br,rodrigues,Rodrigues,14,,-16.266667,-54.816667
br,rodrigues,Rodrigues,25,,3.7,-61.383333
br,rodrigues,Rodrigues,27,,-23.061312,-47.913276
br,roladeira,Roladeira,04,,-6.994167,-70.705833
br,rolador,Rolador,23,,-28.25,-54.816667
br,rolandia,Rolândia,18,51005,-23.3,-51.366667
br,rolante,Rolante,23,15594,-29.666667,-50.566667
br,rolantinho da figueira,Rolantinho da Figueira,23,,-29.666667,-50.55
br,rolao,Rolão,20,,-6.3,-41.416667
br,rolas,Rôlas,21,,-22.433333,-41.933333
br,roldao,Roldão,06,,-5.25,-38.5
br,rolim de moura,Rolim de Moura,24,37953,-13.083333,-62.266667
br,romao,Romão,04,,-.366667,-62.983333
br,romao,Romão,11,,-22.083333,-53.316667
br,romao,Romão,15,,-15.416667,-42.516667
br,romaria,Romaria,15,,-18.883333,-47.633333
br,roma,Roma,05,,-12.133333,-39.266667
br,roma,Roma,31,,-11.316667,-48.35
br,romelandia,Romelândia,26,,-26.633333,-53.316667
br,romeu,Romeu,15,,-19.233333,-48.55
br,romualda,Romualda,15,,-16.066667,-40.466667
br,romualdo,Romualdo,15,,-18.45,-48.483333
br,rona,Ronã,15,,-19.416667,-48.2
br,roncadeira,Roncadeira,02,,-9.033333,-36.066667
br,roncadon,Roncadon,06,,-6.916667,-39.966667
br,roncado,Roncado,05,,-14.566667,-39.45
br,roncador,Roncador,02,,-9.7,-36.05
br,roncador,Roncador,05,,-14.566667,-39.45
br,roncador,Roncador,11,,-21.916667,-55.75
br,roncador,Roncador,13,,-4.533333,-43.816667
br,roncador,Roncador,15,,-20.016667,-45.05
br,roncador,Roncador,18,,-24.616667,-52.416667
br,roncador,Roncador,20,,-7.266667,-41.616667
br,roncador,Roncador,26,,-26.893401,-49.737278
br,roncador,Roncador,29,,-17.366667,-48.25
br,ronca,Ronca,31,,-5.983333,-48.116667
br,ronco d' agua,Ronco d' Agua,05,,-18.05,-39.933333
br,ronda alta,Ronda Alta,23,,-27.783333,-52.783333
br,ronda das salinas,Ronda das Salinas,14,,-15.7,-60.1
br,ronda do sul,Ronda do Sul,14,,-15.95,-59.7
br,rondinha,Rondinha,18,,-25.883333,-52.083333
br,rondinha,Rondinha,23,,-27.816667,-52.9
br,rondolandia,Rondolândia,14,,-14.5,-55.416667
br,rondonia,Rondônia,24,,-10.866667,-61.95
br,rondonopolis,Rondonópolis,14,152921,-16.466667,-54.633333
br,rondon,Rondon,18,,-23.383333,-52.8
br,roque gonzales,Roque Gonzales,23,,-28.116667,-55.033333
br,roque gonzalez,Roque Gonzalez,23,,-28.116667,-55.033333
br,roque,Roque,13,,-3.016667,-45.383333
br,roque,Roque,15,,-22.547583,-45.537974
br,roque,Roque,16,,-6.461389,-58.138611
br,roque,Roque,23,,-30.216667,-52.083333
br,roque sousa dias,Roque Sousa Dias,15,,-21.55,-45.95
br,rosa branca,Rosa Branca,25,,-3.733333,-60.683333
br,rosa d' agua,Rosa d' Agua,05,,-13.333333,-39.366667
br,rosadia,Rosadia,20,,-9.116667,-44.65
br,rosa do felicio,Rosa do Felício,23,,-30.716667,-56.033333
br,rosa e silva,Rosa e Silva,30,,-7.433333,-35.35
br,rosalandia,Rosalândia,29,,-16.433333,-50.416667
br,rosalia,Rosália,27,,-21.983333,-49.983333
br,rosalina,Rosalina,27,,-20.266667,-50.666667
br,rosalinda,Rosalinda,15,,-19.55,-45.966667
br,rosal,Rosal,04,,-6.416667,-62.283333
br,rosal,Rosal,21,,-20.966667,-41.733333
br,rosapolis,Rosápolis,20,,-2.95,-41.8
br,rosarial,Rosarial,27,,-23.664506,-47.245878
br,rosaria,Rosária,15,,-21.233333,-44.833333
br,rosaria,Rosária,27,,-21.466667,-46.783333
br,rosarinho,Rosarinho,04,,-5.875278,-61.390278
br,rosario da limeira,Rosário da Limeira,15,,-20.983333,-42.516667
br,rosario de minas,Rosário de Minas,15,,-21.716667,-43.633333
br,rosario do catete,Rosário do Catete,28,,-10.683333,-37.033333
br,rosario do rio acima,Rosário do Rio Acima,14,,-14.833333,-56.416667
br,rosario do sul,Rosário do Sul,23,36722,-30.25,-54.916667
br,rosario oeste,Rosário Oeste,14,10469,-14.833333,-56.416667
br,rosario oueste,Rosario Oueste,14,,-14.833333,-56.416667
br,rosario,Rosário,05,,-10.183333,-38.983333
br,rosario,Rosário,06,,-5.416667,-39.533333
br,rosario,Rosário,08,,-20.233333,-41.516667
br,rosario,Rosário,13,23271,-2.95,-44.233333
br,rosario,Rosário,15,,-21.233333,-44.833333
br,rosario,Rosário,20,,-3.55,-41.816667
br,rosario,Rosário,21,,-22.683333,-43.25
br,rosario,Rosário,23,,-30.25,-54.916667
br,rosario,Rosário,27,,-23.175885,-47.672404
br,rosario,Rosário,28,,-10.683333,-37.033333
br,rosa,Rosa,06,,-5.283333,-40.683333
br,rosa,Rosa,11,,-21.85,-57.566667
br,rosa,Rosa,23,,-29.433333,-53.5
br,rosas,Rosas,15,,-20.2,-45.2
br,rosas,Rosas,27,,-22.766667,-45.683333
br,roseiral,Roseiral,15,,-19.9,-41.366667
br,roseiral,Roseiral,27,,-22.9,-45.3
br,roseira,Roseira,08,,-20.883333,-41.533333
br,roseira,Roseira,15,,-21.2,-46.9
br,roseira,Roseira,18,,-23.316667,-50.883333
br,roseira,Roseira,27,,-22.9,-45.3
br,roseiras,Roseiras,15,,-22.816667,-46.283333
br,roseira velha,Roseira Velha,27,,-22.9,-45.283333
br,rosensal,Rosensal,14,,-14.366667,-56.716667
br,roseo,Róseo,30,,-7.75,-37.8
br,rosetinha,Rosetinha,15,,-22.6,-45.433333
br,rosilha,Rosilha,20,,-8.883333,-41.833333
br,rossensal,Rossensal,14,,-14.366667,-56.716667
br,roteiro,Roteiro,02,,-9.833333,-35.966667
br,roteiro,Roteiro,27,,-20.933333,-51.15
br,rothirs,Rothirs,26,,-26.7726,-49.0631
br,rotulo,Rótulo,15,,-19.2,-43.783333
br,rovaldo,Rovaldo,15,,-19.05,-48.083333
br,rozal,Rozal,04,,-6.416667,-62.283333
br,rozal,Rozal,21,,-20.966667,-41.733333
br,rozendo pinto,Rozendo Pinto,15,,-17.833333,-41.516667
br,rua de palha,Rua de Palha,05,,-14.35,-39.166667
br,rua do arco,Rua do Arco,05,,-13.8,-39.583333
br,rua nova,Rua Nova,02,,-9.716667,-35.783333
br,rua nova,Rua Nova,17,,-6.7,-38.633333
br,rubelita,Rubelita,15,,-16.416667,-42.283333
br,rubiacea,Rubiácea,27,,-21.333333,-50.733333
br,rubiao,Rubião,21,,-22.9,-43.966667
br,rubiataba,Rubiataba,29,16128,-15.133333,-49.8
br,rubim,Rubim,06,,-5.333333,-40.733333
br,rubim,Rubim,15,,-16.1,-40.4
br,rubim,Rubim,23,,-29.366667,-53.383333
br,rubineia,Rubinéia,27,,-20.216667,-51.033333
br,rucas,Ruças,06,,-4.933333,-37.966667
br,rucinha,Rucinha,30,,-8.15,-35.45
br,rucinho,Rucinho,30,,-8.15,-35.45
br,rudado,Rudado,17,,-7.016667,-38.633333
br,ruestao,Ruestão,20,,-7.25,-40.733333
br,rufino felix,Rufino Félix,05,,-13.533333,-39.383333
br,rufino miranda,Rufino Miranda,15,,-17.1,-41.8
br,rufino,Rufino,16,,-.233333,-56.016667
br,rufino,Rufino,26,,-27.866667,-49.783333
br,rufinos,Rufinos,17,,-6.333333,-38.516667
br,rui barbosa,Rui Barbosa,05,,-12.3,-40.45
br,rui barbosa,Rui Barbosa,17,,-5.883333,-35.95
br,rui barbosa,Rui Barbosa,18,,-26.231667,-53.581944
br,rui barbosa,Rui Barbosa,27,,-20.95,-49.516667
br,ruilandia,Ruilândia,27,,-20.95,-49.516667
br,ruinas,Ruínas,20,,-10.033333,-44.116667
br,ruinha,Ruinha,15,,-19.133333,-42.533333
br,ruivo,Ruivo,27,,-23.687717,-47.407329
br,ruizubo,Ruizubo,14,,-15.916667,-54.616667
br,rumo,Rumo,05,,-12.183333,-38.633333
br,rumo,Rumo,13,,-1.8,-44.716667
br,rusina,Rusina,05,,-13.55,-39.866667
br,russas,Russas,06,39465,-4.933333,-37.966667
br,russinha,Russinha,06,,-4.5,-38.683333
br,russinha,Russinha,13,,-3.740278,-43.462778
br,russinha,Russinha,30,,-8.15,-35.45
br,ruy barbosa,Ruy Barbosa,05,21093,-12.3,-40.45
br,ruy barbosa,Ruy Barbosa,26,,-26.883333,-52.383333
br,sabana,Sabana,27,,-23.4797,-46.085
br,sabao,Sabão,06,,-7.533333,-39.1
br,sabara,Sabará,15,158359,-19.9,-43.8
br,saba,Saba,16,,-4.366667,-51.816667
br,sabaudia,Sabáudia,18,,-23.3,-51.55
br,sabia grande,Sabiá Grande,05,,-10.666667,-43.333333
br,sabia,Sabiá,06,,-5.4,-39.666667
br,sabia,Sabiá,18,,-25.55,-51.666667
br,sabia,Sabia,20,,-6.783333,-42.083333
br,sabia,Sabiá,22,,-5.544722,-37.185278
br,sabiauna,Sabiaúna,27,,-23.453134,-47.986553
br,sabinopolis,Sabinópolis,15,9713,-18.666667,-43.1
br,sabino,Sabino,27,,-21.466667,-49.566667
br,sabiuca,Sabiucá,05,,-8.85,-38.583333
br,sabiu grande,Sabiú Grande,05,,-10.666667,-43.333333
br,saboeiro,Saboeiro,06,,-6.533333,-39.9
br,saboeiro,Saboeiro,17,,-7.166667,-37.916667
br,saboeiro,Saboeiro,22,,-6.35,-37.066667
br,saboga,Saboga,15,,-15.183333,-44.133333
br,saboia,Sabóia,11,,-19.216667,-55.716667
br,sabonete,Sabonete,06,,-4.666667,-40.383333
br,sabonete,Sabonete,20,,-3.3575,-42.090556
br,sabonete,Sabonete,30,,-7.6,-39.433333
br,saboo,Saboó,27,,-23.933333,-46.35
br,sabugirana,Sabugirana,17,,-6.766667,-37
br,sabugi,Sabugi,23,,-29.116667,-54.05
br,sabugueiro,Sabugueiro,18,,-24.366667,-51.55
br,sabugueiro,Sabugueiro,26,,-26.8628,-49.8782
br,sabujirana,Sabujirana,17,,-6.766667,-37
br,sabuji,Sabuji,23,,-29.116667,-54.05
br,sacada,Sacada,01,,-10.933333,-69.25
br,sacada,Sacada,15,,-15.5,-46.566667
br,sacado,Sacado,01,,-10.933333,-69.25
br,sacado,Sacado,04,,-4.725556,-62.374167
br,sacai,Sacaí,04,,-3.945833,-62.953611
br,sacambu,Sacambu,04,,-3.266667,-60.95
br,sacao,Sacão,30,,-8.9,-37.283333
br,sacaron,Sacaron,11,,-23.666667,-54.566667
br,sacco de penedinho,Sacco de Penedinho,05,,-8.966667,-38.683333
br,sacco dos morcegos,Sacco dos Morcegos,05,,-10.666667,-38.616667
br,saco bonito,Saco Bonito,20,,-7.933333,-42.25
br,saco comprido,Saco Comprido,05,,-12.683333,-41.783333
br,saco comprido,Saco Comprido,30,,-7.966667,-40.516667
br,saco da arara,Saco da Arara,05,,-9.516667,-41.116667
br,saco da conceicao,Saco da Conceição,17,,-6.983333,-37.466667
br,saco da ema,Saco da Ema,20,,-7.616667,-41.233333
br,saco da forquilha,Saco da Forquilha,17,,-6.083333,-37.2
br,saco da gangorra,Saco Da Gangorra,06,,-5.3,-38.1
br,saco da gorda,Saco da Gorda,14,,-16.8,-57.483333
br,saco da jurema,Saco da Jurema,05,,-12.416667,-42.666667
br,saco da manga,Saco da Manga,20,,-7.833333,-41.65
br,saco da melancia,Saco da Melancia,20,,-6.883333,-40.8
br,saco danta,Saco Danta,20,,-3.503889,-42.323889
br,saco da onca,Saco da Onça,05,,-14.766667,-42.566667
br,saco da onca,Saco da Onça,20,,-6.7,-40.566667
br,saco da onca,Saco da Onça,22,,-5.806944,-36.974167
br,saco da onca,Saco da Onça,30,,-7.683333,-37.533333
br,saco da roca,Saco da Roça,20,,-6.85,-40.65
br,saco da serra branca,Saco da Serra Branca,17,,-7.366667,-37.75
br,saco da serra,Saco da Serra,30,,-7.766667,-37.85
br,saco da taboa,Saco da Taboa,20,,-5.133333,-41.1
br,saco de bois,Saco de Bois,05,,-11,-42.766667
br,saco de fora,Saco de Fora,21,,-22.75,-41.883333
br,saco de nova olinda,Saco de Nova Olinda,17,,-7.483333,-38.033333
br,saco de penedinho,Saco de Penedinho,05,,-8.966667,-38.683333
br,saco do andre,Saco do André,17,,-6.65,-37.516667
br,saco do boi,Saco do Boi,05,,-11,-42.766667
br,saco do capao,Saco do Capão,05,,-11.333333,-43.1
br,saco do capim,Saco do Capim,17,,-7.45,-37.833333
br,saco do cipo,Saco do Cipo,20,,-6.866667,-41.483333
br,saco do correio,Saco do Correio,05,,-11.716667,-38.95
br,saco do cruzeiro,Saco do Cruzeiro,20,,-7.016667,-41.45
br,saco do engano,Saco do Engano,20,,-6.933333,-41.516667
br,saco do escondido,Saco do Escondido,20,,-6.45,-40.9
br,saco do feijao,Saco do Feijão,06,,-4.716667,-39.266667
br,saco do geremias,Saco do Geremias,20,,-6.783333,-41.333333
br,saco do jorge,Saco do Jorge,06,,-6.383333,-38.783333
br,saco do jua,Saco do Jua,30,,-7.6,-39.983333
br,saco do martinho,Saco do Martinho,20,,-6.433333,-41.316667
br,saco do martins,Saco do Martins,20,,-6.45,-41.333333
br,saco do medeiras,Saco do Medeiras,02,,-9.933333,-37.083333
br,saco do morcego,Saco do Morcego,20,,-6.85,-41.35
br,saco do muquem,Saco do Muquém,05,,-14.016667,-43.366667
br,saco do pau branco,Saco do Pau Branco,06,,-4.583333,-40.333333
br,saco do peba,Saco do Peba,22,,-6.8,-36.633333
br,saco do penedinho,Saco do Penedinho,05,,-8.966667,-38.683333
br,saco do pequi,Saco do Pequi,20,,-3.728889,-42.513611
br,saco do riacho,Saco do Riacho,20,,-6.633333,-41.433333
br,saco do romao,Saco do Romão,30,,-7.933333,-37.983333
br,saco dos bois,Saco dos Bois,02,,-9.983333,-36.916667
br,saco dos bois,Saco dos Bois,05,,-13.65,-43.466667
br,saco dos bois,Saco dos Bois,30,,-7.883333,-38.083333
br,saco dos cacoes,Saco dos Cações,08,,-21.15,-40.883333
br,saco dos campos,Saco dos Campos,30,,-7.966667,-38.083333
br,saco dos ladroes,Saco dos Ladrões,05,,-12.216667,-39.75
br,saco dos morcegos,Saco dos Morcegos,05,,-10.666667,-38.616667
br,saco dos negros,Saco dos Negros,30,,-7.766667,-40.5
br,saco dos reis,Saco dos Reis,20,,-7.233333,-42.183333
br,saco do tamandua,Saco do Tamanduá,17,,-6.816667,-37.466667
br,saco do tambarutaca,Saco do Tambarutaca,18,,-25.431279,-48.453094
br,saco do umbu,Saco do Umbu,20,,-7.316667,-41.883333
br,saco do urubu,Saco do Urubu,20,,-7.316667,-41.883333
br,saco do viegas,Saco do Viegas,21,,-22.894333,-43.497141
br,saco fora,Saco Fora,21,,-22.783333,-41.933333
br,saco fundo,Saco Fundo,20,,-7.15,-41.516667
br,saco fundo,Saco Fundo,27,,-20.783333,-47.45
br,saco grande,Saco Grande,05,,-12.816667,-42.533333
br,saco grande,Saco Grande,06,,-4.85,-39.083333
br,saco grande,Saco Grande,20,,-7.033333,-41.55
br,saco grande,Saco Grande,28,,-9.75,-37.45
br,saco novo,Saco Novo,15,,-18.883333,-44.25
br,saco,Saco,02,,-9.283333,-37.316667
br,saco,Saco,05,,-10.466667,-43.5
br,saco,Saco,06,,-3.916667,-41.266667
br,saco,Saco,13,,-3.408611,-42.350556
br,saco,Saco,15,,-20.633333,-45.583333
br,saco,Saco,17,,-6.483333,-37.883333
br,saco,Saco,20,,-3.541667,-42.284167
br,saco,Saco,21,,-22.9414,-44.0419
br,saco,Saco,22,,-5.316667,-35.483333
br,saco,Saco,30,,-7.916667,-38.283333
br,saco sao pedro,Saco São Pedro,06,,-6.566667,-38.75
br,saco verde,Saco Verde,06,,-5.233333,-38.033333
br,sacra familia do tingua,Sacra Família do Tinguá,21,,-22.49,-43.608333
br,sacramento,Sacramento,15,16983,-19.883333,-47.45
br,sacramento,Sacramento,16,,-.616667,-51.2
br,sacramento,Sacramento,22,,-5.497778,-36.853333
br,sadio,Sadio,20,,-6.983333,-41.566667
br,saecinza,Saecinza,16,,-6.283333,-57.7
br,safiro,Safiro,15,,-16.833333,-40.833333
br,safra,Safra,08,,-20.933333,-41.083333
br,sagrada familia,Sagrada Família,08,,-20.583333,-40.7
br,sagrado coracao,Sagrado Coração,15,,-17.783333,-41.883333
br,sagrado,Sagrado,11,,-19.416667,-56.966667
br,sagres,Sagres,27,,-21.866667,-50.966667
br,saguim,Saguim,17,,-7.116667,-38.466667
br,saguim,Saguim,20,,-5.75,-42.533333
br,saguim,Saguim,30,,-8.516667,-36.083333
br,saguoes,Saguões,13,,-3.946111,-42.813889
br,saias,Saias,18,,-25.516667,-50.2
br,saican,Saican,23,,-29.85,-54.966667
br,saica,Saicã,23,,-29.85,-54.966667
br,sai-cinza,Sai-Cinza,16,,-6.283333,-57.7
br,sai de cima,Sai de Cima,20,,-9.15,-42.066667
br,saids,Saids,18,,-25.516667,-50.2
br,sainauma,Sainaúma,16,,-6.333333,-57.833333
br,saint anna,Saint Anna,08,,-20.283333,-41.766667
br,saiqui,Saiqui,18,,-24.955902,-48.79896
br,saire,Sairé,30,,-8.333333,-35.65
br,sai,Saí,21,,-22.935556,-44.000833
br,sai,Saí,26,,-26.183333,-48.666667
br,saiva,Saivá,18,,-25.4509,-48.7321
br,saladero oeste,Saladero Oeste,23,,-29.766667,-56.966667
br,salamanca,Salamanca,20,,-6.9,-40.95
br,salao,Salão,06,,-4.416667,-39.3
br,salao,Salão,22,,-5.828611,-37.490556
br,salceiro,Salceiro,26,,-27.333333,-49.333333
br,saldanha marinho,Saldanha Marinho,23,,-28.4,-53.1
br,saldanha,Saldanha,05,,-10.416667,-42.55
br,saldanha,Saldanha,18,,-25.73487,-50.5134
br,sal de cima,Sal de Cima,20,,-9.15,-42.066667
br,salesiano,Salesiano,08,,-20.733333,-41
br,sales oliveira,Sales Oliveira,27,,-20.766667,-47.85
br,salesopolis,Salesópolis,27,,-23.533333,-45.85
br,sales,Sales,16,,-8.783333,-50
br,sales,Sales,27,,-21.316667,-49.5
br,salete,Salete,26,,-26.979,-50
br,salgadalia,Salgadália,05,,-11.466667,-39.183333
br,salgada,Salgada,04,,-3.366667,-60.15
br,salgada,Salgada,05,,-11.466667,-39.183333
br,salgada,Salgada,17,,-7.35,-35.433333
br,salgadinha,Salgadinha,06,,-5.55,-40.033333
br,salgadinho,Salgadinho,02,,-9.233333,-37.816667
br,salgadinho,Salgadinho,05,,-12.333333,-38.666667
br,salgadinho,Salgadinho,06,,-5.066667,-39.883333
br,salgadinho,Salgadinho,13,,-3.055833,-42.164167
br,salgadinho,Salgadinho,17,,-6.533333,-35.616667
br,salgadinho,Salgadinho,20,,-7.416667,-41.55
br,salgadinho,Salgadinho,22,,-5.607222,-36.4925
br,salgadinho,Salgadinho,28,,-9.966667,-37.783333
br,salgadinho,Salgadinho,30,,-7.916667,-35.666667
br,salgado de sao felix,Salgado de São Félix,17,4266,-7.35,-35.433333
br,salgado do melao,Salgado do Melão,05,,-9.316667,-38.683333
br,salgado do nicolau,Salgado do Nicolau,06,,-3.266667,-39.483333
br,salgado filho,Salgado Filho,18,,-26.166667,-53.366667
br,salgado filho,Salgado Filho,23,,-28.016667,-54.533333
br,salgado,Salgado,02,,-9.433333,-36.666667
br,salgado,Salgado,05,,-10.4,-40.366667
br,salgado,Salgado,06,,-3.333333,-39.533333
br,salgado,Salgado,13,,-2.616667,-43.9
br,salgado,Salgado,17,,-7.283333,-36.866667
br,salgado,Salgado,20,,-3.528889,-42.126667
br,salgado,Salgado,22,,-5.679167,-37.153611
br,salgado,Salgado,28,5457,-11.033333,-37.466667
br,salgado,Salgado,30,,-7.783333,-38.166667
br,salgidinho,Salgidinho,17,,-6.383333,-37.833333
br,salgueirinho,Salgueirinho,30,,-7.783333,-39.466667
br,salgueiro,Salgueiro,21,,-22.929098,-43.223337
br,salgueiro,Salgueiro,30,42153,-8.066667,-39.1
br,salinada,Salinada,05,,-15.65,-39.766667
br,salina de cima,Salina de Cima,20,,-5.083333,-41.316667
br,salina grande,Salina Grande,30,,-8.683333,-38.383333
br,salina,Salina,05,,-14.083333,-42.166667
br,salina,Salina,13,,-8.983333,-46.066667
br,salina,Salina,14,,-15.7,-60.1
br,salina,Salina,17,,-7.85,-36.616667
br,salina,Salina,20,,-6.833333,-40.716667
br,salina,Salina,22,,-5.974444,-36.920833
br,salina,Salina,29,,-18.25,-49.566667
br,salina,Salina,30,,-8.4,-38.883333
br,salinas da margarida,Salinas da Margarida,05,,-12.866667,-38.766667
br,salinas do almeida,Salinas do Almeida,14,,-16.25,-58.516667
br,salinas do santo antonio,Salinas do Santo Antônio,05,,-10.416667,-42.55
br,salinas,Salinas,05,,-12.866667,-38.766667
br,salinas,Salinas,08,,-20.75,-40.65
br,salinas,Salinas,13,,-1.583333,-45
br,salinas,Salinas,14,,-15.7,-60.1
br,salinas,Salinas,15,25747,-16.166667,-42.283333
br,salinas,Salinas,16,,-.616667,-47.333333
br,salinas,Salinas,20,,-3.904167,-42.688611
br,salinas,Salinas,21,,-21.466667,-41.05
br,salininha,Salininha,05,,-9.516667,-41.55
br,salinopolis,Salinópolis,16,40999,-.616667,-47.333333
br,salinopolis,Salinópolis,22,,-5.15,-36.6
br,salinora,Salinorã,23,,-29.016667,-51.7
br,salitre,Salitre,05,,-11.6,-42.333333
br,salitre,Salitre,06,,-4.216667,-39.733333
br,salitre,Salitre,15,,-19.1,-46.683333
br,salitre,Salitre,27,,-24.631228,-48.985564
br,salles de oliveira,Salles de Oliveira,27,,-20.766667,-47.85
br,sallesopolis,Sallesopolis,27,,-23.533333,-45.85
br,salles,Salles,16,,-8.783333,-50
br,salmorao,Salmorão,27,,-21.616667,-50.866667
br,salmourao,Salmourão,27,,-21.616667,-50.866667
br,sal nascente,Sal Nascente,02,,-9.45,-36.116667
br,saloa,Saloá,30,,-8.966667,-36.65
br,salobinha,Salobinha,29,,-16.016667,-51.45
br,salobra,Salobra,11,,-20.166667,-56.516667
br,salobre,Salobre,16,,-7.75,-49.916667
br,salobro,Salobro,05,,-13.816667,-40.15
br,salobro,Salobro,16,,-7.75,-49.916667
br,salobro,Salobro,20,,-4.516667,-42.666667
br,salobro,Salobro,30,,-8.6,-36.683333
br,salome,Salomé,02,,-9.933333,-36.566667
br,salome,Salomé,05,,-14.85,-39.633333
br,salome,Salomé,06,,-6.2,-40.533333
br,salqueiro,Salqueiro,30,,-8.066667,-39.1
br,sal,Sal,20,,-9.2,-42.083333
br,salsas,Salsas,20,,-3.8,-42.516667
br,salseiro,Salseiro,26,,-26.25,-50.35
br,salta,Salta,16,,-8.066667,-50.183333
br,saltinho d'oeste,Saltinho d'Oeste,18,,-23.966667,-53.433333
br,saltinho,Saltinho,11,,-21.066667,-54.416667
br,saltinho,Saltinho,18,,-25.221806,-48.869122
br,saltinho,Saltinho,23,,-27.416667,-53.166667
br,saltinho,Saltinho,26,,-26.8532,-49.0034
br,saltinho,Saltinho,27,,-22.833333,-47.666667
br,salto alegre,Salto Alegre,27,,-20.533333,-47.583333
br,salto da divisa,Salto da Divisa,15,,-16,-39.95
br,salto da pedra,Salto da Pedra,13,,-3.449722,-42.301389
br,salto da pedra,Salto da Pedra,20,,-4.05,-41.75
br,salto de bota,Salto de Bota,27,,-22.283333,-47.983333
br,salto de cima,Salto de Cima,15,,-22.85,-46.216667
br,salto de pirapora,Salto de Pirapora,27,32228,-23.6494,-47.5715
br,salto do avanhandava,Salto do Avanhandava,27,,-21.25,-49.95
br,salto do cubatao,Salto do Cubatão,18,,-25.81198,-48.805684
br,salto do itarare,Salto do Itararé,18,,-23.583333,-49.616667
br,salto do itu,Salto do Itú,27,,-23.2,-47.283333
br,salto dollman,Salto Dollman,26,,-26.8611,-49.7867
br,salto do mandira,Salto do Mandira,27,,-24.9863,-48.0597
br,salto do norte,Salto do Norte,26,,-26.8747,-49.1031
br,saltoes,Saltões,20,,-9.75,-45.35
br,salto grande do paranapanema,Salto Grande do Paranapanema,27,,-22.9,-49.983333
br,salto grande,Salto Grande,15,,-16,-39.95
br,salto grande,Salto Grande,18,,-25.983333,-52.716667
br,salto grande,Salto Grande,26,,-27.416667,-49.6
br,salto grande,Salto Grande,27,,-22.9,-49.983333
br,salto pilao,Salto Pilão,26,,-27.128074,-49.537057
br,salto,Salto,05,,-10.886389,-45.821667
br,salto,Salto,11,,-20.4,-54.733333
br,salto,Salto,13,,-5.783333,-43.866667
br,salto,Salto,15,,-18.716667,-45
br,salto,Salto,18,,-25.066667,-53.25
br,salto,Salto,21,,-22.297952,-42.831544
br,salto,Salto,23,,-2.333333,-50.683333
br,salto,Salto,26,,-26.533333,-48.833333
br,salto,Salto,27,98389,-23.2,-47.283333
br,salto weissbach,Salto Weissbach,26,,-26.8899,-49.1188
br,salutaris,Salutáris,21,,-22.183889,-43.296389
br,salvacao,Salvação,04,,-6.283333,-64.25
br,salvacao,Salvação,13,,-3.257222,-42.684722
br,salvador,Salvador,05,2711903,-12.983333,-38.516667
br,salvador,Salvador,06,,-5.116667,-39.516667
br,salvador,Salvador,13,,-3.37,-43.425278
br,salvador,Salvador,15,,-16.266667,-40.566667
br,salvador,Salvador,23,,-29.45,-51.516667
br,salvador,Salvador,26,,-26.416667,-48.833333
br,salvador,Salvador,31,,-10.165,-48.873889
br,salvarano,Salvarano,04,,-7.883333,-60.683333
br,salva,Salva,04,,-7.083333,-60.4
br,salvaterra,Salvaterra,05,,-13.966667,-39.633333
br,salvaterra,Salvaterra,13,,-4.516667,-44.016667
br,salvaterra,Salvaterra,16,,-.766667,-48.516667
br,salva vida,Salva Vida,04,,-7.016667,-71.6
br,salvavida,Salvavida,05,,-12.566667,-40.916667
br,salva vida,Salva Vida,06,,-5.3,-39.3
br,salvavidas,Salvavidas,05,,-12.566667,-40.916667
br,salva vidas,Salva Vidas,22,,-6.05,-37.833333
br,samambaial,Samambaial,27,,-23.65,-49.55
br,samambaia,Samambaia,02,,-9.6,-37.166667
br,samambaia,Samambaia,06,,-7.016667,-39.7
br,samambaia,Samambaia,15,,-20.033333,-42.866667
br,samambaia,Samambaia,18,,-25.5,-51.516667
br,samambaia,Samambaia,20,,-10.35,-44.35
br,samambaia,Samambaia,22,,-5.733333,-35.65
br,samambaia,Samambaia,27,,-23.1,-47.433333
br,samambaia,Samambaia,28,,-10.933333,-38.066667
br,samambaia,Samambaia,30,,-8.35,-37.716667
br,samara,Samará,06,,-3.533333,-39.566667
br,samauma,Samaúma,01,,-8.35,-71.4
br,samauma,Samaúma,04,,.15,-69.266667
br,sambaetiba,Sambaetiba,21,,-22.683333,-42.8
br,sambaia,Sambaia,15,,-20.616667,-42.333333
br,sambaiba i,Sambaiba I,13,,-3.02,-42.0975
br,sambaibal,Sambaibal,13,,-3.815833,-43.104444
br,sambaiba,Sambaíba,05,,-10.983333,-43.083333
br,sambaiba,Sambaíba,13,,-3.420278,-42.479722
br,sambaiba,Sambaíba,18,,-23.474667,-52.639307
br,sambaiba,Sambaíba,20,,-3.614722,-42.562778
br,sambaitiba,Sambaitiba,21,,-22.683333,-42.8
br,sambaituba,Sambaituba,05,,-14.65,-39.083333
br,sambaqui,Sambaqui,26,,-26.3358,-48.5669
br,samba quixaba,Samba Quixaba,22,,-5.7225,-36.783889
br,sambauma,Sambauma,05,,-12.25,-37.8
br,sambito,Sambito,20,,-6.3,-41.45
br,sampaio correia,Sampaio Correia,21,,-22.866667,-42.6
br,sampaio,Sampaio,15,,-18.066667,-43.85
br,sampaio,Sampaio,21,,-22.900642,-43.267128
br,sampaio,Sampaio,27,,-21.266667,-47.883333
br,sampaio,Sampaio,31,,-5.291944,-47.735833
br,samuel bueno,Samuel Bueno,15,,-20.6,-46.216667
br,samuel,Samuel,23,,-28.666667,-51.183333
br,samuel sousa,Samuel Sousa,23,,-30.716667,-54.05
br,sananduva,Sananduva,23,9601,-27.95,-51.8
br,san antonio,San Antônio,18,,-26.068889,-53.725278
br,san antonio,San Antônio,21,,-22.6475,-43.556944
br,san antonio,San Antonio,30,,-7.516667,-39.516667
br,sana,Sana,21,,-22.4,-42.183333
br,sanata barbara de baixo,Sanata Bárbara de Baixo,18,,-25.560466,-50.033388
br,san carlos,San Carlos,11,,-23.6,-54.9
br,san carlos,San Carlos,24,,-9.083333,-64.133333
br,sander,Sander,23,,-29.466667,-50.833333
br,sandolandia,Sandolândia,31,,-12.513056,-49.879167
br,sandovalina,Sandovalina,27,,-22.45,-51.733333
br,sandoval,Sandoval,04,,.95,-67.166667
br,san francisco,San Francisco,21,,-23.008275,-43.454221
br,sanga da areia,Sanga da Areia,26,,-29.083333,-49.766667
br,sanga do engenho,Sanga do Engenho,26,,-28.8,-49.566667
br,sanga do veado,Sanga do Veado,26,,-28.983333,-49.5
br,sanga funda,Sanga Funda,23,,-29.7659,-51.3249
br,sanga grande,Sanga Grande,26,,-28.883333,-49.566667
br,sangaia,Sangãiã,13,,-4.45,-43.816667
br,sanganha,Sanganhã,13,,-4.45,-43.816667
br,sangao,Sangão,26,,-28.633333,-49.133333
br,sanga pucha,Sanga Puchã,11,,-22.666667,-55.6
br,sanga puita,Sanga Puitã,11,,-22.666667,-55.6
br,sangrador,Sangrador,13,,-5.133333,-42.866667
br,sangradouro,Sangradouro,05,,-12.333333,-38.55
br,sangradouro,Sangradouro,06,,-4.2,-40.433333
br,sangradouro,Sangradouro,20,,-5.133333,-42.716667
br,sangradouro,Sangradouro,30,,-7.633333,-39.65
br,sangue,Sangue,13,,-3.993056,-43.355278
br,sanguessuga,Sanguessuga,05,,-11.975278,-46.054722
br,sanguessuga,Sanguessuga,06,,-4.766667,-39.983333
br,sanharao,Sanharão,13,,-3.963889,-43.178333
br,sanharao,Sanharao,22,,-6.033333,-37.966667
br,sanharao,Sanharão,27,,-24.8247,-48.5447
br,sanharo,Sanharó,05,,-11.816667,-42.016667
br,sanharo,Sanharó,13,,-3.411111,-42.674722
br,sanharo,Sanharó,20,,-6.983333,-40.633333
br,sanharo,Sanharó,30,,-8.35,-36.566667
br,sania luzia,Sania Luzia,04,,-2.733333,-67.583333
br,san joaquim,San Joaquim,04,,1.716667,-69.383333
br,san jose de cuxo,San Jose de Cuxo,04,,-6.201389,-60.259444
br,san jose do quilombo,San José do Quilombo,15,,-18.8,-43.166667
br,san jose,San José,04,,-4.416111,-63.689444
br,san lucas,San Lucas,24,,-8.35,-63.416667
br,san miguel,San Miguel,01,,-10.916667,-69.416667
br,sanna,Sanna,21,,-22.4,-42.183333
br,san paulo,San Paulo,27,,-23.533333,-46.616667
br,san pedro,San Pedro,23,,-29.616667,-54.166667
br,sanriago,Sanriago,17,,-8.116667,-36.883333
br,santa adelaide,Santa Adelaide,20,,-4.7,-41.983333
br,santa adelaide,Santa Adelaide,27,,-23.412679,-47.883164
br,santa adelia,Santa Adélia,27,12585,-21.266667,-48.8
br,santa alaide,Santa Alaide,11,,-18.2,-56.283333
br,santa albertina,Santa Albertina,27,,-20.033333,-50.733333
br,santa alda,Santa Alda,11,,-20.716667,-53.766667
br,santa alice,Santa Alice,27,,-21.9,-47.916667
br,santa ambrosina,Santa Ambrosina,27,,-21.666667,-47.466667
br,santa amelia,Santa Amélia,13,,-8.983333,-46.7
br,santa amelia,Santa Amélia,18,,-23.266667,-50.383333
br,santa amelia,Santa Amélia,27,,-21.3,-47.95
br,santa america,Santa América,27,,-21.8,-50.083333
br,santa ana da chapada,Santa Ana Da Chapada,14,,-15.433333,-55.75
br,santa ana de piraguara,Santa Ana de Piraguara,15,,-20.833333,-43.333333
br,santa ana do paranaiba,Santa Ana do Paranaiba,11,,-19.666667,-51.183333
br,santa ana dos piloes,Santa Ana dos Pilões,27,,-22.666667,-45.316667
br,santa ana dos remedios,Santa Ana dos Remedios,30,,-3.85,-32.4
br,santa ana do vargem grande,Santa Ana do Vargem Grande,27,,-21.833333,-46.883333
br,santa ana,Santa Ana,04,,.283333,-67.266667
br,santa ana,Santa Ana,05,,-12.716667,-39.916667
br,santa ana,Santa Ana,14,,-16.05,-55.866667
br,santa ana,Santa Ana,16,,-.316667,-56.016667
br,santa angelica,Santa Angélica,08,,-20.683333,-41.45
br,santa anita,Santa Anita,14,,-15.4,-60.266667
br,santa anna da barriera,Santa Anna da Barriera,16,,-8.8775,-49.711111
br,santa anna da chapada,Santa Anna da Chapada,14,,-15.433333,-55.75
br,santa anna da paraopeba,Santa Anna da Paraopeba,15,,-20.383333,-44.116667
br,santa anna da vargem,Santa Anna da Vargem,15,,-21.25,-45.5
br,santa anna de carapanatuba,Santa Anna de Carapanatuba,04,,-6.754167,-62.591667
br,santa anna de cataguazes,Santa Anna de Cataguazes,15,,-21.283333,-42.55
br,santa anna de itabapoana,Santa Anna de Itabapoana,21,,-20.966667,-41.733333
br,santa anna do alfie,Santa Anna do Alfie,15,,-19.766667,-42.866667
br,santa anna do capim,Santa Anna do Capim,16,,-2.033333,-47.733333
br,santa anna do carapanatuba,Santa Anna do Carapanatuba,04,,-6.754167,-62.591667
br,santa anna do deserto,Santa Anna do Deserto,15,,-21.948611,-43.165833
br,santa anna do rio das velhas,Santa Anna do Rio das Velhas,15,,-19.033333,-47.916667
br,santa anna dos patos,Santa Anna dos Patos,15,,-18.833333,-46.583333
br,santa anna dos remedios,Santa Anna dos Remedios,30,,-3.85,-32.4
br,santa anna,Santa Anna,04,,.283333,-67.266667
br,santa anna,Santa Anna,14,,-16.05,-55.866667
br,santa anna,Santa Anna,16,,-.316667,-56.016667
br,santa anna,Santa Anna,30,,-3.85,-32.4
br,santa antonio da patrulha,Santa Antonio da Patrulha,23,,-29.833333,-50.533333
br,santa antonio,Santa Antonio,31,,-5.728056,-47.33
br,santa aparecida,Santa Aparecida,11,,-19.466667,-55.283333
br,santa aroca,Santa Aroca,11,,-19.933333,-56.083333
br,santa avoia,Santa Avoia,11,,-19.933333,-56.083333
br,santa avoya,Santa Avoya,11,,-19.933333,-56.083333
br,santa barbara de cima,Santa Bárbara de Cima,18,,-25.519896,-50.028912
br,santa barbara d'oeste,Santa Barbara d'Oeste,27,,-22.749167,-47.413611
br,santa barbara do fervedouro,Santa Bárbara do Fervedouro,15,,-20.733333,-42.283333
br,santa barbara do monte verde,Santa Bárbara do Monte Verde,15,,-21.966667,-43.7
br,santa barbara do oeste,Santa Bárbara do Oeste,27,,-22.749167,-47.413611
br,santa barbara do rio pardo,Santa Bárbara do Rio Pardo,27,,-22.916667,-49.25
br,santa barbara dos casados,Santa Bárbara dos Casados,05,,-14.116667,-41.983333
br,santa barbara do sul,Santa Barbara do Sul,23,,-28.366667,-53.25
br,santa barbara do tigurio,Santa Barbara do Tigurio,15,,-21.25,-43.583333
br,santa barbara,Santa Bárbara,04,,-4.062222,-66.418611
br,santa barbara,Santa Bárbara,05,,-11.95,-38.966667
br,santa barbara,Santa Bárbara,06,,-5.566667,-39.633333
br,santa barbara,Santa Bárbara,07,,-15.983333,-47.8
br,santa barbara,Santa Bárbara,11,,-22.25,-53.483333
br,santa barbara,Santa Bárbara,13,,-3.666667,-44.883333
br,santa barbara,Santa Bárbara,14,,-15.65,-59.15
br,santa barbara,Santa Bárbara,15,19991,-19.933333,-43.4
br,santa barbara,Santa Bárbara,18,,-26.166667,-51.566667
br,santa barbara,Santa Bárbara,21,,-21.533333,-41.45
br,santa barbara,Santa Barbara,23,,-28.366667,-53.25
br,santa barbara,Santa Bárbara,24,,-9.2,-62.916667
br,santa barbara,Santa Barbara,27,,-22.749167,-47.413611
br,santa barbara,Santa Bárbara,29,,-16.583333,-49.7
br,santa barbara,Santa Bárbara,31,,-6.983333,-47.75
br,santa boa ventura,Santa Bôa Ventura,17,,-7.4,-38.216667
br,santa branca,Santa Branca,21,,-22.896745,-43.569989
br,santa branca,Santa Branca,27,8661,-23.4,-45.883333
br,santa brigida,Santa Brígida,05,,-9.733333,-38.133333
br,santa candida,Santa Cândida,27,,-21.75,-47.916667
br,santa candido,Santa Cândido,27,,-21.75,-47.916667
br,santa carlota,Santa Carlota,18,,-25.35,-50.216667
br,santa catarina,Santa Catarina,06,,-4.866667,-39.35
br,santa catarina,Santa Catarina,11,,-18.166667,-56.233333
br,santa catarina,Santa Catarina,15,,-16.833333,-43.6
br,santa catarina,Santa Catarina,17,,-7.766667,-37.1
br,santa catarina,Santa Catarina,22,,-5.195278,-36.212778
br,santa catarina,Santa Catarina,27,,-23.95,-47.483333
br,santa catharina,Santa Catharina,15,,-22.116667,-45.5
br,santa cecilia do pavao,Santa Cecília do Pavão,18,,-23.533333,-50.75
br,santa cecilia,Santa Cecília,11,,-18.366667,-56.05
br,santa cecilia,Santa Cecília,18,,-23.389099,-52.529236
br,santa cecilia,Santa Cecilia,20,,-6.3,-42.133333
br,santa cecilia,Santa Cecília,21,,-22.466667,-43.866667
br,santa cecilia,Santa Cecília,23,,-28.166667,-51.933333
br,santa cecilia,Santa Cecília,26,15092,-26.933333,-50.45
br,santa christina do pinhal,Santa Christina do Pinhal,23,,-29.7,-50.85
br,santa clara carangola,Santa Clara Carangola,21,,-20.833333,-41.916667
br,santa clara do caparao,Santa Clara do Caparaó,08,,-20.383333,-41.7
br,santa clara d'oeste,Santa Clara d'Oeste,27,,-20.1,-50.933333
br,santa clara do ingai,Santa Clara do Ingaí,23,,-28.683333,-53.283333
br,santa clara do sul,Santa Clara do Sul,23,,-29.466667,-52.083333
br,santa clara ingai,Santa Clara Ingaí,23,,-28.683333,-53.283333
br,santa clara,Santa Clara,01,,-9.8725,-67.7675
br,santa clara,Santa Clara,04,,-4.405,-59.8425
br,santa clara,Santa Clara,05,,-12.116667,-39.4
br,santa clara,Santa Clara,06,,-5.2,-38.733333
br,santa clara,Santa Clara,11,,-23.683333,-55.283333
br,santa clara,Santa Clara,13,,-3.282222,-42.708333
br,santa clara,Santa Clara,16,,-1.083333,-49.616667
br,santa clara,Santa Clara,17,,-7.316667,-36.383333
br,santa clara,Santa Clara,18,,-25.616667,-51.983333
br,santa clara,Santa Clara,21,,-20.833333,-41.916667
br,santa clara,Santa Clara,23,,-29.466667,-52.083333
br,santa clara,Santa Clara,26,,-27.15,-51.583333
br,santa clara,Santa Clara,27,,-22.75,-45.633333
br,santa clara,Santa Clara,30,,-8.75,-37.333333
br,santa clara,Santa Clara,31,,-7.266667,-48.15
br,santa clementina,Santa Clementina,18,,-23.0587,-50.1849
br,santa corona,Santa Corona,23,,-29.2107,-51.1762
br,santa cristina,Santa Cristina,23,,-29.7,-50.85
br,santa cruz cabralia,Santa Cruz Cabrália,05,19549,-16.283333,-39.033333
br,santa cruz da aparecida,Santa Cruz da Aparecida,15,,-21.233333,-46.266667
br,santa cruz da baixa verde,Santa Cruz da Baixa Verde,30,,-7.816667,-38.166667
br,santa cruz da boa vista,Santa Cruz da Boa Vista,27,,-22.65,-46.866667
br,santa cruz da conceicao,Santa Cruz da Conceição,27,,-22.15,-47.45
br,santa cruz da esperanca,Santa Cruz da Esperança,27,,-21.3,-47.416667
br,santa cruz da estrela,Santa Cruz da Estrêla,27,,-21.75,-47.333333
br,santa cruz da estrella,Santa Cruz da Estrella,27,,-21.75,-47.333333
br,santa cruz da prata,Santa Cruz da Prata,15,,-21.2,-46.75
br,santa cruz das areias,Santa Cruz das Areias,15,,-20.85,-40.716667
br,santa cruz das gaivotas,Santa Cruz das Gaivotas,04,,-5.61,-63.439167
br,santa cruz das palmeiras,Santa Cruz das Palmeiras,27,25801,-21.816667,-47.25
br,santa cruz das posses,Santa Cruz das Posses,27,,-21.083333,-47.9
br,santa cruz da vitoria,Santa Cruz da Vitória,05,,-14.95,-39.8
br,santa cruz de barcellos,Santa Cruz de Barcellos,05,,-14.1,-39.083333
br,santa cruz de barcelos,Santa Cruz de Barcelos,05,,-14.1,-39.083333
br,santa cruz de cabralia,Santa Cruz de Cabrália,05,,-16.283333,-39.033333
br,santa cruz de goias,Santa Cruz de Goiás,29,,-17.316667,-48.5
br,santa cruz de salina,Santa Cruz de Salina,15,,-16.1,-41.75
br,santa cruz de salinas,Santa Cruz de Salinas,15,,-16.1,-41.75
br,santa cruz do arari,Santa Cruz do Arari,16,,-.6,-49.183333
br,santa cruz do capibaribe,Santa Cruz do Capibaribe,30,76451,-7.95,-36.2
br,santa cruz do cupari,Santa Cruz do Cuparí,16,,-3.233333,-55.266667
br,santa cruz do cupary,Santa Cruz do Cupary,16,,-3.233333,-55.266667
br,santa cruz do deserto,Santa Cruz do Deserto,02,,-9.233333,-37.833333
br,santa cruz do escalvado,Santa Cruz do Escalvado,15,,-20.233333,-42.816667
br,santa cruz do ijovai,Santa Cruz do Ijovaí,11,,-23.516667,-54.8
br,santa cruz do lopes,Santa Cruz do Lopes,27,,-23.933333,-49.5
br,santa cruz do lopez,Santa Cruz do Lopez,27,,-23.933333,-49.5
br,santa cruz do monte alegre,Santa Cruz do Monte Alegre,21,,-21.55,-42.283333
br,santa cruz do monte alverne,Santa Cruz do Mónte Alverne,15,,-20.8,-42.416667
br,santa cruz do monte castelo,Santa Cruz do Monte Castelo,18,,-22.95,-53.316667
br,santa cruz do piaui,Santa Cruz do Piauí,20,,-7.15,-41.8
br,santa cruz do pinhal,Santa Cruz do Pinhal,23,,-29.7572,-50.8253
br,santa cruz do prata,Santa Cruz do Prata,15,,-21.2,-46.75
br,santa cruz do rio abaixo,Santa Cruz do Rio Abaixo,27,,-23.3,-45.4
br,santa cruz do rio clarinho,Santa Cruz do Rio Clarinho,27,,-21.733333,-47.4
br,santa cruz do rio pardo,Santa Cruz do Rio Pardo,27,37336,-22.916667,-49.616667
br,santa cruz dos lopes,Santa Cruz dos Lopes,27,,-23.933333,-49.5
br,santa cruz dos matas,Santa Cruz dos Matas,27,,-23.7492,-47.9603
br,santa cruz dos milagres,Santa Cruz dos Milagres,20,,-5.8,-41.966667
br,santa cruz dos motas,Santa Cruz dos Motas,27,,-23.7492,-47.9603
br,santa cruz do sul,Santa Cruz do Sul,23,106115,-29.716667,-52.433333
br,santa cruz do timbo,Santa Cruz do Timbó,26,,-26.35,-50.883333
br,santa cruz do uruburetama,Santa Cruz do Uruburetama,06,,-3.683333,-39.566667
br,santa cruz,Santa Cruz,01,,-20,-40.166667
br,santa cruz,Santa Cruz,02,,-9.233333,-37.833333
br,santa cruz,Santa Cruz,03,,1.116667,-50.833333
br,santa cruz,Santa Cruz,04,,1.25,-67.2
br,santa cruz,Santa Cruz,05,,-11.1,-40.6
br,santa cruz,Santa Cruz,06,,-4.166667,-40.583333
br,santa cruz,Santa Cruz,08,,-19.25,-40.633333
br,santa cruz,Santa Cruz,11,,-18.533333,-57.2
br,santa cruz,Santa Cruz,13,,-1.716667,-44.866667
br,santa cruz,Santa Cruz,14,,-16.333333,-54.916667
br,santa cruz,Santa Cruz,15,,-16.1,-41.75
br,santa cruz,Santa Cruz,16,,-1.8,-49.1
br,santa cruz,Santa Cruz,17,,-6.533333,-38.05
br,santa cruz,Santa Cruz,18,,-23.8,-51.25
br,santa cruz,Santa Cruz,20,,-10.166667,-45.466667
br,santa cruz,Santa Cruz,21,,-21.55,-42.283333
br,santa cruz,Santa Cruz,22,27776,-6.216667,-36.016667
br,santa cruz,Santa Cruz,23,,-28.733333,-50.25
br,santa cruz,Santa Cruz,24,,-10.233333,-63.216667
br,santa cruz,Santa Cruz,25,,3.783333,-61.016667
br,santa cruz,Santa Cruz,26,,-26.35,-50.883333
br,santa cruz,Santa Cruz,27,,-23.073286,-47.701506
br,santa cruz,Santa Cruz,28,,-10.25,-36.75
br,santa cruz,Santa Cruz,29,,-17.316667,-48.5
br,santa cruz,Santa Cruz,30,,-7.883333,-39.266667
br,santa cruz,Santa Cruz,31,,-10.626111,-49.003611
br,santa efigenia,Santa Efigênia,02,,-9.316667,-36.116667
br,santa efigenia,Santa Efigênia,15,,-18.833333,-42.45
br,santa egidera,Santa Egidera,14,,-16.983333,-55.983333
br,santa elena,Santa Elena,11,,-20.933333,-55.333333
br,santa elena,Santa Elena,18,,-24.933333,-54.383333
br,santa elisa,Santa Elisa,11,,-22.016667,-56.533333
br,santa elisa,Santa Elisa,15,,-19.783333,-41.566667
br,santa elizia,Santa Elízia,22,,-5.433333,-35.933333
br,santa eloisa,Santa Eloísa,21,,-21.433333,-41.683333
br,santa elvira,Santa Elvira,13,,-3.631667,-43.32
br,santa emilia,Santa Emília,24,,-9.716667,-65.8
br,santa ephigenia,Santa Ephigenia,02,,-9.316667,-36.116667
br,santa erica,Santa Erica,14,,-15.566667,-58.6
br,santa ernestina,Santa Ernestina,27,,-21.45,-48.383333
br,santa escolastica,Santa Escolástica,27,,-21.85,-47.233333
br,santa estela,Santa Estela,27,,-21.866667,-50.466667
br,santa etelvina,Santa Etelvina,27,,-21.766667,-47.633333
br,santa eudoxia,Santa Eudóxia,27,,-21.766667,-47.783333
br,santa eufrasia,Santa Eufrásia,11,,-21.566667,-56.283333
br,santa eugenia,Santa Eugênia,04,,-3.8,-62.116667
br,santa eugenia,Santa Eugênia,11,,-21.066667,-57.05
br,santa eugenia,Santa Eugênia,21,,-22.941337,-43.634755
br,santa eugenia,Santa Eugênia,27,,-21.816667,-47.35
br,santa familia do tingua,Santa Familia do Tingua,21,,-22.49,-43.608333
br,santa fe do araguaia,Santa Fé do Araguaia,31,,-7.122778,-48.571111
br,santa fe dos amarelo,Santa Fé dos Amarelo,08,,-20.9,-41.133333
br,santa fe dos amarelos,Santa Fé dos Amarelos,08,,-20.9,-41.133333
br,santa fe do sul,Santa Fé do Sul,27,25802,-20.216667,-50.933333
br,santa felicia,Santa Felicia,06,,-6.1,-39.2
br,santa felicidade,Santa Felicidade,18,,-25.383333,-49.333333
br,santa fe,Santa Fé,01,,-10.833333,-68.583333
br,santa fe,Santa Fé,05,,-12.5,-39.866667
br,santa fe,Santa Fé,06,,-3.283333,-39.95
br,santa fe,Santa Fé,08,,-20.816667,-41.216667
br,santa fe,Santa Fé,11,,-18.633333,-55.8
br,santa fe,Santa Fé,13,,-3.976944,-42.834722
br,santa fe,Santa Fé,14,,-16.333333,-56.766667
br,santa fe,Santa Fé,17,,-7.2,-38.466667
br,santa fe,Santa Fé,18,,-23.016667,-51.8
br,santa fe,Santa Fé,20,,-5.483333,-42.7
br,santa fe,Santa Fé,22,,-5.401111,-36.404167
br,santa-fe,Santa-Fé,25,,2.399784,-59.946715
br,santa fe,Santa Fé,27,,-20.933333,-47.883333
br,santa fe,Santa Fé,29,,-15.666667,-51.266667
br,santa fe,Santa Fé,31,,-7.716667,-48.1
br,santa filomena,Santa Filomena,13,,-3.164722,-43.045
br,santa filomena,Santa Filomena,15,,-19.933333,-41.833333
br,santa filomena,Santa Filomena,18,,-23.016667,-50.683333
br,santa filomena,Santa Filomena,20,,-9.136389,-45.910833
br,santa filomena,Santa Filomena,22,,-5.326389,-36.273889
br,santa filomena,Santa Filomena,30,,-8.233333,-40.616667
br,santa flora,Santa Flora,31,,-11.616667,-47.633333
br,santa gertrudes,Santa Gertrudes,11,,-21.533333,-55.2
br,santa gertrudes,Santa Gertrudes,17,,-6.6,-38.25
br,santa gertrudes,Santa Gertrudes,20,,-6.95,-37.383333
br,santa gertrudes,Santa Gertrudes,27,18490,-22.466667,-47.516667
br,santa helena de goias,Santa Helena de Goiás,29,34254,-17.716667,-50.583333
br,santa helena,Santa Helena,04,,-4.463611,-59.823889
br,santa helena,Santa Helena,05,,-12.4,-44.25
br,santa helena,Santa Helena,11,,-19.3,-55.266667
br,santa helena,Santa Helena,13,16045,-2.233333,-45.3
br,santa helena,Santa Helena,14,,-16.466667,-56.683333
br,santa helena,Santa Helena,16,,-5.216667,-56.283333
br,santa helena,Santa Helena,17,,-6.733333,-38.633333
br,santa helena,Santa Helena,18,,-24.133333,-53.666667
br,santa helena,Santa Helena,20,,-6.366667,-42.05
br,santa helena,Santa Helena,21,,-23.003723,-43.336529
br,santa helena,Santa Helena,22,,-5.35,-35.483333
br,santa helena,Santa Helena,23,,-30.35,-56.283333
br,santa helena,Santa Helena,26,,-27.166667,-51.666667
br,santa helena,Santa Helena,27,,-20.266667,-47.533333
br,santa helena,Santa Helena,29,,-17.716667,-50.583333
br,santa helena,Santa Helena,31,,-10.45,-49.283333
br,santa ignez,Santa Ignez,05,,-13.283333,-39.8
br,santa ilidia,Santa Ilídia,11,,-22.416667,-52.883333
br,santa inacia,Santa Inácia,21,,-22.170556,-43.721667
br,santa ines,Santa Inês,05,10521,-13.283333,-39.8
br,santa ines,Santa Inês,13,67426,-3.65,-45.366667
br,santa ines,Santa Inês,16,,-.25,-50
br,santa ines,Santa Inês,17,,-7.616667,-38.566667
br,santa ines,Santa Inês,18,,-22.65,-51.916667
br,santa ines,Santa Inês,27,,-20.566667,-47.816667
br,santa ines,Santa Inês,30,,-7.866667,-37.916667
br,santa inez,Santa Inez,13,,-5.1,-42.933333
br,santa iria,Santa Iria,27,,-21.2,-47.733333
br,santa isabel do araguaia,Santa Isabel do Araguaia,16,,-6.116667,-48.316667
br,santa isabel do avai,Santa Isabel do Avaí,18,,-22.966667,-53.233333
br,santa isabel do ivai,Santa Isabel do Ivaí,18,,-22.966667,-53.233333
br,santa isabel do morro,Santa Isabel do Morro,31,,-11.566667,-50.666667
br,santa isabel do para,Santa Isabel do Pará,16,39284,-1.266667,-48.183333
br,santa isabel do rio negro,Santa Isabel do Rio Negro,04,4142,-.4,-65.033333
br,santa isabel do rio preto,Santa Isabel do Rio Prêto,21,,-22.233333,-44.083333
br,santa isabel do sul,Santa Isabel do Sul,23,,-32.1168,-52.5985
br,santa isabel parque,Santa Isabel Parque,27,,-23.3479,-46.1992
br,santa isabel,Santa Isabel,04,,-.116667,-68.95
br,santa isabel,Santa Isabel,05,,-12.35,-39.8
br,santa isabel,Santa Isabel,08,,-20.383333,-40.633333
br,santa isabel,Santa Isabel,13,,-6.766667,-43.183333
br,santa isabel,Santa Isabel,14,,-13.666667,-60.733333
br,santa-isabel,Santa-Isabel,15,,-21.6,-42.5
br,santa isabel,Santa Isabel,15,,-22.066667,-45.533333
br,santa isabel,Santa Isabel,16,,-1.266667,-48.183333
br,santa isabel,Santa Isabel,18,,-26.063333,-53.618611
br,santa isabel,Santa Isabel,20,,-2.883333,-41.8
br,santa isabel,Santa Isabel,21,,-22.4769,-44.4871
br,santa isabel,Santa Isabel,22,,-5.111944,-36.150833
br,santa isabel,Santa Isabel,23,,-32.1168,-52.5985
br,santa isabel,Santa Isabel,27,33709,-23.3158,-46.2241
br,santa isabel,Santa Isabel,31,,-11.3,-48.116667
br,santa isaura,Santa Isaura,27,,-21.35,-47.9
br,santa isobel,Santa Isobel,14,,-17.2,-57
br,santa izabel do morro,Santa Izabel do Morro,31,,-11.566667,-50.666667
br,santa izabel,Santa Izabel,04,,-.4,-65.033333
br,santa izabel,Santa Izabel,06,,-5.383333,-39.533333
br,santa izabel,Santa Izabel,08,,-20.55,-41.166667
br,santa izabel,Santa Izabel,14,,-17.2,-57
br,santa izabel,Santa Izabel,16,,-5.916667,-57.433333
br,santa izabel,Santa Izabel,27,,-20.166667,-50.066667
br,santa izabel,Santa Izabel,31,,-11.566667,-50.666667
br,santa izidio,Santa Izidio,06,,-2.983333,-40.45
br,santa joana,Santa Joana,08,,-19.533333,-40.7
br,santa joana,Santa Joana,13,,-3.433333,-44.55
br,santa joana,Santa Joana,25,,2.883333,-60.866667
br,santa julia do jurupari,Santa Júlia do Jurupari,16,,.05,-50.583333
br,santa juliana,Santa Juliana,15,,-19.316667,-47.533333
br,santa julia,Santa Júlia,04,,-7.1,-58.9
br,santa julia,Santa Júlia,08,,-19.733333,-40.666667
br,santa julia,Santa Júlia,14,,-7.820833,-58.211667
br,santa julia,Santa Júlia,16,,-2.35,-56.333333
br,santa julia,Santa Júlia,22,,-5.091389,-37.336111
br,santa justa,Santa Justa,21,,-22.083333,-43.45
br,santa laura,Santa Laura,04,,-6.2,-61.816667
br,santa leda,Santa Leda,11,,-21.45,-56.5
br,santa leocadia,Santa Leocádia,08,,-18.7,-40.066667
br,santa leopoldina,Santa Leopoldina,08,2327,-20.1,-40.533333
br,santa leopoldina,Santa Leopoldina,29,,-14.9,-51.083333
br,santa lidia,Santa Lídia,26,,-26.8,-48.65
br,santa livrada,Santa Livrada,11,,-21.55,-56.683333
br,santa livrado,Santa Livrado,11,,-21.55,-56.683333
br,santa lucia do piai,Santa Lucia do Piaí,23,,-29.2411,-51.0196
br,santa lucia,Santa Lúcia,06,,-3.4,-39.283333
br,santa lucia,Santa Lúcia,13,,-5.483333,-43.216667
br,santa lucia,Santa Lúcia,15,,-19.783333,-43.866667
br,santa lucia,Santa Lucia,21,,-23.001973,-43.331248
br,santa lucia,Santa Lúcia,22,,-5.216667,-35.883333
br,santa lucia,Santa Lúcia,23,,-28.283333,-54.633333
br,santa lucia,Santa Lúcia,27,,-21.683333,-48.1
br,santa lucrecia,Santa Lucrécia,27,,-22.792555,-45.081727
br,santa lugenia,Santa Lugenia,11,,-21.066667,-57.05
br,santa luisa de baixo,Santa Luísa de Baixo,15,,-22.766667,-45.816667
br,santa luisa,Santa Luísa,11,,-19.5,-55
br,santa luisa,Santa Luísa,24,,-10.116667,-63.183333
br,santa luiza,Santa Luiza,05,,-11.25,-39.366667
br,santa luiza,Santa Luiza,22,,-5.4475,-36.7425
br,santa luiza,Santa Luiza,24,,-10.1,-63.166667
br,santa luzia de picui,Santa Lúzia de Picuí,17,,-6.433333,-36.283333
br,santa luzia do cariri,Santa Luzia do Cariri,17,,-7.583333,-36.85
br,santa luzia do engenho,Santa Luzia do Engenho,16,,-.783333,-47.95
br,santa luzia do itanhi,Santa Luzia do Itanhi,28,,-11.333333,-37.5
br,santa luzia do norte,Santa Luzia do Norte,02,,-9.6,-35.816667
br,santa luzia do sabugy,Santa Luzia do Sabugy,23,,-29.116667,-54.05
br,santa luzia,Santa Luzia,02,,-9.433333,-35.533333
br,santa luzia,Santa Luzia,04,,-2.733333,-67.583333
br,santa luzia,Santa Luzia,05,,-10.983333,-45.55
br,santa luzia,Santa Luzia,06,,-3.5,-40.85
br,santa luzia,Santa Luzia,08,,-19.233333,-40.85
br,santa luzia,Santa Luzia,11,,-17.933333,-54.95
br,santa luzia,Santa Luzia,13,22910,-7.633333,-47.2
br,santa luzia,Santa Luzia,15,243506,-19.783333,-43.866667
br,santa luzia,Santa Luzia,16,,-1.116667,-51.15
br,santa luzia,Santa Luzia,17,13243,-6.883333,-36.933333
br,santa luzia,Santa Luzia,18,,-24.716667,-53.233333
br,santa luzia,Santa Luzia,20,,-7.766667,-41.566667
br,santa luzia,Santa Luzia,22,,-5.283333,-35.483333
br,santa luzia,Santa Luzia,23,,-29.116667,-54.05
br,santa luzia,Santa Luzia,24,,-8.233333,-63.366667
br,santa luzia,Santa Luzia,25,,1.2,-61.3
br,santa luzia,Santa Luzia,27,,-21.116667,-49.783333
br,santa luzia,Santa Luzia,28,,-11.333333,-37.5
br,santa-luzia,Santa-Luzia,29,,-16.25,-47.933333
br,santa luzia,Santa Luzia,30,,-7.85,-38.05
br,santa luzia velha,Santa Luzia Velha,05,,-12.166667,-40.1
br,santa luz,Santa Luz,05,,-11.25,-39.366667
br,santa luz,Santa Luz,31,,-10.183333,-48.866667
br,santa madalena,Santa Madalena,06,,-4.216667,-38.85
br,santa marcelina,Santa Marcelina,14,,-15.016667,-58.55
br,santa marcia,Santa Márcia,06,,-6.033333,-40.8
br,santa margarida,Santa Margarida,15,,-20.383333,-42.25
br,santa margarida,Santa Margarida,18,,-22.95,-51.216667
br,santa margarida,Santa Margarida,21,,-21.45,-41.45
br,santa margarida,Santa Margarida,26,,-26.8961,-49.9872
br,santa maria boa vista,Santa Maria Boa Vista,30,,-8.816667,-39.816667
br,santa maria da barreira,Santa Maria da Barreira,16,,-8.8775,-49.711111
br,santa maria da boa vista,Santa Maria da Boa Vista,30,14695,-8.816667,-39.816667
br,santa maria da boca do acre,Santa Maria da Bôca do Acre,04,,-8.75,-67.383333
br,santa maria das barreiras,Santa Maria das Barreiras,16,,-8.8775,-49.711111
br,santa maria da serra,Santa Maria da Serra,27,,-22.55,-48.166667
br,santa maria da vitoria,Santa Maria da Vitória,05,23489,-13.4,-44.2
br,santa maria de barauna,Santa Maria de Baraúna,16,,-.116667,-50.266667
br,santa maria de belem do grao para,Santa Maria de Belém do Grão Pará,16,,-1.45,-48.483333
br,santa maria de belem,Santa Maria de Belém,04,,-5.95,-61.683333
br,santa maria de itabira,Santa Maria de Itabira,15,,-19.45,-43.133333
br,santa maria de suassuhy,Santa Maria de Suassuhy,15,,-18.2,-42.416667
br,santa maria do ajura,Santa Maria do Ajurá,04,,-3.939167,-62.771111
br,santa maria do araguaia,Santa Maria do Araguaia,31,,-8.791944,-49.430556
br,santa maria do baracari,Santa Maria do Baracari,04,,-3.918056,-62.868333
br,santa maria do belem,Santa Maria do Belem,04,,-5.95,-61.683333
br,santa maria do bocca do monte,Santa Maria do Bocca do Monte,23,,-29.683333,-53.8
br,santa maria do curupa,Santa Maria do Curupá,27,,-21.65,-50.016667
br,santa maria do erval,Santa Maria do Erval,23,,-29.466667,-50.983333
br,santa maria do gurupa,Santa Maria do Gurupá,27,,-21.65,-50.016667
br,santa-maria-do-itabira,Santa-Maria-do-Itabira,15,,-19.45,-43.133333
br,santa maria do ouro,Santa Maria do Ouro,05,,-13,-42.2
br,santa maria do para,Santa Maria do Pará,16,12915,-1.35,-47.566667
br,santa maria do rio preto,Santa Maria do Rio Preto,05,,-11.033333,-45.533333
br,santa maria do sacai,Santa Maria do Sacaí,04,,-3.953889,-62.9575
br,santa maria do salto,Santa Maria do Salto,15,,-16.25,-40.116667
br,santa maria dos marmellos,Santa Maria dos Marmellos,04,,-6.116667,-61.85
br,santa maria dos marmelos,Santa Maria dos Marmelos,04,,-6.116667,-61.85
br,santa maria do suacui,Santa Maria do Suaçuí,15,9936,-18.2,-42.416667
br,santa maria do suassui,Santa Maria do Suassuí,15,,-18.2,-42.416667
br,santa maria do taguatinga,Santa Maria do Taguatinga,31,,-12.465556,-46.366944
br,santa maria do tocantins,Santa Maria do Tocantins,31,,-8.747222,-47.571389
br,santa maria eterna,Santa Maria Eterna,15,,-21.016667,-42.333333
br,santa maria madaelna,Santa Maria Madaelna,21,,-21.95,-42.016667
br,santa maria madalena,Santa Maria Madalena,21,,-21.95,-42.016667
br,santa maria magdalena,Santa Maria Magdalena,21,,-21.95,-42.016667
br,santa mariana,Santa Mariana,18,,-23.15,-50.55
br,santa maria nova,Santa Maria Nova,31,,-8.791944,-49.430556
br,santa maria,Santa Maria,03,,.25,-51.65
br,santa maria,Santa Maria,04,,-1.75,-58.55
br,santa maria,Santa Maria,05,,-13.4,-44.2
br,santa maria,Santa Maria,06,,-2.9,-40.083333
br,santa maria,Santa Maria,08,,-20.033333,-40.7
br,santa maria,Santa Maria,11,,-19.516667,-55.6
br,santa maria,Santa Maria,13,,-2.716667,-45.083333
br,santa maria,Santa Maria,14,,-16.043333,-56.592778
br,santa maria,Santa Maria,15,,-15.366667,-42.3
br,santa maria,Santa Maria,16,,-1.083333,-50.7
br,santa maria,Santa Maria,17,,-6.616667,-36.016667
br,santa maria,Santa Maria,18,,-23.183333,-50.533333
br,santa maria,Santa Maria,20,,-2.9775,-41.331667
br,santa maria,Santa Maria,21,,-21.266667,-41.45
br,santa maria,Santa Maria,22,,-5.260278,-36.276389
br,santa maria,Santa Maria,23,249224,-29.683333,-53.8
br,santa maria,Santa Maria,24,,-9.733333,-65.833333
br,santa maria,Santa Maria,25,,2.916667,-60.816667
br,santa maria,Santa Maria,26,,-26.666667,-50.7
br,santa maria,Santa Maria,27,,-20.416667,-47.716667
br,santa maria,Santa Maria,28,,-9.716667,-37.716667
br,santa maria,Santa Maria,30,,-7.8,-39.983333
br,santa maria,Santa Maria,31,,-12.465556,-46.366944
br,santa maria velha,Santa Maria Velha,31,,-8.340278,-49.268333
br,santa marina,Santa Marina,21,,-22.996419,-43.381147
br,santamaro,Santamaro,21,,-21.983333,-41.133333
br,santa marta,Santa Marta,08,,-20.5,-41.716667
br,santa marta,Santa Marta,21,,-22.94703,-43.193916
br,santa mercedes,Santa Mercedes,27,,-21.35,-51.75
br,santa monica jardins,Santa Mônica Jardins,21,,-22.995992,-43.398854
br,santa monica,Santa Mônica,04,,-6.9,-60.3
br,santa monica,Santa Mônica,11,,-17.25,-56.283333
br,santa monica,Santa Mônica,17,,-6.633333,-36.383333
br,santa monica,Santa Mônica,21,,-22.996358,-43.392182
br,santa monica,Santa Monica,24,,-12.733333,-60.202778
br,santana da barra,Santana da Barra,21,,-22.516111,-43.805
br,santana da boa vista,Santana da Boa Vista,23,,-30.866667,-53.116667
br,santana da chapada,Santana da Chapada,14,,-15.433333,-55.75
br,santana da ponte pensa,Santana da Ponte Pensa,27,,-20.25,-50.8
br,santana da vargem,Santana da Vargem,15,,-21.25,-45.5
br,santana de caldas,Santana de Caldas,15,,-21.833333,-46.4
br,santana de cataguases,Santana de Cataguases,15,,-21.283333,-42.55
br,santana de mangueira,Santana de Mangueira,17,,-7.55,-38.333333
br,sant'ana-de-paranaiba,Sant'Ana-de-Paranaiba,27,,-23.45,-46.916667
br,santana de parnaiba,Santana de Parnaíba,27,98991,-23.45,-46.916667
br,santana de patos,Santana de Patos,15,,-18.833333,-46.583333
br,santana de pirapama,Santana de Pirapama,15,,-19.016667,-44.016667
br,santana de sao joaquim,Santana de São Joaquim,30,,-8.566667,-35.9
br,santana do acarau,Santana do Acaraú,06,14707,-3.45,-40.2
br,santana do alfie,Santana do Alfié,15,,-19.766667,-42.866667
br,santana do aracuai,Santana do Araçuaí,15,,-16.766667,-41.416667
br,santana do barro,Santana do Barro,15,,-18.733333,-42.533333
br,sant'ana do capim,Sant'ana do Capim,16,,-2.033333,-47.733333
br,santana do capivari,Santana do Capivari,15,,-22.233333,-44.933333
br,santana do carapanatuba,Santana do Carapanatuba,04,,-6.754167,-62.591667
br,santana do cariri,Santana do Cariri,06,,-7.183333,-39.733333
br,santana do congo,Santana do Congo,17,,-7.8,-36.666667
br,santana do deserto,Santana do Deserto,15,,-21.948611,-43.165833
br,santana do garambeu,Santana do Garambéu,15,,-21.6,-44.1
br,santana do hilario,Santana do Hilário,04,,-7.666667,-65.933333
br,santana do ipanema,Santana do Ipanema,02,26147,-9.366667,-37.233333
br,santana do itarare,Santana do Itararé,18,,-23.75,-49.633333
br,santana do jacare,Santana do Jacaré,15,,-20.9,-45.133333
br,santana do livramento,Santana do Livramento,23,89696,-30.883333,-55.516667
br,santana do lustosa,Santana do Lustosa,05,,-12.2,-38.6
br,santana do mandau,Santana do Mandaú,02,,-9.166667,-36.183333
br,santana do manhuacu,Santana do Manhuaçu,15,,-20.1,-41.933333
br,santana do manhuassu,Santana do Manhuassú,15,,-20.1,-41.933333
br,santana do matos,Santana do Matos,22,8050,-5.956111,-36.652778
br,santana do mundau,Santana do Mundaú,02,6439,-9.15,-36.183333
br,santana do ouro,Santana do Ouro,05,,-12.016667,-42.483333
br,santana do paraiso,Santana do Paraíso,15,25537,-19.366667,-42.533333
br,santana do paranaiba,Santana do Paranaíba,11,,-19.666667,-51.183333
br,santana do paraopeba,Santana do Paraopeba,15,,-20.383333,-44.116667
br,santana do piraguara,Santana do Piraguara,15,,-20.833333,-43.333333
br,santana do queira deus,Santana do Queira Deus,08,,-19.683333,-40.783333
br,santana do rio das velhas,Santana do Rio das Velhas,15,,-19.033333,-47.916667
br,santana dos brejos,Santana dos Brejos,05,,-12.983333,-44.05
br,santana dos garrotes,Santana dos Garrotes,17,,-7.383333,-37.983333
br,santana dos montes,Santana dos Montes,15,,-20.783333,-43.683333
br,sant' ana dos neris,Sant' Ana dos Neris,05,,-12.2,-43.85
br,santana dos piloes,Santana dos Pilões,27,,-22.666667,-45.316667
br,santana dos tiradentes,Santana dos Tiradentes,21,,-22.255278,-43.193056
br,santana do taboleiro,Santana do Taboleiro,15,,-19.916667,-42.2
br,santana do tabuleiro,Santana do Tabuleiro,15,,-19.916667,-42.2
br,santana,Santana,04,,1.033333,-67.483333
br,sant'ana,Sant'Ana,04,,-4.407778,-59.91
br,sant' ana,Sant' Ana,04,,-5.574444,-61.048889
br,santana,Santana,04,,-.5,-63.55
br,santana,Santana,05,12629,-14.466667,-41.8
br,santana,Santana,06,,-3.383333,-39.366667
br,santana,Santana,08,,-18.566667,-39.75
br,sant'ana,Sant'Ana,11,,-17.333333,-55.366667
br,santana,Santana,11,,-17.95,-56.2
br,santana,Santana,13,,-2.616667,-44.183333
br,santana,Santana,14,,-14.983333,-57.883333
br,santana,Santana,15,,-14.9,-42.8
br,santana,Santana,16,,-1.283333,-50.4
br,santana,Santana,17,,-6.433333,-37.7
br,santana,Santana,18,,-25.333333,-51.75
br,santana,Santana,20,,-4.15,-41.15
br,santana,Santana,21,,-20.966667,-41.733333
br,santana,Santana,22,,-5.336389,-37.301111
br,santana,Santana,23,,-28.866667,-51.433333
br,santana,Santana,25,,3.433333,-60.7
br,santana,Santana,26,,-27.566667,-48.75
br,santana,Santana,27,,-20.45,-47.733333
br,santana,Santana,29,,-14.5,-49.166667
br,santana,Santana,30,,-7.766667,-36.233333
br,santana,Santana,31,,-11.55,-47.7
br,santa natalia,Santa Natália,11,,-18.366667,-55.983333
br,santana velha,Santana Velha,05,,-13.833333,-40.766667
br,santana velha,Santana Velha,23,,-29.883333,-57.3
br,santana velho,Santana Velho,23,,-29.883333,-57.3
br,santanesia,Santanésia,21,,-22.523889,-43.820833
br,sant'anna da boa vista,Sant'Anna da Boa Vista,23,,-30.866667,-53.116667
br,sant'anna de catu,Sant'Anna de Catu,05,,-12.35,-38.383333
br,sant'anna de garambeo,Sant'Anna de Garambeo,15,,-21.6,-44.1
br,sant'anna de japuhyba,Sant'Anna de Japuhyba,21,,-22.583333,-42.7
br,sant'anna de lustosa,Sant'Anna de Lustosa,05,,-12.2,-38.6
br,sant'anna do capivary,Sant'Anna do Capivary,15,,-22.233333,-44.933333
br,sant'anna do cariry,Sant'Anna do Cariry,06,,-7.183333,-39.733333
br,sant'anna do congo,Sant'Anna do Congo,17,,-7.8,-36.666667
br,sant'anna do ipanema,Sant'Anna do Ipanema,02,,-9.366667,-37.233333
br,sant'anna do jacare,Sant'Anna do Jacare,15,,-20.9,-45.133333
br,sant'anna do livramento,Sant'Anna do Livramento,23,,-30.883333,-55.516667
br,sant'anna do manhuassu,Sant'Anna do Manhuassu,15,,-20.1,-41.933333
br,sant'anna do paranahyba,Sant'Anna do Paranahyba,11,,-19.666667,-51.183333
br,sant'anna do paranaiba,Sant'Anna do Paranaiba,11,,-19.666667,-51.183333
br,sant'anna dos brejos,Sant'Anna dos Brejos,05,,-12.983333,-44.05
br,sant'anna dos garrotes,Sant'Anna dos Garrotes,17,,-7.383333,-38
br,sant'anna dos mattos,Sant'Anna dos Mattos,22,,-5.956111,-36.652778
br,sant'anna,Sant'Anna,04,,.283333,-67.266667
br,sant'anna,Sant'Anna,05,,-12.3,-44.833333
br,sant'anna,Sant'Anna,06,,-3.45,-40.2
br,sant'anna,Sant'Anna,11,,-19.75,-55.333333
br,santanna,Santanna,26,,-27.95,-49.866667
br,sant'anna,Sant'Anna,29,,-14.5,-49.166667
br,santanopole,Santanópole,06,,-7.183333,-39.733333
br,santanopolis,Santanópolis,05,,-12.05,-38.85
br,santanopolis,Santanópolis,31,,-7.7,-47.3
br,sant' antonio de balsas,Sant' Antonio de Balsas,13,,-7.516667,-46.033333
br,santa paula,Santa Paula,24,,-12.1625,-60.716667
br,santa paula,Santa Paula,30,,-8.416667,-36.75
br,santa paulina,Santa Paulina,27,,-21.733333,-47.183333
br,santa paz,Santa Paz,22,,-5.265556,-36.328056
br,santa penha,Santa Penha,22,,-5.476944,-36.360556
br,santa philomena,Santa Philomena,15,,-19.933333,-41.833333
br,santa philomena,Santa Philomena,20,,-9.136389,-45.910833
br,santa polonia,Santa Polonia,22,,-5.6075,-36.222778
br,santa quiteria do maranhao,Santa Quitéria do Maranhão,13,17180,-3.516667,-42.533333
br,santa quiteria,Santa Quitéria,05,,-12.366667,-40.033333
br,santa quiteria,Santa Quitéria,06,24391,-4.333333,-40.166667
br,santa quiteria,Santa Quitéria,13,,-3.516667,-42.533333
br,santa quiteria,Santa Quiteria,15,,-19.75,-44.316667
br,santa quiteria,Santa Quitéria,17,,-6.6,-37.95
br,santa quiteria,Santa Quitéria,18,,-24.716667,-49.666667
br,santa quiteria,Santa Quitéria,21,,-21.333333,-41.733333
br,santa quitiria,Santa Quitiria,22,,-5.605278,-36.791667
br,santarem-nova,Santarém-Nova,13,,-.933333,-47.383333
br,santarem novo,Santarém Novo,13,,-.933333,-47.383333
br,santarem,Santarém,03,,-.95,-50.966667
br,santarem,Santarém,05,,-13.283333,-42.166667
br,santarem,Santarém,06,,-5.166667,-39.666667
br,santarem,Santarém,13,,-3.716667,-45
br,santarem,Santarém,16,189053,-2.433333,-54.7
br,santarem,Santarem,30,,-8.3,-39.9
br,santa rita da curema,Santa Rita da Curema,17,,-7.016667,-37.966667
br,santa rita da estrela,Santa Rita da Estrêla,15,,-18.733333,-47.7
br,santa rita da floresta,Santa Rita da Floresta,21,,-21.916667,-42.433333
br,santa rita da gloria,Santa Rita da Gloria,15,,-20.883333,-42.35
br,santa rita da lagoa de cima,Santa Rita da Lagoa de Cima,21,,-21.816667,-41.466667
br,santa rita da prata,Santa Rita da Prata,21,,-20.85,-41.75
br,santa rita de anta,Santa Rita de Anta,29,,-15.383333,-50.416667
br,santa rita de antas,Santa Rita de Antas,29,,-15.383333,-50.416667
br,santa rita de caldas,Santa Rita de Caldas,15,,-22.033333,-46.333333
br,santa rita de cassia dos coqueiros,Santa Rita de Cássia dos Coqueiros,27,,-21.283333,-47.166667
br,santa rita de cassia,Santa Rita de Cássia,05,,-11,-44.533333
br,santa rita de cassia,Santa Rita de Cassia,15,,-20.6,-46.933333
br,santa rita de cima,Santa Rita de Cima,21,,-21.816667,-41.466667
br,santa rita de ibitipoca,Santa Rita de Ibitipoca,15,,-21.55,-43.916667
br,santa rita de jacutinga,Santa Rita de Jacutinga,15,,-22.15,-44.1
br,santa rita de ouro fino,Santa Rita de Ouro Fino,21,,-21.033333,-41.9
br,santa rita de ouro preto,Santa Rita de Ouro Prêto,15,,-20.533333,-43.55
br,santa rita de patos,Santa Rita de Patos,15,,-18.416667,-46.416667
br,santa rita de sao domingos,Santa Rita de São Domingos,08,,-20.2,-41.366667
br,santa rita do anta,Santa Rita do Anta,29,,-15.383333,-50.416667
br,santa rita do antas,Santa Rita do Antas,29,,-15.383333,-50.416667
br,santa rita do araguaia,Santa Rita do Araguaia,14,,-17.316667,-53.2
br,santa rita do araguaia,Santa Rita do Araguaia,29,,-17.333333,-53.2
br,santa rita do araguaya,Santa Rita do Araguaya,14,,-17.316667,-53.2
br,santa rita do aventureiro,Santa Rita do Aventureiro,15,,-20.533333,-41.916667
br,santa rita do cedro,Santa Rita do Cedro,15,,-18.8,-44.15
br,santa rita d'oeste,Santa Rita d'Oeste,27,,-20.15,-50.833333
br,santa rita do gloria,Santa Rita do Glória,15,,-20.883333,-42.35
br,santa rita do itinga,Santa Rita do Itinga,15,,-16.25,-41.483333
br,santa rita do itueto,Santa Rita do Itueto,15,,-19.35,-41.383333
br,santa rita do malta,Santa Rita do Malta,17,,-6.9,-37.516667
br,santa rita do medina,Santa Rita do Medina,15,,-16.25,-41.483333
br,santa-rita-do-ouro-preto,Santa-Rita-do-Ouro-Prêto,15,,-20.533333,-43.55
br,santa rita do paranahyba,Santa Rita do Paranahyba,29,,-18.416667,-49.216667
br,santa rita do paranaiba,Santa Rita do Paranaíba,29,,-18.416667,-49.216667
br,santa rita do paranaib,Santa Rita do Paranaib,29,,-18.416667,-49.216667
br,santa rita do paranaiha,Santa Rita do Paranaiha,29,,-18.416667,-49.216667
br,santa rita do passa quatro,Santa Rita do Passa Quatro,27,24579,-21.7,-47.466667
br,santa rita do pontal,Santa Rita do Pontal,29,,-17.516667,-49.45
br,santa rita do prata,Santa Rita do Prata,21,,-20.85,-41.75
br,santa rita do rio abaixo,Santa Rita do Rio Abaixo,15,,-21.033333,-44.316667
br,santa rita do rio de peixe,Santa Rita do Rio de Peixe,15,,-19.133333,-43.166667
br,santa rita do rio do peixe,Santa Rita do Rio do Peixe,15,,-19.133333,-43.166667
br,santa rita do rio negro,Santa Rita do Rio Negro,21,,-21.9,-42.266667
br,santa rita do rio pardo,Santa Rita do Rio Pardo,11,,-21.25,-52.8
br,santa rita do rio preto,Santa Rita do Rio Prêto,05,,-11,-44.533333
br,santa rita do rio,Santa Rita do Rio,11,,-21.25,-52.8
br,santa rita do sapucahy,Santa Rita do Sapucahy,15,,-22.25,-45.7
br,santa rita do sapucai,Santa Rita do Sapucaí,15,28766,-22.25,-45.7
br,santa rita dos coqueiros,Santa Rita dos Coqueiros,15,,-20.95,-42.166667
br,santa rita dos coqueiros,Santa Rita dos Coqueiros,27,,-21.283333,-47.166667
br,santa rita dos patos,Santa Rita dos Patos,15,,-18.416667,-46.416667
br,santa rita do weil,Santa Rita do Weil,04,,-3.466667,-69.316667
br,santa rita durao,Santa Rita Durão,15,,-20.183333,-43.416667
br,santa rita durao,Santa Rita Durão,16,,-1.883333,-47.516667
br,santa rita,Santa Rita,01,,-8.45,-73.166667
br,santa rita,Santa Rita,02,,-9.7,-35.8
br,santa rita,Santa Rita,04,,-3.466667,-69.316667
br,santa rita,Santa Rita,05,,-11,-44.533333
br,santa rita,Santa Rita,06,,-3.433333,-40.066667
br,santa rita,Santa Rita,08,,-18.266667,-40.916667
br,santa rita,Santa Rita,11,,-17.85,-57.366667
br,santa rita,Santa Rita,13,13226,-3.833333,-43.883333
br,santa rita,Santa Rita,14,,-16.25,-59
br,santa rita,Santa Rita,15,,-15.933333,-44.083333
br,santa rita,Santa Rita,16,,-1.983333,-49.6
br,santa rita,Santa Rita,17,119895,-7.133333,-34.966667
br,santa rita,Santa Rita,18,,-24.616667,-53.2
br,santa rita,Santa Rita,20,,-5.033333,-42.666667
br,santa rita,Santa Rita,21,,-21.783333,-41.516667
br,santa rita,Santa Rita,22,,-5.305,-36.688889
br,santa rita,Santa Rita,23,,-29.8572,-51.2742
br,santa rita,Santa Rita,27,,-21.7,-47.466667
br,santa rita,Santa Rita,29,,-14.433333,-48.25
br,santa rita,Santa Rita,30,,-7.75,-37.216667
br,santa rita,Santa Rita,31,,-10.874167,-48.831389
br,santa rosa de lima,Santa Rosa de Lima,15,,-16.3,-43.95
br,santa rosa de lima,Santa Rosa de Lima,28,,-10.683333,-37.216667
br,santa rosa de viterbo,Santa Rosa de Viterbo,27,21473,-21.466667,-47.35
br,santa rosa dos dourados,Santa Rosa dos Dourados,15,,-18.683333,-47.15
br,santa rosa do tengue,Santa Rosa do Tengué,04,,-4.683333,-66.75
br,santa rosa do tocantins,Santa Rosa do Tocantins,31,,-11.499444,-48.059167
br,santa rosa,Santa Rosa,01,,-8.666667,-70.516667
br,santa rosa,Santa Rosa,04,,.1,-67.733333
br,santa rosa,Santa Rosa,05,,-10.1,-39.85
br,santa rosa,Santa Rosa,06,,-3.533333,-40.416667
br,santa rosa,Santa Rosa,08,,-19.916667,-40.266667
br,santa rosa,Santa Rosa,11,,-19.533333,-54.866667
br,santa rosa,Santa Rosa,13,,-2.666667,-44.183333
br,santa rosa,Santa Rosa,14,,-16.616667,-56.816667
br,santa rosa,Santa Rosa,15,,-18.683333,-47.15
br,santa rosa,Santa Rosa,16,,-2.466667,-48.683333
br,santa rosa,Santa Rosa,17,,-6.716667,-36.066667
br,santa rosa,Santa Rosa,18,,-24.466667,-53.966667
br,santa rosa,Santa Rosa,20,,-3.283333,-41.433333
br,santa rosa,Santa Rosa,21,,-22.206667,-43.654722
br,santa rosa,Santa Rosa,23,58958,-27.866667,-54.483333
br,santa rosa,Santa Rosa,24,,-10.133333,-62.7
br,santa rosa,Santa Rosa,25,,3.366667,-61.366667
br,santa rosa,Santa Rosa,26,,-29.133333,-49.716667
br,santa rosa,Santa Rosa,27,,-21.466667,-47.35
br,santa-rosa,Santa-Rosa,28,,-10.683333,-37.216667
br,santa rosa,Santa Rosa,29,,-15.016667,-47.216667
br,santa rosa,Santa Rosa,30,,-7.7,-37.483333
br,santa rosa,Santa Rosa,31,,-11.499444,-48.059167
br,santa,Santa,11,,-21.1,-56.233333
br,santa silvana,Santa Silvana,23,,-31.45,-52.283333
br,santa silvania,Santa Silvânia,23,,-31.45,-52.283333
br,santa sofia,Santa Sofia,11,,-21.583333,-53.733333
br,santa tecla,Santa Tecla,23,,-28.883333,-54.133333
br,santa teresa do bonito,Santa Teresa do Bonito,15,,-18.4,-42.483333
br,santa teresa,Santa Teresa,05,,-12.983333,-38.783333
br,santa teresa,Santa Teresa,06,,-4.366667,-41.05
br,santa teresa,Santa Teresa,08,9160,-19.916667,-40.6
br,santa teresa,Santa Teresa,11,,-20.8,-55.433333
br,santa teresa,Santa Teresa,13,,-1.983333,-44.55
br,santa teresa,Santa Teresa,16,,-.666667,-49.333333
br,santa teresa,Santa Teresa,17,,-6.2,-37.35
br,santa teresa,Santa Teresa,18,,-25.016667,-53.566667
br,santa teresa,Santa Teresa,20,,-9.15,-42.266667
br,santa teresa,Santa Teresa,21,,-22.166667,-43.585278
br,santa teresa,Santa Teresa,22,,-5.65,-35.5
br,santa teresa,Santa Teresa,23,,-28.783333,-53.416667
br,santa teresa,Santa Teresa,26,,-27.666667,-49.4
br,santa teresa,Santa Teresa,29,,-13.633333,-49.016667
br,santa teresa,Santa Teresa,30,,-8.15,-36.25
br,santa teresa,Santa Teresa,31,,-11.983333,-47.666667
br,santa teresinha do tauiri,Santa Teresinha do Tauiri,16,,-5.133333,-49.3
br,santa teresinha,Santa Teresinha,04,,-5.64,-61.081667
br,santa teresinha,Santa Teresinha,05,,-11.433333,-40.766667
br,santa teresinha,Santa Teresinha,08,,-18.5,-40.816667
br,santa teresinha,Santa Teresinha,11,,-17.533333,-56.883333
br,santa teresinha,Santa Teresinha,14,,-10.466667,-50.516667
br,santa teresinha,Santa Teresinha,16,,-1.316667,-47.733333
br,santa teresinha,Santa Teresinha,17,,-7.083333,-37.45
br,santa teresinha,Santa Teresinha,18,,-25.9,-52.65
br,santa teresinha,Santa Teresinha,22,,-5.1,-35.966667
br,santa teresinha,Santa Teresinha,23,,-27.633333,-54.166667
br,santa teresinha,Santa Teresinha,27,,-21.216667,-47.683333
br,santa teresinha,Santa Teresinha,30,,-7.35,-37.466667
br,santa teresinha,Santa Teresinha,31,,-5.666667,-48.1
br,santa teresinna,Santa Teresinna,14,,-10.466667,-50.516667
br,santa tereza do bonito,Santa Tereza do Bonito,15,,-18.4,-42.483333
br,santa tereza do tocantins,Santa Tereza do Tocantins,31,,-10.278611,-47.689444
br,santa tereza,Santa Tereza,05,,-9.666667,-43.666667
br,santa tereza,Santa Tereza,06,,-3.533333,-40.416667
br,santa tereza,Santa Tereza,08,,-19.916667,-40.6
br,santa tereza,Santa Tereza,11,,-20.8,-55.433333
br,santa tereza,Santa Tereza,13,,-3.5,-45.066667
br,santa tereza,Santa Tereza,16,,-.666667,-49.333333
br,santa tereza,Santa Tereza,18,,-25.016667,-53.566667
br,santa tereza,Santa Tereza,20,,-5.616667,-42.75
br,santa tereza,Santa Tereza,21,,-22.383333,-41.85
br,santa tereza,Santa Tereza,31,,-11.983333,-47.666667
br,santa terezinha,Santa Terezinha,04,,-6.973611,-71.394722
br,santa terezinha,Santa Terezinha,05,,-11.433333,-40.766667
br,santa terezinha,Santa Terezinha,06,,-5.05,-40.583333
br,santa terezinha,Santa Terezinha,08,,-18.5,-40.816667
br,santa terezinha,Santa Terezinha,11,,-17.533333,-56.883333
br,santa terezinha,Santa Terezinha,14,,-10.466667,-50.516667
br,santa terezinha,Santa Terezinha,16,,-1.316667,-47.733333
br,santa terezinha,Santa Terezinha,17,,-7.083333,-37.45
br,santa terezinha,Santa Terezinha,21,,-22.901546,-43.574626
br,santa terezinha,Santa Terezinha,22,,-5.35,-36.363333
br,santa terezinha,Santa Terezinha,23,,-27.633333,-54.166667
br,santa terezinha,Santa Terezinha,27,,-23.366667,-49.166667
br,santa terezinha,Santa Terezinha,31,,-5.666667,-48.1
br,santa theresa,Santa Theresa,23,,-29.183333,-51.733333
br,santa thereza,Santa Thereza,08,,-19.916667,-40.6
br,santa thereza,Santa Thereza,21,,-22.166667,-43.585278
br,santa thereza,Santa Thereza,26,,-27.666667,-49.4
br,santa therezinha,Santa Therezinha,14,,-10.466667,-50.516667
br,santa uniao,Santa União,31,,-11.7,-48.633333
br,santa unido,Santa Unido,31,,-11.7,-48.633333
br,santa ursula,Santa Úrsula,20,,-4.833333,-41.983333
br,santa vera,Santa Vera,18,,-26.217636,-49.508208
br,santa victoria do palmar,Santa Victoria do Palmar,23,,-33.516667,-53.35
br,santa victoria,Santa Victoria,15,,-18.833333,-50.133333
br,santa victoria,Santa Victoria,23,,-33.516667,-53.35
br,santa virginia,Santa Virgínia,11,,-20.133333,-55.916667
br,santa vitoria do palmar,Santa Vitória do Palmar,23,27776,-33.516667,-53.35
br,santa vitoria,Santa Vitória,05,,-12.083333,-40.2
br,santa vitoria,Santa Vitória,06,,-6.883333,-38.833333
br,santa vitoria,Santa Vitória,15,11657,-18.833333,-50.133333
br,santa zelia,Santa Zélia,18,,-23.166667,-51.666667
br,santelmo,Santelmo,27,,-22.166667,-48.85
br,santelo,Santelo,20,,-6.516667,-41.316667
br,santiago do boqueirao,Santiago do Boqueirão,23,,-29.183333,-54.883333
br,santiago do iguape,Santiago do Iguape,05,,-12.683333,-38.85
br,santiago hernandez,Santiago Hernândez,23,,-30.15,-55.9
br,santiago,Santiago,05,,-12.4,-38.35
br,santiago,Santiago,06,,-5.966667,-39.666667
br,santiago,Santiago,13,,-1.966667,-44.816667
br,santiago,Santiago,17,,-8.116667,-36.883333
br,santiago,Santiago,20,,-6.9,-41.083333
br,santiago,Santiago,23,46612,-29.183333,-54.883333
br,santiago,Santiago,26,,-28.416667,-48.9
br,santiago,Santiago,27,,-20.6,-47.766667
br,santiago,Santiago,30,,-7.716667,-37.566667
br,santinho,Santinho,15,,-17.3,-40.95
br,santissimo,Santíssimo,21,,-22.876226,-43.514555
br,santo afonso,Santo Afonso,15,,-19.9,-44.266667
br,santo agostinho de minas,Santo Agostinho de Minas,08,,-18.333333,-41
br,santo agostinho,Santo Agostinho,06,,-6.416667,-39.616667
br,santo agostinho,Santo Agostinho,08,,-18.333333,-41
br,santo agostinho,Santo Agostinho,15,,-22.2,-46.183333
br,santo agostinho,Santo Agostinho,23,,-29.066667,-51.033333
br,santo agostinho,Santo Agostinho,30,,-8.35,-34.933333
br,santo aleixo,Santo Aleixo,15,,-21.233333,-46.5
br,santo aleixo,Santo Aleixo,17,,-7.35,-37.433333
br,santo aleixo,Santo Aleixo,20,,-6.616667,-42.683333
br,santo aleixo,Santo Aleixo,21,,-22.553889,-43.048611
br,santo alem,Santo Além,11,,-21.45,-56.5
br,santo amaro da imperatriz,Santo Amaro da Imperatriz,26,18420,-27.683333,-48.766667
br,santo amaro da itaparica,Santo Amaro da Itaparica,05,,-13.066667,-38.783333
br,santo amaro das brotas,Santo Amaro das Brotas,28,9302,-10.783333,-37.066667
br,santo amaro de campos,Santo Amaro de Campos,21,,-21.983333,-41.133333
br,santo amaro do catu,Santo Amaro do Catú,05,,-13.066667,-38.783333
br,santo amaro do cubatao,Santo Amaro do Cubatão,26,,-27.683333,-48.766667
br,santo amaro do sul,Santo Amaro do Sul,23,,-29.933333,-51.9
br,santo amaro,Santo Amaro,04,,-4.933333,-60.2
br,santo amaro,Santo Amaro,05,46749,-12.533333,-38.716667
br,santo amaro,Santo Amaro,11,,-21.716667,-56.583333
br,santo amaro,Santo Amaro,13,,-2.55,-43.233333
br,santo amaro,Santo Amaro,14,,-16.083333,-55.433333
br,santo amaro,Santo Amaro,15,,-20.733333,-43.883333
br,santo amaro,Santo Amaro,17,,-6.633333,-38.066667
br,santo amaro,Santo Amaro,18,,-24.416667,-50.266667
br,santo amaro,Santo Amaro,20,,-5.783333,-41.233333
br,santo amaro,Santo Amaro,21,,-21.983333,-41.133333
br,santo amaro,Santo Amaro,23,,-29.933333,-51.9
br,santo amaro,Santo Amaro,26,,-27.683333,-48.766667
br,santo amaro,Santo Amaro,27,,-23.65,-46.7
br,santo amaro,Santo Amaro,28,,-10.783333,-37.066667
br,santo amaro,Santo Amaro,30,,-8.783333,-38.933333
br,santo amo,Santo Amo,05,,-12.716667,-39.916667
br,santo anastacio,Santo Anastácio,27,17233,-21.966667,-51.65
br,santo andre,Santo André,05,,-12.25,-42.083333
br,santo andre,Santo André,06,,-7.816667,-38.983333
br,santo andre,Santo André,08,,-20.65,-41.2
br,santo andre,Santo André,16,,-1.15,-49.216667
br,santo andre,Santo André,17,,-7.216667,-36.633333
br,santo andre,Santo André,18,,-24.8,-50.216667
br,santo andre,Santo André,27,662387,-23.666667,-46.516667
br,santo andre,Santo André,30,,-8.766667,-35.3
br,santo angelo,Santo Ángelo,14,,-15.4,-58.683333
br,santo angelo,Santo Ângelo,23,64607,-28.3,-54.266667
br,santo angelo,Santo Angelo,27,,-23.55,-46.25
br,santo anionio,Santo Aniônio,04,,-2.983333,-69.466667
br,santo antao,Santo Antão,23,,-29.2467,-51.1846
br,santo antonio da alegria,Santo Antônio da Alegria,27,,-21.1,-47.166667
br,santo antonio da barra,Santo Antônio da Barra,14,,-16.466667,-56.1
br,santo antonio da barra,Santo Antônio da Barra,27,,-21.55,-46.533333
br,santo antonio da boa vista,Santo Antônio da Boa Vista,15,,-15.866667,-44.15
br,santo antonio da cachoeira,Santo Antônio da Cachoeira,03,,-.666667,-52.5
br,santo antonio da cachoeira,Santo Antonio da Cachoeira,31,,-5.728056,-47.33
br,santo antonio da camela,Santo Antônio da Camela,30,,-8.516667,-35.116667
br,santo antonio da esperanca,Santo Antônio da Esperança,29,,-17.266667,-48.6
br,santo antonio da estiva,Santo Antônio da Estiva,27,,-21.883333,-49.383333
br,santo antonio da fortaleza,Santo Antônio da Fortaleza,15,,-19.166667,-42.9
br,santo antonio da gloria,Santo Antonio da Gloria,05,,-9.183333,-38.3
br,santo antonio da gloria,Santo Antonio da Gloria,15,,-20.95,-42.3
br,santo antonio da lagoa,Santo Antonio da Lagôa,15,,-19.116667,-44.2
br,santo antonio da montanha,Santo Antônio da Montanha,08,,-18.133333,-40.35
br,santo antonio da patrulha,Santo Antônio da Patrulha,23,,-29.833333,-50.533333
br,santo antonio da pindoba,Santo Antônio da Pindoba,06,,-3.95,-41.066667
br,santo antonio da platina,Santo Antônio da Platina,18,35260,-23.2942,-50.075
br,santo antonio da solta,Santo Antônio da Solta,16,,-8.066667,-50.183333
br,santo antonio das queimadas,Santo Antônio das Queimadas,30,,-8.75,-36.183333
br,santo antonio das russas,Santo Antonio das Russas,06,,-4.833333,-38.166667
br,santo antonio das tabuas,Santo Antônio das Tábuas,05,,-13.2,-40.266667
br,santo antonio das trempes,Santo Antônio das Trempes,30,,-8.766667,-35.683333
br,santo antonio da vargem alegre,Santo Antônio da Vargem Alegre,15,,-20.316667,-44.2
br,santo antonio de aruans,Santo Antônio de Aruans,16,,-.166667,-49.916667
br,santo antonio de aruas,Santo Antônio de Aruãs,16,,-.166667,-49.916667
br,santo antonio de balsas,Santo Antonio de Balsas,13,,-7.516667,-46.033333
br,santo antonio de barcelona,Santo Antônio de Barcelona,05,,-17.45,-40.15
br,santo antonio de cassiana,Santo Antônio de Cassianã,04,,-7.25,-64.933333
br,santo antonio de gurupa,Santo Antonio De Gurupa,16,,-1.416667,-51.65
br,santo antonio de imbituva,Santo Antonio de Imbituva,18,,-25.2,-50.583333
br,santo antonio de itabapoana,Santo Antonio de Itabapoana,21,,-21.016667,-41.733333
br,santo antonio de jesus,Santo Antônio de Jesus,05,73959,-12.966667,-39.266667
br,santo antonio de juquia,Santo António de Juquia,27,,-24.316667,-47.633333
br,santo antonio de lisboa,Santo Antônio de Lisboa,20,,-6.966667,-41.233333
br,santo antonio de lisboa,Santo Antônio de Lisboa,26,,-27.516667,-48.516667
br,santo antonio de padua,Santo Antônio de Pádua,21,33076,-21.533333,-42.183333
br,santo antonio de posse,Santo Antônio de Posse,27,18149,-22.6,-46.916667
br,santo antonio de taua,Santo Antônio de Tauá,16,,-1.183333,-48.133333
br,santo antonio de teofilo dias,Santo Antônio de Teófilo Dias,15,,-17.75,-40.583333
br,santo antonio do amacia,Santo Antônio do Amaciã,04,,-5.569444,-64.258333
br,santo antonio do amparo,Santo Antônio do Amparo,15,16730,-20.95,-44.916667
br,santo antonio do andira,Santo Antônio do Andirá,15,,-20.55,-42.266667
br,santo antonio do arrozal,Santo Antônio do Arrozal,15,,-20.566667,-42.233333
br,santo antonio do atininga,Santo Antônio do Atininga,04,,-5.610278,-60.98
br,santo antonio do azeite,Santo Antônio do Azeite,15,,-21.55,-44.183333
br,santo antonio do bogueirao de quixeramobim,Santo Antônio do Bogueirão de Quixeramobim,06,,-5.2,-39.283333
br,santo antonio do caiua,Santo Antônio do Caiuá,18,,-22.7,-52.366667
br,santo antonio do calva,Santo Antônio do Calvá,18,,-22.7,-52.366667
br,santo antonio do capivari,Santo Antônio do Capivarí,21,,-22.833,-44.1921
br,santo antonio do capoeirao,Santo Antônio do Capoeirão,29,,-16.266667,-49.366667
br,santo antonio do caracaru,Santo Antônio do Caracaru,16,,-1.066667,-52.416667
br,santo antonio do caracol,Santo Antonio do Caracól,11,,-21.533333,-56.983333
br,santo antonio do cumaru,Santo Antônio do Cumaru,16,,-1.433333,-47.333333
br,santo antonio do gloria,Santo Antônio do Glória,15,,-20.95,-42.3
br,santo antonio do grama,Santo Antônio do Grama,15,,-20.316667,-42.6
br,santo antonio do ica,Santo Antônio do Içá,04,9302,-3.083333,-67.95
br,santo antonio do imbe,Santo Antônio do Imbé,21,,-21.983333,-41.883333
br,santo antonio do inca,Santo Antonio do Inca,04,,-3.083333,-67.95
br,santo antonio do indaia,Santo Antônio do Indaiá,15,,-20.55,-42.266667
br,santo antonio do iratim,Santo Antônio do Iratim,18,,-26.166667,-51.383333
br,santo antonio do itaim,Santo Antônio do Itaim,15,,-22.4,-45.883333
br,santo antonio do itambe,Santo Antônio do Itambé,15,,-18.5,-43.3
br,santo antonio do jacinto,Santo Antônio do Jacinto,15,,-16.516667,-40.133333
br,santo antonio do jardim,Santo Antônio do Jardim,06,,-7.583333,-39.266667
br,santo antonio do jardim,Santo Antônio do Jardim,27,,-22.116667,-46.683333
br,santo antonio do jari,Santo Antônio do Jari,04,,-4.937222,-62.361111
br,santo antonio do jordao,Santo Antônio do Jordão,05,,-12.55,-39.083333
br,santo antonio do leite,Santo Antônio do Leite,15,,-20.35,-43.733333
br,santo antonio do leverger,Santo Antônio do Leverger,14,6387,-15.866667,-56.083333
br,santo antonio do lopes,Santo Antônio do Lopes,13,,-4.833333,-44.483333
br,santo antonio do manhuacu,Santo Antônio do Manhuaçu,15,,-19.666667,-41.833333
br,santo antonio do manhuassu,Santo Antônio do Manhuassú,15,,-19.666667,-41.833333
br,santo antonio do matipo,Santo Antonio do Matipó,15,,-20.183333,-42.4
br,santo antonio do monte,Santo Antônio do Monte,15,22592,-20.083333,-45.283333
br,santo antonio do mucuri,Santo Antônio do Mucuri,15,,-17.766667,-41.966667
br,santo antonio do muqui,Santo Antônio do Muqui,08,,-21.033333,-41.433333
br,santo antonio do mutum,Santo Antônio do Mutum,08,,-19.666667,-40.616667
br,santo antonio do norte,Santo Antônio do Norte,15,,-18.8,-43.533333
br,santo antonio do olho d'agua,Santo Antonio do Olho d'Agua,29,,-16.033333,-48.6
br,santo antonio do oriente,Santo Antônio do Oriente,08,,-20.4,-41.15
br,santo antonio do padua,Santo Antonio do Padua,21,,-21.533333,-42.183333
br,santo antonio do palmital,Santo Antônio do Palmital,18,,-23.816667,-51.45
br,santo antonio do paraiso,Santo Antônio do Paraiso,18,,-23.533333,-50.666667
br,santo antonio do pari,Santo Antônio do Pari,18,,-23.533333,-50.666667
br,santo antonio do pelotas,Santo Antônio do Pelotas,26,,-28.2,-50.7
br,santo antonio do pinhal,Santo Antônio do Pinhal,26,,-27.233333,-51.916667
br,santo antonio do pinhal,Santo Antônio do Pinhal,27,,-22.833333,-45.666667
br,santo antonio do pirapetinga,Santo Antônio do Pirapetinga,15,,-20.616667,-43.35
br,santo antonio do platino,Santo Antonio do Platino,18,,-23.2942,-50.075
br,santo antonio do portao,Santo Antônio do Portão,16,,-5.366667,-55.833333
br,santo antonio do rio abaixo,Santo Antonio do Rio Abaixo,14,,-15.866667,-56.083333
br,santo antonio do rio abaixo,Santo Antônio do Rio Abaixo,15,,-19.233333,-43.25
br,santo antonio do rio das pedras,Santo Antônio do Rio das Pedras,05,,-12.85,-38.4
br,santo antonio do rio de peixe,Santo Antônio do Rio de Peixe,15,,-18.716667,-43.366667
br,santo antonio do rio do peixe,Santo Antonio do Rio do Peixe,15,,-18.716667,-43.366667
br,santo antonio do rio madeira,Santo Antônio do Rio Madeira,24,,-8.8,-63.933333
br,santo antonio do rio preto,Santo Antônio do Rio Prêto,15,,-21.066667,-42.583333
br,santo antonio do rio verde,Santo Antônio do Rio Verde,29,,-17.95,-47.45
br,santo antonio dos alves,Santo Antônio dos Alves,13,,-4.266667,-43.766667
br,santo antonio dos camilos,Santo Antônio dos Camilos,06,,-3.6,-40.483333
br,santo antonio dos campos,Santo Antônio dos Campos,15,,-20.1,-44.966667
br,santo antonio dos cavalheiros,Santo Antonio dos Cavalheiros,29,,-17.25,-48.033333
br,santo antonio dos indios,Santo Antonio dos Indios,26,,-27.783333,-50.2
br,santo antonio dos lopes,Santo Antônio dos Lopes,13,,-4.833333,-44.483333
br,santo antonio dos milagres,Santo Antônio dos Milagres,21,,-20.3,-41.666667
br,santo antonio dos prazeres,Santo Antônio dos Prazeres,05,,-12.233333,-38.933333
br,santo antonio dos tiros,Santo Antonio dos Tiros,15,,-19,-45.966667
br,santo antonio do sudoeste,Santo Antônio do Sudoeste,18,11723,-26.068889,-53.725278
br,santo antonio dos velasques,Santo Antônio dos Velasques,05,,-12.933333,-38.6
br,santo antonio do tara,Santo Antônio do Tará,30,,-8.716667,-36.866667
br,santo antonio do taua,Santo Antônio do Tauá,16,8921,-1.183333,-48.133333
br,santo antonio do tibiri,Santo Antônio do Tibiri,05,,-12.533333,-38.9
br,santo antonio do urupi,Santo Antônio do Urupi,05,,-12.433333,-38.8
br,santo antonio pouso alegre,Santo Antônio Pouso Alegre,08,,-18.533333,-40.333333
br,santo antonio rio verde,Santo Antônio Rio Verde,29,,-17.95,-47.45
br,santo antonio,Santo Antônio,01,,-10.1,-69.216667
br,santo antonio,Santo Antônio,02,,-9.233333,-35.883333
br,santo antonio,Santo Antônio,03,,.316667,-50.7
br,santo antonio,Santo Antônio,04,,.016667,-68.5
br,santo antonio,Santo Antônio,05,,-10.233333,-39.683333
br,santo antonio,Santo Antônio,06,,-3.016667,-39.866667
br,santo antonio,Santo Antônio,08,,-19.466667,-40.1
br,santo antonio,Santo Antônio,11,,-18.766667,-56.45
br,santo antonio,Santo Antônio,13,,-1.883333,-45.383333
br,santo antonio,Santo Antonio,14,,-15.866667,-56.083333
br,santo antonio,Santo Antônio,15,,-14.966667,-42.783333
br,santo antonio,Santo Antônio,16,,-1.166667,-50.233333
br,santo antonio,Santo Antônio,17,,-6.816667,-36.883333
br,santo antonio,Santo Antônio,18,,-23.166667,-51.15
br,santo antonio,Santo Antônio,20,,-10.483333,-44.133333
br,santo antonio,Santo Antônio,21,,-22.166667,-41.883333
br,santo antonio,Santo Antônio,22,12529,-6.3,-35.45
br,santo antonio,Santo Antônio,23,,-28.416667,-52.216667
br,santo antonio,Santo Antônio,24,,-12.533333,-63.566667
br,santo antonio,Santo Antônio,25,,2.616667,-60.366667
br,santo antonio,Santo Antonio,26,,-27.516667,-48.516667
br,santo antonio,Santo Antônio,27,,-20.483333,-50.183333
br,santo antonio,Santo Antônio,30,,-7.316667,-37.5
br,santo antonio,Santo Antônio,31,,-11.5,-48.65
br,santo augusto,Santo Augusto,23,10305,-27.85,-53.783333
br,santo christo,Santo Christo,23,,-27.833333,-54.666667
br,santo cristo,Santo Cristo,16,,-1.216667,-47.666667
br,santo cristo,Santo Cristo,21,,-22.898654,-43.20133
br,santo cristo,Santo Cristo,22,,-5.116667,-35.633333
br,santo cristo,Santo Cristo,23,,-27.833333,-54.666667
br,santo domingo da bocaina,Santo Domingo da Bocaina,15,,-21.833333,-44.016667
br,santo domingos,Santo Domingos,11,,-19.233333,-57.633333
br,santo eduardo,Santo Eduardo,21,,-21.216667,-41.466667
br,santo elias,Santo Elias,01,,-7.766667,-72.6
br,santo emilio,Santo Emílio,05,,-12.55,-40.533333
br,santo-engenio,Santo-Engênio,20,,-8.15,-41.833333
br,santo esidro,Santo Esidro,11,,-21.816667,-57.733333
br,santo estevam,Santo Estevam,05,,-12.7,-38.6
br,santo estevao,Santo Estêvão,05,27280,-12.433333,-39.216667
br,santo estevao,Santo Estêvão,06,,-4.9,-39.15
br,santo estevao,Santo Estevão,17,,-7.133333,-37.383333
br,santo estevao,Santo Estêvão,20,,-7.5,-45.1
br,santo estevao velho,Santo Estêvão Velho,05,,-12.4,-39.15
br,santo eugenio,Santo Eugênio,13,,-3.43,-42.425
br,santo eugenio,Santo Eugênio,20,,-8.15,-41.833333
br,santo eusebio,Santo Eusébio,04,,-4.398611,-71.075833
br,santo expedito,Santo Expedito,27,,-21.816667,-51.366667
br,santo hilario,Santo Hilário,13,,-3.165,-42.690833
br,santo hilario,Santo Hilário,15,,-20.666667,-45.833333
br,santo hipolito,Santo Hipólito,15,,-18.266667,-44.233333
br,santo hippolyto,Santo Hippolyto,15,,-18.266667,-44.233333
br,santo inacio,Santo Inácio,04,,-5.583333,-61.103056
br,santo inacio,Santo Inácio,05,,-11.1,-42.733333
br,santo inacio,Santo Inácio,13,,-3.251944,-42.16
br,santo inacio,Santo Inácio,18,,-22.683333,-51.816667
br,santo inacio,Santo Inácio,23,,-30.666667,-55.15
br,santo inacio,Santo Inácio,27,,-22.416667,-49.8
br,santo inacio,Santo Inácio,30,,-8.266667,-34.983333
br,santo isidio,Santo Isídio,06,,-3.783333,-40.35
br,santo isidio,Santo Isídio,13,,-3.667778,-43.393333
br,santo isidoro,Santo Isidoro,13,,-3.114722,-43.223333
br,santo isidro,Santo Isidro,06,,-4.283333,-40.566667
br,santo isidro,Santo Isidro,22,,-5.218611,-36.440556
br,santo izabel,Santo Izabel,14,,-13.666667,-60.733333
br,santo izidio,Santo Izídio,06,,-3.233333,-40.05
br,santo izidio,Santo Izídio,22,,-5.866667,-35.4
br,santo onofre,Santo Onofre,05,,-13.1,-42.9
br,santo onofre,Santo Onofre,08,,-18.416667,-41
br,santo onofre,Santo Onofre,11,,-20.966667,-55.083333
br,santo onofre,Santo Onofre,14,,-7.583333,-57.9
br,santo rita,Santo Rita,04,,-3.466667,-69.316667
br,santo rosa,Santo Rosa,21,,-22.814687,-43.760258
br,santo,Santo,05,,-13.6,-38.883333
br,santos cosme e damiao da serra do pereiro,Santos Cosme e Damião da Serra do Pereiro,06,,-6.05,-38.466667
br,santos cosme e damiao,Santos Cosme e Damião,06,,-6.05,-38.466667
br,santos dumont,Santos Dumont,04,,-5.386944,-60.404167
br,santos dumont,Santos Dumont,06,,-5.2,-40.716667
br,santos dumont,Santos Dumont,14,,-13.45,-60.433333
br,santos dumont,Santos Dumont,15,41582,-21.466667,-43.566667
br,santos dumont,Santos Dumont,24,,-10.416667,-62.416667
br,santo sebastian,Santo Sebastian,04,,-2.866667,-68.433333
br,santos reis,Santos Reis,18,,-23.616667,-50.266667
br,santos reis,Santos Reis,20,,-5.583333,-41.25
br,santos reis,Santos Reis,23,,-28.616667,-55.9
br,santos,Santos,06,,-7.033333,-39.283333
br,santos,Santos,15,,-16.35,-41.566667
br,santos,Santos,20,,-7.066667,-43.133333
br,santos,Santos,23,,-32.65,-52.6
br,santos,Santos,27,411411,-23.95,-46.333333
br,santo thomaz,Santo Thomaz,11,,-22.55,-55.683333
br,sao amaro das brotas,Sào Amaro das Brotas,28,,-10.783333,-37.066667
br,sao amaro,São Amaro,06,,-3.433333,-39.966667
br,sao amelia,São Amélia,13,,-8.983333,-46.7
br,sao andre,São André,06,,-6.5,-39.45
br,sao antonio da mutum,São Antônio da Mutum,08,,-19.666667,-40.616667
br,sao antonio da salta,São Antonio da Salta,16,,-8.066667,-50.183333
br,sao antonio de itahim,São Antonio de Itahim,15,,-22.4,-45.883333
br,sao antonio de pouso alegre,São Antônio de Pouso Alegre,08,,-18.533333,-40.333333
br,sao antonio,São Antonio,01,,-8.65,-70.15
br,sao antonio,São Antônio,06,,-6.116667,-39.25
br,sao antonio,São Antonio,08,,-18.533333,-40.333333
br,sao antonio,São Antônio,13,,-5.3,-43.483333
br,sao antonio,São Antônio,14,,-17.016667,-56.6
br,sao antonio,São Antonio,20,,-9.016667,-42.766667
br,sao barnabe,São Barnabé,05,,-11.366667,-39.6
br,sao barnabe,São Barnabé,15,,-19.866667,-41.6
br,sao bartholomeu,São Bartholomeu,15,,-20.3,-43.583333
br,sao bartholomeu,São Bartholomeu,27,,-23.05,-49.25
br,sao bartolomeu,São Bartolomeu,02,,-9.433333,-37.266667
br,sao bartolomeu,São Bartolomeu,05,,-12.466667,-42.833333
br,sao bartolomeu,São Bartolomeu,06,,-6.6,-39.5
br,sao bartolomeu,São Bartolomeu,15,,-20.05,-42.833333
br,sao bartolomeu,São Bartolomeu,27,,-23.05,-49.25
br,sao basilio,São Basilio,21,,-22.891792,-43.574175
br,sao benedicto,São Benedicto,06,,-4.05,-40.883333
br,sao benedicto,São Benedicto,13,,-3.333333,-43.583333
br,sao benedicto,São Benedicto,16,,-2.45,-49.416667
br,sao benedicto,São Benedicto,25,,3.466667,-60.133333
br,sao benedicto,São Benedicto,30,,-8.816667,-35.95
br,sao benedito da cachoeira,São Benedito da Cachoeira,27,,-20.233333,-47.883333
br,sao benedito da cachoeirinha,São Benedito da Cachoeirinha,27,,-20.233333,-47.883333
br,sao benedito das areias,São Benedito das Areias,27,,-21.316667,-47.033333
br,sao benedito do rio preto,São Benedito do Rio Prêto,13,12081,-3.333333,-43.583333
br,sao benedito,São Benedito,04,,-3.916667,-61.95
br,sao benedito,São Benedito,05,,-12.733333,-39.866667
br,sao benedito,São Benedito,06,,-4.05,-40.883333
br,sao benedito,São Benedito,11,,-18.8,-56.016667
br,sao benedito,São Benedito,13,,-3.128333,-42.683889
br,sao benedito,São Benedito,15,,-19.05,-46.8
br,sao benedito,São Benedito,16,,-1.566667,-52.983333
br,sao benedito,São Benedito,17,,-6.966667,-36.033333
br,sao benedito,São Benedito,20,,-5.45,-42.366667
br,sao benedito,São Benedito,21,,-21.766667,-41.55
br,sao benedito,São Benedito,25,,3.466667,-60.133333
br,sao benedito,São Benedito,27,,-20.233333,-47.883333
br,sao benedito,São Benedito,29,,-17.116667,-49.6
br,sao benedito,São Benedito,30,,-7.95,-37.766667
br,sao benito dos perizes,São Benito dos Perizes,13,,-2.7,-44.833333
br,sao benito,São Benito,14,,-16.833333,-58.366667
br,sao benitos,São Benitos,14,,-16.833333,-58.366667
br,sao bennardo,São Bennardo,04,,-7.166667,-71.95
br,sao bentinho,São Bentinho,15,,-17.466667,-41.883333
br,sao bento alto,São Bento Alto,26,,-28.666667,-49.566667
br,sao bento da amontada,São Bento da Amontada,06,,-3.383333,-39.833333
br,sao bento d'amontada,Sao Bento d'Amontada,06,,-3.383333,-39.833333
br,sao bento das lajes,São Bento das Lajes,05,,-12.616667,-38.683333
br,sao bento das perdizes,São Bento das Perdizes,13,,-2.7,-44.833333
br,sao bento de caldas,São Bento de Caldas,15,,-22.133333,-46.3
br,sao bento do inhata,São Bento do Inhatá,05,,-12.416667,-38.683333
br,sao bento do norte,São Bento do Norte,22,,-5.063889,-36.053611
br,sao bento do sapucahy,São Bento do Sapucahy,27,,-22.689392,-45.732183
br,sao bento do sapucai,São Bento do Sapucaí,27,,-22.689392,-45.732183
br,sao bento dos perizes,Sao Bento dos Perizes,13,,-2.7,-44.833333
br,sao bento do sul,São Bento do Sul,26,77598,-26.249722,-49.3825
br,sao bento do tocantins,São Bento do Tocantins,31,,-5.872222,-47.831389
br,sao bento do trairi,São Bento do Trairi,22,,-6.333333,-36.083333
br,sao bento do una,São Bento do Una,30,24506,-8.533333,-36.366667
br,sao bento,São Bento,01,,-9.233333,-68.75
br,sao bento,São Bento,02,,-9.066667,-35.25
br,sao bento,São Bento,03,,1.283333,-50.783333
br,sao bento,São Bento,04,,.366667,-68.816667
br,sao bento,São Bento,05,,-11.816667,-42.1
br,sao bento,São Bento,06,,-3.383333,-39.833333
br,sao bento,São Bento,08,,-20.483333,-40.933333
br,sao bento,São Bento,11,,-17.983333,-54.9
br,sao bento,São Bento,13,17245,-2.7,-44.833333
br,sao bento,São Bento,14,,-15.233333,-57.7
br,sao bento,São Bento,15,,-16.128333,-44.225833
br,sao bento,São Bento,16,,-2.5,-47.733333
br,sao bento,São Bento,17,24749,-6.283333,-37.75
br,sao bento,São Bento,18,,-25.89928,-49.774727
br,sao bento,São Bento,20,,-5.033333,-41.116667
br,sao bento,São Bento,21,,-21.916667,-41.116667
br,sao bento,São Bento,22,,-5.063889,-36.053611
br,sao bento,São Bento,23,,-28.3,-52.9
br,sao bento,São Bento,25,,3.033333,-60.5
br,sao bento,São Bento,26,,-26.249722,-49.3825
br,sao bento,São Bento,27,,-22.316667,-47.616667
br,sao bento,São Bento,29,,-18.45,-51.783333
br,sao bento,São Bento,30,,-7.566667,-39.666667
br,sao bento,São Bento,31,,-11.933333,-48.683333
br,sao bentos,São Bentos,14,,-16.833333,-58.366667
br,sao bento velho,São Bento Velho,11,,-20.983333,-57.5
br,sao bernado,São Bernado,04,,-4.072222,-65.082778
br,sao bernardo das russas,São Bernardo das Russas,06,,-4.933333,-37.966667
br,sao bernardo do campo,São Bernardo do Campo,27,743386,-23.7,-46.55
br,sao bernardo do parnahyba,São Bernardo do Parnahyba,13,,-3.366667,-42.4
br,sao bernardo do parnaiba,São Bernardo do Parnaíba,13,,-2.89,-41.903611
br,sao bernardo,São Bernardo,04,,-7.166667,-71.95
br,sao bernardo,São Bernardo,06,,-5.916667,-39.25
br,sao bernardo,São Bernardo,13,11171,-3.366667,-42.4
br,sao bernardo,São Bernardo,15,,-22.5602,-45.5374
br,sao bernardo,São Bernardo,16,,-1.05,-47.2
br,sao bernardo,São Bernardo,21,,-22.735468,-43.383514
br,sao bernardo,São Bernardo,22,,-6.283333,-37.933333
br,sao bernardo,São Bernardo,23,,-28.85,-51.133333
br,sao bernardo,São Bernardo,27,,-23.7,-46.55
br,sao berto,São Berto,27,,-23.05,-49.25
br,sao beuto,São Beuto,13,,-6,-43.133333
br,sao boaventura d'agua bella,Sao Boaventura d'Agua Bella,15,,-17.083333,-40.95
br,sao boa ventura,São Boa Ventura,17,,-7.4,-38.216667
br,sao boaventura,São Boaventura,30,,-8.183333,-37.816667
br,sao bonifacio,São Bonifácio,26,,-27.9,-48.933333
br,sao bonto,São Bonto,16,,-5.5,-48.35
br,sao borja,São Borja,23,59614,-28.65,-56
br,sao bras de cima,São Brás de Cima,22,,-6.466667,-38.15
br,sao bras do suacui,São Brás do Suaçuí,15,,-20.633333,-43.95
br,sao bras do suassui,São Brás do Suassuí,15,,-20.633333,-43.95
br,sao bras,São Brás,01,,-9.066667,-69.766667
br,sao bras,São Brás,02,,-10.083333,-36.916667
br,sao bras,São Brás,04,,-3.248333,-62.794444
br,sao bras,São Brás,05,,-12.6,-38.733333
br,sao bras,São Brás,16,,-6.416667,-58.066667
br,sao bras,São Brás,18,,-24.95,-50.6
br,sao bras,São Brás,20,,-9.066667,-42.983333
br,sao-bras,São-Brás,26,,-28.45,-48.866667
br,sao bras,São Brás,26,,-28.466667,-48.866667
br,sao bras,São Brás,30,,-8.45,-37.983333
br,sao braz do suassuhy,São Braz do Suassuhy,15,,-20.633333,-43.95
br,sao braz,São Braz,02,,-10.083333,-36.916667
br,sao braz,São Braz,04,,-6.233333,-61.816667
br,sao braz,São Braz,05,,-12.6,-38.733333
br,sao braz,São Braz,06,,-3.6,-40.416667
br,sao braz,São Braz,13,,-3.156667,-43.374444
br,sao braz,São Braz,18,,-24.95,-50.6
br,sao braz,São Braz,20,,-9.066667,-42.983333
br,sao braz,São Braz,23,,-29.1528,-51.0614
br,sao braz,São Braz,26,,-28.45,-48.866667
br,sao braz,São Braz,30,,-8.45,-37.983333
br,sao caetano da raposa,São Caetano da Raposa,30,,-8.35,-36.1
br,sao caetano de odivelas,São Caetano de Odivelas,16,8862,-.75,-48.033333
br,sao caetano de odivellas,São Caetano de Odivellas,16,,-.75,-48.033333
br,sao caetano do sul,São Caetano do Sul,27,136456,-23.6,-46.566667
br,sao caetano,São Caetano,04,,-6.933333,-60.316667
br,sao caetano,São Caetano,05,,-12.55,-38.666667
br,sao caetano,São Caetano,06,,-6.666667,-39.25
br,sao caetano,São Caetano,08,,-20.733333,-40.9
br,sao caetano,São Caetano,11,,-20.2,-55.266667
br,sao caetano,São Caetano,13,,-3.286111,-42.294444
br,sao caetano,São Caetano,14,,-14.9,-56.366667
br,sao caetano,São Caetano,15,,-17.483333,-42.716667
br,sao-caetano,São-Caetano,15,,-20.333333,-43.3
br,sao caetano,São Caetano,20,,-3.416667,-41.916667
br,sao caetano,São Caetano,21,,-21.283333,-41.75
br,sao caetano,São Caetano,27,,-23.6,-46.566667
br,sao caetano,São Caetano,30,,-8.2,-37.983333
br,sao-caetano,São-Caetano,30,,-8.35,-36.1
br,sao caitano,São Caitano,30,25259,-8.35,-36.1
br,sao candido,São Cândido,15,,-19.5,-42.3
br,sao carlos do caiua,São Carlos do Caiuá,18,,-23.283333,-52.5
br,sao carlos do ivai,São Carlos do Ivaí,18,,-23.283333,-52.5
br,sao carlos do pinhal,São Carlos do Pinhal,27,,-22.016667,-47.9
br,sao carlos,São Carlos,11,,-21.35,-55.233333
br,sao carlos,São Carlos,13,,-1.883333,-45.25
br,sao carlos,São Carlos,16,,-.633333,-49.3
br,sao carlos,Sao Carlos,18,,-25.776865,-50.248824
br,sao carlos,São Carlos,20,,-6.183333,-41.933333
br,sao carlos,São Carlos,22,,-5.2375,-37.376667
br,sao carlos,São Carlos,24,,-9.083333,-64.133333
br,sao carlos,São Carlos,26,,-27.066667,-52.983333
br,sao carlos,São Carlos,27,205039,-22.016667,-47.9
br,sao christovao,São Christovão,04,,-6.05,-64.3
br,sao christovao,São Christovão,28,,-11.016667,-37.2
br,sao cinza,São Cinza,16,,-6.283333,-57.7
br,sao cipriano,São Cipriano,06,,-3.583333,-40.483333
br,sao ciro,São Ciro,23,,-29.1448,-51.137
br,sao clemente,São Clemente,13,,-3.612778,-43.432222
br,sao clemente,São Clemente,27,,-21.816667,-47.583333
br,sao concalo,São Conçalo,17,,-6.883333,-37.666667
br,sao conrado,São Conrado,21,,-22.996667,-43.269722
br,sao cosme,São Cosme,05,,-12.533333,-38.8
br,sao cosme,São Cosme,13,,-3.422222,-43.243056
br,sao crispim,São Crispim,30,,-7.85,-38.066667
br,sao cristavem,São Cristavem,21,,-22.9,-43.216667
br,sao cristovam,São Cristovam,04,,-6.05,-64.3
br,sao cristovam,São Cristovam,11,,-20.533333,-56.5
br,sao cristovam,São Cristovam,21,,-22.9,-43.216667
br,sao cristovao,São Cristóvão,04,,-6.05,-64.3
br,sao cristovao,São Cristóvão,06,,-5.833333,-40.35
br,sao cristovao,São Cristóvão,08,,-20.566667,-41.133333
br,sao cristovao,São Cristóvão,11,,-17.75,-56.133333
br,sao cristovao,São Cristóvão,13,,-3.183333,-45.116667
br,sao cristovao,São Cristóvão,15,,-22.09,-43.951667
br,sao cristovao,São Cristóvão,21,,-22.9,-43.216667
br,sao cristovao,São Cristovão,23,,-29.0516,-51.1853
br,sao cristovao,São Cristóvão,28,71540,-11.016667,-37.2
br,sao cristovao,São Cristovão,30,,-7.8,-38.783333
br,sao damiao,São Damião,06,,-4.3,-40.05
br,sao desiderio,São Desidério,05,7295,-12.366667,-44.966667
br,sao diogo,São Diogo,17,,-6.6,-38.316667
br,sao diogo,São Diogo,20,,-8.366667,-44.8
br,sao diogo,São Diogo,21,,-21.55,-41.283333
br,sao domingoes,São Domingoes,04,,-8.116667,-69.483333
br,sao domingo,São Domingo,04,,-6.45,-61.75
br,sao domingo,São Domingo,11,,-18.45,-55.966667
br,sao domingo,São Domingo,30,,-8.65,-37.033333
br,sao domingos da boa vista,São Domingos da Bôa Vista,16,,-1.683333,-47.783333
br,sao domingos da bocaina,São Domingos da Bocaina,15,,-21.833333,-44.016667
br,sao domingos da prata,Sao Domingos da Prata,15,,-19.866667,-42.966667
br,sao-domingos-do-aracuai,São-Domingos-do-Araçuaí,15,,-16.816667,-42.35
br,sao domingos do arassuahy,São Domingos do Arassuahy,15,,-16.816667,-42.35
br,sao domingos do arassuai,São Domingos do Arassuaí,15,,-16.816667,-42.35
br,sao domingos do capim,São Domingos do Capim,16,,-1.683333,-47.783333
br,sao domingos do maranhao,São Domingos do Maranhão,13,18275,-5.7,-44.366667
br,sao domingos do prata,São Domingos do Prata,15,9466,-19.866667,-42.966667
br,sao domingos do rio do peixe,São Domingos do Rio do Peixe,15,,-18.95,-43.266667
br,sao domingos do sul,São Domingos do Sul,23,,-28.533333,-51.9
br,sao domingos,São Domingos,02,,-9.65,-36.1
br,sao domingos,São Domingos,04,,-1.936944,-61.347778
br,sao domingos,São Domingos,05,,-11.566667,-42.55
br,sao domingos,São Domingos,06,,-4.233333,-39.283333
br,sao domingos,São Domingos,08,,-19.15,-40.616667
br,sao domingos,São Domingos,11,,-18.45,-55.966667
br,sao domingos,São Domingos,13,,-3.045278,-42.128889
br,sao domingos,São Domingos,15,,-17.883333,-42.983333
br,sao domingos,São Domingos,16,,-1.083333,-47.033333
br,sao domingos,São Domingos,17,,-6.75,-35.05
br,sao domingos,São Domingos,18,,-23.616667,-51.466667
br,sao domingos,São Domingos,20,,-3.066667,-41.4
br,sao domingos,São Domingos,21,,-21.266667,-41.8
br,sao domingos,São Domingos,22,,-5.700833,-36.019167
br,sao domingos,São Domingos,23,,-28.533333,-51.9
br,sao domingos,São Domingos,24,,-10.033333,-63.4
br,sao domingos,São Domingos,25,,3.733333,-61.35
br,sao domingos,São Domingos,26,,-26.566667,-52.533333
br,sao domingos,São Domingos,28,,-10.766667,-38.9
br,sao domingos,São Domingos,29,4784,-13.4,-46.316667
br,sao domingos,São Domingos,30,,-7.883333,-37.633333
br,sao domingos,São Domingos,31,,-5.733333,-47.5
br,sao expedito,São Expedito,06,,-3.633333,-40.45
br,sao felipe,São Felipe,04,,-3.44,-61.748889
br,sao felipe,São Felipe,05,9574,-14.816667,-41.383333
br,sao felipe,São Felipe,06,,-2.866667,-40.083333
br,sao felipe,São Felipe,08,,-20.916667,-41.183333
br,sao felipe,São Felipe,13,,-3.230278,-43.159167
br,sao felipe,São Felipe,22,,-5.664167,-36.556111
br,sao felipe,São Felipe,25,,2.3,-60.883333
br,sao felippe,São Felippe,04,,.35,-67.316667
br,sao felippe,São Felippe,05,,-12.85,-39.1
br,sao felippe,São Felippe,08,,-20.916667,-41.183333
br,sao felix das balsas,São Félix das Balsas,13,,-7.133333,-44.866667
br,sao felix de balsas,São Félix de Balsas,13,,-7.133333,-44.866667
br,sao felix do paraguassu,São Felix do Paraguassu,05,,-12.633333,-38.966667
br,sao felix do piaui,São Félix do Piauí,20,,-5.933333,-42.116667
br,sao felix do tocantins,São Félix do Tocantins,31,,-10.177222,-46.541944
br,sao felix do xingu,São Félix do Xingu,16,16478,-6.633333,-51.983333
br,sao felix,São Félix,04,,-2.766667,-67.666667
br,sao felix,São Félix,05,,-12.633333,-38.966667
br,sao felix,São Felix,06,,-7.25,-38.766667
br,sao felix,São Félix,11,,-19.95,-55.2
br,sao felix,São Félix,13,,-3.876667,-42.896944
br,sao felix,São Félix,15,,-18.583333,-41.483333
br,sao felix,São Felix,16,,-6.633333,-51.983333
br,sao felix,São Félix,17,,-7.783333,-38.183333
br,sao felix,São Félix,18,,-24.980615,-48.914459
br,sao felix,São Félix,20,,-3.4,-42.016667
br,sao felix,São Félix,24,,-9.316667,-61.733333
br,sao felix,São Félix,29,,-13.55,-47.683333
br,sao felix,São Felix,30,,-7.483333,-39.566667
br,sao felix,São Félix,31,,-11.6,-50.65
br,sao feliz,São Feliz,05,,-12.633333,-38.966667
br,sao feliz,São Feliz,31,,-11.6,-50.65
br,sao fermino,São Fermino,04,,-5.033333,-60.3
br,sao fernando,São Fernando,13,,-3.598889,-43.418889
br,sao fernando,São Fernando,15,,-21.2,-42.45
br,sao fernando,São Fernando,22,,-6.366667,-37.183333
br,sao fidelis,São Fidélis,05,,-13.35,-39.133333
br,sao fidelis,São Fidélis,21,27793,-21.65,-41.733333
br,sao filipe,São Filipe,04,,.35,-67.316667
br,sao filipe,São Filipe,05,,-12.85,-39.1
br,sao filipe,São Filipe,06,,-7.466667,-39.05
br,sao filippe,São Filippe,05,,-14.816667,-41.383333
br,sao firmino,São Firmino,04,,-5.033333,-60.3
br,sao floriano,São Floriano,08,,-20.416667,-40.966667
br,sao fortunato,São Fortunato,20,,-7.366667,-41.633333
br,sao francisca da paulo,São Francisca da Paulo,23,,-29.45,-50.583333
br,sao francisco da 6a legua,São Francisco da 6a Légua,23,,-29.2072,-51.1319
br,sao francisco da gloria,São Francisco da Gloria,15,,-20.8,-42.266667
br,sao francisco da jararaca,São Francisco da Jararaca,16,,-1.666667,-49.4
br,sao francisco das chagas,São Francisco das Chagas,15,,-19.2,-46.25
br,sao francisco das chagas,São Francisco das Chagas,29,,-15.916667,-49.266667
br,sao francisco da sexta legua,São Francisco da Sexta Légua,23,,-29.2072,-51.1319
br,sao francisco de aguiar,São Francisco de Aguiar,17,,-7.083333,-38.183333
br,sao francisco de aruma,São Francisco de Arumã,04,,-4.7,-62.133333
br,sao francisco de assis,São Francisco de Assis,04,,-1.983333,-61.2
br,sao francisco de assis,São Francisco de Assis,23,14305,-29.55,-55.133333
br,sao francisco de goias,São Francisco de Goiás,29,,-15.916667,-49.266667
br,sao francisco de oliveira,São Francisco de Oliveira,15,,-20.716667,-44.983333
br,sao francisco de paula,São Francisco de Paula,15,,-20.716667,-44.983333
br,sao francisco de paula,São Francisco de Paula,23,13292,-29.45,-50.583333
br,sao francisco de sales,São Francisco de Sales,15,,-19.866667,-49.766667
br,sao francisco de salles,São Francisco de Salles,15,,-19.866667,-49.766667
br,sao francisco do aruma,São Francisco do Arumã,04,,-4.7,-62.133333
br,sao francisco do brasil,São Francisco do Brasil,08,,-19.116667,-40.516667
br,sao francisco do cajueiro,São Francisco do Cajueiro,05,,-13,-39.516667
br,sao francisco do castanhal,São Francisco do Castanhal,04,,-1.4975,-61.469444
br,sao francisco do conde,São Francisco do Conde,05,24615,-12.65,-38.683333
br,sao francisco do gloria,São Francisco do Glória,15,,-20.8,-42.266667
br,sao francisco do humaita,São Francisco do Humaitá,15,,-20.033333,-41.35
br,sao francisco do humayta,São Francisco do Humaytá,15,,-20.033333,-41.35
br,sao francisco do maranhao,São Francisco do Maranhão,13,,-6.25,-42.866667
br,sao francisco do piaui,São Francisco do Piauí,20,,-7.25,-42.533333
br,sao francisco do sul,São Francisco do Sul,23,,-28.783333,-50.8
br,sao francisco do sul,São Francisco do Sul,26,36225,-26.233333,-48.65
br,sao francisco do terere,São Francisco do Tereré,11,,-21.316667,-57.833333
br,sao francisco do uruburetama,São Francisco do Uruburetama,06,,-3.683333,-39.566667
br,sao francisco novo,São Francisco Novo,11,,-21.3,-57.516667
br,sao francisco novo,São Francisco Novo,16,,-4.816667,-54.466667
br,sao francisco,São Francisco,01,,-10.95,-69.633333
br,sao francisco,São Francisco,02,,-10.283333,-36.6
br,sao francisco,São Francisco,04,,-1.983333,-61.2
br,sao francisco,São Francisco,05,,-12.1,-42.183333
br,sao francisco,São Francisco,06,,-3.416667,-40.266667
br,sao francisco,São Francisco,08,,-18.75,-40.866667
br,sao francisco,São Francisco,11,,-18.383333,-57.366667
br,sao francisco,São Francisco,13,,-2.016667,-45.133333
br,sao francisco,São Francisco,15,33033,-15.95,-44.866667
br,sao francisco,São Francisco,16,,-1.116667,-49.766667
br,sao francisco,São Francisco,17,,-6.616667,-38.083333
br,sao francisco,São Francisco,18,,-24.9,-54.2
br,sao francisco,São Francisco,20,,-10.466667,-44.05
br,sao francisco,São Francisco,21,,-22.116667,-41.583333
br,sao francisco,São Francisco,22,,-5.116944,-36.51
br,sao francisco,São Francisco,23,,-28.783333,-50.8
br,sao francisco,São Francisco,25,,3.15,-61.133333
br,sao francisco,São Francisco,26,,-26.233333,-48.65
br,sao francisco,São Francisco,27,,-21.983333,-51.216667
br,sao francisco,São Francisco,28,,-10.35,-36.866667
br,sao francisco,São Francisco,29,,-14.483333,-47.083333
br,sao francisco,São Francisco,30,,-8.183333,-38.55
br,sao francisco,São Francisco,31,,-10.966667,-48.516667
br,sao francisco velho,São Francisco Velho,11,,-21.3,-57.55
br,sao francisco xavier,São Francisco Xavier,21,,-22.900207,-43.246462
br,sao francisco xavier,São Francisco Xavier,27,,-22.9,-45.966667
br,sao francisco xavier,São Francisco Xavier,29,,-17.133333,-48.6
br,sao franciso,São Franciso,21,,-22.7,-43.133333
br,sao gabriel da cachoeira,São Gabriel da Cachoeira,04,15232,-.133333,-67.083333
br,sao gabriel de goias,São Gabriel de Goiás,29,,-15.2,-47.566667
br,sao gabriel,São Gabriel,04,,-.133333,-67.083333
br,sao gabriel,São Gabriel,06,,-5.783333,-38.1
br,sao gabriel,São Gabriel,08,,-19.016667,-40.533333
br,sao-gabriel,São-Gabriel,08,,-20.9,-41.266667
br,sao gabriel,São Gabriel,15,,-18.783333,-40.983333
br,sao gabriel,São Gabriel,16,,-1.116667,-50.233333
br,sao gabriel,São Gabriel,23,55435,-30.333333,-54.316667
br,sao gabriel,São Gabriel,26,,-26.6,-49.783333
br,sao gabriel,São Gabriel,27,,-21.716667,-47.1
br,sao gaspar,São Gaspar,04,,-6.983333,-58.233333
br,sao geraldo da piedade,São Geraldo da Piedade,15,,-18.8,-42.333333
br,sao geraldo de tumiritinga,São Geraldo de Tumiritinga,15,,-18.966667,-41.833333
br,sao geraldo do araguaia,São Geraldo do Araguaia,16,12925,-6.4,-48.533333
br,sao geraldo do baixio,São Geraldo do Baixio,15,,-18.933333,-41.35
br,sao geraldo do central,São Geraldo do Central,15,,-18.75,-41.333333
br,sao geraldo do vieira,São Geraldo do Vieira,15,,-16.8,-43.883333
br,sao geraldo,São Geraldo,02,,-9.783333,-37.283333
br,sao geraldo,São Geraldo,05,,-12.133333,-40.366667
br,sao geraldo,São Geraldo,06,,-4.2,-38.8
br,sao geraldo,São Geraldo,15,,-16.8,-43.883333
br,sao geraldo,São Geraldo,16,,-5.433333,-54.366667
br,sao geraldo,São Geraldo,17,,-6.816667,-38.3
br,sao geraldo,São Geraldo,20,,-3.802778,-42.039444
br,sao geraldo,São Geraldo,22,,-5.277222,-37.450833
br,sao geraldo,São Geraldo,23,,-29.766667,-53.7
br,sao geraldo,São Geraldo,27,,-21.05,-47.75
br,sao geraldo,São Geraldo,29,,-16.5,-49.433333
br,sao gerardo,São Gerardo,06,,-4.2,-38.8
br,sao giacomo,São Giácomo,23,,-29.1656,-51.2331
br,sao goncala,São Gonçala,15,,-20.65,-43.866667
br,sao goncalo de baixo,São Gonçalo de Baixo,13,,-3.650278,-43.422222
br,sao goncalo do abaete,São Gonçalo do Abaeté,15,,-18.333333,-45.816667
br,sao goncalo do amarante,São Gonçalo do Amarante,06,23583,-3.6,-38.966667
br,sao goncalo do amarante,São Gonçalo do Amarante,22,10381,-5.766667,-35.333333
br,sao goncalo do monte,São Gonçalo do Monte,15,,-20.233333,-43.733333
br,sao goncalo do para,São Gonçalo do Pará,15,,-19.983333,-44.85
br,sao goncalo do piaui,São Gonçalo do Piauí,20,,-6,-42.7
br,sao goncalo do rio abaixo,São Gonçalo do Rio Abaixo,15,,-19.816667,-43.35
br,sao goncalo do rio acima,São Gonçalo do Rio Acima,15,,-20.016667,-43.533333
br,sao goncalo do rio da prata,São Gonçalo do Rio da Prata,15,,-18.4,-43.483333
br,sao goncalo do rio das pedras,São Gonçalo do Rio das Pedras,15,,-18.4,-43.483333
br,sao goncalo do sapucai,São Gonçalo do Sapucaí,15,19487,-21.9,-45.6
br,sao goncalo dos campos,São Gonçalo dos Campos,05,14822,-12.416667,-38.966667
br,sao goncalo,São Gonçalo,05,,-11.566667,-42.616667
br,sao goncalo,São Gonçalo,06,,-3.05,-40.3
br,sao goncalo,São Gonçalo,08,,-18.733333,-40.633333
br,sao goncalo,São Gonçalo,13,,-3.104444,-42.338333
br,sao goncalo,São Gonçalo,15,,-14.333333,-44.533333
br,sao goncalo,São Gonçalo,17,,-6.833333,-38.316667
br,sao goncalo,São Gonçalo,20,,-4.683333,-41.416667
br,sao goncalo,São Gonçalo,21,939101,-22.800278,-43.025556
br,sao goncalo,São Gonçalo,22,,-5.766667,-35.333333
br,sao goncalo,São Goncalo,30,,-7.516667,-39.766667
br,sao goncalves,São Gonçalves,08,,-20.216667,-41.316667
br,sao gondo,São Gondó,02,,-9.566667,-37.733333
br,sao gotardo,São Gotardo,15,34145,-19.316667,-46.05
br,sao gotardo,São Gotardo,23,,-29.0644,-51.0564
br,sao gothardo,São Gothardo,15,,-19.316667,-46.05
br,sao gregorio,São Gregório,16,,-1.783333,-47.483333
br,sao gregorio,São Gregório,25,,4.016667,-60.533333
br,sao gregorio,São Gregório,30,,-7.933333,-38.95
br,sao guilherme,São Guilherme,04,,-2.983333,-69.116667
br,sao guilherme,São Guilherme,27,,-22,-47.633333
br,sao ignacio,São Ignacio,05,,-11.1,-42.733333
br,sao izidio,São Izídio,22,,-5.25,-35.833333
br,sao jaco,São Jacó,23,,-29.0234,-51.0634
br,sao jeronimo da serra,São Jerônimo da Serra,18,,-23.7222,-50.7389
br,sao jeronimo dos pocoes,São Jerônimo dos Poções,15,,-19.55,-46.2
br,sao jeronimo,São Jerônimo,04,,-3.616667,-69.416667
br,sao jeronimo,São Jerônimo,06,,-4.066667,-38.7
br,sao jeronimo,São Jerônimo,11,,-19.883333,-55.233333
br,sao jeronimo,São Jerônimo,14,,-17.366667,-57.083333
br,sao jeronimo,São Jerônimo,18,,-23.7222,-50.7389
br,sao jeronimo,São Jerônimo,23,17057,-29.966667,-51.716667
br,sao jeronimo,São Jerônimo,25,,3.683333,-60.966667
br,sao jeronimo,São Jerônimo,27,,-20.866667,-47.916667
br,sao jeronimo,São Jerônimo,29,,-18.683333,-50.25
br,sao jeronimo,São Jerônimo,30,,-7.816667,-38
br,sao jeronymo do pocoes,São Jeronymo do Poções,15,,-19.55,-46.2
br,sao jeronymo,São Jeronymo,04,,-3.616667,-69.416667
br,sao jeronymo,São Jeronymo,18,,-23.7222,-50.7389
br,sao jeronymo,São Jeronymo,23,,-29.966667,-51.716667
br,sao jeronymo,São Jeronymo,27,,-21.066667,-49.983333
br,sao joao abaixo,São João Abaixo,26,,-25.9969,-48.819
br,sao joao baptista da gloria,São João Baptista da Gloria,15,,-20.633333,-46.5
br,sao joao baptista de serra de canastra,São João Baptista de Serra de Canastra,15,,-20.133333,-46.65
br,sao joao baptista do arrozal,São João Baptista do Arrozal,21,,-22.616667,-44.05
br,sao joao baptista,São João Baptista,15,,-20.766667,-44.583333
br,sao joao baptista,São João Baptista,23,,-28.05,-51.2
br,sao joao baptista,São João Baptista,26,,-27.266667,-48.833333
br,sao joao batista da serra da canastra,São João Batista da Serra da Canastra,15,,-20.133333,-46.65
br,sao joao batista do gloria,São João Batista do Glória,15,,-20.633333,-46.5
br,sao joao batista do meia ponte,São João Batista do Meia Ponte,29,,-16.433333,-49.383333
br,sao joao batista,São João Batista,13,3634,-2.966667,-44.85
br,sao joao batista,São João Batista,15,,-20.766667,-44.583333
br,sao joao batista,São João Batista,26,14539,-27.266667,-48.833333
br,sao joao bosco,São João Bosco,17,,-6.383333,-38.55
br,sao joao curaba,São João Curaba,04,,-.45,-63.566667
br,sao joao da alianca,São João da Aliança,29,,-14.7,-47.533333
br,sao joao da barra,São João da Barra,21,20606,-21.633333,-41.05
br,sao joao da boa vista,São João da Boa Vista,27,76541,-21.966667,-46.783333
br,sao joao da chapada,São João da Chapada,15,,-18.083333,-43.783333
br,sao joao da dourado,São João da Dourado,27,,-22.116667,-48.3
br,sao joao da esperanca,São João da Esperança,26,,-26.635644,-49.527222
br,sao joao da figueira,São João da Figueira,15,,-20.116667,-41.8
br,sao joao da fortaleza,São João da Fortaleza,05,,-10.55,-38.6
br,sao joao da graciosa,São João da Graciosa,18,,-25.386952,-48.859398
br,sao joao da lagoa,São João da Lagoa,15,,-16.033333,-43.883333
br,sao joao da lapa,São João da Lapa,27,,-22.4,-47.783333
br,sao joao da mata,São João da Mata,15,,-21.933333,-45.933333
br,sao joao da mata,São João da Mata,22,,-5.323056,-36.663611
br,sao joao da ocalina,São João da Ocalina,18,,-24.033333,-51.866667
br,sao joao da parnahiba,São Joao da Parnahiba,20,,-2.909167,-41.774722
br,sao joao da passagem,São João da Passagem,20,,-5.5,-41.916667
br,sao joao da ponta,São João da Ponta,16,,-.833333,-47.916667
br,sao joao da ponte,São João da Ponte,15,8373,-15.933333,-44.016667
br,sao joao da prata,São João da Prata,15,,-16.233333,-40.933333
br,sao joao da sapucaia,São João da Sapucaia,15,,-21.283333,-42.433333
br,sao joao das duas pontas,São João das Duas Pontas,27,,-20.416667,-50.366667
br,sao joao das duas pontes,São João das Duas Pontes,27,,-20.416667,-50.366667
br,sao joao da serra negra,São João da Serra Negra,15,,-18.833333,-46.783333
br,sao joao da serra,São João da Serra,15,,-21.466667,-43.45
br,sao joao da serra,São João da Serra,20,,-5.5,-41.916667
br,sao joao das pitas,São João Das Pitas,27,,-23.079722,-46.556389
br,sao joao da terra alta,São João da Terra Alta,08,,-19.433333,-40.383333
br,sao joao da urtiga,São João da Urtiga,23,,-27.783333,-51.816667
br,sao joao da vacaria,São João da Vacaria,15,,-16.533333,-42.4
br,sao joao da vajota,São João da Vajota,20,,-6.85,-41.35
br,sao joao da varjota,São João da Varjota,20,,-6.916667,-41.85
br,sao joao da vereda,São João da Vereda,15,,-16.700278,-44.114722
br,sao joao da vila nova,São João da Vila Nova,05,,-14.6,-41.133333
br,sao joao de alegria,São João de Alegria,15,,-19.983333,-41.866667
br,sao joao de amatary,São João de Amatary,04,,-3.266667,-58.883333
br,sao joao de barra,São Joao De Barra,21,,-21.633333,-41.05
br,sao joao de camaquam,São João de Camaquam,23,,-30.85,-51.816667
br,sao joao de campos,São João de Campos,30,,-8.1,-38.733333
br,sao joao de cima,São João de Cima,26,,-26.616667,-50.966667
br,sao joao de cortes,São João de Côrtes,13,,-2.2,-44.533333
br,sao joao de iracema,São João de Iracema,27,,-20.5,-50.35
br,sao joao de itaguacu,São João de Itaguaçu,27,,-21.183333,-49.2
br,sao joao de itatinga,São João de Itatinga,27,,-23.116667,-48.6
br,sao joao del rei,São João del Rei,15,78593,-21.15,-44.266667
br,sao joao de manteninha,São João de Manteninha,15,,-18.716667,-41.166667
br,sao joao de marauhia,São João de Marauhiá,04,,-.4,-65.266667
br,sao joao de marauia,São João de Marauiá,04,,-.4,-65.266667
br,sao joao de meriti,São João de Meriti,21,454855,-22.798614,-43.360894
br,sao joao de muquy,São João de Muquy,08,,-20.95,-41.3
br,sao joao de pau d'alho,Sao Joao de Pau d'Alho,27,,-21.266667,-51.666667
br,sao joao de petropolis,São João de Petrópolis,08,,-19.816667,-40.666667
br,sao joao de pirabas,São João de Pirabas,16,10065,-.766667,-47.166667
br,sao joao de sabugy,São João de Sabugy,22,,-6.716667,-37.2
br,sao joao de serra,São João de Serra,15,,-21.466667,-43.45
br,sao joao de sul,São João de Sul,05,,-16.5,-39.916667
br,sao joao de uruburetama,São João de Uruburetama,06,,-3.633333,-39.5
br,sao joao de vicosa,São João de Viçosa,08,,-20.333333,-41.183333
br,sao joao de vigia,São João de Vigia,15,,-16.183333,-40.7
br,sao joao do alipio,São João do Alipio,05,,-14.7,-41.666667
br,sao joao do amanari,São João do Amanari,06,,-4.016667,-38.883333
br,sao joao do araguaia,São João do Araguaia,16,,-5.383333,-48.766667
br,sao joao do araguaya,São João do Araguaya,16,,-5.383333,-48.766667
br,sao joao do barro vermelho,São João do Barro Vermelho,30,,-8.166667,-38.233333
br,sao joao do bonito,São João do Bonito,15,,-15.316667,-42.833333
br,sao joao do cacipore,São João do Caciporé,03,,3.433333,-51.166667
br,sao joao do caiua,São João do Caiuá,18,,-22.8,-52.366667
br,sao joao do canastrao,São João do Canastrão,15,,-18.566667,-45.75
br,sao joao do capim,São João do Capim,15,,-19.716667,-41.25
br,sao joao do cariri,São João do Cariri,17,,-7.383333,-36.516667
br,sao joao do cariry,São João do Cariry,17,,-7.383333,-36.516667
br,sao joao do cassipore,São João do Cassiporé,03,,3.433333,-51.166667
br,sao joao do chapada,São João do Chapada,15,,-18.083333,-43.783333
br,sao joao do grajau,São João do Grajaú,13,,-4.266667,-45.35
br,sao joao do guapore,São João do Guaporé,14,,-15.977778,-59.886111
br,sao joao do itaguacu,São João do Itaguaçu,27,,-21.183333,-49.2
br,sao joao do itaperiu,São João do Itaperiú,26,,-26.6058,-48.737
br,sao joao do itatinga,São João do Itatinga,27,,-23.116667,-48.6
br,sao joao do jaboti,São João do Jaboti,08,,-20.633333,-40.583333
br,sao joao do jabuti,São João do Jabuti,08,,-20.633333,-40.583333
br,sao joao do jacutinga,São João do Jacutinga,15,,-19.733333,-41.916667
br,sao joao do jaguaribe,São João do Jaguaribe,06,,-5.266667,-38.266667
br,sao joao do javaes,São João do Javaés,31,,-11.752778,-49.874722
br,sao joao do largo,São João do Largo,08,,-21.05,-41.133333
br,sao joao do manhuacu,São João do Manhuaçu,15,,-20.383333,-42.15
br,sao joao do manteninha,São João do Manteninha,15,,-18.716667,-41.166667
br,sao joao do marinheiro,São João do Marinheiro,27,,-20.033333,-50.05
br,sao joao do matipo,São João do Matipo,15,,-20.283333,-42.35
br,sao joao do monte negro,São João do Monte Negro,23,,-29.7,-51.466667
br,sao-joao-do-muqui,São-Joao-do-Muqui,08,,-20.95,-41.3
br,sao joao do norte,São João do Norte,15,,-20.533333,-42.1
br,sao joao do oriente,São João do Oriente,15,,-19.35,-42.15
br,sao joao do pacui,São João do Pacuí,15,,-16.530556,-44.508333
br,sao joao do paraiso,São João do Paraíso,15,8859,-15.316667,-42.016667
br,sao joao do paraiso,São João do Paraíso,21,,-21.416667,-41.833333
br,sao joao do paraizo,São João do Paraizo,15,,-15.316667,-42.016667
br,sao joao do parana,São João do Paraná,16,,-9.016667,-57.133333
br,sao joao do parauna,São João do Paraúna,15,,-18.633333,-43.766667
br,sao joao do pau d'alho,Sao Joao do Pau d'Alho,27,,-21.266667,-51.666667
br,sao joao do piauhy,São Joao Do Piauhy,20,,-8.35,-42.25
br,sao joao do piaui,São João do Piauí,20,12689,-8.35,-42.25
br,sao joao do pirangi,São João do Pirangi,06,,-4.583333,-38.35
br,sao joao do pracajuba,São João do Pracajuba,16,,-1.833333,-51.35
br,sao joao do rio do peixe,São João do Rio do Peixe,17,,-6.733333,-38.45
br,sao joao do rio vermelho,São João do Rio Vermelho,26,,-27.466667,-48.416667
br,sao joao do sabugi,São João do Sabugi,22,,-6.716667,-37.2
br,sao-joao-do-sabuji,São-João-do-Sabuji,22,,-6.716667,-37.2
br,sao joao do sarapui,São João do Sarapuí,27,,-23.6309,-47.8251
br,sao joao dos coelhos,São João dos Coelhos,21,,-22.033333,-42.45
br,sao joao dos inhamuns,São João dos Inhamuns,06,,-6,-40.283333
br,sao joao dos missoes,São João dos Missões,15,,-14.883333,-44.083333
br,sao joao dos morros,São João dos Morros,13,,-3.288056,-42.745833
br,sao joao do sobrado,São João do Sobrado,08,,-18.333333,-40.366667
br,sao joao dos patos,São João dos Patos,13,19539,-6.5,-43.7
br,sao joao dos paulistas,São João dos Paulistas,15,,-18.416667,-42.866667
br,sao joao dos poieiros,São João dos Poieiros,13,,-5.1,-43.85
br,sao joao dos poleiros,São João dos Poleiros,13,,-5.1,-43.85
br,sao joao dos pombos,São João dos Pombos,30,,-8.15,-35.4
br,sao joao do sul,São João do Sul,26,,-29.216667,-49.8
br,sao joao do tigre,São Joao do Tigre,17,,-8.066667,-36.866667
br,sao joao do triumpho,São João do Triumpho,18,,-25.683,-50.2974
br,sao joao do triunfo,São João do Triunfo,18,,-25.683,-50.2974
br,sao joao evangelista,São João Evangelista,15,10049,-18.533333,-42.75
br,sao joao evengelista,São João Evengelista,29,,-13.633333,-46.316667
br,sao joao gazeta,São João Gazeta,27,,-23.379855,-46.708904
br,sao joao grande,São João Grande,15,,-16.683333,-41.5
br,sao joao marcos,São João Marcos,21,,-22.9,-43.966667
br,sao joao nepomuceno,São João Nepomuceno,15,23155,-21.55,-43.016667
br,sao joao novo,São João Novo,01,,-9.1,-72.666667
br,sao joao novo,São João Novo,27,,-23.523345,-47.039745
br,sao joao,São João,01,,-9.1,-72.666667
br,sao joao,São João,04,,-1.460278,-61.487778
br,sao joao,São João,05,,-11.933333,-39.216667
br,sao joao,São João,06,,-3.116667,-40.416667
br,sao joao,São João,08,,-20.65,-40.866667
br,sao joao,São João,11,,-18.333333,-55.883333
br,sao joao,São João,13,,-2.216667,-45.05
br,sao joao,São João,14,,-14.1,-56.366667
br,sao joao,São João,15,,-15.866667,-40.85
br,sao joao,São João,16,,-1.6,-52.966667
br,sao joao,São João,17,,-6.85,-35.25
br,sao joao,São João,18,,-23.866667,-53.816667
br,sao joao,São João,20,,-10.3,-44.133333
br,sao joao,São João,21,,-21.283333,-41.583333
br,sao joao,Sâo João,22,,-5.166667,-35.966667
br,sao joao,São João,23,,-27.783333,-51.816667
br,sao joao,São João,24,,-10.35,-63.45
br,sao joao,São João,26,,-26.166667,-50.15
br,sao joao,São João,27,,-20.983333,-47.833333
br,sao joao,São João,29,,-13.633333,-46.316667
br,sao joao,São João,30,6926,-8.866667,-36.366667
br,sao joao,São João,31,,-10.1,-48.866667
br,sao joao terra alta,São João Terra Alta,08,,-19.433333,-40.383333
br,sao joao vermelho,São João Vermelho,20,,-8.633333,-42.483333
br,sao joaozinho felix,São Joãozinho Felix,18,,-25.467515,-48.754698
br,sao joaquim da barra,São Joaquim da Barra,27,42720,-20.583333,-47.883333
br,sao joaquim da costa da serra,São Joaquim da Costa da Serra,26,,-28.3,-49.933333
br,sao joaquim das botas,São Joaquim das Botas,04,,-6.984722,-62.812778
br,sao joaquim de bicas,São Joaquim de Bicas,15,14630,-20.05,-44.283333
br,sao joaquim do catupi,São Joaquim do Catupi,23,,-29.633333,-51.733333
br,sao joaquim do matao,São Joaquim do Matão,18,,-23.881655,-50.042002
br,sao joaquim do monte,São Joaquim do Monte,30,13520,-8.416667,-35.85
br,sao joaquim do pomtal,São Joaquim do Pomtal,18,,-22.966667,-50.466667
br,sao joaquim do pontal,São Joaquim do Pontal,18,,-22.966667,-50.466667
br,sao joaquim do salgado,São Joaquim do Salgado,06,,-5.416667,-39.583333
br,sao joaquim dos baetas,São Joaquim dos Baetas,04,,-6.984722,-62.812778
br,sao joaquim dos melos,São Joaquim dos Melos,13,,-5.8,-44.733333
br,sao joaquim mirim,São Joaquim Mirim,04,,1.483333,-68.233333
br,sao joaquim,São Joaquim,02,,-9.966667,-36.633333
br,sao joaquim,São Joaquim,03,,.433333,-50.9
br,sao joaquim,São Joaquim,04,,.016667,-67.266667
br,sao joaquim,São Joaquim,05,,-14.65,-42.316667
br,sao-joaquim,São-Joaquim,05,,-14.766667,-39.45
br,sao joaquim,São Joaquim,06,,-3.733333,-39.7
br,sao joaquim,São Joaquim,11,,-19.233333,-56.666667
br,sao joaquim,São Joaquim,13,,-1.7,-45.1
br,sao joaquim,São Joaquim,14,,-14.7,-55.583333
br,sao joaquim,São Joaquim,15,,-15.483333,-45.15
br,sao joaquim,São Joaquim,16,,-1.116667,-49.75
br,sao joaquim,São Joaquim,17,,-6.8,-37.7
br,sao joaquim,São Joaquim,20,,-5.733333,-42.983333
br,sao joaquim,São Joaquim,21,,-21.466667,-41.5
br,sao joaquim,São Joaquim,22,,-5.2325,-36.864167
br,sao joaquim,São Joaquim,23,,-29.633333,-51.733333
br,sao joaquim,São Joaquim,24,,-9.616667,-63.133333
br,sao joaquim,São Joaquim,25,,3.833333,-61.466667
br,sao joaquim,São Joaquim,26,16250,-28.3,-49.933333
br,sao joaquim,São Joaquim,27,,-20.583333,-47.883333
br,sao joaquim,São Joaquim,30,,-8.416667,-35.85
br,sao joaquin,São Joaquin,04,,-.383333,-64.033333
br,sao joazinho,São Joãzinho,17,,-7.683333,-36.616667
br,sao jorge d'oeste,Sao Jorge d'Oeste,18,,-25.666667,-52.916667
br,sao jorge do ivai,São Jorge do Ivaí,18,,-23.4,-52.283333
br,sao jorge dos ilheos,São Jorgé dos Ilhéos,05,,-14.816667,-39.033333
br,sao jorge,São Jorge,01,,-9.583333,-71.766667
br,sao jorge,São Jorge,04,,-3.108889,-60.041111
br,sao jorge,São Jorge,05,,-13.416667,-39.416667
br,sao jorge,São Jorge,06,,-4.866667,-39.85
br,sao jorge,São Jorge,16,,-1.283333,-47.583333
br,sao jorge,São Jorge,18,,-23.4,-52.283333
br,sao jorge,São Jorge,21,,-22.725354,-43.398056
br,sao jorge,São Jorge,23,,-28.5,-51.7
br,sao jorge,São Jorge,26,,-26.7,-53.4
br,sao jorge,São Jorge,27,,-22.116667,-51.566667
br,sao-jose-cocais,São-José-Cocais,14,,-15.8,-56.366667
br,sao jose da antinha,São José da Antinha,15,,-19.333333,-47.016667
br,sao jose da barra,São José da Barra,15,,-20.716667,-46.133333
br,sao jose da bela vista,São José da Bela Vista,27,,-20.6,-47.666667
br,sao jose da bella vista,São José da Bella Vista,27,,-20.6,-47.666667
br,sao jose da boa vista,São José da Boa Vista,18,,-23.9,-49.65
br,sao jose da boa vista,São José da Boa Vista,27,,-20.6,-47.666667
br,sao jose da casa nova,São José da Casa Nova,05,,-9.416667,-41.133333
br,sao jose da catinga,São José da Catinga,28,,-10.633333,-36.933333
br,sao jose da coroa grande,São José da Coroa Grande,30,11512,-8.9,-35.15
br,sao jose da figueira,São José da Figueira,15,,-20.15,-41.85
br,sao jose da fortuna,São José da Fortuna,15,,-18.016667,-41.833333
br,sao jose da fruteira,São José da Fruteira,08,,-20.616667,-41.033333
br,sao jose da gameleira,São José da Gameleira,05,,-14.483333,-42.683333
br,sao jose da ingazeira,São José da Ingàzeira,30,,-7.466667,-37.266667
br,sao jose da lage,São José da Lage,02,,-9,-36.033333
br,sao jose da lagoa,São José da Lagôa,15,,-19.75,-43.05
br,sao jose da lagoa tapada,São José da Lagoa Tapada,17,,-6.95,-38.166667
br,sao jose da laje,São José da Laje,02,12811,-9,-36.033333
br,sao jose da mata ou queimadas,São José da Mata ou Queimadas,22,,-5.35,-35.866667
br,sao jose da mata,São José da Mata,05,,-12.55,-38.3
br,sao jose da mata,São José da Mata,17,,-7.216667,-35.916667
br,sao jose danazaria,São José Danazária,04,,-3.837222,-62.671111
br,sao jose da passagem,São José da Passagem,22,,-5.872778,-36.435833
br,sao jose da pedra menina,São José da Pedra Menina,15,,-20.583333,-41.816667
br,sao jose da pedra,São José da Pedra,15,,-20.583333,-41.816667
br,sao jose da safira,São José da Safira,15,,-18.333333,-42.166667
br,sao jose das aguas belas,São José das Aguas Belas,15,,-17.083333,-40.95
br,sao jose das creoulas,São José das Creoulas,14,,-15.116667,-57.6
br,sao jose das crioulas,São José das Crioulas,14,,-15.116667,-57.6
br,sao jose da serra,São José da Serra,14,,-15.666667,-55.3
br,sao jose das lontras,São José das Lontras,06,,-4.566667,-40.966667
br,sao jose da soledade,São José da Soledade,15,,-21.1,-43.166667
br,sao jose das palmeiras,São José das Palmeiras,27,,-22.55,-47.2
br,sao jose das panelas,São José das Panelas,30,,-8.7,-36.133333
br,sao jose das perobas,São José das Perobas,15,,-19.266667,-45.9
br,sao jose das pombas,São José das Pombas,17,,-7.316667,-36.65
br,sao jose das queimadas,São José das Queimadas,30,,-7.466667,-37.266667
br,sao jose das torres,São José das Tôrres,08,,-21.083333,-41.233333
br,sao jose das tronqueiras,São José das Tronqueiras,15,,-18.716667,-42.3
br,sao jose da tapera,São José da Tapera,02,12392,-9.633333,-37.383333
br,sao jose da varginha,São José da Varginha,15,,-19.716667,-44.566667
br,sao jose da villa nova,São José da Villa Nova,05,,-14.6,-41.133333
br,sao jose de anaua,São José de Anauá,25,,.961111,-61.374444
br,sao jose de baixo,São José de Baixo,05,,-17.033333,-39.6
br,sao jose de baraunas,São José de Baraúnas,30,,-9.05,-36.533333
br,sao jose de calheiro,São José de Calheiro,15,,-18.533333,-44.083333
br,sao jose de cambira,São José de Cambira,18,,-23.6,-51.566667
br,sao jose de canastrao,São José de Canastrão,15,,-18.566667,-45.75
br,sao jose de cuxo,São José de Cuxo,04,,-6.201389,-60.259444
br,sao jose de espinharas,São José de Espinharas,17,,-6.85,-37.316667
br,sao jose de figueira,São José de Figueira,15,,-20.116667,-41.783333
br,sao jose de gaiana,São Jose de Gaiana,17,,-7.25,-38.3
br,sao jose de gurupi,São José de Gurupi,16,,-1.6,-46.216667
br,sao jose de itapororocas,São José de Itapororocas,05,,-12.133333,-39.033333
br,sao jose de jamimbu,São José de Jamimbú,29,,-13.683333,-50.8
br,sao jose de lagoa tapada,São José de Lagoa Tapada,17,,-6.95,-38.166667
br,sao jose del rey,São José del Rey,15,,-21.15,-44.266667
br,sao jose de mipibu,São José de Mipibu,22,15317,-6.083333,-35.25
br,sao jose de pedra menina,São José de Pedra Menina,15,,-20.583333,-41.816667
br,sao jose de piranhas,São José de Piranhas,17,7628,-7.116667,-38.5
br,sao jose de ribamar,São José de Ribamar,13,27777,-2.55,-44.05
br,sao jose de serido,São José de Seridó,22,,-6.45,-36.883333
br,sao jose de sirigi,São José de Sirigí,30,,-7.6,-35.483333
br,sao jose de tocantins,Sao Jose De Tocantins,29,,-14.45,-48.45
br,sao jose de uba,São José de Ubá,21,,-21.35,-41.95
br,sao jose do acacio,São José do Acácio,15,,-19.083333,-41.983333
br,sao jose do acarai,São José do Acaraí,26,,-26.2706,-48.6073
br,sao jose do alegre,São José do Alegre,15,,-22.316667,-45.533333
br,sao jose do ananha,São José do Ananha,15,,-19.333333,-47.016667
br,sao jose do anaua,São José do Anauá,25,,.961111,-61.374444
br,sao jose do apora,São José do Aporá,05,,-12.616667,-39.166667
br,sao jose do araguaia,São José do Araguaia,29,,-13.683333,-50.8
br,sao jose do araguaya,São José do Araguaya,29,,-13.683333,-50.8
br,sao jose do aterrado,São José do Aterrado,13,,-4.25,-45.633333
br,sao jose do barreiro,São José do Barreiro,15,,-20.333333,-46.483333
br,sao jose do barreiro,São José do Barreiro,27,,-22.633333,-44.583333
br,sao jose do barreto,São José do Barreto,21,,-22.333333,-41.75
br,sao jose do barroso,São José do Barroso,15,,-20.883333,-42.966667
br,sao jose do belmonte,São José do Belmonte,30,14211,-7.866667,-38.766667
br,sao jose do bomfim,São José Do Bomfim,17,,-7.166667,-37.3
br,sao jose do bom jardim,São José do Bom Jardim,21,,-22.718333,-43.851389
br,sao jose do bugre,São José do Bugre,15,,-19.366667,-42.2
br,sao jose do buranhem,São José do Buranhém,05,,-16.533333,-40.066667
br,sao jose do buriti,São José do Buriti,15,,-18.75,-45.15
br,sao jose do calcado,São José do Calçado,08,7442,-21.033333,-41.666667
br,sao jose do camaru,São José do Camaru,22,,-5.15,-35.783333
br,sao jose do cambira,São José do Cambira,18,,-23.6,-51.566667
br,sao jose do campestre,São José do Campestre,22,10254,-6.3,-35.7
br,sao jose do campo formoso,São José do Campo Formoso,05,,-8.8,-41.283333
br,sao jose do capim,São José do Capim,18,,-23.616667,-51.2
br,sao jose do cedro,São José do Cedro,26,,-26.5,-53.5
br,sao jose do centro,São José do Centro,23,,-28.4,-52.683333
br,sao jose do cerrito,São José do Cerrito,26,,-27.666667,-50.583333
br,sao jose do corrego d'anta,Sao Jose do Corrego d'Anta,15,,-19.8,-45.9
br,sao jose do divino,São José do Divino,15,,-18.483333,-41.416667
br,sao jose do duro,São José do Duro,31,,-11.700556,-46.743056
br,sao jose do egito,São José do Egito,30,18219,-7.466667,-37.266667
br,sao jose do egypto,São José do Egypto,30,,-7.466667,-37.266667
br,sao jose do erval,São José do Erval,23,,-29.033333,-52.3
br,sao jose do garrote,São José do Garrote,30,,-8.416667,-36.166667
br,sao jose do goiabal,São José do Goiabal,15,,-19.933333,-42.7
br,sao jose do gorutuba,São José do Gorutuba,15,,-15.833333,-43.2
br,sao jose do gurupi,São José do Gurupi,16,,-1.6,-46.216667
br,sao jose do hortencio,São José do Hortêncio,23,,-29.533333,-51.266667
br,sao jose do inhacora,São José do Inhacorá,23,,-27.716667,-54.133333
br,sao jose do itamonte,São José do Itamonte,15,,-22.283333,-44.883333
br,sao jose do jacem,São José do Jaçém,15,,-18.85,-43.366667
br,sao jose do jacuipe,São José do Jacuípe,05,,-11.5,-40.033333
br,sao jose do jacuri,São José do Jacuri,15,,-18.266667,-42.666667
br,sao jose do jacury,São José do Jacury,15,,-18.266667,-42.666667
br,sao jose do jassen,São José do Jassén,15,,-18.85,-43.366667
br,sao jose do javary,São José do Javary,04,,-4.3725,-69.749722
br,sao jose do juma,São José do Juma,04,,-5.361111,-60.440278
br,sao jose do lajeadao,São José do Lajeadão,15,,-16.216667,-40.283333
br,sao jose do limoeiro,São José do Limoeiro,15,,-19.583333,-41.366667
br,sao jose do macapa,São José do Macapá,21,,-21.85,-41.966667
br,sao jose do mantimento,São José do Mantimento,15,,-20,-41.733333
br,sao jose do martyrios,São José do Martyrios,31,,-6.333333,-48.366667
br,sao jose do mipibu,Sao Jose Do Mipibu,22,,-6.083333,-35.25
br,sao jose do miriti,São José do Miriti,04,,-3.926111,-62.9375
br,sao jose do norte,São José do Norte,23,,-32.016667,-52.05
br,sao jose do olho d'agua,Sao Jose do Olho D'agua,20,,-5.933333,-42.233333
br,sao jose do ouro,São José do Ouro,23,,-27.733333,-51.583333
br,sao jose do pampan,São José do Pampan,15,,-16.9,-40.933333
br,sao jose do paraopeba,São José do Paraopeba,15,,-20.25,-44.133333
br,sao jose do patrocinio,São José do Patrocinio,23,,-30.866667,-52.25
br,sao jose do peixe,São José do Peixe,15,,-19.533333,-41.816667
br,sao jose do peixe,São José do Peixe,20,,-7.4,-42.566667
br,sao jose do peruipe,São José do Peruípe,05,,-17.816667,-39.5
br,sao jose do piaui,São José do Piauí,20,,-6.866667,-41.466667
br,sao jose do picu,São José do Picú,15,,-22.283333,-44.883333
br,sao jose do piquiri,São José do Piquiri,11,,-17.3,-56.466667
br,sao jose do piria,São José do Piriá,16,,-1.283333,-46.3
br,sao jose do prado,São José do Prado,05,,-17.133333,-40.016667
br,sao jose do prata,São José do Prata,15,,-16.233333,-40.933333
br,sao jose do queimado,São José do Queimado,08,,-20.15,-40.383333
br,sao jose do ribamar,São José do Ribamar,04,,-6.773056,-70.869722
br,sao-jose-do-ribamar,São-José-do-Ribamar,13,,-2.55,-44.05
br,sao jose do ribeirao,São José do Ribeirão,21,,-22.2,-42.4
br,sao jose do rio dos veados,São José do Rio dos Veados,08,,-20.6,-40.683333
br,sao jose do rio negrinho,São José do Rio Negrinho,11,,-19.1,-54.916667
br,sao jose do rio pardo,São José do Rio Pardo,27,46990,-21.6,-46.9
br,sao jose do rio preto,São José do Rio Prêto,21,,-22.166667,-42.95
br,sao jose do rio preto,São José do Rio Prêto,27,374706,-20.8,-49.383333
br,sao jose do sabugi,São José do Sabugi,17,,-6.766667,-36.8
br,sao jose do sambito,São José do Sambito,20,,-6.566667,-41.316667
br,sao jose dos botelhos,São José dos Botelhos,15,,-21.65,-46.4
br,sao jose dos brasilios,São José dos Brasílios,13,,-5.05,-44.633333
br,sao jose dos campos,São José dos Campos,15,,-22.166667,-45.1
br,sao jose dos campos,São José dos Campos,27,613776,-23.183333,-45.883333
br,sao jose dos canos,São José dos Canos,13,,-4.916667,-44.816667
br,sao jose dos cocais,São José dos Cocais,14,,-15.8,-56.366667
br,sao jose dos cordeiros,São José dos Cordeiros,17,,-7.383333,-36.8
br,sao jose do serido,São José do Seridó,22,,-6.45,-36.883333
br,sao jose do serrito,São José do Serrito,26,,-27.666667,-50.583333
br,sao jose dos guerra,São José dos Guerra,06,,-4.716667,-39.716667
br,sao jose do sirigy,São José do Sirigy,30,,-7.6,-35.483333
br,sao jose dos lopes,São José dos Lopes,15,,-21.8,-43.883333
br,sao jose dos martirios,São José dos Martírios,31,,-6.333333,-48.366667
br,sao jose dos matoes,São Jose dos Matões,13,,-5.516667,-43.2
br,sao jose dos mattoes,Sao José Dos Mattoes,13,,-5.516667,-43.2
br,sao jose dos orfaos,São José dos Órfãos,20,,-3.8575,-42.431944
br,sao jose dos patos,São José dos Patos,13,,-5.75,-43.283333
br,sao jose dos paulistas,São José dos Paulistas,15,,-18.416667,-42.866667
br,sao jose dos pinhaes,São José dos Pinhaes,18,,-25.516667,-49.216667
br,sao jose dos pinhais,São José dos Pinhais,18,229988,-25.516667,-49.216667
br,sao jose dos salgados,São José dos Salgados,15,,-20.083333,-44.766667
br,sao jose do tocantins,São José do Tocantins,29,,-14.45,-48.45
br,sao jose do triunfo,São José do Triunfo,15,,-20.75,-42.816667
br,sao jose do turvo,São José do Turvo,21,,-22.35,-43.983333
br,sao jose espinharas,São José Espinharas,17,,-6.85,-37.316667
br,sao jose ii,São José II,13,,-3.393333,-43.016389
br,sao jose i,São José I,13,,-3.395833,-43.043611
br,sao jose,São José,01,,-9.4,-68.733333
br,sao jose,São José,02,,-9.65,-36.166667
br,sao jose,São José,04,,-3.588056,-62.989722
br,sao jose,São José,05,,-10.683333,-44.1
br,sao jose,São José,06,,-3.016667,-40.4
br,sao jose,São José,08,,-18.75,-40.516667
br,sao jose,São José,11,,-17.366667,-56.8
br,sao jose,São José,13,,-3.0075,-42.988056
br,sao jose,São José,14,,-14.45,-55.666667
br,sao jose,São José,15,,-17.883333,-40.916667
br,sao jose,São José,16,,-1.466667,-48.683333
br,sao jose,São José,17,,-6.183333,-37.283333
br,sao jose,São José,18,,-22.716667,-53.166667
br,sao-jose,São-José,18,,-23.116667,-51.55
br,sao jose,São José,18,,-23.268565,-50.226345
br,sao jose,São José,20,,-3.616667,-42.616667
br,sao jose,São José,21,,-21.416667,-41.35
br,sao jose,São José,22,,-5.133333,-35.566667
br,sao jose,São José,23,,-27.616667,-54.666667
br,sao jose,São José,24,,-10.15,-63.066667
br,sao jose,São José,25,,2.933333,-60.533333
br,sao jose,São José,26,203142,-27.633333,-48.65
br,sao jose,São José,27,,-20.2,-47.383333
br,sao jose,São José,28,,-10.633333,-36.933333
br,sao jose,São José,29,,-13.683333,-50.8
br,sao jose,São José,30,,-8.070833,-34.883333
br,sao jose,São José,31,,-10.35,-48.983333
br,sao jose taquarucu,São José Taquaruçu,11,,-20.716667,-56.516667
br,sao judas tadeu,São Judas Tadeu,18,,-23.520979,-50.672217
br,sao juliao,São Julião,15,,-20.433333,-43.783333
br,sao juliao,São Julião,20,,-7.083333,-40.833333
br,sao julio,São Júlio,13,,-5.433333,-43.233333
br,sao julio,São Julio,16,,-2.35,-56.333333
br,sao laurenco,São Laurenco,25,,3.480786,-59.875864
br,sao leocadia,São Leocádia,18,,-26.066667,-50.583333
br,sao leopoldo,São Leopoldo,04,,-7.516667,-72.55
br,sao leopoldo,São Leopoldo,23,209233,-29.766667,-51.15
br,sao lidio,São Lídio,26,,-26.8,-48.65
br,sao longuilho,Sao Longuilho,04,,-3.583333,-59.133333
br,sao lorentino,São Lorentino,01,,-8.283333,-73.2
br,sao lourenco da mata,São Lourenço da Mata,30,88417,-8,-35.05
br,sao lourenco da matta,São Lourenço da Matta,30,,-8,-35.05
br,sao lourenco da serra,São Lourenço da Serra,27,13331,-23.866667,-46.95
br,sao lourenco das missoes,São Lourenço das Missões,23,,-28.466667,-54.716667
br,sao lourenco d'oeste,Sao Lourenco d'Oeste,26,,-26.4,-52.766667
br,sao lourenco do ipixuna,São Lourenço do Ipixuna,13,,-4.466667,-44.9
br,sao lourenco do oeste,São Lourenço do Oeste,26,14872,-26.4,-52.766667
br,sao lourenco do sul,São Lourenço do Sul,23,25341,-31.366667,-51.966667
br,sao lourenco do turvo,São Lourenço do Turvo,27,,-21.55,-48.55
br,sao lourenco,São Lourenço,04,,-5.573333,-61.0575
br,sao lourenco,São Lourenço,05,,-12.583333,-38.683333
br,sao lourenco,São Lourenço,06,,-3.866667,-40.183333
br,sao lourenco,São Lourenco,08,,-20.616667,-41.683333
br,sao lourenco,São Lourenço,13,,-1.9,-44.95
br,sao lourenco,São Lourenço,14,,-16.533333,-55.033333
br,sao lourenco,São Lourenço,15,41144,-22.116667,-45.05
br,sao lourenco,São Lourenço,16,,-1.6,-52.55
br,sao lourenco,São Lourenço,17,,-6.816667,-37.966667
br,sao lourenco,São Lourenço,18,,-24.733333,-49.833333
br,sao lourenco,Sâo Lourenço,20,,-5.8,-42.416667
br,sao lourenco,São Lourenço,21,,-22.883333,-43.116667
br,sao lourenco,São Lourenço,23,,-31.366667,-51.966667
br,sao lourenco,São Lourenço,24,,-9.5,-64.8
br,sao lourenco,São Lourenço,25,,3.480786,-59.875864
br,sao lourenco,São Lourenço,26,,-26.4,-52.766667
br,sao lourenco,São Lourenço,27,,-23.816667,-46.05
br,sao lourenco,São Lourenço,30,,-7.75,-38.483333
br,sao lucas,São Lucas,13,,-1.516667,-44.8
br,sao lucas,São Lucas,23,,-29.766667,-54.45
br,sao lucas,São Lucas,24,,-8.35,-63.416667
br,sao luis casiana,São Luís Casianã,04,,-7.233333,-64.933333
br,sao luis coanaru,São Luís Coanaru,04,,-3.866667,-63.583333
br,sao luis da boa sorte,São Luís da Boa Sorte,08,,-20.166667,-41.1
br,sao luis de caceres,São Luís de Cáceres,14,,-16.066667,-57.683333
br,sao luis de cassiana,São Luís de Cassianã,04,,-7.233333,-64.933333
br,sao luis de mamoria,São Luís de Mamoriá,04,,-7.55,-66.416667
br,sao luis de montes belos,São Luís de Montes Belos,29,23619,-16.533333,-50.333333
br,sao luis do curu,São Luís do Curu,06,,-3.666667,-39.233333
br,sao luis do miranda,São Luís do Miranda,08,,-19.95,-41.066667
br,sao luis do paraguai,São Luís do Paraguai,14,,-16.066667,-57.683333
br,sao luis do paraitinga,São Luís do Paraitinga,27,,-23.233333,-45.333333
br,sao luis do puruna,São Luís do Purunã,18,,-25.483333,-49.733333
br,sao luis do quitunde,São Luís do Quitunde,02,20564,-9.333333,-35.55
br,sao luis do tocantins,São Luís do Tocantins,29,,-14.283333,-47.983333
br,sao luis gonzaga,São Luís Gonzaga,13,,-4.366667,-44.566667
br,sao luis gonzaga,São Luís Gonzaga,21,,-21.4,-41.15
br,sao luis gonzaga,São Luís Gonzaga,23,,-28.4,-54.966667
br,sao luis,São Luís,01,,-10.3,-67.133333
br,sao luis,São Luís,03,,1.083333,-50.616667
br,sao luis,São Luís,04,,-3.083333,-61.433333
br,sao luis,São Luís,05,,-10.916667,-45.45
br,sao luis,São Luís,06,,-3.95,-38.583333
br,sao luis,São Luís,08,,-20.8,-41.45
br,sao luis,São Luís,11,,-19.383333,-55.816667
br,sao luis,São Luís,13,917252,-2.516667,-44.266667
br,sao luis,São Luis,14,,-13.083333,-60.033333
br,sao luis,São Luís,15,,-20.25,-43.233333
br,sao luis,São Luís,16,,-1.15,-47.516667
br,sao luis,São Luís,18,,-23.5,-51.266667
br,sao luis,São Luís,20,,-4.566667,-41.933333
br,sao luis,São Luís,21,,-21.566667,-41.616667
br,sao luis,São Luís,22,,-5.202222,-36.545833
br,sao luis,São Luís,24,,-10.1,-63.166667
br,sao luis,São Luís,25,,3.033333,-60.433333
br,sao luis,São Luís,26,,-27.016667,-51.25
br,sao luis,São Luís,27,,-20.383333,-47.616667
br,sao luiz de caceres,São Luiz de Cáceres,14,,-16.066667,-57.683333
br,sao luiz de cassiana,São Luiz de Cassianã,04,,-7.233333,-64.933333
br,sao luiz de maranhao,São Luiz de Maranhão,13,,-2.516667,-44.266667
br,sao luiz de quitunde,São Luiz de Quitunde,02,,-9.333333,-35.55
br,sao luiz do maranhao,São Luiz do Maranhão,13,,-2.516667,-44.266667
br,sao luiz do parahytinga,São Luiz do Parahytinga,27,,-23.233333,-45.333333
br,sao luiz do paraitinga,São Luiz do Paraitinga,27,,-23.233333,-45.333333
br,sao luiz do puruna,São Luiz do Purunã,18,,-25.483333,-49.733333
br,sao luiz do quitunde,São Luiz do Quitunde,02,,-9.333333,-35.55
br,sao luiz gonzaga,São Luiz Gonzaga,13,,-4.366667,-44.566667
br,sao luiz gonzaga,São Luiz Gonzaga,21,,-21.4,-41.15
br,sao luiz gonzaga,São Luiz Gonzaga,23,31798,-28.4,-54.966667
br,sao luiz,São Luiz,01,,-10.3,-67.133333
br,sao luiz,São Luiz,04,,-7.45,-71.9
br,sao luiz,São Luiz,05,,-10.916667,-45.45
br,sao luiz,São Luiz,06,,-4.75,-37.95
br,sao luiz,São Luiz,11,,-19.383333,-55.816667
br,sao luiz,São Luiz,13,,-2.516667,-44.266667
br,sao luiz,São Luiz,14,,-16.933333,-57.1
br,sao luiz,São Luiz,15,,-21.716667,-42.583333
br,sao luiz,São Luiz,16,,-1.15,-47.516667
br,sao luiz,São Luiz,18,,-23.5,-51.266667
br,sao luiz,São Luiz,20,,-8.983333,-44.066667
br,sao luiz,São Luiz,23,,-28.4,-54.966667
br,sao luiz,São Luiz,26,,-28.183333,-48.95
br,sao luzia do itanhi,Sào Luzia do Itanhi,28,,-11.333333,-37.5
br,sao luzia,São Luzia,11,,-19.5,-55
br,sao luzia,São Luzia,13,,-9.216667,-46.266667
br,sao mamede,São Mamede,17,,-6.933333,-37.1
br,sao mamede,São Mamede,20,,-4.416667,-42.866667
br,sao manoel do mutum,São Manoel do Mutum,15,,-19.816667,-41.433333
br,sao manoel do paraizo,São Manoel do Paraizo,27,,-22.733333,-48.566667
br,sao manoel du mutum,Sao Manoel du Mutum,15,,-19.816667,-41.433333
br,sao manoel,São Manoel,05,,-13.433333,-44.483333
br,sao manoel,São Manoel,11,,-21.933333,-56.966667
br,sao manoel,São Manoel,15,,-21.1,-42.183333
br,sao manoel,São Manoel,18,,-23.395513,-52.644441
br,sao manoel,São Manoel,20,,-9.4,-44.116667
br,sao manoel,São Manoel,22,,-5.368056,-37.16
br,sao manuel de carangola,São Manuel de Carangola,15,,-20.7,-42.1
br,sao manuel do mutum,Sao Manuel do Mutum,15,,-19.816667,-41.433333
br,sao manuel,São Manuel,02,,-9.683333,-36.3
br,sao manuel,São Manuel,05,,-13.433333,-44.483333
br,sao manuel,São Manuel,11,,-20.766667,-53
br,sao manuel,São Manuel,15,,-21.1,-42.183333
br,sao manuel,São Manuel,16,,-1.85,-48.666667
br,sao manuel,São Manuel,18,,-24.983333,-50.583333
br,sao manuel,São Manuel,20,,-9.4,-44.116667
br,sao manuel,São Manuel,21,,-22.083333,-41.6
br,sao manuel,São Manuel,23,,-28.8,-51.033333
br,sao manuel,São Manuel,25,,-3.266667,-61.3
br,sao manuel,São Manuel,27,33588,-22.733333,-48.566667
br,sao marcal,São Marçal,13,,-3,-45.083333
br,sao marcelino,São Marcelino,04,,.9,-67.2
br,sao marcellino,São Marcellino,04,,.9,-67.2
br,sao marcello,São Marcello,05,,-11.033333,-45.533333
br,sao marcelo,São Marcelo,05,,-11.033333,-45.533333
br,sao marciano,São Marciano,21,,-22.893186,-43.358372
br,sao marcos,São Marcos,11,,-18.333333,-55.716667
br,sao marcos,São Marcos,13,,-5.516667,-43.083333
br,sao marcos,São Marcos,22,,-5.316667,-35.766667
br,sao marcos,São Marcos,23,18591,-28.966667,-51.066667
br,sao marcos,São Marcos,25,,3.083333,-60.416667
br,sao marecas,São Marecas,23,,-28.966667,-51.066667
br,sao maria,São Maria,13,,-8.266667,-46.4
br,sao martim,São Martim,13,,-3.508333,-43.306111
br,sao martim,São Martim,23,,-31.283333,-54.116667
br,sao martinho do capivaras,São Martinho do Capivaras,26,,-28.166667,-48.966667
br,sao martinho d'oeste,Sao Martinho d'Oeste,27,,-21.566667,-50.266667
br,sao martinho do oeste,São Martinho do Oeste,27,,-21.566667,-50.266667
br,sao martinho,São Martinho,16,,-6.083333,-57.516667
br,sao martinho,São Martinho,18,,-23.183333,-51.45
br,sao martinho,São Martinho,21,,-22.016667,-41.2
br,sao martinho,São Martinho,23,,-27.716667,-53.966667
br,sao martinho,São Martinho,26,,-28.166667,-48.966667
br,sao martins,São Martins,23,,-31.283333,-54.116667
br,sao mateus da palestina,São Mateus da Palestina,28,,-10.05,-37.183333
br,sao mateus do maranhao,São Mateus do Maranhão,13,28234,-4.033333,-44.466667
br,sao mateus do sul,São Mateus do Sul,18,24904,-25.866667,-50.383333
br,sao mateus,São Mateus,04,,-5.545556,-60.914722
br,sao mateus,São Mateus,06,,-2.890278,-40.787778
br,sao mateus,São Mateus,08,77119,-18.733333,-39.85
br,sao mateus,São Mateus,15,,-18.1,-40.9
br,sao mateus,São Mateus,16,,-5.65,-48.166667
br,sao mateus,São Mateus,18,,-25.866667,-50.383333
br,sao mateus,São Mateus,21,,-22.807338,-43.379218
br,sao mateuss,São Mateuss,20,,-5.75,-42.033333
br,sao matheus,São Matheus,06,,-6.533333,-39.533333
br,sao matheus,São Matheus,08,,-18.733333,-39.85
br,sao matheus,São Matheus,18,,-25.866667,-50.383333
br,sao mauricio,São Maurício,26,,-28.133333,-49.116667
br,sao miguel arcanjo,São Miguel Arcanjo,27,,-23.883333,-47.983333
br,sao miguel archanjo,São Miguel Archanjo,27,,-23.883333,-47.983333
br,sao miguel da ponte nova,São Miguel da Ponte Nova,15,,-19.133333,-47.683333
br,sao miguel da roseira,São Miguel da Roseira,18,,-25.933333,-50.383333
br,sao miguel das matas,São Miguel das Matas,05,,-13.016667,-39.45
br,sao miguel das milagres,São Miguel das Milagres,02,,-9.266667,-35.366667
br,sao miguel das missoes,São Miguel das Missões,23,,-28.533333,-54.55
br,sao miguel de campos,Sao Miguel De Campos,02,,-9.783333,-36.083333
br,sao miguel de jequitinhonha,São Miguel de Jequitinhonha,15,,-16.433333,-41
br,sao miguel de jucurutu,São Miguel de Jucurutú,22,,-6.033333,-37.016667
br,sao miguel de paxituba,São Miguel de Paxituba,16,,-1.533333,-49.466667
br,sao miguel de practuba,São Miguel de Practuba,16,,-1.533333,-49.466667
br,sao miguel de pracutuba,São Miguel de Pracutuba,16,,-1.533333,-49.466667
br,sao miguel de pratuba,São Miguel de Pratuba,16,,-1.533333,-49.466667
br,sao miguel de taipu,São Miguel de Taipu,17,,-7.25,-35.216667
br,sao miguel de touros,São Miguel de Touros,22,,-5.116667,-35.633333
br,sao miguel do anta,São Miguel do Anta,15,,-20.7,-42.716667
br,sao miguel do araguaia,São Miguel do Araguaia,29,18810,-13.316667,-50.216667
br,sao miguel d'oeste,Sao Miguel d'Oeste,26,,-26.75,-53.566667
br,sao miguel do gostoso,São Miguel do Gostoso,22,,-5.116667,-35.633333
br,sao miguel do guama,São Miguel do Guamá,16,28266,-1.616667,-47.45
br,sao miguel do iguacu,São Miguel do Iguaçu,18,15434,-25.35,-54.166667
br,sao miguel do oeste,São Miguel do Oeste,26,27360,-26.75,-53.566667
br,sao miguel dos campos,São Miguel dos Campos,02,40891,-9.783333,-36.083333
br,sao miguel dos macacos,São Miguel dos Macacos,16,,-1.183333,-50.466667
br,sao miguel dos milagres,São Miguel dos Milagres,02,,-9.266667,-35.366667
br,sao miguel do tapuio,São Miguel do Tapuio,20,7964,-5.5,-41.333333
br,sao miguel do tocantins,São Miguel do Tocantins,31,,-5.498611,-47.381389
br,sao miguel do turvo,São Miguel do Turvo,27,,-20.9,-48.85
br,sao miguel e almas,São Miguel e Almas,31,,-11.626111,-47.101667
br,sao miguel paulista,São Miguel Paulista,27,,-23.5,-46.433333
br,sao miguel,São Miguel,01,,-10.916667,-69.416667
br,sao miguel,São Miguel,02,,-9.283333,-36.483333
br,sao miguel,São Miguel,03,,1.283333,-50.25
br,sao miguel,São Miguel,04,,-5.762778,-59.266667
br,sao miguel,São Miguel,05,,-12.416667,-38.466667
br,sao miguel,São Miguel,06,,-3.366667,-41
br,sao miguel,São Miguel,08,,-20.6,-40.65
br,sao miguel,São Miguel,11,,-18.583333,-56.683333
br,sao miguel,São Miguel,13,,-1.35,-45.8
br,sao miguel,São Miguel,14,,-15.916667,-56
br,sao miguel,São Miguel,15,,-18.183333,-41.383333
br,sao miguel,São Miguel,16,,-1.183333,-50.466667
br,sao miguel,São Miguel,17,,-6.966667,-37.683333
br,sao miguel,São Miguel,18,,-24.95,-48.916667
br,sao miguel,São Miguel,20,,-5.5,-41.333333
br,sao miguel,São Miguel,21,,-22.066667,-41.566667
br,sao miguel,São Miguel,22,12838,-5.466667,-35.366667
br,sao miguel,São Miguel,23,,-28.083333,-53.1
br,sao miguel,São Miguel,25,,3.15,-61.133333
br,sao miguel,São Miguel,26,,-26.166667,-49.233333
br,sao miguel,São Miguel,27,,-20.9,-48.85
br,sao miguel,São Miguel,29,,-16.9,-48.133333
br,sao miguel,São Míguel,30,,-8.166667,-38.366667
br,sao murtinho,São Murtinho,21,,-22.016667,-42.316667
br,sao nicolao,São Nicolão,23,,-28.183333,-55.266667
br,sao nicolau,São Nicolau,06,,-6.666667,-40.066667
br,sao nicolau,São Nicolau,20,,-3.561667,-42.311944
br,sao nicolau,São Nicolau,22,,-6.366667,-36.933333
br,sao nicolau,São Nicolau,23,,-28.183333,-55.266667
br,sao paulinho,São Paulinho,05,,-16.883333,-39.633333
br,sao paulino,São Paulino,18,,-25.633333,-50.916667
br,sao paulo de olivenca,São Paulo de Olivença,04,11763,-3.45,-68.8
br,sao paulo do potengi,São Paulo do Potengi,22,9334,-5.916667,-35.75
br,sao paulo do potenji,São Paulo do Potenji,22,,-5.916667,-35.75
br,sao paulo dos pinhais,São Paulo dos Pinhais,26,,-27.866667,-49.083333
br,sao paulo ii,São Paulo II,18,,-26.201111,-53.6425
br,sao paulo i,São Paulo I,18,,-26.225833,-53.641111
br,sao paulo,São Paulo,02,,-9.45,-36.033333
br,sao paulo,São Paulo,04,,-3.216667,-57.083333
br,sao paulo,São Paulo,05,,-10.1,-39.483333
br,sao paulo,São Paulo,06,,-3.8,-40.016667
br,sao paulo,São Paulo,08,,-20.433333,-41.016667
br,sao paulo,São Paulo,13,,-1.583333,-45
br,sao paulo,São Paulo,17,,-6.616667,-38.15
br,sao paulo,São Paulo,20,,-5.566667,-42.066667
br,sao paulo,São Paulo,22,,-5.191111,-36.246667
br,sao paulo,São Paulo,23,,-27.95,-52.116667
br,sao paulo,São Paulo,25,,3.8,-61.4
br,sao paulo,São Paulo,26,,-27.633333,-50.95
br,sao paulo,São Paulo,27,10021437,-23.473293,-46.665803
br,sao paulo,São Paulo,28,,-10.55,-37.533333
br,sao paulo,São Paulo,30,,-7.916667,-37.616667
br,sao paulo,São Paulo,31,,-5.716667,-48.166667
br,sao pedro cachoeira,São Pedro Cachoeira,22,,-5.144444,-37.452778
br,sao pedro da aldeia,São Pedro da Aldeia,21,55014,-22.85,-42.1
br,sao pedro da cachoeirinha,São Pedro da Cachoeirinha,06,,-6.216667,-40.716667
br,sao pedro da cipa,São Pedro da Cipa,14,,-15.866667,-54.666667
br,sao pedro da garca,São Pedro da Garça,15,,-16.166667,-43.866667
br,sao pedro d'alcantara,Sao Pedro d'Alcantara,15,,-19.483333,-46.533333
br,sao pedro d'aldeia,Sao Pedro d'Aldeia,21,,-22.85,-42.1
br,sao pedro da pedra bonita,São Pedro da Pedra Bonita,15,,-19.116667,-41.1
br,sao pedro da ponta firma,São Pedro da Ponta Firma,15,,-18.066667,-46.416667
br,sao pedro das lajes,São Pedro das Lajes,30,,-7.366667,-37.183333
br,sao pedro da uniao,São Pedro da União,15,,-21.133333,-46.616667
br,sao pedro de alcantara,São Pedro de Alcantara,13,,-3.616667,-45.35
br,sao pedro de alcantara,São Pedro de Alcantara,15,,-21.963889,-43.313056
br,sao pedro de alcantara,São Pedro de Alcantara,18,,-23.283333,-51.05
br,sao pedro de alcantara,São Pedro de Alcântara,21,,-21.65,-42.3
br,sao pedro de alcantara,São Pedro de Alcântara,23,,-29.35,-49.85
br,sao pedro de alcantara,São Pedro de Alcântara,26,,-27.583333,-48.8
br,sao pedro de caldas,São Pedro de Caldas,15,,-21.816667,-46.25
br,sao-pedro-de-ferros,São-Pedro-de-Ferros,15,,-20.166667,-42.516667
br,sao pedro de itabapoana,São Pedro de Itabapoana,08,,-21.083333,-41.483333
br,sao pedro de malet,Sao Pedro de Malet,18,,-25.916667,-50.833333
br,sao pedro de mallet,São Pedro de Mallet,18,,-25.916667,-50.833333
br,sao pedro de nova friburgo,São Pedro de Nova Friburgo,21,,-22.333333,-42.233333
br,sao pedro de rates,São Pedro de Rates,08,,-20.783333,-41.8
br,sao pedro de suacui,São Pedro de Suaçuí,15,,-18.35,-42.6
br,sao pedro de suassuhy,São Pedro de Suassuhy,15,,-18.35,-42.6
br,sao pedro de viseu,São Pedro de Viseu,16,,-2.366667,-51.033333
br,sao pedro do acude,Sao Pedro do Acude,05,,-13.2,-44.166667
br,sao pedro do avai,São Pedro do Avaí,15,,-20.2,-42.183333
br,sao pedro do avai,São Pedro do Avaí,18,,-23.85,-51.85
br,sao pedro do cariri,São Pedro do Carirí,06,,-7.033333,-39.283333
br,sao pedro do desterro,São Pedro do Destêrro,04,,-8.583333,-67.4
br,sao pedro do gloria,São Pedro do Glória,15,,-20.7,-42.366667
br,sao pedro do itangua,São Pedro do Itanguá,15,,-22.106944,-43.888889
br,sao pedro do ivai,São Pedro do Ivaí,18,,-23.85,-51.85
br,sao pedro do jequitinhonha,São Pedro do Jequitinhonha,15,,-16.5,-41.333333
br,sao pedro do piaui,São Pedro do Piauí,20,7408,-5.933333,-42.716667
br,sao pedro do rio grande do sul,São Pedro do Rio Grande do Sul,23,,-32.033333,-52.083333
br,sao pedro dos ferros,São Pedro dos Ferros,15,,-20.166667,-42.516667
br,sao pedro dos lages,São Pedro dos Lages,30,,-7.366667,-37.183333
br,sao pedro do suacui,São Pedro do Suaçuí,15,,-18.35,-42.6
br,sao pedro do suassui,São Pedro do Suassuí,15,,-18.35,-42.6
br,sao pedro do sul,São Pedro do Sul,23,12137,-29.616667,-54.166667
br,sao pedro do turvo,São Pedro do Turvo,27,,-22.766667,-49.716667
br,sao pedro do viseu,São Pedro do Viseu,16,,-2.55,-49.55
br,sao pedro do vizeu,São Pedro do Vizeu,16,,-2.55,-49.55
br,sao pedro,São Pedro,01,,-10.033333,-66.8
br,sao pedro,São Pedro,02,,-9.133333,-36.166667
br,sao pedro,São Pedro,04,,-.25,-66.766667
br,sao pedro,São Pedro,05,,-10.95,-39.366667
br,sao pedro,São Pedro,06,,-3.666667,-38.8
br,sao pedro,São Pedro,08,,-19.433333,-40.8
br,sao pedro,São Pedro,11,,-18.733333,-56.4
br,sao pedro,São Pedro,13,,-3.25,-42.116667
br,sao pedro,São Pedro,14,,-15.866667,-54.666667
br,sao pedro,São Pedro,15,,-17.316667,-40.683333
br,sao pedro,São Pedro,16,,-1.883333,-46.416667
br,sao pedro,São Pedro,17,,-6.4,-37.783333
br,sao pedro,São Pedro,18,,-23.483333,-51.55
br,sao pedro,São Pedro,20,,-5.35,-42.35
br,sao pedro,São Pedro,22,,-5.155833,-36.285278
br,sao pedro,São Pedro,23,,-28.616667,-54.083333
br,sao pedro,São Pedro,24,,-10.116667,-63.766667
br,sao pedro,São Pedro,25,,3.733333,-61.033333
br,sao pedro,São Pedro,26,,-28.833333,-49.516667
br,sao pedro,São Pedro,27,27068,-22.55,-47.9
br,sao pedro,São Pedro,29,,-13.05,-46.466667
br,sao pedro,São Pedro,30,,-7.85,-38.35
br,sao phelippe,São Phelippe,04,,-6.666667,-69.866667
br,sao rafael do alto,São Rafael do Alto,08,,-19.316667,-40.5
br,sao rafael,São Rafael,04,,-6.466667,-62.316667
br,sao rafael,São Rafael,05,,-13.816667,-39.5
br,sao rafael,São Rafael,08,,-19.4,-40.433333
br,sao rafael,São Rafael,11,,-22.166667,-53.266667
br,sao rafael,São Rafael,22,,-5.8,-36.918611
br,sao rafael,São Rafael,24,,-8.633333,-62.45
br,sao raimundo das mangabeiras,São Raimundo das Mangabeiras,13,10216,-7.016667,-45.483333
br,sao raimundo de codo,São Raimundo de Codó,13,,-4.35,-43.616667
br,sao raimundo nonato,São Raimundo Nonato,20,19569,-9.016667,-42.7
br,sao raimundo,São Raimundo,02,,-9.633333,-36.166667
br,sao raimundo,São Raimundo,04,,-2.6,-67.433333
br,sao raimundo,São Raimundo,13,,-3.076389,-42.263056
br,sao raimundo,São Raimundo,14,,-7.9,-58.05
br,sao raimundo,São Raimundo,15,,-18.866667,-41.916667
br,sao raimundo,São Raimundo,16,,-1.316667,-50.3
br,sao raimundo,São Raimundo,20,,-3.866667,-42.466667
br,sao raimundo,São Raimundo,22,,-5.345278,-36.446111
br,sao raimundo,São Raimundo,25,,3.366667,-60.2
br,sao raimundo,São Raimundo,31,,-6.416667,-48.116667
br,sao ramos,São Ramos,15,,-17.85,-41.516667
br,sao raphael,São Raphael,22,,-5.8,-36.918611
br,sao raymundo do rio neves,São Raymundo do Rio Neves,13,,-7.016667,-45.483333
br,sao raymundo nonato,Sao Raymundo Nonato,20,,-9.016667,-42.7
br,sao raymundo,São Raymundo,04,,-6.016667,-64.283333
br,sao roberto,São Roberto,04,,-4.278889,-59.982778
br,sao roberto,São Roberto,16,,-.85,-47.5
br,sao roberto,São Roberto,27,,-21.85,-47.966667
br,sao roche,São Roche,05,,-12.633333,-40.266667
br,sao romao,São Romão,04,,-3.65,-66.283333
br,sao romao,São Romão,08,,-20.75,-41.75
br,sao romao,São Romão,11,,-18.55,-54.45
br,sao romao,São Romão,15,,-16.366667,-45.066667
br,sao roque da fartura,São Roque da Fartura,27,,-21.85,-46.75
br,sao roque da fortuna,São Roque da Fortuna,27,,-21.85,-46.75
br,sao roque de cima,São Roque de Cima,22,,-6.7,-36.85
br,sao roque do paraguacu,São Roque do Paraguaçu,05,,-12.85,-38.85
br,sao roque do paraguai,São Roque do Paraguai,05,,-12.85,-38.85
br,sao roque do pinhal,São Roque do Pinhal,18,,-23.487529,-49.829904
br,sao roque,São Roque,02,,-8.916667,-36.033333
br,sao roque,São Roque,05,,-12.183333,-40.4
br,sao roque,São Roque,08,,-18.916667,-40.5
br,sao roque,São Roque,11,,-19.366667,-56.333333
br,sao roque,São Roque,13,,-3.496389,-42.718333
br,sao roque,São Roque,14,,-16.633333,-56.45
br,sao roque,São Roque,15,,-15.583333,-43.816667
br,sao roque,São Roque,18,,-23.431241,-49.826189
br,sao roque,São Roque,21,,-21.3,-41.383333
br,sao roque,São Roque,23,,-27.716667,-54.55
br,sao roque,São Roque,26,,-26.416667,-50.783333
br,sao roque,São Roque,27,50541,-23.528458,-47.135273
br,sao roque,São Roque,30,,-8.55,-36.916667
br,sao rosa,São Rosa,01,,-8.666667,-70.516667
br,sao sabasido,Sao Sabasido,04,,-9.133333,-66.483333
br,sao sabestiao aguas claras,São Sabestião Águas Claras,15,,-20.0448,-43.9155
br,sao sabino,São Sabino,22,,-5.516667,-37.9
br,sao saite,São Saité,05,,-9.066667,-38.916667
br,sao salvador dos campos,São Salvador dos Campos,21,,-21.75,-41.3
br,sao salvador do tocantins,São Salvador do Tocantins,31,,-12.7875,-48.231667
br,sao salvador,São Salvador,01,,-7.433333,-73.216667
br,sao salvador,São Salvador,03,,1.083333,-50.7
br,sao salvador,São Salvador,04,,.1,-67.9
br,sao salvador,Sao Salvador,05,,-12.983333,-38.516667
br,sao salvador,São Salvador,08,,-21.116667,-40.983333
br,sao salvador,São Salvador,11,,-21.983333,-56.383333
br,sao salvador,São Salvador,23,,-29.45,-51.516667
br,sao salvador,São Salvador,25,,2.983333,-60.866667
br,sao saturnino,São Saturnino,14,,-15.716667,-58
br,sao sebastiam dos pocoes,São Sebastiam dos Poções,15,,-14.516667,-44.433333
br,sao sebastiao da americaninha,São Sebastião da Americaninha,15,,-17.133333,-41.2
br,sao sebastiao da amoreira,São Sebastião da Amoreira,18,,-23.466667,-50.75
br,sao sebastiao da anta,São Sebastião da Anta,15,,-19.5,-41.966667
br,sao sebastiao da barra,São Sebastião da Barra,15,,-20.616667,-41.6
br,sao sebastiao da barra seca,São Sebastião da Barra Sêca,08,,-18.916667,-40.583333
br,sao sebastiao da bela vista,São Sebastião da Bela Vista,15,,-22.166667,-45.75
br,sao sebastiao da bela vista,São Sebastião da Bela Vista,18,,-26.066667,-53.366667
br,sao sebastiao da boa vista,São Sebastião da Boa Vista,16,,-1.7,-49.516667
br,sao sebastiao da boa vista,São Sebastiao da Boa Vista,21,,-21.316667,-42.016667
br,sao sebastiao da estrela,São Sebastião da Estrêla,15,,-21.75,-42.433333
br,sao sebastiao da estrella,São Sebastião da Estrella,15,,-21.75,-42.433333
br,sao sebastiao da grama,São Sebastião da Grama,27,,-21.716667,-46.816667
br,sao sebastiao das laranjeiras,São Sebastião das Laranjeiras,15,,-18.933333,-41.5
br,sao sebastiao da vala,São Sebastião da Vala,15,,-19.75,-41.266667
br,sao sebastiao da vista alegre,São Sebastião da Vista Alegre,21,,-20.933333,-41.95
br,sao sebastiao da vitoria,São Sebastião da Vitória,15,,-21.233333,-44.416667
br,sao sebastiao de campos,São Sebastião de Campos,21,,-21.85,-41.2
br,sao sebastiao de itabapoana,São Sebastião de Itabapoana,21,,-21.3,-40.966667
br,sao sebastiao de leovigildo,São Sebastião de Leovigildo,08,,-20.116667,-41.35
br,sao sebastiao de mantenas,São Sebastião de Mantenas,15,,-18.65,-41.333333
br,sao sebastiao de rio de janeiro,São Sebastião de Rio de Janeiro,21,,-22.9,-43.233333
br,sao sebastiao de tapuru,São Sebastião de Tapuru,04,,-6.55,-62.333333
br,sao sebastiao de vicosa,São Sebastião de Viçosa,16,,.483333,-49.95
br,sao sebastiao do alto,São Sebastião do Alto,21,,-21.95,-42.133333
br,sao sebastiao do bananal,São Sebastião do Bananal,08,,-19.666667,-41.083333
br,sao sebastiao do barreado,São Sebastião do Barreado,15,,-22.060833,-43.645
br,sao sebastiao do cahy,São Sebastião do Cahy,23,,-29.583333,-51.383333
br,sao sebastiao do cai,São Sebastião do Caí,23,19013,-29.583333,-51.383333
br,sao sebastiao do curral,São Sebastião do Curral,15,,-20.266667,-45
br,sao sebastiao do erval,São Sebastião do Erval,26,,-27.283333,-51.433333
br,sao sebastiao do ferreiros,São Sebastião do Ferreiros,15,,-19.133333,-43
br,sao sebastiao do florido,São Sebastião do Florido,18,,-26.026111,-53.641389
br,sao sebastiao do gil,São Sebastião do Gil,15,,-20.6,-44.2
br,sao sebastiao do indaia,São Sebastião do Indaiá,15,,-17.45,-42.3
br,sao sebastiao do jauari,São Sebastião do Jauari,04,,-4.428056,-59.793056
br,sao sebastiao do leavigildo,São Sebastião do Leavigildo,08,,-20.116667,-41.35
br,sao sebastiao do mantenas,São Sebastiao do Mantenas,15,,-18.65,-41.333333
br,sao sebastiao do maranhao,São Sebastião do Maranhão,15,,-18.083333,-42.583333
br,sao sebastiao do monte alegre,São Sebastião do Monte Alegre,15,,-21.9,-43.816667
br,sao sebastiao do parahyba,São Sebastião do Parahyba,21,,-21.766667,-42.366667
br,sao sebastiao do paraiba,São Sebastião do Paraíba,21,,-21.766667,-42.366667
br,sao sebastiao do paraiso,São Sebastião do Paraíso,15,57239,-20.916667,-47
br,sao sebastiao do paraizo,São Sebastião do Paraizo,15,,-20.916667,-47
br,sao sebastiao do paraju,São Sebastião do Paraju,08,,-20.316667,-40.866667
br,sao sebastiao do passe,São Sebastião do Passé,05,31050,-12.516667,-38.466667
br,sao sebastiao do pontal,São Sebastião do Pontal,16,,-5.8,-52.6
br,sao sebastiao do rio benito,São Sebastião do Rio Benito,21,,-22.158611,-43.754444
br,sao sebastiao do rio bonito,São Sebastião do Rio Bonito,21,,-22.158611,-43.754444
br,sao sebastiao do rio claro,São Sebastião do Rio Claro,29,,-15.75,-51.5
br,sao sebastiao do rio de janeiro,São Sebastião do Rio de Janeiro,21,,-22.9,-43.233333
br,sao sebastiao do rio preto,São Sebastião do Rio Prêto,15,,-19.283333,-43.183333
br,sao sebastiao do rio verde,São Sebastião do Rio Verde,15,,-22.216667,-44.966667
br,sao sebastiao dos abreus,São Sebastião dos Abreus,15,,-21,-43.3
br,sao sebastiao do sacramento,São Sebastião do Sacramento,15,,-20.083333,-42.166667
br,sao sebastiao do salto grande,São Sebastião do Salto Grande,15,,-16,-39.95
br,sao sebastiao do sem peixe,São Sebastião do Sem Peixe,15,,-20.1,-42.85
br,sao sebastiao dos ferreiros,São Sebastião dos Ferreiros,15,,-19.133333,-43
br,sao sebastiao dos ferreiros,São Sebastião dos Ferreiros,21,,-22.4275,-43.566111
br,sao sebastiao dos franciscos,São Sebastião dos Franciscos,15,,-20.6,-46.05
br,sao sebastiao do soberbo,São Sebastião do Soberbo,15,,-20.233333,-42.866667
br,sao sebastiao do sobrado,São Sebastião do Sobrado,15,,-20.633333,-43.633333
br,sao sebastiao dos peitudos,São Sebastião dos Peitudos,15,,-22.316667,-46.483333
br,sao sebastiao dos pintos,São Sebastião dos Pintos,15,,-18.4,-42.7
br,sao sebastiao dos pocoes,São Sebastião dos Poções,15,,-14.516667,-44.433333
br,sao sebastiao dos robertos,São Sebastião dos Robertos,15,,-22.216667,-46.533333
br,sao sebastiao do sul,São Sebastião do Sul,26,,-26.783333,-50.833333
br,sao sebastiao do taboao,São Sebastião do Taboão,15,,-21.983333,-44.033333
br,sao sebastiao do tocantins,São Sebastião do Tocantins,31,,-5.236944,-48.069167
br,sao sebastiao do umbuzeiro,São Sebastião do Umbuzeiro,17,,-8.15,-37.016667
br,sao sebastiao do utinga,São Sebastião do Utinga,05,,-12.35,-41.15
br,sao sebastiao ferreira,São Sebastião Ferreira,02,,-9.8,-36.066667
br,sao sebastiao paraiso,São Sebastião Paraíso,15,,-20.916667,-47
br,sao sebastiao,São Sebastião,02,9551,-9.933333,-36.566667
br,sao sebastiao,São Sebastião,03,,1.066667,-50.7
br,sao sebastiao,São Sebastião,04,,-2.521667,-60.798333
br,sao sebastiao,São Sebastião,05,,-11.283333,-40.616667
br,sao sebastiao,São Sebastião,06,,-6.583333,-39.583333
br,sao sebastiao,São Sebastião,08,,-18.1,-40.25
br,sao sebastiao,São Sebastião,11,,-20.533333,-56.5
br,sao sebastiao,São Sebastião,13,,-4.083333,-44.683333
br,sao sebastiao,São Sebastião,15,,-17.183333,-46.85
br,sao sebastiao,São Sebastião,16,,-1.266667,-50.016667
br,sao sebastiao,São Sebastião,17,,-7.016667,-37.883333
br,sao sebastiao,São Sebastião,18,,-23.2754,-49.7513
br,sao sebastiao,São Sebastião,20,,-6.65,-42.866667
br,sao sebastiao,São Sebastião,21,,-21.233333,-41.666667
br,sao sebastiao,São Sebastião,22,,-5.439167,-36.528333
br,sao sebastiao,São Sebastião,23,,-27.3,-53.716667
br,sao sebastiao,São Sebastião,24,,-9.25,-64
br,sao sebastiao,São Sebastião,25,,2.316667,-60.883333
br,sao-sebastiao,São-Sebastião,26,,-26.783333,-50.833333
br,sao sebastiao,São Sebastião,26,,-28.333333,-49.183333
br,sao sebastiao,São Sebastião,27,76369,-23.8,-45.416667
br,sao sebastiao,São Sebastião,30,,-8.466667,-36.4
br,sao sebastiao,São Sebastião,31,,-5.25,-48.2
br,sao sehastiao,São Sehastião,06,,-7.466667,-38.966667
br,sao sepe,São Sepé,23,19182,-30.166667,-53.566667
br,sao serafim,São Serafim,17,,-7.933333,-38.183333
br,sao serafim,São Serafim,30,,-8.966667,-36.65
br,sao severino,São Severino,22,,-6.15,-38.466667
br,sao severino,São Severino,30,,-7.933333,-36.15
br,sao silvano,São Silvano,08,,-19.516667,-40.633333
br,sao silvestre,São Silvestre,18,,-25.05,-49.633333
br,sao simao,São Simão,05,,-12.183333,-38.816667
br,sao simao,São Simão,08,,-18.916667,-40.65
br,sao simao,São Simão,15,,-20.116667,-42.016667
br,sao simao,São Simão,23,,-30.95,-50.75
br,sao simao,São Simão,27,12351,-21.5,-47.55
br,sao simao,São Simão,29,,-18.933333,-50.5
br,sao simoes,São Simões,11,,-19.65,-55.2
br,saossaite,Sãossaité,05,,-9.066667,-38.916667
br,sao sylvestre,São Sylvestre,18,,-25.083333,-49.633333
br,sao teodosio,São Teodósio,22,,-6.166667,-36.45
br,sao teresa,São Teresa,13,,-9.033333,-46.816667
br,sao teresa,São Teresa,20,,-9.716667,-45.566667
br,sao thiago de iguape,São Thiago de Iguape,05,,-12.683333,-38.85
br,sao thiago,São Thiago,15,,-20.916667,-44.5
br,sao thome das lettras,São Thomé das Lettras,15,,-21.716667,-44.983333
br,sao thome,São Thomé,05,,-10.6,-40.933333
br,sao thome,São Thomé,17,,-7.65,-36.916667
br,sao thome,São Thomé,22,,-5.971389,-36.073611
br,sao tiago do iguape,São Tiago do Iguape,05,,-12.683333,-38.85
br,sao tiago,São Tiago,08,,-20.616667,-41.683333
br,sao tiago,São Tiago,11,,-21.716667,-56.033333
br,sao tiago,São Tiago,15,,-20.916667,-44.5
br,sao tiago,São Tiago,16,,-.983333,-57
br,sao timoteo,São Timóteo,05,,-13.85,-42.183333
br,sao tomas de aquinho,São Tomas de Aquinho,15,,-20.783333,-47.1
br,sao tomas de aquino,São Tomás de Aquino,15,,-20.783333,-47.1
br,sao tomas,São Tomás,11,,-21.8,-56.783333
br,sao tomas,São Tomás,26,,-28.316667,-48.933333
br,sao tomaz de aquino,Sao Tomaz de Aquino,15,,-20.783333,-47.1
br,sao tomaz,São Tomaz,11,,-21.8,-56.783333
br,sao tomaz,São Tomaz,26,,-28.316667,-48.933333
br,sao tome das letras,São Tomé das Letras,15,,-21.716667,-44.983333
br,sao tome de paripe,São Tomé de Paripe,05,,-12.816667,-38.483333
br,sao tome do paripe,São Tomé do Paripé,05,,-12.816667,-38.483333
br,sao tome,São Tomé,03,,-.416667,-51.5
br,sao tome,São Tomé,05,,-10.6,-40.933333
br,sao tome,São Tomé,11,,-21.966667,-57.3
br,sao tome,São Tomé,13,,-3.529722,-42.736389
br,sao tome,São Tomé,15,,-17.95,-43.433333
br,sao tome,São Tomé,16,,-1.466667,-47.716667
br,sao tome,São Tomé,17,,-7.65,-36.916667
br,sao tome,São Tomé,18,,-22.866667,-51.133333
br,sao tome,São Tomé,21,,-22.166667,-41.166667
br,sao tome,São Tomé,22,6137,-5.971389,-36.073611
br,sao tome,São Tomé,27,,-20.566667,-47.183333
br,sao valentim,São Valentim,23,,-27.55,-52.533333
br,sao valentin,São Valentin,23,,-29.0602,-51.1319
br,sao valerio da natividade,São Valério da Natividade,31,,-11.989167,-48.1725
br,sao valerio,São Valerio,31,,-11.633333,-48.233333
br,sao vendelino,São Vendelino,23,,-29.383333,-51.3
br,sao verdolino,São Verdolino,23,,-29.383333,-51.3
br,sao vicente da estrela,São Vicente da Estrêla,15,,-19.95,-42.433333
br,sao vicente da grama,São Vicente da Grama,15,,-20.5,-42.533333
br,sao vicente de dentro,São Vicente de Dentro,20,,-5.833333,-42.883333
br,sao vicente de minas,São Vicente de Minas,15,,-21.7,-44.45
br,sao vicente de paula,São Vicente de Paula,21,,-22.716667,-42.25
br,sao vicente de paulo,Sao Vicente de Paulo,21,,-22.716667,-42.25
br,sao vicente do araguaya,São Vicente do Araguaya,31,,-5.600278,-47.933056
br,sao vicente do grama,São Vicente do Grama,15,,-20.5,-42.533333
br,sao vicente do rio doce,São Vicente do Rio Doce,15,,-19.266667,-41.8
br,sao vicente do sul,São Vicente do Sul,23,,-29.7,-54.666667
br,sao vicente ferrer,São Vicente Férrer,13,,-2.883333,-44.866667
br,sao vicente ferrer,São Vicente Ferrer,15,,-21.7,-44.45
br,sao vicente ferrer,São Vicente Férrer,21,,-22.298,-44.3099
br,sao vicente ferrer,São Vicente Férrer,30,,-7.583333,-35.5
br,sao vicente franco,São Vicente Franco,16,,-2.216667,-47.833333
br,sao vicente,São Vicente,01,,-10.633333,-69.416667
br,sao vicente,São Vicente,04,,-5.95,-61.3
br,sao vicente,São Vicente,05,,-12.066667,-38.883333
br,sao vicente,Sao Vicente,06,,-2.916667,-39.883333
br,sao vicente,São Vicente,08,,-20.05,-41.2
br,sao vicente,São Vicente,11,,-18.316667,-55.666667
br,sao vicente,São Vicente,13,,-3.323889,-42.431944
br,sao vicente,São Vicente,14,,-15.816667,-55.4
br,sao vicente,São Vicente,15,,-16.533333,-41.033333
br,sao vicente,São Vicente,16,,-1.033333,-50.366667
br,sao vicente,São Vicente,17,,-6.933333,-36.4
br,sao vicente,São Vicente,18,,-24.05,-52.533333
br,sao vicente,São Vicente,20,,-3.273333,-42.054444
br,sao vicente,São Vicente,21,,-22.298,-44.3099
br,sao vicente,São Vicente,22,,-5.4075,-37.495833
br,sao vicente,São Vicente,23,,-29.7,-54.666667
br,sao vicente,São Vicente,27,324464,-23.966667,-46.383333
br,sao vicente,São Vicente,29,,-13.633333,-46.516667
br,sao vicente,São Vicente,30,,-7.583333,-35.5
br,sao vicente,São Vicente,31,,-5.600278,-47.933056
br,sao victor,São Victor,11,,-21.683333,-57.066667
br,sao victor,São Victor,23,,-29.2388,-51.1101
br,sao vigilio,São Vigilio,26,,-26.883333,-49.333333
br,sao vincente ferrer,Sao Vincente Ferrer,13,,-2.883333,-44.866667
br,sao vincente ferrer,São Vincente Ferrer,30,,-9.033333,-36.416667
br,sao vincente,São Vincente,13,,-5.4,-43.3
br,sao vincente,São Vincente,16,,-1.033333,-50.366667
br,sao vincente,São Vincente,20,,-5.833333,-42.916667
br,sao virgilio,São Virgilio,23,,-29.2073,-51.1158
br,sao virgilio,São Virgílio,26,,-26.883333,-49.333333
br,sao vitor,São Vítor,15,,-18.8,-41.7
br,sao vitor,São Vítor,21,,-22.874583,-43.530219
br,sao vito,São Vito,27,,-22.729167,-47.308333
br,sao xavier,São Xavier,23,,-29.5,-54.633333
br,sapataria,Sapataria,26,,-26.666667,-52.083333
br,sapateiro,Sapateiro,05,,-12.083333,-39.283333
br,sapateiro,Sapateiro,26,,-26.666667,-52.083333
br,sapato,Sapato,05,,-12.716667,-38.133333
br,sapatu,Sapatu,27,,-24.653594,-48.346033
br,sapeacu,Sapeaçu,05,,-12.733333,-39.216667
br,sapecada,Sapecada,18,,-24.166667,-51.533333
br,sapecado,Sapecado,15,,-20.45,-44.55
br,sapecado,Sapecado,20,,-5.466667,-41.4
br,sapecado,Sapecado,27,,-21.666667,-46.666667
br,sapesal,Sapesal,27,,-22.35,-50.65
br,sape,Sapé,05,,-12.383333,-38.35
br,sape,Sapé,13,,-5.633333,-43.316667
br,sape,Sapé,14,,-16.183333,-57.633333
br,sape,Sapé,15,,-16.15,-43.833333
br,sape,Sapé,17,36149,-7.1,-35.216667
br,sape,Sapé,18,,-23.626816,-50.027095
br,sape,Sapé,20,,-7.4,-43.183333
br,sape,Sapé,21,,-22.183333,-41.8
br,sape,Sapé,28,,-10.966667,-37.383333
br,sape,Sapé,29,,-17.55,-48.616667
br,sape,Sapé,30,,-7.65,-35.433333
br,sapezal,Sapèzal,14,,-14.966667,-57.2
br,sapezal,Sapèzal,27,,-22.35,-50.65
br,sapezeiro,Sapèzeiro,27,,-22.233333,-47.583333
br,sapicoa,Sapicoá,11,,-18.9,-57.116667
br,sapiranga,Sapiranga,23,76053,-29.633333,-51
br,sapitanduva,Sapitanduva,18,,-25.455013,-48.825218
br,sapopema,Sapopema,18,,-23.910208,-50.579531
br,sapopemba,Sapopemba,27,,-23.101482,-47.744607
br,sapo queimado,Sapo Queimado,30,,-8.5,-36.533333
br,sapo,Sapó,06,,-3.366667,-40.15
br,sapo,Sapo,15,,-18.95,-43.366667
br,sapucaeiro,Sapucaeiro,05,,-18.083333,-39.916667
br,sapucahy mirim,Sapucahy Mirim,27,,-22.75,-45.742236
br,sapucaia de guanhaes,Sapucaia de Guanhães,15,,-18.95,-42.616667
br,sapucaia do norte,Sapucaia do Norte,15,,-18.833333,-41.516667
br,sapucaial,Sapucaial,20,,-5.033333,-41.75
br,sapucaia,Sapucaia,02,,-9.55,-36.066667
br,sapucaia,Sapucaia,04,,-3.383333,-57
br,sapucaia,Sapucaia,05,,-11.45,-40.533333
br,sapucaia,Sapucaia,08,,-19.333333,-40.583333
br,sapucaia,Sapucaia,13,,-3.323056,-43.442222
br,sapucaia,Sapucaia,15,,-16.166667,-40.866667
br,sapucaia,Sapucaia,16,,-1.066667,-46.75
br,sapucaia,Sapucaia,20,,-3.505278,-42.506389
br,sapucaia,Sapucaia,21,12329,-22,-42.9
br,sapucaia,Sapucaia,23,130939,-29.833333,-51.15
br,sapucaia,Sapucaia,28,,-10.633333,-36.883333
br,sapucaia,Sapucaia,30,,-8.35,-35.833333
br,sapucaia,Sapucaia,31,,-5.55,-47.583333
br,sapucaieiro,Sapucaieiro,05,,-18.083333,-39.916667
br,sapucai-mirim,Sapucaí-Mirim,27,,-22.75,-45.742236
br,sapucai,Sapucaí,15,,-22.316667,-46.7
br,sapucarana,Sapucarana,30,,-8.35,-35.833333
br,sapupara,Sapupara,06,,-3.95,-38.7
br,sapuparo,Sapuparo,06,,-3.95,-38.7
br,sapyranga,Sapyranga,23,,-29.633333,-51
br,saquarema,Saquarema,21,62057,-22.933333,-42.5
br,saquassu,Saquassu,21,,-22.90609,-43.651396
br,saquim,Saquim,17,,-6.416667,-38.466667
br,saquinho,Saquinho,05,,-12.35,-38.966667
br,saquinho,Saquinho,06,,-5.116667,-40.216667
br,saquinho,Saquinho,13,,-3.591944,-42.999167
br,saquinho,Saquinho,17,,-6.483333,-37.85
br,saquinho,Saquinho,20,,-3.484444,-42.351111
br,saquinho,Saquinho,22,,-6.216667,-37.783333
br,saquinho,Saquinho,30,,-7.983333,-38
br,saracura,Saracura,04,,-.8,-62.966667
br,saracura,Saracura,27,,-23.289769,-47.983667
br,saracuru,Saracuru,16,,-1.333333,-52.2
br,saraiago,Saraiago,05,,-9.616667,-43.3
br,saraiva,Saraiva,15,,-16.75,-40.5
br,saraiva,Saraiva,29,,-15.566667,-49.433333
br,sarandira,Sarandira,15,,-21.829722,-43.186944
br,sarandi,Sarandi,15,,-21.816667,-42.9
br,sarandi,Sarandi,18,84698,-23.433333,-51.866667
br,sarandi,Sarandi,23,15159,-27.933333,-52.916667
br,sarandi,Sarandi,27,,-21.066667,-47.75
br,sarandy,Sarandy,15,,-21.829722,-43.186944
br,sarandy,Sarandy,23,,-30.666667,-55.95
br,sarandy,Sarandy,27,,-21.066667,-47.75
br,sarapia,Sarapiá,18,,-25.5222,-48.8039
br,sarapo,Sarapó,17,,-7.366667,-36.95
br,sarapuhy,Sarapuhy,27,,-23.6412,-47.8258
br,sarapui,Sarapui,27,,-23.40636,-47.775074
br,sarare de baixo,Sararé de Baixo,14,,-16.733333,-57.133333
br,sarare,Sararé,14,,-16.733333,-57.133333
br,sara-sara,Sará-Sará,27,,-23.666667,-47.083333
br,sarauna,Sarauna,05,,-13.833333,-40.8
br,sardinha,Sardinha,11,,-21.9,-56.883333
br,sardinha,Sardinha,13,,-5.733333,-45.333333
br,sardoa,Sardoá,15,,-18.766667,-42.383333
br,sargento,Sargento,06,,-4.833333,-37.833333
br,sargento,Sargento,26,,-26.416667,-53.15
br,saria,Sariã,04,,-5.794722,-65.644722
br,sariema,Sariema,06,,-5.683333,-40.683333
br,sariema,Sariema,13,,-3.450833,-43.1725
br,sarutaia,Sarutaiá,27,,-23.266667,-49.45
br,sarutai,Sarutai,27,,-23.266667,-49.45
br,sarutaya,Sarutaya,27,,-23.266667,-49.45
br,sarvuela,Sarvuela,24,,-13.55,-60.6
br,sarzeda,Sarzêda,31,,-11.65,-47.383333
br,sarzedo,Sarzedo,15,20800,-20.033333,-44.15
br,sassafraz,Sassafráz,05,,-10.605556,-45.835833
br,sassego,Sâssego,15,,-20.016667,-41.616667
br,sassoro,Sassoró,11,,-23.566667,-54.766667
br,satao,Satão,06,,-6.633333,-40.383333
br,satiro dias,Sátiro Dias,05,,-11.6,-38.6
br,satiro,Sátiro,20,,-3.431111,-42.023056
br,satoro ohara,Satoro Ohara,27,,-20.833333,-51.166667
br,satuba,Satuba,02,15898,-9.566667,-35.816667
br,satubim,Satubim,16,,-1.233333,-46.366667
br,satucaia,Satucaia,04,,-3.383333,-57
br,saturnino braga,Saturnino Braga,21,,-21.883333,-41.183333
br,saturnino,Saturnino,15,,-20.966667,-45.2
br,sauacu,Sauaçu,08,,-19.816667,-40.266667
br,saubara,Saubara,05,15669,-12.75,-38.75
br,saudade,Saudade,04,,-5.952778,-64.312778
br,saudade,Saudade,05,,-12.233333,-37.983333
br,saudade,Saudade,06,,-4.6,-41.05
br,saudade,Saudade,08,,-20.65,-41.533333
br,saudade,Saudade,11,,-21.083333,-56.116667
br,saudade,Saudade,15,,-21.929722,-43.060278
br,saudade,Saudade,16,,-1.183333,-52.033333
br,saudade,Saudade,21,,-22.25,-42.966667
br,saudade,Saudade,26,,-26.95,-52.966667
br,saudade,Saudade,27,,-23.9,-47.616667
br,saudade,Saudade,30,,-7.8,-39.766667
br,saudades,Saudades,26,,-26.95,-52.966667
br,saudavel,Saudável,05,,-12.1,-42.183333
br,saude,Saúde,02,,-9.516667,-35.616667
br,saude,Saúde,05,,-10.933333,-40.4
br,saude,Saúde,15,,-19.95,-45.066667
br,saude,Saúde,21,,-22.897548,-43.184724
br,saude,Saúde,27,,-23.6,-46.633333
br,saue,Saué,30,,-8.766667,-35.3
br,sauia,Sauiá,16,,-.733333,-56.866667
br,sauipe de dentro,Sauípe de Dentro,05,,-12.35,-37.933333
br,saumama,Saumama,01,,-8.35,-71.4
br,sauraura,Sauraura,04,,-5.333333,-59.7
br,sauva,Saúva,04,,-6.35,-61.8
br,savanduva,Savanduva,23,,-27.95,-51.8
br,saycan,Saycan,23,,-29.85,-54.966667
br,schroeder,Schroeder,26,15515,-26.433333,-49.066667
br,seabra,Seabra,01,,-8.166667,-70.766667
br,seabra,Seabra,05,16765,-12.416667,-41.766667
br,seabra,Seabra,15,,-20.0188,-43.8327
br,seara,Seara,26,10976,-27.116667,-52.283333
br,sebastiana,Sebastiana,21,,-22.27688,-42.865961
br,sebastianopolis do sul,Sebastianópolis do Sul,27,,-20.65,-49.9
br,sebastianopolis,Sebastianópolis,22,,-5.466667,-37.516667
br,sebastianopolis,Sebastianopolis,27,,-20.65,-49.9
br,sebastian,Sebastian,21,,-22.343596,-42.861477
br,sebastiao abreu,Sebastião Abreu,15,,-20.216667,-45.05
br,sebastiao bruno,Sebastião Bruno,15,,-20.316667,-45.2
br,sebastiao caixao,Sebastião Caixão,20,,-6.366667,-40.833333
br,sebastiao crispim,Sebastião Crispim,15,,-18.5,-41.966667
br,sebastiao da barra,Sebastião da Barra,15,,-20.616667,-41.6
br,sebastiao de lacerda,Sebastião de Lacerda,06,,-5.433333,-39.35
br,sebastiao de lacerda,Sebastião de Lacerda,21,,-22.288611,-43.579167
br,sebastiao ferreira,Sebastião Ferreira,02,,-9.8,-36.066667
br,sebastiao ferreira,Sebastião Ferreira,15,,-17.466667,-41.433333
br,sebastiao goncalves,Sebastião Gonçalves,15,,-16.916667,-41.733333
br,sebastiao lopes,Sebastião Lopes,15,,-20.066667,-46.066667
br,sebastiao nunes,Sebastião Nunes,08,,-20.6,-41.816667
br,sebastiao pereira,Sebastião Pereira,07,,-15.966667,-47.416667
br,sebastiao pereira,Sebastião Pereira,11,,-23.366667,-55.216667
br,sebastiao,Sebastião,17,,-7.2,-37.15
br,sebastopol,Sebastopol,04,,-7.566667,-65.5
br,sebastopol,Sebastopol,25,,3.533333,-60.016667
br,seberi,Seberi,23,,-27.483333,-53.4
br,secador,Secador,05,,-15.416667,-39.483333
br,secao schneider,Seção Schneider,26,,-26.532241,-49.831931
br,seca,Sêca,23,,-28.7,-51.7
br,secco do boi,Secco do Boi,05,,-11,-42.766667
br,seco do manduca,Sêco do Manduca,24,,-11.3,-61.9
br,seco,Sêco,05,,-13.616667,-41.533333
br,seco,Sêco,14,,-15.666667,-56.533333
br,secretario,Secretário,21,,-22.325278,-43.1825
br,seculo vigesimo,Século Vigésimo,23,,-29.1344,-51.1316
br,seculo xx,Século XX,23,,-29.1344,-51.1316
br,secundino veiga,Secundino Veiga,27,,-23.2,-46.833333
br,secundo,Secundo,15,,-17.083333,-40.616667
br,secura,Secura,13,,-3.638889,-43.0775
br,sede cacimba de baixo,Séde Cacimba de Baixo,22,,-6.05,-37.533333
br,sede da fazenda da lagoa dourada,Sede da Fazenda da Lagoa Dourada,18,,-25.625031,-50.00574
br,sede nova,Sede Nova,23,,-27.633333,-53.966667
br,sede,Sede,23,,-30.15,-55.066667
br,sede uniao,Sede União,18,,-26.038611,-53.534722
br,segredo,Segrêdo,05,,-12.016667,-41.616667
br,segredo,Segrêdo,08,,-20.833333,-41.616667
br,segredo,Segrêdo,16,,-1,-52.5
br,segredo,Segrêdo,18,,-25.716667,-52.116667
br,segredo,Segrêdo,20,,-4.95,-41.55
br,segredo,Segrêdo,23,,-28.766667,-51.383333
br,seguido rodrigues,Seguido Rodrigues,15,,-20.483333,-45.75
br,segundo alianca,Segundo Alianca,27,,-20.933333,-51.15
br,segundo faxinal dos castilhos,Segundo Faxinal dos Castilhos,18,,-25.844658,-50.014079
br,segundo ja come,Segundo Já Come,22,,-5.909444,-37.094444
br,segundo passa-dois,Segundo Passa-Dois,18,,-25.745521,-50.101277
br,segundo,Segundo,30,,-8.6,-38.566667
br,seguro,Seguro,05,,-12.766667,-38.366667
br,seguro,Seguro,17,,-7.016667,-36.316667
br,seis carnaubas,Seis Carnaúbas,06,,-4.516667,-38.433333
br,seis irmaos,Seis Irmâos,22,,-5.311389,-36.223889
br,seival,Seival,23,,-31.45,-53.75
br,seixa,Seixa,05,,-13.05,-39.416667
br,seixas,Seixas,05,,-13.05,-39.416667
br,selado,Selado,14,,-15.466667,-57.35
br,selbach,Selbach,23,,-28.633333,-52.966667
br,selke,Selke,26,,-26.8019,-49.1405
br,sellado,Sellado,14,,-15.466667,-57.35
br,sellin,Sellin,26,,-27.009235,-49.511264
br,selva,Selva,18,,-23.433333,-51.133333
br,se-me-apanhas,Se-me-Apanhas,13,,-8.166667,-45.633333
br,sem peixe,Sem Peixe,15,,-20.1,-42.85
br,sempre viva,Sempre Viva,04,,-4.403056,-59.907778
br,sempre-viva,Sempre-Viva,04,,-5.666667,-61.266667
br,sempre viva,Sempre Viva,05,,-13.65,-39.85
br,sempre-viva,Sempre-Viva,05,,-13.666667,-40.833333
br,sem rival,Sem Rival,20,,-6.633333,-41.25
br,sem-sal,Sem-Sal,18,,-25.766642,-50.153743
br,sem-tripa,Sem-Tripa,16,,-4.566667,-54.016667
br,senador amaral,Senador Amaral,15,,-22.583333,-46.183333
br,senador camara,Senador Camará,21,,-22.877888,-43.485013
br,senador canedo,Senador Canedo,29,61801,-16.716667,-49.083333
br,senador cortes,Senador Côrtes,15,,-21.8,-42.933333
br,senador firmino,Senador Firmino,15,,-20.916667,-43.1
br,senador guiomard,Senador Guiomard,01,11727,-10.166667,-67.833333
br,senador jose bento,Senador José Bento,15,,-22.166667,-46.166667
br,senador jose porfirio,Senador José Porfírio,16,5708,-2.583333,-51.916667
br,senador lemos,Senador Lemos,15,,-22.066667,-45.533333
br,senador mourao,Senador Mourão,15,,-17.85,-43.366667
br,senador pompeu,Senador Pompeu,06,16516,-5.583333,-39.366667
br,senador sa,Senador Sá,06,,-3.366667,-40.45
br,senador tiburcio,Senador Tibúrcio,30,,-8.55,-35.85
br,senador vasconcelos,Senador Vasconcelos,21,,-22.895562,-43.531947
br,senador victorino,Senador Victorino,11,,-20.566667,-52.216667
br,senador vitorino freire,Senador Vitorino Freire,13,,-4.066667,-45.166667
br,senador vitorino,Senador Vitorino,11,,-20.566667,-52.216667
br,sena madureira,Sena Madureira,01,20516,-9.066667,-68.666667
br,senandes,Senandes,23,,-32.15,-52.2
br,senegal,Senegal,01,,-10.583333,-69.966667
br,senges,Sengés,18,14868,-24.1,-49.483333
br,sengo,Sengó,15,,-22.116667,-44.95
br,senhora da gloria,Senhora da Glória,15,,-18.466667,-44.2
br,senhora da penha,Senhora da Penha,15,,-19.116667,-42.166667
br,senhora de oliveira,Senhora de Oliveira,15,,-20.8,-43.333333
br,senhora do carmo,Senhora do Carmo,15,,-19.5,-43.366667
br,senhora do porto,Senhora do Pôrto,15,,-18.883333,-43.1
br,senhora dos remedios,Senhora dos Remédios,15,,-21.033333,-43.583333
br,senhor bom jesus da lapa,Senhor Bom Jesus da Lapa,05,,-13.25,-43.416667
br,senhor do bonfim,Senhor do Bonfim,05,48472,-10.45,-40.183333
br,senhor dos passos,Senhor dos Passos,05,,-12.766667,-38.633333
br,senhorita,Senhorita,11,,-23.45,-55.083333
br,senhorita,Senhorita,14,,-16.2,-59.8
br,senhor porto,Senhor Pôrto,15,,-18.883333,-43.1
br,senho,Senhô,11,,-20.95,-53.166667
br,senna madureira,Senna Madureira,01,,-9.066667,-68.666667
br,sentim,Sentim,13,,-5.116667,-43.216667
br,sentinela,Sentinela,14,,-16.5,-57.2
br,sentinela,Sentinela,15,,-17.083333,-43.983333
br,sento ce,Sento Cé,05,,-9.666667,-41.3
br,sento se,Sento Sé,05,19596,-9.666667,-41.3
br,sepa forte,Sepa Forte,05,,-11.566667,-37.7
br,separacaco,Separaçãco,18,,-24.916667,-53.583333
br,separacao,Separação,18,,-26.316667,-53.2
br,sepetiba,Sepetiba,21,,-22.97817,-43.695916
br,sepotuba,Sepotuba,14,,-15.866667,-57.616667
br,sepultura,Sepultura,15,,-20,-45.783333
br,sepultura,Sepultura,26,,-26.933333,-50.45
br,serafim correia,Serafim Correia,23,,-28.716667,-51.933333
br,serafim dias,Serafim Dias,06,,-5.716667,-39.666667
br,serafim dias,Serafim Dias,11,,-20.766667,-56.716667
br,serafim diez,Serafim Diez,11,,-20.766667,-56.716667
br,serafim schmidt,Serafim Schmidt,23,,-29.366667,-52.383333
br,serafina corea,Serafina Corêa,23,,-28.716667,-51.933333
br,serafina correia,Serafina Correia,23,,-28.716667,-51.933333
br,serafina,Serafina,30,,-7.983333,-37.966667
br,serafina torrein,Serafina Torrein,23,,-28.716667,-51.933333
br,serceira,Serceira,21,,-22.75,-42.2
br,serebinho,Serebinho,05,,-11.733333,-37.516667
br,serelepe,Serelepe,27,,-22.2,-47.383333
br,sereno,Sereno,06,,-3.833333,-40.3
br,sereno,Sereno,15,,-21.316667,-42.65
br,sergio correia,Sérgio Correia,15,,-17.016667,-45.533333
br,sergio,Sérgio,15,,-14.816667,-44.3
br,sergipe,Sergipe,27,,-21.133333,-50.8
br,sergi,Sergi,05,,-12.433333,-38.866667
br,seribinha,Seribinha,05,,-11.733333,-37.516667
br,sericita,Sericita,15,,-20.483333,-42.483333
br,serido,Seridó,17,,-6.85,-36.416667
br,seriema,Seriema,30,,-7.9,-37.883333
br,serieme,Serieme,20,,-6.15,-42.516667
br,seringal aripuana,Seringal Aripuanã,04,,-9.05,-67.316667
br,seringal axioma,Seringal Axioma,04,,-6.75,-64.516667
br,seringal boa agua,Seringal Boa Água,01,,-9.833333,-67.283333
br,seringal boa esperanca,Seringal Boa Esperança,01,,-10.083333,-69.133333
br,seringal boa fonte,Seringal Boa Fonte,01,,-10.1,-69.266667
br,seringal bom destino,Seringal Bom Destino,01,,-9.95,-67.183333
br,seringal campinas,Seringal Campinas,04,,-9.15,-67.45
br,seringal curitiba,Seringal Curitiba,01,,-10.05,-69.083333
br,seringal entre-rios,Seringal Entre-Rios,04,,-9.15,-67.383333
br,seringal granada central,Seringal Granada Central,01,,-9.8,-67.083333
br,seringal guaraja,Seringal Guarajá,04,,-9.016667,-67.35
br,seringal nova fe,Seringal Nova Fé,04,,-5.639722,-63.634444
br,seringal nova olinda,Seringal Nova Olinda,01,,-10.116667,-69.183333
br,seringal novo acordo,Seringal Novo Acordo,01,,-9.933333,-67.016667
br,seringal novo encanto,Seringal Novo Encanto,04,,-9.65,-67.1
br,seringal paraguacu,Seringal Paraguaçu,01,,-10.933333,-69.566667
br,seringal piratini,Seringal Piratini,01,,-9.933333,-67.45
br,seringal porto central,Seringal Porto Central,04,,-9.166667,-67.45
br,seringal rio verde,Seringal Rio Verde,14,,-12.8,-56.25
br,seringal sacado,Seringal Sacado,01,,-10.933333,-69.25
br,seringal santa filomena,Seringal Santa Filomena,04,,-9.25,-67.433333
br,seringal santa maria,Seringal Santa Maria,01,,-9.933333,-67.266667
br,seringal santa maria,Seringal Santa Maria,04,,-6.866667,-64.666667
br,seringal santana,Seringal Santana,01,,-10.216667,-69.416667
br,seringal sao domingos,Seringal São Domingos,01,,-9.783333,-67.066667
br,seringal sao francisco,Seringal São Francisco,04,,-9.083333,-67.4
br,seringal sao joao,Seringal São João,04,,-9.583333,-67.083333
br,seringal sao vicente,Seringal São Vicente,01,,-9.9,-67.433333
br,seringal setenta,Seringal Setenta,24,,-10.325,-62.627778
br,seringal sobral,Seringal Sobral,04,,-9.033333,-67.35
br,seringal tabatinga,Seringal Tabatinga,01,,-10.166667,-69.333333
br,seringal tres lagoas,Seringal Três Lagoas,14,,-13.783333,-56.533333
br,seringal triunfo,Seringal Triunfo,01,,-9.083333,-70.033333
br,seringal triunfo,Seringal Triunfo,04,,-9.001944,-67.35
br,seringa,Seringa,20,,-3.479167,-42.5075
br,seringueiro,Seringueiro,06,,-4.433333,-38.45
br,serinhaem,Serinhaem,30,,-8.583333,-35.116667
br,serio,Sério,23,,-29.383333,-52.266667
br,seritinga,Seritinga,15,,-21.9,-44.5
br,serji,Serji,05,,-12.433333,-38.866667
br,seropedica,Seropédica,21,54846,-22.747222,-43.716944
br,serpa,Serpa,04,,-3.05,-58.433333
br,serpa,Serpa,06,,-4.016667,-38.483333
br,serra aguda,Serra Aguda,22,,-5.991944,-36.18
br,serra alegre,Serra Alegre,27,,-23.415755,-46.699113
br,serra alta,Serra Alta,26,,-26.249722,-49.3825
br,serra areiao,Serra Areião,16,,-.95,-52.483333
br,serra azul,Serra Azul,05,,-11.333333,-40.4
br,serra azul,Serra Azul,06,,-5.6,-40.933333
br,serra azul,Serra Azul,15,,-20.066667,-44.433333
br,serra azul,Serra Azul,22,,-5.816667,-35.783333
br,serra azul,Serra Azul,27,,-21.316667,-47.566667
br,serra baixa verde,Serra Baixa Verde,06,,-6.166667,-40.833333
br,serra bonita,Serra Bonita,15,,-15.216667,-46.816667
br,serra bonita,Serra Bonita,22,,-6.083333,-36
br,serra branca,Serra Branca,05,,-11.15,-39.316667
br,serra branca,Serra Branca,17,8765,-6.533333,-38.266667
br,serra branca,Serra Branca,22,,-5.896944,-36.804167
br,serra branca,Serra Branca,30,,-7.566667,-40.2
br,serra bravo,Serra Bravo,06,,-7.25,-38.8
br,serra cadeado,Serra Cadeado,23,,-28.566667,-53.816667
br,serra caiada,Serra Caiada,22,,-6.1,-35.7
br,serra cruz,Serra Cruz,17,,-7.633333,-36.25
br,serra da boa vista,Serra da Boa Vista,05,,-13.2,-40.15
br,serra da canabrava,Serra da Canabrava,05,,-9.75,-39.616667
br,serra da canastra,Serra da Canastra,15,,-20.133333,-46.65
br,serra da esperanca,Serra da Esperança,26,,-26.833333,-50.666667
br,serra d' agua,Serra d' Agua,05,,-12.583333,-38.816667
br,serra d'agua,Serra d'Agua,06,,-5.466667,-39.45
br,serra d'agua,Serra d'Agua,27,,-22.366667,-47.6
br,serra d'alva,Serra d'Alva,30,,-8.633333,-36.083333
br,serra da macambira,Serra da Macambira,22,,-5.440278,-36.025833
br,serra da ouricana,Serra da Ouricana,05,,-14.5,-40.15
br,serra da palha,Serra da Palha,17,,-7.45,-38.433333
br,serra da prata,Serra da Prata,18,,-24.783333,-51.083333
br,serra da raiz,Serra da Raiz,17,,-6.683333,-35.433333
br,serra da rodagem,Serra da Rodagem,06,,-6.283333,-40.766667
br,serra da rosa,Serra da Rosa,05,,-12.133333,-40.55
br,serra das almas,Serra das Almas,22,,-6.216667,-38.366667
br,serra das araras,Serra das Araras,15,,-15.5,-45.35
br,serra da saudade,Serra da Saudade,15,,-19.433333,-45.783333
br,serra das canoas,Serra das Canoas,26,,-27.174019,-49.666169
br,serra das queimadas,Serra das Queimadas,22,,-5.726944,-36.318611
br,serra das vacas,Serra das Vacas,30,,-8.9,-36.733333
br,serra da volta,Serra da Volta,22,,-5.570278,-36.611389
br,serra de santo estevao,Serra de Santo Estevão,06,,-4.9,-39.15
br,serra de sao bento,Serra de São Bento,22,,-6.416667,-35.633333
br,serrade zuzo,Serrade Zuzo,30,,-7.9,-37.8
br,serra do abiar,Serra do Abiar,05,,-13.3,-39.35
br,serra do amuado,Serra do Amuado,26,,-27.1858,-49.7312
br,serra do apora,Serra do Aporá,05,,-11.716667,-38.233333
br,serra do bocu,Serra do Bocu,30,,-7.45,-39.666667
br,serra do cabugizinho,Serra do Cabugizinho,22,,-5.75,-36.3
br,serra do caete,Serra do Caetê,18,,-23.981129,-50.448518
br,serra do camapua,Serra do Camapuã,15,,-20.766667,-44.016667
br,serra do capim,Serra do Capim,21,,-22.166667,-42.85
br,serra do cicero ferreira,Serra do Cicero Ferreira,06,,-6.4,-40.783333
br,serra do cigano,Serra do Cigano,30,,-8.016667,-38.383333
br,serra do coral,Serra do Coral,15,,-17.9,-41.05
br,serra do cuite,Serra do Cuité,17,,-6.483333,-36.15
br,serra do doutor,Serra do Doutor,22,,-6.233333,-36.183333
br,serra do gado,Serra do Gado,22,,-5.469722,-36.768889
br,serra do jacaranda,Serra do Jacaranda,20,,-5.866667,-42.783333
br,serra do joaozinho do mestre pedro,Serra do Joâozinho do Mestre Pedro,20,,-6.266667,-40.85
br,serra do matoso,Serra do Matoso,21,,-22.782778,-43.849444
br,serra do meio,Serra do Meio,06,,-5.966667,-40.916667
br,serra do miguel,Serra do Miguel,22,,-6.183333,-38.333333
br,serra do miradouro,Serra do Miradouro,26,,-26.8545,-49.9877
br,serra do navio,Serra do Navio,03,,.983333,-52.05
br,serra do padre,Serra do Padre,17,,-6.433333,-38.55
br,serra do pateirao,Serra do Pateirão,05,,-15.45,-40.716667
br,serra do pedrao,Serra do Pedrão,02,,-9.466667,-37.15
br,serra do raimundo bernardo,Serra do Raimundo Bernardo,20,,-6.266667,-40.833333
br,serra dos aimores,Serra dos Aimorés,15,,-17.766667,-40.25
br,serra do salitre,Serra do Salitre,15,,-19.1,-46.683333
br,serra dos alves,Serra dos Alves,26,,-27.5,-49.783333
br,serra dos dourados,Serra dos Dourados,18,,-23.55,-53.416667
br,serra dos marques,Serra dos Marques,15,,-22.5526,-45.5709
br,serra dos matoes,Serra dos Matões,20,,-4.383333,-41.433333
br,serra do sobrado,Serra do Sobrado,20,,-7.816667,-41.216667
br,serra do sobrodo,Serra do Sobrodo,20,,-7.816667,-41.216667
br,serra do tumil,Serra do Tumil,26,,-27.1808,-49.7073
br,serra dourada,Serra Dourada,29,,-14.683333,-49.266667
br,serra do valente,Serra do Valente,20,,-5.883333,-41.633333
br,serra do velho artur,Serra do Velho Artur,06,,-6.416667,-40.783333
br,serra do vento,Serra do Vento,30,,-8.233333,-36.366667
br,serra do vital,Serra do Vital,17,,-7.033333,-38.583333
br,serra feia,Serra Feia,18,,-23.634565,-50.227359
br,serra fita,Serra Fita,18,,-25.61906,-50.30704
br,serra fria,Serra Fria,18,,-23.861469,-50.614125
br,serragem,Serragem,06,,-4.416667,-38.5
br,serragem,Serragem,20,,-3.624722,-42.578333
br,serragem,Serragem,30,,-7.816667,-38.3
br,serra grande,Serra Grande,05,,-12.5,-40.6
br,serra grande,Serra Grande,17,,-7.25,-38.316667
br,serra grande,Serra Grande,27,,-24.9873,-48.5881
br,serra grande,Serra Grande,30,,-8.2,-35.35
br,serra jo janiao,Serra Jo Janião,15,,-20.2,-41.566667
br,serra laurentino,Serra Laurentino,26,,-27.169568,-49.718404
br,serra limpa,Serra Limpa,02,,-9.666667,-36.45
br,serra morena,Serra Morena,18,,-23.233333,-50.85
br,serra mossoro,Serra Mossoró,22,,-5.084722,-37.45
br,serrana,Serrana,27,39826,-21.233333,-47.6
br,serra negra do norte,Serra Negra do Norte,22,,-6.666667,-37.4
br,serra negra,Serra Negra,05,,-10.033333,-37.9
br,serra negra,Serra Negra,13,,-6.1,-44.133333
br,serra negra,Serra Negra,15,,-18.833333,-46.783333
br,serra negra,Serra Negra,18,,-25.164177,-48.411828
br,serra negra,Serra Negra,20,,-4.083333,-41.683333
br,serra negra,Serra Negra,22,,-6.666667,-37.4
br,serra negra,Serra Negra,27,22632,-22.6,-46.7
br,serrania,Serrania,13,,-1.633333,-45.15
br,serrania,Serrania,15,,-21.55,-46.05
br,serrania,Serrania,29,,-17.3,-49.466667
br,serranopolis,Serranópolis,15,,-15.8,-42.883333
br,serranopolis,Serranópolis,29,,-18.266667,-52
br,serranopolis,Serranópolis,31,,-12.103333,-47.767222
br,serrano,Serrano,27,,-22.6986,-45.7441
br,serranos,Serranos,15,,-21.85,-44.5
br,serra nova,Serra Nova,06,,-4.8,-40.133333
br,serra nova,Serra Nova,13,,-7.95,-47.1
br,serra nova,Serra Nova,15,,-15.65,-42.733333
br,serra nova,Serra Nova,20,,-8.983333,-42.866667
br,serra nova,Serra Nova,22,,-6.3,-37.833333
br,serra padilha,Serra Padilha,21,,-22.908217,-43.30505
br,serra pelada,Serra Pelada,08,,-19.983333,-41.033333
br,serra perdida,Serra Perdida,30,,-7.783333,-37.9
br,serra preta,Serra Preta,05,,-12.15,-39.333333
br,serra preta,Serra Prêta,22,,-5.833333,-36.356944
br,serra redonda,Serra Redonda,17,,-6.433333,-37.616667
br,serraria aimore,Serraria Aimoré,27,,-21.833333,-51.866667
br,serraria aimores,Serraria Aimores,27,,-21.833333,-51.866667
br,serraria alberto blum,Serraria Alberto Blum,18,,-24.883333,-53.383333
br,serraria do gentil,Serraria do Gentil,18,,-24.416667,-49.633333
br,serraria,Serraria,05,,-11.883333,-38.166667
br,serraria,Serraria,06,,-4.75,-38.4
br,serraria,Serraria,08,,-19.116667,-40.416667
br,serraria,Serraria,11,,-21.783333,-56.233333
br,serraria,Serraria,13,,-2.95,-46.633333
br,serraria,Serraria,15,,-22.016667,-43.2
br,serraria,Serraria,17,,-6.816667,-35.633333
br,serraria,Serraria,26,,-27.533333,-48.65
br,serraria stoltz,Serraria Stoltz,26,,-26.641824,-49.989958
br,serra sao miguel,Serra São Miguel,26,,-27.1104,-49.5251
br,serras das tabocas,Serras das Tabocas,30,,-7.4,-39.833333
br,serra,Serra,05,,-12.4,-39.516667
br,serra,Serra,08,394160,-20.116667,-40.3
br,serra,Serra,13,,-3.766667,-44.516667
br,serra,Serra,15,,-17.75,-42.183333
br,serra,Serra,20,,-7.25,-41.6
br,serra,Serra,21,,-22.1,-43.4
br,serra,Serra,27,,-21.366667,-47.216667
br,serra talhada,Serra Talhada,30,51204,-7.983333,-38.3
br,serra uru,Serra Uru,26,,-27.0183,-49.7283
br,serra vencida,Serra Vencida,26,,-27.120728,-49.720764
br,serra verde,Serra Verde,05,,-15.666667,-40.5
br,serra verde,Serra Verde,06,,-3.516667,-40.316667
br,serra verde,Serra Verde,17,,-7.366667,-38.55
br,serra verde,Serra Verde,18,,-25.119322,-48.35107
br,serra verde,Serra Verde,22,,-5.383333,-35.85
br,serra verde zabele,Serra Verde Zabele,22,,-5.366667,-35.733333
br,serra vermeiha,Serra Vermeiha,20,,-5.45,-40.033333
br,serra vermelha,Serra Vermelha,05,,-9.883333,-38.966667
br,serra vermelha,Serra Vermelha,06,,-5.666667,-38.316667
br,serra vermelha,Serra Vermelha,17,,-7.466667,-38.566667
br,serra vermelha,Serra Vermelha,20,,-7.833333,-44.166667
br,serra vermelha,Serra Vermelha,22,,-5.033889,-37.131111
br,serra vermelha,Serra Vermelha,30,,-8.233333,-38.433333
br,serrinha do canto,Serrinha do Canto,22,,-6.116667,-37.966667
br,serrinha do geraldo,Serrinha do Geraldo,06,,-7.016667,-40.183333
br,serrinha do itajai,Serrinha do Itajaí,26,,-26.5336,-49.9024
br,serrinha do mendanha,Serrinha do Mendanha,21,,-22.832101,-43.56262
br,serrinha dos pintos,Serrinha dos Pintos,22,,-6.1,-37.95
br,serrinha,Serrinha,02,,-9.416667,-37.35
br,serrinha,Serrinha,05,49079,-11.65,-39
br,serrinha,Serrinha,06,,-4.25,-38.833333
br,serrinha,Serrinha,11,,-21.783333,-56.233333
br,serrinha,Serrinha,13,,-7.916667,-46.95
br,serrinha,Serrinha,15,,-19.333333,-44.3
br,serrinha,Serrinha,17,,-7.15,-38.433333
br,serrinha,Serrinha,18,,-23.104309,-52.02316
br,serrinha,Serrinha,20,,-5.25,-41.366667
br,serrinha,Serrinha,21,,-22.369635,-42.887365
br,serrinha,Serrinha,22,,-6.25,-37.85
br,serrinha,Serrinha,23,,-28.333333,-54.833333
br,serrinha,Serrinha,25,,2.633333,-61.116667
br,serrinha,Serrinha,26,,-26.975248,-49.74312
br,serrinha,Serrinha,27,,-21.15,-50.783333
br,serrinha,Serrinha,30,,-7.683333,-37.333333
br,serrinha,Serrinha,31,,-10.966667,-47.45
br,serrinha velha,Serrinha Velha,06,,-5.983333,-40.466667
br,serrinha velha,Serrinha Velha,23,,-29.366667,-52.85
br,serrita,Serrita,30,,-7.933333,-39.316667
br,serrito,Serrito,11,,-23.233333,-54.866667
br,serrito,Serrito,26,,-26.116667,-50.483333
br,serro azul,Serro Azul,18,,-24.833333,-49.25
br,serro do monte,Serro do Monte,17,,-7.366667,-36.133333
br,serrolandia,Serrolândia,05,,-11.433333,-40.3
br,serro negro,Serro Negro,26,,-27.8,-50.883333
br,serro,Sêrro,15,12616,-18.616667,-43.383333
br,serro,Sêrro,26,,-26.6,-49.15
br,serrota,Serrota,06,,-3.533333,-40.166667
br,serrota,Serrota,17,,-7.233333,-38.133333
br,serrota,Serrota,22,,-6.433333,-38.05
br,serrote alto,Serrote Alto,06,,-4.916667,-39.666667
br,serrote branco,Serrote Branco,06,,-5.466667,-38.883333
br,serrote branco,Serrote Branco,17,,-7.05,-37
br,serrote branco,Serrote Branco,22,,-5.969444,-36.876389
br,serrote branco,Serrote Branco,30,,-7.883333,-38.4
br,serrote campo comprido,Serrote Campo Comprido,17,,-7.083333,-37.316667
br,serrote da guia,Serrote da Guia,30,,-7.783333,-38.883333
br,serrote da mina,Serrote da Mina,06,,-4.283333,-39.683333
br,serrote de baixo,Serrote de Baixo,02,,-9.466667,-37.283333
br,serrote do boi,Serrote do Boi,30,,-8.783333,-38.483333
br,serrote do grengonso,Serrote do Grengonso,30,,-8.55,-36.383333
br,serrote do meio,Serrote do Meio,17,,-6.7,-37.833333
br,serrote duberto,Serrote Duberto,22,,-5.716667,-35.583333
br,serrote exu,Serrote Exu,06,,-4.05,-39.916667
br,serrote pelado,Serrote Pelado,30,,-9.016667,-38.233333
br,serrote pintado,Serrote Pintado,30,,-7.533333,-37.183333
br,serrote redondo,Serrote Redondo,17,,-7.05,-38.066667
br,serrotes brancos,Serrotes Brancos,22,,-5.851944,-36.386111
br,serrote,Serrote,02,,-9.733333,-37.233333
br,serrote,Serrote,05,,-10.05,-41.466667
br,serrote,Serrote,06,,-3.183333,-40.45
br,serrote,Serrote,15,,-22.066667,-46.383333
br,serrote,Serrote,17,,-6.683333,-38.433333
br,serrote,Serrote,30,,-7.9,-39.366667
br,serrote verde,Serrote Verde,17,,-6.7,-38.183333
br,serrote verde,Serrote Verde,30,,-7.816667,-37.666667
br,serrote vermelho,Serrote Vermelho,22,,-6.083333,-37.683333
br,serrotinho,Serrotinho,17,,-6.916667,-37.633333
br,serrotinho,Serrotinho,30,,-7.733333,-38.7
br,serro verde,Sêrro Verde,11,,-23.783333,-54.9
br,sertaneja,Sertaneja,18,,-23.05,-50.833333
br,sertanejo,Sertanejo,05,,-16.6,-40.1
br,sertania,Sertânia,30,18190,-8.083333,-37.266667
br,sertanopolis,Sertanópolis,18,13904,-23.066667,-51.033333
br,sertao de baixo,Sertão de Baixo,02,,-9.566667,-37
br,sertao de dentro,Sertão de Dentro,20,,-4.3,-41.683333
br,sertao de santana,Sertão de Santana,23,,-30.45,-51.6
br,sertao do calixto,Sertão do Calixto,21,,-22.306389,-43.307778
br,sertao,Sertão,15,,-20.85,-42.133333
br,sertao,Sertão,23,,-27.983333,-52.25
br,sertao,Sertão,30,,-8.766667,-37.166667
br,sertaosinho,Sertãosinho,02,,-9.533333,-37
br,sertaosinho,Sertãosinho,26,,-27,-52.05
br,sertaosinho,Sertãosinho,30,,-8.9,-35.733333
br,sertaozinho de baixo,Sertãozinho de Baixo,30,,-8.9,-35.733333
br,sertaozinho,Sertãozinho,02,,-9.533333,-37
br,sertaozinho,Sertãozinho,15,,-20.833333,-46.566667
br,sertaozinho,Sertãozinho,18,,-24.95,-53.05
br,sertaozinho,Sertãozinho,26,,-26.6196,-48.7365
br,sertaozinho,Sertãozinho,27,99213,-21.133333,-47.983333
br,servo,Servo,26,,-26.6,-49.15
br,sesmarias,Sesmarias,18,,-25.164622,-48.947339
br,sesta das parelhas,Sesta das Parelhas,28,,-9.7,-37.716667
br,sete barracas,Sete Barracas,27,,-22.816667,-47.716667
br,sete barras,Sete Barras,18,,-24.703082,-48.841575
br,sete barras,Sete Barras,27,,-24.383333,-47.916667
br,sete cachoeiras,Sete Cachoeiras,15,,-19.233333,-42.866667
br,sete de abril,Sete de Abril,21,,-22.928877,-43.637188
br,sete de setembro,Sete de Setembro,23,,-27.916667,-54.6
br,sete estrelas,Sete Estrêlas,01,,-8.45,-71.683333
br,sete fogoes,Sete Fogões,27,,-23.09273,-47.611087
br,sete lagoas,Sete Lagoas,15,201337,-19.45,-44.233333
br,sete lagoas,Sete Lagoas,20,,-8.45,-41.7
br,sete leguas,Sete Léguas,23,,-29.35,-52.4
br,setembrina,Setembrina,23,,-29.516667,-51.983333
br,setembrinha,Setembrinha,23,,-29.516667,-51.983333
br,setenta,Setenta,24,,-10.325,-62.627778
br,sete ponte,Sete Ponte,21,,-22.836944,-43.082778
br,sete pontes,Sete Pontes,21,,-22.836944,-43.082778
br,sete portas,Sete Pôrtas,05,,-13.7,-39.733333
br,sete ranchos,Sete Ranchos,15,,-16.533333,-40.266667
br,sete saltos de baixo,Sete Saltos de Baixo,18,,-25.2,-49.733333
br,sete saltos-para-baixo,Sete Saltos-para-Baixo,18,,-25.2,-49.733333
br,sete saltos,Sete Saltos,18,,-25.2,-49.733333
br,sete vargens,Sete Vargens,05,,-14.183333,-41.133333
br,sete voltas,Sete Voltas,11,,-21.783333,-55.183333
br,sete voltas,Sete Voltas,13,,-1.533333,-45.733333
br,setubal,Setúbal,13,,-3.905,-42.921389
br,setubal,Setúbal,22,,-6.033333,-37.4
br,setubinha,Setubinha,15,,-17.616667,-42.15
br,severiano d'almeida,Severiano d'Almeida,23,,-27.433333,-52.133333
br,severiano de almeida,Severiano de Almeida,23,,-27.433333,-52.133333
br,severiano melo,Severiano Melo,22,2503,-5.766667,-37.95
br,severiano,Severiano,15,,-16.533333,-40.7
br,severinia,Severínia,27,13212,-20.833333,-48.8
br,severino ribeiro,Severino Ribeiro,23,,-30.083333,-56.066667
br,severino,Severino,15,,-18.4,-48.316667
br,severo,Severo,30,,-8.15,-36.566667
br,sibo,Sibó,04,,-.366667,-66.6
br,sico,Sicó,02,,-9.083333,-37.766667
br,sideropolis,Siderópolis,26,8536,-28.583333,-49.433333
br,sidrolandia,Sidrolândia,11,16878,-20.916667,-54.966667
br,siempre viva,Siempre Viva,04,,-5.666667,-61.266667
br,silencio,Silêncio,23,,-30.283333,-55.9
br,silva campos,Silva Campos,15,,-19.1,-44.933333
br,silvado,Silvado,20,,-5.5,-41.616667
br,silva jardim,Silva Jardim,15,,-18.433333,-44.3
br,silva jardim,Silva Jardim,21,16889,-22.466667,-42.3
br,silvania,Silvânia,27,,-21.016667,-50.716667
br,silvania,Silvânia,29,11377,-16.666667,-48.6
br,silvanopolis,Silvanópolis,31,,-11.165833,-48.075556
br,silvano,Silvano,15,,-18.833333,-47.166667
br,silva paes,Silva Paes,23,,-28.733333,-51.7
br,silva pais,Silva Pais,23,,-28.733333,-51.7
br,silva reis,Silva Reis,18,,-23.916667,-50.1
br,silva,Silva,03,,1.816667,-50.783333
br,silva,Silva,05,,-9.983333,-38.9
br,silva,Silva,23,,-31.233333,-52.8
br,silva xavier,Silva Xavier,15,,-19.333333,-44.233333
br,silveira carvalho,Silveira Carvalho,15,,-21.3,-42.266667
br,silveira martins,Silveira Martins,23,,-29.65,-53.583333
br,silveirania,Silveirânia,15,,-21.166667,-43.2
br,silveira,Silveira,23,,-28.616667,-49.95
br,silveira,Silveira,27,,-22.666667,-44.866667
br,silveiras,Silveiras,15,,-21.166667,-43.2
br,silveiras,Silveiras,27,,-22.55,-46.916667
br,silverania,Silverânia,15,,-21.166667,-43.2
br,silverio nery,Silverio Nery,04,,-3.116667,-58.15
br,silverio,Silvério,13,,-1.65,-44.866667
br,silverio,Silvério,15,,-16.816667,-40.466667
br,silves,Silves,04,,-2.838056,-58.2125
br,silvestre-ferraz,Silvestre-Ferraz,15,,-22.116667,-45.133333
br,silvestre,Silvestre,18,,-23.5,-53.116667
br,silvestre,Silvestre,21,,-22.947531,-43.204268
br,silvestre,Silvestre,27,,-22.7,-46.816667
br,silvianopolis,Silvianópolis,15,,-22.033333,-45.833333
br,silvino aquino,Silvino Aquino,11,,-23.416667,-54.65
br,simao dias,Simão Dias,28,18386,-10.733333,-37.816667
br,simao nunes,Simão Nunes,14,,-16.333333,-57.733333
br,simao pereira,Simão Pereira,15,,-21.963889,-43.313056
br,simao,Simão,06,,-6.5,-40.65
br,simao,Simão,22,,-5.434167,-37.023611
br,simeao,Simeão,05,,-12.766667,-41.733333
br,simiao,Simião,25,,3.683333,-61.233333
br,simoes,Simões,20,4332,-7.6,-40.816667
br,simoes,Simões,27,,-21.7,-49.45
br,simonesia,Simonésia,15,,-20.116667,-42.016667
br,simonsen,Simonsen,27,,-20.45,-49.866667
br,simplicio mendes,Simplício Mendes,20,7076,-7.85,-41.9
br,simplicio,Simplício,15,,-16.516667,-40.916667
br,sincora,Sincorá,05,,-13.616667,-41.066667
br,sincora,Sincorá,13,,-3.95,-44.65
br,sincora velho,Sincorá Velho,05,,-13.5,-41.2
br,singular,Singular,06,,-5.216667,-40.4
br,sinhazinha,Sinhàzinha,15,,-16.433333,-40.983333
br,sinimbu,Sinimbu,02,,-9.916667,-36.133333
br,sinimbu,Sinimbu,23,,-29.533333,-52.533333
br,sintra,Sintra,04,,-7.122222,-62.846944
br,sinunga,Sinunga,05,,-12.7,-38.95
br,sipauba,Sipaúba,30,,-7.666667,-39.983333
br,sipicue,Sipicuê,11,,-22.55,-55.683333
br,sipo,Sipó,05,,-11.1,-38.516667
br,siqueira belo,Siqueira Belo,18,,-26.216667,-53.466667
br,siqueira campos,Siqueira Campos,08,,-20.766667,-41.683333
br,siqueira campos,Siqueira Campos,18,,-23.6877,-49.8295
br,siqueira,Siqueira,26,,-28.35,-48.883333
br,siqueiro,Siqueiro,26,,-28.35,-48.883333
br,siria,Síria,04,,-2.633333,-67.016667
br,siricucu,Siricucu,30,,-8.85,-36.116667
br,siriema,Siriema,13,,-3.710833,-43.480556
br,sirigado,Sirigado,05,,-11.783333,-41.966667
br,sirigi,Sirigí,30,,-7.6,-35.483333
br,siriji,Siriji,30,,-7.6,-35.483333
br,sirinhaem,Sirinhaém,05,,-13.833333,-38.966667
br,sirinhaem,Sirinhaém,30,,-8.583333,-35.116667
br,siriri,Siriri,18,,-25.20559,-48.429112
br,siriri,Siriri,28,,-10.583333,-37.133333
br,siriu,Siriú,26,,-27.978611,-48.641667
br,sitia,Sitiá,06,,-5.166667,-38.65
br,sitiio jurumirim,Sítiio Jurumirim,27,,-24.548526,-48.512916
br,sitinho,Sitinho,18,,-24.738863,-48.956419
br,sitinho,Sitinho,30,,-8.9,-37.416667
br,sitio abaete,Sítio Abaeté,27,,-23.9255,-47.1061
br,sitio abel galvao,Sítio Abel Galvão,18,,-23.36217,-50.023583
br,sitio abel gruber,Sítio Abel Gruber,26,,-26.2425,-49.9037
br,sitio abel rodrigues,Sítio Abel Rodrigues,18,,-23.461395,-49.777936
br,sitio abel sabatk,Sítio Abel Sabatk,26,,-26.1922,-49.9552
br,sitio abel schultz,Sítio Abel Schultz,26,,-26.1077,-49.8642
br,sitio abel veloso,Sítio Abel Veloso,18,,-23.737013,-50.572044
br,sitio abigail monteiro,Sítio Abigail Monteiro,18,,-25.076454,-48.831381
br,sitio abigail n. rangel,Sítio Abigail N. Rangel,18,,-26.0168,-49.8649
br,sitio abilio cardoso,Sítio Abílio Cardoso,18,,-25.7864,-49.4723
br,sitio abilio espirito santo,Sítio Abílio Espírito Santo,27,,-23.00173,-49.768854
br,sitio abilio messias,Sítio Abílio Messias,18,,-23.607064,-50.174881
br,sitio abilio vidal,Sítio Abílio Vidal,18,,-25.09957,-48.801079
br,sitio abner s. linhares,Sítio Abner S. Linhares,18,,-25.886667,-49.666667
br,sitio abobora,Sítio Abóbora,30,,-7.733333,-40.316667
br,sitio aboboras,Sítio Aboboras,06,,-5.866667,-40.433333
br,sitio abraao inacio,Sítio Abraão Inácio,18,,-25.2936,-48.5309
br,sitio abrao de p. lima,Sítio Abrão de P. Lima,18,,-25.7977,-49.154
br,sitio abrao godesk,Sítio Abrão Godesk,26,,-26.1985,-49.9586
br,sitio abrao konkl,Sítio Abrão Konkl,26,,-26.1434,-49.9496
br,sitio acacio f. dos reis,Sítio Acácio F. dos Reis,18,,-23.6881,-49.9032
br,sitio acacio felix,Sítio Acácio Félix,18,,-23.6535,-49.8885
br,sitio acacio nicolau,Sítio Acácio Nicolau,27,,-23.6357,-47.7498
br,sitio acelao moro,Sítio Acelão Moro,18,,-26.0684,-49.8222
br,sitio acioli c. nolasco,Sítio Acioli C. Nolasco,18,,-25.9757,-48.6744
br,sitio acir a. fernandes,Sítio Acir A. Fernandes,18,,-26.0238,-49.8688
br,sitio acir gross,Sítio Acir Gross,18,,-25.971725,-49.845389
br,sitio acir negrelle,Sítio Acir Negrelle,18,,-26.141383,-49.419989
br,sitio acir pinto,Sítio Acir Pinto,18,,-25.7148,-49.8138
br,sitio acir schilling,Sítio Acir Schilling,18,,-25.909334,-49.812153
br,sitio a. claras,Sítio A. Claras,27,,-23.582709,-47.174655
br,sitio adair c. da silva,Sítio Adair C. da Silva,18,,-25.5624,-48.8418
br,sitio adalberto alexandre,Sítio Adalberto Alexandre,18,,-23.302488,-50.238192
br,sitio adalberto bicudo,Sítio Adalberto Bicudo,18,,-26.010379,-49.647291
br,sitio adalberto gluck,Sítio Adalberto Gluck,18,,-25.759722,-49.739167
br,sitio adalto n. tetu,Sítio Adalto N. Tetu,18,,-25.9305,-49.2762
br,sitio adao berniak,Sítio Adão Berniak,18,,-25.8373,-49.5582
br,sitio adao bots,Sítio Adão Bots,18,,-25.7879,-49.5985
br,sitio adao cersoscki,Sítio Adão Cersoscki,18,,-25.8647,-49.5399
br,sitio adao covask,Sítio Adão Covask,18,,-25.5042,-49.9865
br,sitio adao daudt,Sítio Adão Daudt,18,,-25.8076,-49.5696
br,sitio adao jukrienski,Sítio Adão Jukrienski,18,,-25.984167,-49.741389
br,sitio adao klisievcz,Sítio Adão Klisievcz,18,,-25.964,-49.4361
br,sitio adao marzur,Sítio Adão Marzur,18,,-25.757421,-49.483411
br,sitio adao m. de paula,Sítio Adão M. de Paula,18,,-26.130193,-49.666089
br,sitio adao pirachovoski,Sítio Adão Pirachovoski,18,,-25.9444,-49.4595
br,sitio adao przblovixz,Sítio Adão Przblovixz,18,,-25.7981,-49.5396
br,sitio adao salak,Sítio Adão Salak,18,,-25.8225,-49.508
br,sitio adao scheneider,Sítio Adão Scheneider,27,,-23.746842,-47.51428
br,sitio adao simonsen,Sítio Adão Simonsen,18,,-25.8683,-49.575
br,sitio adao,Sítio Adão,18,,-23.971,-50.9293
br,sitio adao s. sante,Sítio Adão S. Santé,18,,-23.5325,-49.8797
br,sitio adario costa,Sítio Adário Costa,18,,-23.924755,-50.482993
br,sitio adauto a. franco,Sítio Adauto A. Franco,18,,-25.9938,-49.2228
br,sitio adega sao jose,Sítio Adega São José,27,,-23.541597,-47.103085
br,sitio adelaide,Sítio Adelaide,18,,-23.431727,-49.836435
br,sitio adelicio bonfa,Sítio Adelício Bonfa,18,,-23.396881,-49.988151
br,sitio adelina cordeiro,Sítio Adelina Cordeiro,18,,-25.10758,-48.826346
br,sitio adelino a. da silva,Sítio Adelino A. da Silva,18,,-25.5636,-48.8436
br,sitio adelino bacatinho,Sítio Adelino Bacatinho,18,,-23.5136,-49.9206
br,sitio adelino de o. castro,Sítio Adelino de O. Castro,18,,-23.895784,-50.551388
br,sitio adelino ferreira,Sítio Adelino Ferreira,18,,-23.5118,-49.9248
br,sitio adelino g. ribeiro,Sítio Adelino G. Ribeiro,18,,-23.533888,-50.660999
br,sitio adelino javilaski,Sítio Adelino Javilaski,18,,-25.921129,-49.233601
br,sitio adelino sanches,Sítio Adelino Sanches,18,,-23.1993,-50.0665
br,sitio adelino seidel,Sítio Adelino Seidel,26,,-26.1012,-49.9794
br,sitio adelir ratti,Sítio Adelir Ratti,18,,-25.459157,-48.853799
br,sitio ademar lemos,Sítio Ademar Lemos,18,,-23.423551,-49.927689
br,sitio ademar stivan,Sítio Ademar Stivan,18,,-23.5463,-49.9501
br,sitio ademir a. dos santos,Sítio Ademir A. dos Santos,18,,-23.5351,-49.8976
br,sitio ademir cirilo da silva,Sítio Ademir Cirilo da Silva,18,,-23.377544,-50.075117
br,sitio ademir de andrade,Sítio Ademir de Andrade,18,,-23.568101,-50.000822
br,sitio ademir gelbk,Sítio Ademir Gelbk,26,,-26.197,-49.9429
br,sitio ademir mingotte,Sítio Ademir Mingotte,18,,-23.930036,-50.155942
br,sitio ademir nicolele,Sítio Ademir Nicolele,18,,-23.7381,-49.921
br,sitio ademir siqueira,Sítio Ademir Siqueira,18,,-23.745966,-50.101902
br,sitio ademir,Sítio Ademir,18,,-23.736168,-50.066289
br,sitio adil j. pereira,Sítio Adil J. Pereira,18,,-25.859495,-48.92196
br,sitio adilson dornelles,Sítio Adilson Dornelles,18,,-25.5692,-49.9036
br,sitio adilson lourenco,Sítio Adilson Lourenço,18,,-23.0114,-50.2448
br,sitio adino braga,Sítio Adino Bragá,18,,-23.2485,-50.1818
br,sitio adnir buzatto,Sítio Adnir Buzatto,18,,-25.5528,-48.7866
br,sitio adolar ador,Sítio Adolar Ador,18,,-25.9775,-49.698333
br,sitio adolar edwinsilki,Sítio Adolar Edwinsilki,26,,-26.2148,-49.3784
br,sitio adolar neumann,Sítio Adolar Neumann,26,,-26.1628,-49.4055
br,sitio adolar rudnik,Sítio Adolar Rudnik,18,,-26.110732,-49.525463
br,sitio adolar scholz,Sítio Adolar Scholz,18,,-25.951064,-48.825233
br,sitio adolar schuwz,Sítio Adolar Schuwz,26,,-26.223127,-49.610917
br,sitio adolfo babst,Sítio Adolfo Babst,18,,-25.966202,-48.828992
br,sitio adolfo b. buherer,Sítio Adolfo B. Buherer,18,,-25.9254,-49.2255
br,sitio adolfo candido,Sítio Adolfo Cândido,18,,-23.662,-49.9299
br,sitio adolfo drusz,Sítio Adolfo Drusz,18,,-25.8323,-49.6076
br,sitio adolfo emmerich,Sítio Adolfo Emmerich,26,,-26.1456,-49.8648
br,sitio adolfo kimiestz,Sítio Adolfo Kimiestz,18,,-25.841111,-49.6225
br,sitio adolfo leaneher,Sítio Adolfo Leaneher,18,,-25.854444,-49.745278
br,sitio adolfo schafascheck,Sítio Adolfo Schafascheck,26,,-26.187623,-49.74479
br,sitio adolfo schalmarra,Sítio Adolfo Schalmarra,18,,-26.1572,-49.4805
br,sitio adolfo schultz,Sítio Adolfo Schultz,18,,-25.92933,-49.843076
br,sitio adolfo schvazc,Sítio Adolfo Schvazc,26,,-26.2061,-49.3439
br,sitio adolfo shaphausr,Sítio Adolfo Shaphausr,18,,-25.7314,-49.7537
br,sitio adolfo,Sítio Adolfo,18,,-23.073336,-49.97751
br,sitio adolfo valerio,Sítio Adolfo Valério,18,,-26.173596,-49.634365
br,sitio adolfo zanett,Sítio Adolfo Zanett,18,,-23.1567,-50.1908
br,sitio adriano aparecido,Sítio Adriano Aparecido,18,,-23.968086,-50.158315
br,sitio adroaldo votroba,Sítio Adroaldo Votroba,18,,-26.183711,-49.573178
br,sitio adrovaldo carvalho,Sítio Adrovaldo Carvalho,18,,-23.435968,-50.083142
br,sitio afonso albrecht,Sítio Afonso Albrecht,26,,-26.1898,-49.8255
br,sitio afonso alves,Sítio Afonso Alves,18,,-26.20719,-49.581133
br,sitio afonso augustin,Sítio Afonso Augustin,26,,-26.171132,-49.448287
br,sitio afonso balma,Sítio Afonso Balma,26,,-26.1237,-49.8555
br,sitio afonso brichi,Sítio Afonso Brichi,18,,-25.8616,-49.4438
br,sitio afonso bulabauer,Sítio Afonso Bulabauer,26,,-26.2307,-49.3288
br,sitio afonso cherede,Sítio Afonso Cherede,26,,-26.2131,-49.7751
br,sitio afonso dranka,Sítio Afonso Dranka,18,,-26.155687,-49.446241
br,sitio afonso dums,Sítio Afonso Dums,26,,-26.1944,-49.4602
br,sitio afonso ellmer,Sítio Afonso Ellmer,18,,-25.7988,-48.9036
br,sitio afonso g. de miranda,Sítio Afonso G. de Miranda,26,,-25.998313,-48.829679
br,sitio afonso groskop,Sítio Afonso Groskop,18,,-26.049498,-49.517279
br,sitio afonso gruber,Sítio Afonso Gruber,18,,-26.176026,-49.52497
br,sitio afonso kobus,Sítio Afonso Kobus,18,,-26.0888,-49.2979
br,sitio afonso koziba,Sítio Afonso Koziba,18,,-26.0149,-49.8297
br,sitio afonso libel,Sítio Afonso Libel,26,,-26.1995,-49.8289
br,sitio afonso l. padilha,Sítio Afonso L. Padilha,26,,-25.9983,-48.7112
br,sitio afonso murbach,Sítio Afonso Murbach,18,,-25.814435,-49.957505
br,sitio afonso pisque,Sítio Afonso Pisque,18,,-25.972778,-49.676389
br,sitio afonso rodrigues simoes,Sítio Afonso Rodrigues Simões,15,,-22.5973,-45.5905
br,sitio afonso schulz,Sítio Afonso Schulz,26,,-26.1865,-49.3624
br,sitio afonso slominski,Sítio Afonso Slominski,18,,-26.0674,-49.3455
br,sitio afonso staba,Sítio Afonso Staba,18,,-25.7564,-49.5212
br,sitio afonso stanckvis,Sítio Afonso Stanckvis,26,,-26.1453,-49.8513
br,sitio afonso thonik,Sítio Afonso Thonik,18,,-25.7694,-49.6002
br,sitio afonso wosniaki,Sítio Afonso Wosniaki,18,,-25.93428,-49.795703
br,sitio afranio cortes,Sítio Afrânio Cortes,18,,-25.498803,-48.825991
br,sitio agenor d. simao,Sítio Agenor D. Simão,26,,-26.3872,-48.7268
br,sitio agenor guimaraes,Sítio Agenor Guimarães,18,,-25.6074,-48.959
br,sitio agenor r. de barros,Sítio Agenor R. de Barros,18,,-25.5061,-48.998
br,sitio agenor resende,Sítio Agenor Resende,18,,-23.0706,-50.1341
br,sitio agenor rita,Sítio Agenor Rita,18,,-23.0507,-50.1904
br,sitio aglaeia bastos,Sítio Aglaéia Bastos,26,,-26.1944,-49.8287
br,sitio agnaldo f. correa,Sítio Agnaldo F. Corrêa,18,,-23.7023,-49.8067
br,sitio agnaldo lazaro,Sítio Agnaldo Lázaro,18,,-23.6173,-49.8167
br,sitio agostinho branco,Sítio Agostinho Branco,18,,-25.783611,-49.653333
br,sitio agostinho daucucco,Sítio Agostinho Daucucco,18,,-25.464278,-48.861782
br,sitio agostinho novelo,Sítio Agostinho Novelo,18,,-23.066,-50.0194
br,sitio agostinho pife,Sítio Agostinho Pife,18,,-23.790699,-50.753803
br,sitio agua amarela,Sítio Água Amarela,18,,-23.632757,-50.747924
br,sitio agua bonita,Sítio Água Bonita,18,,-23.578243,-50.621613
br,sitio agua-branca,Sítio Água-Branca,18,,-23.098,-50.1826
br,sitio agua-branca,Sítio Água-Branca,27,,-23.212548,-47.604791
br,sitio agua branca,Sítio Água Branca,27,,-23.229167,-46.541389
br,sitio agua-branca,Sítio Água-Branca,27,,-23.248036,-47.653874
br,sitio aguacai,Sítio Aguaçai,27,,-23.640699,-47.077392
br,sitio agua clara,Sítio Água Clara,18,,-25.577245,-50.099983
br,sitio agua da anta,Sítio Água da Anta,18,,-23.9733,-50.9396
br,sitio agua da areia,Sítio Água da Areia,18,,-23.1436,-50.177
br,sitio agua da cabeceira,Sítio Água da Cabeceira,18,,-23.1101,-50.1142
br,sitio agua da corredeira,Sítio Água da Corredeira,18,,-23.518864,-50.218182
br,sitio agua da guabiroba,Sítio Água da Guabiroba,18,,-23.2275,-50.2061
br,sitio agua da limeira,Sítio Água da Limeira,18,,-23.310039,-49.984717
br,sitio agua da noite,Sítio Água da Noite,18,,-23.953577,-50.430358
br,sitio agua da pedra santa,Sítio Água da Pedra Santa,18,,-23.73049,-50.660218
br,sitio agua da pomba,Sítio Água da Pomba,18,,-23.7857,-50.381007
br,sitio agua da prata,Sítio Água da Prata,18,,-23.18,-50.0137
br,sitio agua de santa maria,Sítio Água de Santa Maria,18,,-23.561569,-50.628045
br,sitio agua do bagre,Sítio Água do Bagre,18,,-23.36159,-49.822672
br,sitio agua do barreiro,Sítio Água do Barreiro,18,,-23.1066,-50.1814
br,sitio agua do boi,Sítio Água do Boi,18,,-23.713146,-50.024475
br,sitio agua do cafe,Sítio Água do Café,27,,-23.061177,-49.854792
br,sitio agua do cerne,Sítio Água do Cerne,18,,-23.1485,-50.2008
br,sitio agua do coqueiro,Sítio Água do Coqueiro,27,,-23.002314,-49.762626
br,sitio agua do gaviao,Sítio Água do Gavião,18,,-23.1564,-50.134
br,sitio agua do meio,Sítio Água do Meio,18,,-23.0954,-50.1046
br,sitio agua do paraguai,Sítio Água do Paraguai,18,,-23.3409,-49.847
br,sitio agua dos coqueiros,Sítio Água dos Coqueiros,18,,-23.0122,-50.1487
br,sitio agua do taquaral,Sítio Água do Taquaral,18,,-23.728592,-50.7166
br,sitio agua fria,Sítio Água Fria,18,,-23.835723,-50.145521
br,sitio agua grande,Sítio Água Grande,18,,-23.832532,-50.15394
br,sitio agua limpa,Sítio Água Limpa,18,,-23.316287,-50.141587
br,sitio agua morta,Sítio Água Morta,27,,-24.9281,-48.5685
br,sitio aguas ardentes,Sítio Aguas Ardentes,17,,-7.45,-36.2
br,sitio aguas belas,Sítio Águas Belas,18,,-23.884219,-50.184043
br,sitio aguas claras,Sítio Águas Claras,18,,-23.989904,-50.526702
br,sitio aguas claras,Sítio Águas Claras,27,,-23.646655,-47.056555
br,sitio agua seca,Sítio Água Seca,18,,-23.167263,-49.889416
br,sitio agua tres minas,Sítio Água Três Minas,18,,-23.796916,-50.839411
br,sitio aide b. de oliveira,Sítio Aide B. de Oliveira,18,,-23.996318,-50.124568
br,sitio ailton comelio,Sítio Ailton Comélio,18,,-23.892587,-50.265029
br,sitio ailton dos santos,Sítio Ailton dos Santos,18,,-23.999255,-50.02976
br,sitio ailton f. de melo,Sítio Ailton F. de Melo,18,,-23.928508,-50.212114
br,sitio ailton guarani,Sítio Ailton Guarani,18,,-23.9756,-50.4343
br,sitio ailton guarneri,Sítio Ailton Guarneri,18,,-23.930563,-50.178771
br,sitio ailton trovao,Sítio Ailton Trovão,18,,-23.82299,-50.071373
br,sitio airam,Sítio Airam,27,,-23.501861,-47.005488
br,sitio aires caldense,Sítio Aires caldense,18,,-23.875979,-50.320532
br,sitio aires trainer,Sítio Aires Trainer,18,,-26.159275,-49.585379
br,sitio airton ceschin,Sítio Airton Ceschin,18,,-25.882547,-49.966969
br,sitio airton f. lopes,Sítio Airton F. Lopes,18,,-23.937449,-50.529926
br,sitio airton f. martins,Sítio Airton F. Martins,18,,-25.848257,-49.99225
br,sitio airton levante,Sítio Airton Levante,18,,-23.372912,-49.979634
br,sitio airton maciel,Sítio Airton Maciel,18,,-25.7082,-49.8023
br,sitio airton montanarim,Sítio Airton Montanarim,18,,-25.9244,-49.2314
br,sitio airton schreiner,Sítio Airton Schreiner,18,,-26.152236,-49.524532
br,sitio airys kuss,Sítio Airys Kuss,26,,-26.097,-49.9614
br,sitio alaide moreira,Sítio Alaíde Moreira,18,,-23.896056,-50.58597
br,sitio alairton trovao,Sítio Alairton Trovão,18,,-23.827763,-50.097741
br,sitio alamir g. martins,Sítio Alamir G. Martins,26,,-26.1705,-49.2979
br,sitio alazio dos santos,Sítio Alázio dos Santos,18,,-23.6538,-49.8021
br,sitio alba c. vieira,Sítio Alba C. Vieira,18,,-23.7027,-49.9165
br,sitio albano agostinho,Sítio Albano Agostinho,26,,-26.2363,-49.7551
br,sitio albano patla,Sítio Albano Patla,18,,-25.8196,-49.4157
br,sitio albano reis,Sítio Albano Reis,26,,-26.2385,-49.7588
br,sitio alba,Sítio Alba,27,,-23.427835,-46.733373
br,sitio alberto brambila,Sítio Alberto Brambila,18,,-23.4975,-49.7889
br,sitio alberto fernandes,Sítio Alberto Fernandes,27,,-23.010891,-47.677615
br,sitio alberto kava,Sítio Alberto Kava,18,,-25.751944,-49.534167
br,sitio alberto kuz,Sítio Alberto Kuz,18,,-25.7614,-49.3607
br,sitio alberto lanoski,Sítio Alberto Lanoski,18,,-25.5046,-49.9466
br,sitio alberto pereira,Sítio Alberto Pereira,18,,-23.940132,-50.079499
br,sitio alberto schustir,Sítio Alberto Schustir,18,,-25.7101,-49.752
br,sitio alberto,Sítio Alberto,18,,-23.974379,-50.478675
br,sitio albina czeczyki,Sítio Albina Czeczyki,18,,-25.933889,-49.618056
br,sitio albino charneski,Sítio Albino Charneski,18,,-25.942778,-49.711111
br,sitio albino drusz,Sítio Albino Drusz,18,,-25.8317,-49.614
br,sitio albino eckil,Sítio Albino Eckil,26,,-26.246786,-49.651087
br,sitio albino knopk,Sítio Albino Knopk,18,,-25.8225,-49.6204
br,sitio albino l. faccin,Sítio Albino L. Faccin,18,,-26.0043,-49.9758
br,sitio albino mazur,Sítio Albino Mazur,18,,-25.7994,-49.5246
br,sitio albino ruminisck,Sítio Albino Ruminisck,18,,-23.926547,-50.192215
br,sitio albino saik,Sítio Albino Saik,18,,-25.823894,-49.810626
br,sitio albino senn,Sítio Albino Senn,18,,-26.0243,-49.4466
br,sitio albino taioka,Sítio Albino Taioka,18,,-25.7591,-49.4953
br,sitio albino vieira,Sítio Albino Vieira,18,,-25.054785,-48.972086
br,sitio alcebiades delmonico,Sítio Alcebíades Delmonico,18,,-23.885776,-50.023735
br,sitio alcebiades siqueira,Sítio Alcebíades Siqueira,18,,-25.8623,-49.0256
br,sitio alceu a. coelho,Sítio Alceu A. Coelho,26,,-26.235729,-49.683585
br,sitio alceu arbigaus,Sítio Alceu Arbigaus,26,,-26.1967,-49.8832
br,sitio alceu b. ribas,Sítio Alceu B. Ribas,18,,-25.936676,-49.800908
br,sitio alceu c. dos santos,Sítio Alceu C. dos Santos,26,,-26.205537,-49.711919
br,sitio alceu de sa ribas,Sítio Alceu de Sá Ribas,18,,-25.9575,-49.673333
br,sitio alceu dos santos,Sítio Alceu dos Santos,26,,-26.2162,-49.8104
br,sitio alceu f. bueno,Sítio Alceu F. Bueno,18,,-25.844887,-49.987155
br,sitio alceu manoel murbach,Sítio Alceu Manoel Murbach,18,,-25.815318,-49.955419
br,sitio alceu m. rocco,Sítio Alceu M. Rocco,18,,-25.9486,-49.1102
br,sitio alceu padilha,Sítio Alceu Padilha,18,,-26.122359,-49.580774
br,sitio alceu r. de lima,Sítio Alceu R. de Lima,18,,-26.028661,-49.619069
br,sitio alceu saes,Sítio Alceu Saes,18,,-23.5182,-49.8909
br,sitio alcides baum,Sítio Alcides Baum,18,,-23.812127,-50.05818
br,sitio alcides b. nogueira,Sítio Alcides B. Nogueira,18,,-25.981389,-49.7425
br,sitio alcides camargo,Sítio Alcides Camargo,18,,-25.9954,-49.183
br,sitio alcides canedo,Sítio Alcides Canedo,18,,-23.6243,-49.7963
br,sitio alcides claudio da silva,Sítio Alcides Cláudio da Silva,18,,-23.24271,-49.895949
br,sitio alcides d. goncalves,Sítio Alcides D. Gonçalves,18,,-23.793317,-50.667818
br,sitio alcides grosskopf,Sítio Alcides Grosskopf,26,,-26.2026,-49.4413
br,sitio alcides marfim,Sítio Alcides Marfim,18,,-23.886515,-50.292651
br,sitio alcides p. giese,Sítio Alcides P. Giese,18,,-26.1274,-49.4057
br,sitio alcides rohrbacher,Sítio Alcides Rohrbacher,18,,-26.0508,-49.3005
br,sitio alcides sacoman,Sítio Alcides Sacoman,18,,-23.871665,-50.311872
br,sitio alcides,Sítio Alcides,18,,-23.835019,-50.588751
br,sitio alcides veigas,Sítio Alcides Veigas,26,,-26.249102,-49.72119
br,sitio alcidio vicente zotto,Sítio Alcídio Vicente Zotto,18,,-25.7169,-48.9884
br,sitio alcindo do rosario,Sítio Alcindo do Rosário,18,,-25.9017,-49.0916
br,sitio alcindo miranda,Sítio Alcindo Miranda,18,,-25.79446,-48.761361
br,sitio alcino v. da silva,Sítio Alcino V. da Silva,18,,-23.7484,-49.7677
br,sitio alcinso alves,Sítio Alcinso Alves,18,,-26.138862,-49.639179
br,sitio alcir alves,Sítio Alcir Alves,18,,-25.7043,-48.7782
br,sitio alcir kleinschmidt,Sítio Alcir Kleinschmidt,18,,-25.781389,-49.739722
br,sitio alciro pinheiro,Sítio Alciro Pinheiro,18,,-23.733697,-50.544391
br,sitio aldeia dos indios,Sítio Aldeia dos Índios,21,,-22.282,-44.3237
br,sitio aldo bilckholz,Sítio Aldo Bilckholz,26,,-26.1947,-49.4224
br,sitio aldo tirone,Sítio Aldo Tirone,18,,-23.1678,-50.1317
br,sitio alecrim,Sítio Alecrim,20,,-7.683333,-40.8
br,sitio alecrim,Sítio Alecrim,27,,-23.649678,-47.007209
br,sitio alegre,Sítio Alegre,18,,-23.741738,-50.158498
br,sitio alegre,Sítio Alegre,20,,-3.726667,-42.179722
br,sitio alegria,Sítio Alegria,27,,-24.638326,-48.002146
br,sitio aleixo bochinia,Sítio Aleixo Bochinia,18,,-25.7565,-49.5249
br,sitio aleixo boiano,Sítio Aleixo Boiano,18,,-25.8737,-49.5125
br,sitio aleixo dranka,Sítio Aleixo Dranka,18,,-25.773515,-49.428308
br,sitio aleixo juclinsk,Sítio Aleixo Juclinsk,18,,-25.8532,-49.4289
br,sitio aleixo kossoski,Sítio Aleixo Kossoski,18,,-25.7569,-49.5451
br,sitio aleixo michal,Sítio Aleíxo Michal,18,,-25.8983,-49.3183
br,sitio aleixo mika,Sítio Aleixo Mika,18,,-25.8293,-49.4304
br,sitio aleixo moll,Sítio Aleixo Moll,18,,-25.8868,-49.5397
br,sitio aleixo oracshi,Sítio Aleixo Oracshi,18,,-25.9123,-49.4579
br,sitio aleixo pianosk,Sítio Aleixo Pianosk,18,,-26.0259,-49.7762
br,sitio aleixo,Sítio Aleixo,27,,-24.967,-48.5075
br,sitio aleixo smoqivcz,Sítio Aleixo Smoqivcz,18,,-25.935,-49.533333
br,sitio alemao,Sítio Alemão,18,,-25.5866,-49.9706
br,sitio alexandre carpinski,Sítio Alexandre Carpinski,18,,-25.882,-49.5909
br,sitio alexandre cherede,Sítio Alexandre Cherede,26,,-26.2256,-49.4522
br,sitio alexandre degas,Sítio Alexandre Degas,18,,-23.111,-50.0996
br,sitio alexandre pasda,Sítio Alexandre Pasda,26,,-26.0745,-49.2638
br,sitio alexandre r. filho,Sítio Alexandre R. Filho,18,,-25.7764,-49.5743
br,sitio alexandre souza,Sítio Alexandre Souza,18,,-25.8135,-49.576
br,sitio alexandre stiegler,Sítio Alexandre Stiegler,26,,-26.19788,-49.454197
br,sitio alexandre w. brand,Sítio Alexandre W. Brand,26,,-26.1883,-49.3465
br,sitio alexio ribas,Sítio Alexio Ribas,18,,-25.9601,-49.3452
br,sitio alexo kuzeratsk,Sítio Alexo Kuzeratsk,18,,-25.947,-49.499
br,sitio alfeu godoy,Sítio Alfeu Godoy,18,,-23.579189,-50.525887
br,sitio alfonso fleichmann,Sítio Alfonso Fleichmann,26,,-26.1747,-49.8469
br,sitio alfonso schafaschek,Sítio Alfonso Schafaschek,26,,-26.1746,-49.7542
br,sitio alfredo alves,Sítio Alfredo Alves,18,,-25.707,-48.7645
br,sitio alfredo bartniki,Sítio Alfredo Bartniki,26,,-26.1748,-49.8592
br,sitio alfredo campanhone,Sítio Alfredo Campanhone,18,,-25.953904,-49.972088
br,sitio alfredo elmer,Sítio Alfredo Elmer,26,,-25.996973,-48.864715
br,sitio alfredo f. da silva,Sítio Alfredo F. da Silva,18,,-26.0126,-49.8941
br,sitio alfredo fiber,Sítio Alfredo Fiber,18,,-26.0192,-49.8635
br,sitio alfredo fricher,Sítio Alfredo Fricher,18,,-26.078192,-49.805249
br,sitio alfredo frogel,Sítio Alfredo Frogel,26,,-26.22837,-49.745431
br,sitio alfredo fuchs,Sítio Alfredo Fuchs,18,,-26.0985,-49.7662
br,sitio alfredo goes,Sítio Alfredo Góes,18,,-23.7261,-49.7607
br,sitio alfredo lante,Sítio Alfredo Lante,26,,-26.232609,-49.700812
br,sitio alfredo matias,Sítio Alfredo Matias,18,,-23.827683,-50.551904
br,sitio alfredo mendes,Sítio Alfredo Mendes,18,,-25.8868,-49.5047
br,sitio alfredo neumann,Sítio Alfredo Neumann,26,,-26.1653,-49.4012
br,sitio alfredo pereira,Sítio Alfredo Pereira,26,,-26.0507,-49.8646
br,sitio alfredo r. geisel,Sítio Alfredo R. Geisel,26,,-26.202347,-49.630524
br,sitio alfredo runschk,Sítio Alfredo Runschk,26,,-26.2136,-49.3805
br,sitio alfredo s. camargo,Sítio Alfredo S. Camargo,18,,-25.9212,-49.2882
br,sitio alfredo schoeder,Sítio Alfredo Schoeder,26,,-26.2341,-49.709617
br,sitio alfredo,Sítio Alfredo,18,,-23.7448,-49.9477
br,sitio alfredo snaupz,Sítio Alfredo Snaupz,26,,-26.1392,-49.9373
br,sitio alfredo straka,Sítio Alfredo Straka,18,,-26.125578,-49.607914
br,sitio alfredo s. wochl,Sítio Alfredo S. Wochl,26,,-26.213978,-49.718236
br,sitio alfredo vaz,Sítio Alfredo Vaz,18,,-26.1432,-49.3873
br,sitio alfredo vidi,Sítio Alfredo Vidi,18,,-25.831993,-48.767878
br,sitio alfredo weck,Sítio Alfredo Weck,26,,-26.1675,-49.8611
br,sitio alfredo wotroba,Sítio Alfredo Wotroba,26,,-26.1917,-49.4698
br,sitio alfredo zani,Sítio Alfredo Zani,18,,-23.6166,-49.8471
br,sitio alfredo zappe,Sítio Alfredo Zappe,18,,-26.1199,-49.3668
br,sitio algeny u. philippsen,Sítio Algeny U. Philippsen,18,,-25.491379,-48.877977
br,sitio alho,Sítio Alho,30,,-7.85,-40.45
br,sitio alianca,Sítio Aliança,18,,-23.074204,-52.060566
br,sitio alianca,Sítio Aliança,27,,-23.105493,-46.734827
br,sitio alice carvalho,Sítio Alice Carvalho,18,,-25.8557,-49.4085
br,sitio alice de fatima santos,Sítio Alice de Fatima Santos,18,,-25.100292,-48.72502
br,sitio aliceu montanha,Sítio Aliceu Montanha,18,,-23.5609,-49.8269
br,sitio alicio a. dorneri,Sítio Alício A. Dorneri,18,,-23.892572,-50.545678
br,sitio alicio batista,Sítio Alício Batista,18,,-23.795293,-50.386566
br,sitio alicio pedroso,Sítio Alício Pedroso,18,,-23.981082,-50.460752
br,sitio alim akim,Sítio Alim Akim,18,,-23.5402,-49.915
br,sitio alinor gruber,Sítio Alinor Gruber,26,,-26.2278,-49.9523
br,sitio alipio r. muniz,Sítio Alípio R. Muniz,18,,-25.9,-49.532222
br,sitio alipio,Sítio Alípio,18,,-23.836889,-50.594241
br,sitio alivio w. simm,Sítio Alívio W. Simm,26,,-26.208354,-49.450239
br,sitio almeida junior,Sítio Almeida Júnior,18,,-23.0097,-50.0716
br,sitio almir michele,Sítio Almir Michele,18,,-25.9324,-49.4023
br,sitio almiro baumgartner,Sítio Almiro Baumgartner,18,,-26.119088,-49.657181
br,sitio aloise opalensck,Sítio Aloise Opalensck,18,,-25.7891,-49.5135
br,sitio aloisio almeida,Sítio Aloísio Almeida,18,,-25.780864,-49.836245
br,sitio aloisio marins,Sítio Aloísio Marins,18,,-25.7828,-49.719
br,sitio alois ratrovski,Sítio Alois Ratrovski,26,,-26.1954,-49.9912
br,sitio alorovano a. ferreira,Sítio Alorovano A. Ferreira,18,,-23.392334,-50.15752
br,sitio alpes nogueira,Sítio Alpes Nogueira,27,,-23.561565,-47.097802
br,sitio alta floresta,Sítio Alta Floresta,18,,-23.924583,-50.577601
br,sitio altair kalisto,Sítio Altair Kalisto,26,,-26.222,-49.8407
br,sitio altair levandosk,Sítio Altair Levandosk,18,,-25.9602,-49.4713
br,sitio altair mano,Sítio Altair Mano,18,,-25.9747,-49.3257
br,sitio altair parise,Sítio Altair Parise,18,,-25.940076,-49.804716
br,sitio altair p. pereira,Sítio Altair P. Pereira,18,,-26.056,-49.3248
br,sitio altair v. fonseca,Sítio Altair V. Fonseca,18,,-23.763653,-50.003676
br,sitio altamiro g. de miranda,Sítio Altamiro G. de Miranda,26,,-25.99287,-48.825529
br,sitio altevir robassa,Sítio Altevir Robassa,18,,-25.5053,-48.87
br,sitio altino pires dos santos,Sítio Altino Pires dos Santos,18,,-25.385663,-48.9736
br,sitio alto alegre,Sítio Alto Alegre,18,,-23.1688,-50.2397
br,sitio alto da boa vista,Sítio Alto da Boa Vista,27,,-23.7344,-47.7509
br,sitio alto da colina,Sítio Alto da Colina,18,,-23.926181,-50.265169
br,sitio alto da colina,Sítio Alto da Colina,27,,-23.9339,-47.0059
br,sitio alto da serra,Sítio Alto da Serra,18,,-23.1691,-50.1438
br,sitio alto das oliveiras,Sítio Alto das Oliveiras,18,,-23.85752,-50.585386
br,sitio alto do pinheiro,Sítio Alto do Pinheiro,27,,-23.255217,-46.593756
br,sitio alto padre andre,Sítio Alto Padre André,27,,-24.620202,-48.031155
br,sitio alto,Sítio Alto,05,,-12.45,-39.3
br,sitio alto,Sítio Alto,27,,-24.8415,-48.0936
br,sitio aluino kosinski,Sítio Aluíno Kosinski,18,,-25.9711,-49.4443
br,sitio aluisio prybyquis,Sítio Aluísio Prybyquis,18,,-25.973611,-49.534444
br,sitio aluisio tryseiak,Sítio Aluísio Tryseiak,18,,-25.839862,-49.760761
br,sitio aluisio zoellner,Sítio Aluísio Zoellner,26,,-26.1585,-49.3663
br,sitio alvarenga,Sítio Alvarenga,27,,-23.7513,-46.6184
br,sitio alvaro f. mendes,Sítio Álvaro F. Mendes,18,,-23.960943,-50.455752
br,sitio alvaro hornique,Sítio Álvaro Horníque,18,,-25.9787,-49.1451
br,sitio alvaro l. de souza,Sítio Álvaro L. de Souza,18,,-23.881745,-50.251894
br,sitio alvaro lozano,Sítio Álvaro Lozano,18,,-23.6005,-49.7877
br,sitio alvaro machado,Sítio Álvaro Machado,26,,-26.1556,-49.7684
br,sitio alvaro m. filho,Sítio Álvaro M. Filho,18,,-23.6233,-49.8965
br,sitio alvaro serra,Sítio Álvaro Serra,18,,-25.5953,-49.8858
br,sitio alves,Sítio Alves,18,,-23.799658,-50.481969
br,sitio alvim b. callaco,Sítio Alvim B. Callaço,18,,-25.9669,-49.485
br,sitio alvim,Sítio Alvim,18,,-23.894612,-50.327832
br,sitio alvino chikoviski,Sítio Alvino Chikoviski,18,,-25.8788,-49.0261
br,sitio alvino cruz,Sítio Alvino Cruz,18,,-25.981429,-49.841172
br,sitio alvino fleischamann,Sítio Alvino Fleischamann,26,,-26.2028,-49.754
br,sitio alvino funk,Sítio Alvino Funk,26,,-26.24812,-49.746278
br,sitio alvino j. dreveck,Sítio Alvino J. Dreveck,26,,-26.1453,-49.3338
br,sitio alvino kurovski,Sítio Alvino Kurovski,18,,-25.993889,-49.527222
br,sitio alvino moreira,Sítio Alvino Moreira,18,,-26.0481,-49.4647
br,sitio alvino muller,Sítio Alvino Müller,18,,-26.091125,-49.527916
br,sitio alvino muller,Sítio Alvino Müller,26,,-26.2221,-49.7695
br,sitio alvino portela,Sítio Alvino Portela,18,,-26.08103,-49.705286
br,sitio alvino rador,Sítio Alvino Rador,26,,-26.1762,-49.3118
br,sitio alvino,Sítio Alvino,18,,-23.840321,-50.030982
br,sitio alvino vielevick,Sítio Alvino Vielevick,26,,-26.1819,-49.3567
br,sitio alvira n. moreira,Sítio Alvira N. Moreira,18,,-23.994315,-50.125146
br,sitio alvo e negro,Sítio Alvo e Negro,27,,-23.216667,-46.555
br,sitio alvorada da amizade,Sítio Alvorada da Amizade,27,,-23.575845,-47.075021
br,sitio alvorada,Sítio Alvorada,18,,-23.027696,-52.059806
br,sitio alvorada,Sítio Alvorada,27,,-23.023333,-46.604444
br,sitio alzina goncalves,Sítio Alzina Gonçalves,18,,-23.437385,-49.868475
br,sitio alziro nilde,Sítio Alziro Nilde,26,,-26.239474,-49.704995
br,sitio amadeu a. padilha,Sítio Amadeu A. Padilha,18,,-23.894174,-50.397437
br,sitio amadeu bonotto,Sítio Amadeu Bonotto,18,,-23.5689,-49.9709
br,sitio amadeu conrado,Sítio Amadeu Conrado,18,,-23.6305,-49.866
br,sitio amadeu do valle,Sítio Amadeu do Valle,18,,-25.7948,-49.5963
br,sitio amadeu f. de paula,Sítio Amadeu F. de Paula,18,,-25.8956,-49.0199
br,sitio amadeu filla,Sítio Amadeu Filla,18,,-25.8452,-49.5139
br,sitio amadeu ganassole,Sítio Amadeu Ganassole,18,,-25.5608,-49.9022
br,sitio amadeu m. de carvalho,Sítio Amadeu M. de Carvalho,18,,-25.79661,-49.792586
br,sitio amado m. novaz,Sítio Amado M. Novaz,18,,-23.5158,-49.9648
br,sitio amaldo beckert,Sítio Amaldo Beckert,18,,-26.16542,-49.516397
br,sitio amalia santana,Sítio Amália Santana,18,,-25.811389,-49.71
br,sitio amancio baiao,Sítio Amâncio Baião,18,,-23.275636,-50.160505
br,sitio amandino da silva,Sítio Amândino da Silva,18,,-26.0437,-49.8247
br,sitio amandio oliveira,Sítio Amândio Oliveira,18,,-25.8508,-49.3703
br,sitio amando ferreira,Sítio Amando Ferreira,26,,-26.0926,-49.8824
br,sitio amantino vaz,Sítio Amantino Vaz,18,,-26.153373,-49.642985
br,sitio amantino xavier,Sítio Amantino Xavier,18,,-23.6464,-49.8682
br,sitio amarildo,Sítio Amarildo,18,,-23.489657,-49.90002
br,sitio amaro rosa de oliveira,Sítio Amaro Rosa de Oliveira,18,,-25.131197,-48.857629
br,sitio amauri bauer,Sítio Amauri Bauer,18,,-25.974722,-49.694722
br,sitio amauri bengonca,Sítio Amauri Bengonça,18,,-25.5716,-48.84
br,sitio amazonas,Sítio Amazonas,18,,-23.973312,-50.860322
br,sitio amazonas t. pereira,Sítio Amazonas T. Pereira,18,,-25.9766,-49.4609
br,sitio ambrosina carneiro,Sítio Ambrosina Carneiro,18,,-23.9819,-50.8591
br,sitio ambrosio kaiss,Sítio Ambrósio Kaiss,18,,-25.912222,-49.591111
br,sitio ambrosio schelawer,Sítio Ambrósio Schelawer,26,,-26.1969,-49.9534
br,sitio ambrosio seidel,Sítio Ambrósio Seidel,26,,-26.166,-49.9034
br,sitio ambrosio wosciechoski,Sítio Ambrósio Wosciechoski,26,,-26.0921,-49.2869
br,sitio amelia dutra,Sítio Amélia Dutra,18,,-25.8075,-49.6032
br,sitio amelia,Sítio Amelia,18,,-23.894684,-50.284802
br,sitio americo bonacim,Sítio Américo Bonacim,18,,-23.1572,-50.2078
br,sitio americo brochard,Sítio Américo Brochard,18,,-23.189943,-49.944361
br,sitio americo garanhane,Sítio Américo Garanhane,18,,-23.6086,-49.7958
br,sitio americo,Sítio Américo,18,,-25.478293,-48.757477
br,sitio americo ursini,Sítio Américo Ursini,18,,-23.1222,-50.1602
br,sitio amigao,Sítio Amigão,27,,-23.581159,-47.077054
br,sitio amilton abigalisk,Sítio Amilton Abigalisk,26,,-26.2319,-49.8322
br,sitio amilton ruthes,Sítio Amilton Ruthes,18,,-26.0662,-49.7653
br,sitio amora-preta,Sítio Amora-Preta,18,,-23.857586,-50.343711
br,sitio amor de mae,Sítio Amor de Mãe,27,,-23.503365,-47.14809
br,sitio amoreira,Sítio Amoreira,27,,-23.718402,-47.629331
br,sitio amorim,Sítio Amorim,27,,-23.05768,-47.536829
br,sitio ana a. da veiga,Sítio Ana A. da Veiga,18,,-25.5035,-48.7621
br,sitio ana alves farias,Sítio Ana Alves Farias,18,,-25.9983,-49.2123
br,sitio ana b. linhares,Sítio Ana B. Linhares,18,,-25.818611,-49.723889
br,sitio ana b. lopes,Sítio Ana B. Lopes,18,,-23.884169,-50.24603
br,sitio ana c. almeida,Sítio Ana C. Almeida,18,,-23.692706,-50.721177
br,sitio ana chicoria,Sítio Ana Chicória,18,,-25.8299,-49.405
br,sitio anacleto gabardo,Sítio Anacleto Gabardo,18,,-26.057,-49.7531
br,sitio ana da s. xavier,Sítio Ana da S. Xavier,18,,-23.6707,-49.9596
br,sitio ana figura,Sítio Ana Figura,18,,-25.901111,-49.580278
br,sitio ana gruber,Sítio Ana Gruber,26,,-26.2449,-49.9051
br,sitio ana haid,Sítio Ana Haid,26,,-26.1016,-49.8979
br,sitio ana margarida,Sítio Ana Margarida,18,,-25.798611,-49.654444
br,sitio ana matias,Sítio Ana Matias,26,,-26.1671,-49.9411
br,sitio ana m. bill,Sítio Ana M. Bill,18,,-25.8781,-49.577
br,sitio ana muskuvicz,Sítio Ana Muskuvicz,18,,-26.0335,-49.8477
br,sitio ananias,Sítio Ananias,18,,-23.624186,-50.503583
br,sitio ana raksa,Sítio Ana Raksa,18,,-25.8354,-49.43
br,sitio ana r. vulski,Sítio Ana R. Vulski,18,,-26.0315,-49.8455
br,sitio anastacia buial,Sítio Anastácia Buial,18,,-25.7588,-49.2371
br,sitio anastacio blaskovski,Sítio Anastácio Blaskovski,18,,-26.05,-49.2675
br,sitio anastacio goncalves,Sítio Anastácio Gonçalves,18,,-25.5532,-48.7618
br,sitio anastacio kimiescki,Sítio Anastácio Kimiescki,18,,-26.012,-49.8293
br,sitio anatono,Sítio Anatono,27,,-23.9358,-47.0902
br,sitio ana tuda,Sítio Ana Tuda,18,,-25.853874,-49.958909
br,sitio ana xavier,Sítio Ana Xavier,18,,-23.6129,-49.8825
br,sitio anchieta,Sítio Anchieta,27,,-23.767,-46.555
br,sitio andrade,Sítio Andrade,18,,-23.9239,-50.701704
br,sitio andre a. de abreu,Sítio André A. de Abreu,18,,-23.7003,-49.7891
br,sitio andre a. rosario,Sítio André A. Rosário,18,,-25.9878,-49.195
br,sitio andre atarepraw,Sítio André Atarepraw,18,,-25.753882,-49.242534
br,sitio andre boiko,Sítio André Boiko,18,,-25.7555,-49.2706
br,sitio andre crissa,Sítio André Crissa,18,,-25.9426,-49.4724
br,sitio andre dreveck,Sítio André Dreveck,26,,-26.1641,-49.3191
br,sitio andre estegue,Sítio Andre Estegue,18,,-25.9282,-49.3462
br,sitio andre hajnadi,Sítio André Hajnadi,18,,-25.791304,-48.916816
br,sitio andreia,Sítio Andreia,27,,-24.602523,-48.00441
br,sitio andre lopata,Sítio André Lopata,18,,-26.01057,-49.727476
br,sitio andre ludvinski,Sítio André Ludvinski,18,,-26.0575,-49.4585
br,sitio andre pikos,Sítio André Pikos,18,,-26.1111,-49.3278
br,sitio andre prorocki,Sítio Andre Prorocki,18,,-25.8469,-49.4863
br,sitio andre ranck,Sítio André Ranck,26,,-26.1729,-49.8186
br,sitio andre setlek,Sítio André Setlek,18,,-25.7816,-49.4463
br,sitio andre,Sítio André,18,,-25.77279,-49.413084
br,sitio andre suczech,Sítio André Suczech,26,,-26.0953,-49.2817
br,sitio andre telma,Sítio André Telma,26,,-26.1316,-49.3261
br,sitio andre valerio,Sítio André Valério,18,,-23.1881,-50.0609
br,sitio andre veiga,Sítio André Veiga,18,,-26.073585,-49.674565
br,sitio andre vizinhak,Sítio André Vizinhak,18,,-25.8857,-49.5784
br,sitio anesio prussak,Sítio Anésio Prussak,26,,-26.1575,-49.3595
br,sitio anesio silva,Sítio Anésio Silva,18,,-23.0139,-50.0354
br,sitio anestrao,Sítio Anestrão,18,,-23.882037,-50.240471
br,sitio angela yane,Sítio Ângela Yane,18,,-23.434288,-49.796853
br,sitio angel g. aleaide,Sítio Angel G. Aleaide,18,,-26.0852,-49.8053
br,sitio angelim,Sítio Angelim,18,,-25.195871,-48.86075
br,sitio angelina a. ribeiro,Sítio Angelina A. Ribeiro,18,,-25.8403,-49.3878
br,sitio angelina carneiro,Sítio Angelina Carneiro,18,,-25.527,-49.9263
br,sitio angelina kampa,Sítio Angelina Kampa,18,,-25.5102,-49.9448
br,sitio angelino a. de lima,Sítio Angelino A. de Lima,18,,-25.9159,-49.2712
br,sitio angelino bonarde,Sítio Angelino Bonarde,18,,-23.5487,-49.8829
br,sitio angelino cavalheiro,Sítio Angelino Cavalheiro,18,,-26.0286,-49.4239
br,sitio angelo alves,Sítio Ângelo Alves,18,,-23.732031,-50.233489
br,sitio angelo barbaneira,Sítio Ângelo Barbaneira,18,,-23.7213,-49.8245
br,sitio angelo bortolleto,Sítio Ángelo Bortolleto,18,,-25.830618,-49.762174
br,sitio angelo castanha,Sítio Ângelo Castanha,18,,-25.7032,-48.7531
br,sitio angelo coleti,Sítio Ângelo Coleti,18,,-23.0686,-50.2065
br,sitio angelo crispim,Sítio Ângelo Crispim,18,,-23.6112,-49.8785
br,sitio angelo dos s. padilha,Sítio Ângelo dos S. Padilha,18,,-23.7348,-49.7676
br,sitio angelo frandino,Sítio Ângelo Frandino,18,,-23.5972,-49.8332
br,sitio angelo maneira,Sítio Ângelo Maneira,18,,-26.0457,-49.7652
br,sitio angelo m. da cruz,Sítio Ângelo M. da Cruz,18,,-25.977,-49.1424
br,sitio angelo p. santos,Sítio Angelo P. Santos,18,,-25.042407,-48.9656
br,sitio angelo rodrigues,Sítio Ângelo Rodrigues,18,,-26.0018,-49.4306
br,sitio angelo saia,Sítio Ângelo Saia,18,,-25.8428,-49.5984
br,sitio angelo stivan,Sítio Ângelo Stivan,18,,-23.5619,-49.9819
br,sitio angelo toniollo,Sítio Ângelo Toniollo,18,,-25.5552,-48.7776
br,sitio angemiro barbosa,Sítio Angemiro Barbosa,18,,-26.100977,-49.521721
br,sitio angenor terra,Sítio Angenor Terra,18,,-23.975657,-50.147613
br,sitio angico,Sítio Angico,27,,-23.358518,-46.629429
br,sitio anhanguara,Sítio Anhanguara,27,,-24.5754,-48.4044
br,sitio anibal cordeiro,Sítio Anibal Cordeiro,18,,-26.077559,-49.746392
br,sitio anibal de almeida,Sítio Aníbal de Almeida,18,,-25.8576,-49.5243
br,sitio anibal de lucas,Sítio Anibal de Lucas,18,,-23.293789,-49.931522
br,sitio anibal g. correia,Sítio Anibal G. Correia,18,,-25.091369,-48.879145
br,sitio anibal neto,Sítio Aníbal Neto,18,,-26.0692,-49.7508
br,sitio aniceto woiakievicz,Sítio Aniceto Woiakievicz,18,,-25.9406,-49.2036
br,sitio anilto h. da silva,Sítio Anilto H. da Silva,26,,-26.229033,-49.631626
br,sitio anisio carvalho,Sítio Anísio Carvalho,26,,-26.237,-49.9304
br,sitio anisio juseane,Sítio Anísio Juseane,18,,-23.0099,-49.987015
br,sitio anisio,Sítio Anísio,18,,-23.076,-50.2306
br,sitio anivaldo de lima,Sítio Anivaldo de Lima,18,,-26.0169,-49.7944
br,sitio anizio andrade,Sítio Anízio Andrade,18,,-26.0862,-49.8211
br,sitio anizio l. diniz,Sítio Anízio L. Diniz,18,,-23.95398,-50.281378
br,sitio anizio panique,Sítio Anízio Panique,18,,-23.453438,-49.824406
br,sitio anjo da guarda,Sítio Anjo da Guarda,18,,-23.653188,-50.187366
br,sitio anorfo macedo,Sítio Anorfo Macedo,18,,-23.715816,-50.577208
br,sitio anor pedroso joski,Sítio Anor Pedroso Joski,18,,-25.818317,-49.79657
br,sitio anselmo claudino,Sítio Anselmo Claudino,18,,-25.809969,-48.897018
br,sitio anta brava,Sítio Anta Brava,18,,-23.913292,-50.087123
br,sitio antenor bandeira,Sítio Antenor Bandeira,18,,-25.19596,-48.887855
br,sitio antenor batista,Sítio Antenor Batista,18,,-25.813056,-49.646111
br,sitio antenor de almeida,Sítio Antenor de Almeida,18,,-25.8147,-49.5045
br,sitio antenor de deus,Sítio Antenor de Deus,18,,-25.9952,-49.4004
br,sitio antenor de moura,Sítio Antenor de Moura,18,,-25.8781,-49.442
br,sitio antenor dos santos,Sítio Antenor dos Santos,18,,-25.884601,-49.957639
br,sitio antenor hack,Sítio Antenor Hack,26,,-26.2395,-49.7513
br,sitio antenor jacob,Sítio Antenor Jacob,18,,-23.926725,-50.159127
br,sitio antenor,Sítio Antenor,18,,-25.864422,-49.457399
br,sitio antenor sting,Sítio Antenor Sting,18,,-25.986721,-49.98075
br,sitio antenor v. de moura,Sítio Antenor V. de Moura,18,,-25.873625,-49.450219
br,sitio anthenor b. da rocha,Sítio Anthenor B. da Rocha,18,,-25.8919,-49.2459
br,sitio antinha,Sítio Antinha,18,,-25.8451,-49.1577
br,sitio antonia cavalheiro,Sítio Antônia Cavalheiro,26,,-26.2167,-49.9496
br,sitio antonia conhasque,Sítio Antônia Conhasque,18,,-25.5387,-49.9484
br,sitio antonia mendonca,Sítio Antônia Mendonça,18,,-23.4283,-49.8535
br,sitio antonio a. alencar,Sítio Antônio A. Alencar,04,,-1.597222,-60.2075
br,sitio antonio a. barbosa,Sítio Antônio A. Barbosa,18,,-23.7431,-49.9873
br,sitio antonio a. batista,Sítio Antônio A. Batista,18,,-25.9951,-49.2174
br,sitio antonio a. cordeiro,Sítio Antônio A. Cordeiro,18,,-25.7065,-48.7752
br,sitio antonio a. da silva,Sítio Antônio A. da Silva,18,,-25.9148,-49.0508
br,sitio antonio a. de lima,Sítio Antônio A. de Lima,18,,-25.8975,-49.1118
br,sitio antonio a. de paula,Sítio Antônio A. de Paula,18,,-26.190666,-49.63854
br,sitio antonio a. dos santos,Sítio Antônio A. dos Santos,18,,-25.792,-49.1492
br,sitio antonio a. drevek,Sítio Antônio A. Drevek,18,,-26.1022,-49.3513
br,sitio antonio aires,Sítio Antônio Aires,18,,-25.8206,-49.2672
br,sitio antonio a. lacerda,Sítio Antônio A. Lacerda,18,,-25.9518,-49.2309
br,sitio antonio alcantara,Sítio Antônio Alcântara,18,,-23.432939,-50.131647
br,sitio antonio alexandre,Sítio Antônio Alexandre,18,,-23.7241,-49.9263
br,sitio antonio alves dos santos,Sítio Antônio Alves dos Santos,18,,-25.903673,-48.922775
br,sitio antonio alves,Sítio Antônio Alves,18,,-25.2873,-48.5267
br,sitio antonio amaro da silva,Sítio Antônio Amaro da Silva,18,,-23.8798,-50.9785
br,sitio antonio americo,Sítio Antônio Américo,18,,-23.663208,-50.228571
br,sitio antonio a. messias,Sítio Antônio A. Messias,18,,-25.8792,-49.2994
br,sitio antonio a. pereira,Sítio Antônio A. Pereira,18,,-25.9378,-49.3938
br,sitio antonio a. rocha,Sítio Antônio A. Rocha,18,,-25.9988,-49.1356
br,sitio antonio a. ruthes,Sítio Antônio A. Ruthes,18,,-26.0076,-49.7763
br,sitio antonio arv,Sítio Antônio Arv,26,,-26.0977,-49.9369
br,sitio antonio augus governo,Sítio Antônio Augus Governo,18,,-23.0077,-50.0724
br,sitio antonio a. valikoski,Sítio Antônio A. Valikoski,26,,-26.2394,-49.8296
br,sitio antonio bacalhal,Sítio Antônio Bacalhal,18,,-23.1996,-50.2191
br,sitio antonio balbino,Sítio Antônio Balbino,18,,-23.5813,-49.8458
br,sitio antonio barbosa,Sítio Antônio Barbosa,18,,-23.959627,-50.233961
br,sitio antonio bassani,Sítio Antônio Bassani,18,,-25.761944,-49.696389
br,sitio antonio batista,Sítio Antônio Batista,18,,-23.5522,-49.83
br,sitio antonio b. de camargo,Sítio Antônio B. de Camargo,18,,-23.91413,-50.302776
br,sitio antonio b. do amaral,Sítio Antônio B. do Amaral,18,,-23.6915,-49.7933
br,sitio antonio belniak,Sítio Antônio Belniak,18,,-25.8714,-49.5772
br,sitio antonio benedito da silva,Sítio Antônio Benedito da Silva,18,,-23.550748,-50.2215
br,sitio antonio bero,Sítio Antônio Bero,18,,-25.210749,-48.900718
br,sitio antonio bittencourt,Sítio Antônio Bittencourt,18,,-23.605009,-50.745729
br,sitio antonio b. machado,Sítio Antônio B. Machado,18,,-23.959135,-50.006862
br,sitio antonio b. murbach,Sítio Antônio B. Murbach,18,,-25.855981,-49.908303
br,sitio antonio bocon,Sítio Antônio Boçon,18,,-25.8072,-49.4777
br,sitio antonio bonacim,Sítio Antônio Bonacim,18,,-23.1761,-50.2009
br,sitio antonio borba,Sítio Antônio Borba,18,,-25.5627,-48.8736
br,sitio antonio bordiel,Sítio Antônio Bordiel,18,,-23.4503,-49.8899
br,sitio antonio bordilhao,Sítio Antônio Bordilhão,18,,-23.5274,-49.8672
br,sitio antonio bortole,Sítio Antônio Bortole,18,,-23.702686,-50.675824
br,sitio antonio brechi,Sítio Antônio Brechi,26,,-26.1291,-49.9545
br,sitio antonio budek,Sítio Antônio Budek,18,,-25.84099,-49.903474
br,sitio antonio caixote,Sítio Antônio Caixote,18,,-23.7207,-50.573
br,sitio antonio calisto,Sítio Antônio Calisto,18,,-23.893546,-50.27883
br,sitio antonio camargo,Sítio Antônio Camargo,18,,-25.9208,-49.2287
br,sitio antonio candido,Sítio Antônio Cândido,18,,-23.799884,-50.138764
br,sitio antonio cantele,Sítio Antônio Cantele,18,,-25.8305,-49.517
br,sitio antonio cantelli,Sítio Antônio Cantelli,18,,-25.8501,-49.4717
br,sitio antonio capella,Sítio Antônio Capella,27,,-24.8146,-48.1751
br,sitio antonio capri,Sítio Antônio Capri,18,,-23.2138,-50.2213
br,sitio antonio cardoso,Sítio Antônio Cardoso,18,,-25.5224,-48.8899
br,sitio antonio carlos,Sítio Antônio Carlos,18,,-23.832167,-50.063189
br,sitio antonio catarino manso,Sítio Antônio Catarino Manso,18,,-23.69724,-50.134433
br,sitio antonio c. da silva,Sítio Antônio C. da Silva,18,,-25.559,-48.8137
br,sitio antonio c. de freitas,Sítio Antônio C. de Freitas,18,,-25.8754,-49.0991
br,sitio antonio c. de mello,Sítio Antônio C. de Mello,18,,-25.806074,-49.794723
br,sitio antonio c. demetrio,Sítio Antônio C. Demétrio,26,,-26.2061,-49.9388
br,sitio antonio c. dos santos,Sítio Antônio C. dos Santos,18,,-25.8365,-49.9509
br,sitio antonio cearense,Sítio Antônio Cearense,18,,-23.519967,-50.704564
br,sitio antonio cezario,Sítio Antônio Cezário,18,,-23.607,-49.9784
br,sitio antonio c. ferreira,Sítio Antônio C. Ferreira,18,,-25.906111,-49.678333
br,sitio antonio chuves,Sítio Antônio Chuves,18,,-25.8188,-49.2855
br,sitio antonio ciba,Sítio Antônio Ciba,18,,-25.794606,-49.92249
br,sitio antonio cidral,Sítio Antônio Cidral,18,,-25.8846,-49.1037
br,sitio antonio ciscato,Sítio Antônio Ciscato,18,,-25.450527,-48.833336
br,sitio antonio c. martins,Sítio Antônio C. Martins,18,,-26.006736,-49.436323
br,sitio antonio c. menezes,Sítio Antônio C. Menezes,18,,-23.402617,-49.789438
br,sitio antonio cordeiro,Sítio Antônio Cordeiro,18,,-25.460196,-48.820769
br,sitio antonio correia,Sítio Antônio Correia,27,,-23.730141,-47.528486
br,sitio antonio cortes,Sítio Antônio Cortês,18,,-23.07,-50.1254
br,sitio antonio c. rosario,Sítio Antônio C. Rosário,18,,-25.9581,-49.1187
br,sitio antonio cruz,Sítio Antônio Cruz,18,,-25.7444,-49.7933
br,sitio antonio da cruz,Sítio Antônio da Cruz,18,,-25.7897,-49.2732
br,sitio antonio da s. camargo,Sítio Antônio da S. Camargo,18,,-25.796169,-49.785428
br,sitio antonio da s. maia,Sítio Antônio da S. Maia,18,,-25.9446,-49.0768
br,sitio antonio d. dos santos,Sítio Antônio D. dos Santos,18,,-25.8018,-49.5229
br,sitio antonio de assis,Sítio Antônio de Assis,18,,-25.986944,-49.525833
br,sitio antonio dechima,Sítio Antônio Dechima,18,,-25.861892,-49.786449
br,sitio antonio decor,Sítio Antônio Decor,18,,-23.5999,-49.7755
br,sitio antonio de lima,Sítio Antônio de Lima,18,,-26.184409,-49.677601
br,sitio antonio de lima,Sítio Antônio de Lima,26,,-26.2178,-49.8127
br,sitio antonio de mello,Sítio Antônio de Mello,18,,-23.6025,-50.730941
br,sitio antonio de mello,Sítio Antônio de Mello,26,,-26.0748,-49.8482
br,sitio antonio denobe,Sítio Antônio Denobe,18,,-23.23081,-49.795561
br,sitio antonio de oliveira,Sítio Antônio de Oliveira,18,,-23.870752,-50.567629
br,sitio antonio de paulo,Sítio Antônio de Paulo,18,,-23.219591,-49.872604
br,sitio antonio de s. mendes,Sítio Antônio de S. Mendes,18,,-25.937514,-49.936353
br,sitio antonio d. machado,Sítio Antônio D. Machado,18,,-25.9825,-49.528056
br,sitio antonio domingos,Sítio Antônio Domingos,18,,-23.6692,-49.8343
br,sitio antonio duarte,Sítio Antônio Duarte,18,,-25.5384,-48.8052
br,sitio antonio dudeco,Sítio Antônio Dudeco,18,,-25.3841,-48.5981
br,sitio antonio dudeque,Sítio Antônio Dudeque,18,,-25.881932,-49.933289
br,sitio antonio echel,Sítio Antônio Echel,26,,-26.1446,-49.9026
br,sitio antonio elias,Sítio Antônio Elias,18,,-23.6758,-49.7549
br,sitio antonio elioterio,Sítio Antônio Eliotério,18,,-23.215,-50.2173
br,sitio antonio entraut,Sítio Antônio Entraut,18,,-25.866393,-48.800813
br,sitio antonio esteg,Sítio Antônio Esteg,18,,-25.855833,-49.669167
br,sitio antonio estrugale,Sítio Antônio Estrugale,18,,-25.7025,-49.8575
br,sitio antonio fabianski,Sítio Antônio Fabianski,18,,-25.8462,-49.5397
br,sitio antonio fagundes,Sítio Antônio Fagundes,18,,-25.9116,-49.0973
br,sitio antonio farias,Sítio Antônio Farias,18,,-23.877949,-50.573867
br,sitio antonio fasenki,Sítio Antônio Fasenki,18,,-26.0497,-49.7752
br,sitio antonio f. barbosa,Sítio Antônio F. Barbosa,18,,-25.998,-49.5229
br,sitio antonio f. de carvalho,Sítio Antônio F. de Carvalho,18,,-25.8795,-49.0923
br,sitio antonio f. dos santos,Sítio Antônio F. dos Santos,18,,-23.7123,-49.8689
br,sitio antonio ferreira,Sítio Antônio Ferreira,18,,-23.6177,-49.7689
br,sitio antonio f. franco,Sítio Antônio F. Franco,18,,-23.891817,-50.413145
br,sitio antonio flor,Sítio Antônio Flor,18,,-26.1197,-49.3774
br,sitio antonio fogaca,Sítio Antônio Fogaça,18,,-23.330684,-49.82364
br,sitio antonio fortes,Sítio Antônio Fortes,18,,-23.272,-49.7645
br,sitio antonio f. pinto,Sítio Antônio F. Pinto,18,,-25.7135,-49.8072
br,sitio antonio francisco da rocha,Sítio Antônio Francisco da Rocha,18,,-23.8739,-50.9849
br,sitio antonio francisco siqueira,Sítio Antônio Francisco Siqueira,27,,-24.7956,-48.1831
br,sitio antonio francisco,Sítio Antônio Francisco,18,,-23.807955,-50.758063
br,sitio antonio francisquine,Sítio Antônio Francisquine,18,,-23.0607,-50.1217
br,sitio antonio gabardo,Sítio Antônio Gabardo,18,,-26.0064,-49.963
br,sitio antonio galvao,Sítio Antônio Galvão,18,,-23.66,-49.8577
br,sitio antonio garcia,Sítio Antônio Garcia,18,,-23.520921,-50.224352
br,sitio antonio g. dias,Sítio Antônio G. Dias,27,,-23.5853,-47.5484
br,sitio antonio gerpe,Sítio Antônio Gerpe,18,,-26.0237,-49.9607
br,sitio antonio g. leite,Sítio Antônio G. Leite,18,,-25.8831,-48.7438
br,sitio antonio glisostes,Sítio Antônio Glisostes,18,,-23.74,-49.9167
br,sitio antonio gobr,Sítio Antônio Gobr,18,,-25.956111,-49.515
br,sitio antonio goncalves da costa,Sítio Antônio Gonçalves da Costa,18,,-23.0115,-50.189
br,sitio antonio g. pereira,Sítio Antônio G. Pereira,18,,-23.5766,-49.796
br,sitio antonio grebogi,Sítio Antônio Grebógi,18,,-25.755068,-49.112256
br,sitio antonio grochi,Sítio Antônio Grochi,18,,-25.771193,-48.991265
br,sitio antonio gueder,Sítio Antônio Gueder,18,,-23.2444,-50.1496
br,sitio antonio guerra,Sítio Antônio Guerra,18,,-23.763741,-50.48283
br,sitio antonio henrique,Sítio Antônio Henrique,18,,-23.6419,-49.7936
br,sitio antonio horto,Sítio Antônio Horto,18,,-25.8934,-49.0795
br,sitio antonio ianoski,Sítio Antônio Ianoski,26,,-26.2006,-49.9522
br,sitio antonio iarcas,Sítio Antônio Iarcas,26,,-26.1732,-49.4033
br,sitio antonio i. dos santos,Sítio Antônio I. dos Santos,18,,-23.7479,-49.9882
br,sitio antonio i. sobrinho,Sítio Antônio I. Sobrinho,18,,-23.519747,-50.716607
br,sitio antonio jaros,Sítio Antônio Jaros,18,,-26.028771,-49.714096
br,sitio antonio j. bueno,Sítio Antonio J. Bueno,18,,-25.9983,-49.1878
br,sitio antonio j. de lima,Sítio Antônio J. de Lima,18,,-25.9279,-49.0478
br,sitio antonio j. derbli,Sítio Antônio J. Derbli,18,,-23.550224,-50.605578
br,sitio antonio j. e. portela,Sítio Antônio J. E. Portela,18,,-25.968053,-49.847928
br,sitio antonio jorge,Sítio Antônio Jorge,18,,-25.760556,-49.677778
br,sitio antonio kaiss,Sítio Antônio Kaiss,18,,-25.8127,-49.5183
br,sitio antonio kamaty,Sítio Antônio Kamaty,18,,-23.438984,-49.807183
br,sitio antonio knaut,Sítio Antônio Knaut,18,,-25.848494,-49.927272
br,sitio antonio knopk,Sítio Antônio Knopk,18,,-25.826944,-49.618611
br,sitio antonio kossoski,Sítio Antônio Kossoski,18,,-25.811807,-49.782918
br,sitio antonio kuka,Sítio Antônio Kuka,18,,-26.1046,-49.4884
br,sitio antonio laketa,Sítio Antônio Laketa,18,,-25.437102,-48.859112
br,sitio antonio l. da rosa,Sítio Antônio L. da Rosa,18,,-23.3899,-49.8891
br,sitio antonio l. de siqueira,Sítio Antônio L. de Siqueira,18,,-25.794722,-49.650556
br,sitio antonio leandro de melo,Sítio Antônio Leandro de Melo,18,,-25.822171,-49.802056
br,sitio antonio leodoro,Sítio Antônio Leodoro,18,,-23.6314,-49.9029
br,sitio antonio lima,Sítio Antônio Lima,18,,-25.9341,-49.4228
br,sitio antonio l. junior,Sítio Antônio L. Júnior,18,,-23.9283,-50.2439
br,sitio antonio lopes,Sítio Antônio Lopes,18,,-26.0112,-49.9612
br,sitio antonio lourenco,Sítio Antônio Lourenço,18,,-25.5393,-48.7825
br,sitio antonio lucas,Sítio Antônio Lucas,18,,-23.6305,-49.9188
br,sitio antonio luiz,Sítio Antônio Luiz,18,,-25.7719,-49.4618
br,sitio antonio macedo,Sítio Antônio Macedo,18,,-25.920833,-49.658611
br,sitio antonio maidelon,Sítio Antônio Maidelon,26,,-26.246,-49.8323
br,sitio antonio m. alves,Sítio Antônio M. Alves,18,,-26.125558,-49.677033
br,sitio antonio manco,Sítio Antônio Manco,18,,-23.723055,-50.646046
br,sitio antonio mariano,Sítio Antônio Mariano,18,,-23.9895,-50.8486
br,sitio antonio maria,Sítio Antônio Maria,18,,-23.198892,-49.903529
br,sitio antonio marques,Sítio Antônio Marques,18,,-23.2729,-49.755
br,sitio antonio martinez,Sítio Antônio Martinez,18,,-23.484881,-49.94347
br,sitio antonio martiniano,Sítio Antônio Martiniano,18,,-23.6634,-49.805
br,sitio antonio martins,Sítio Antônio Martins,18,,-23.3901,-49.9064
br,sitio antonio matos,Sítio Antônio Matos,18,,-25.8283,-48.755832
br,sitio antonio mazinho,Sítio Antônio Mazinho,18,,-23.5795,-49.8307
br,sitio antonio mazur,Sítio Antônio Mazur,18,,-26.010078,-49.6895
br,sitio antonio m. da silva,Sítio Antônio M. da Silva,18,,-23.57056,-50.519278
br,sitio antonio m. dos santos,Sítio Antônio M. dos Santos,18,,-25.914387,-49.976042
br,sitio antonio m. estevam,Sítio Antônio M. Estevam,18,,-23.6523,-49.8608
br,sitio antonio m. filho,Sítio Antônio M. Filho,18,,-25.852689,-49.76145
br,sitio antonio miguel,Sítio Antônio Miguel,18,,-23.6898,-49.8506
br,sitio antonio milchivski,Sítio Antônio Milchivski,18,,-26.0612,-49.2724
br,sitio antonio militao,Sítio Antônio Militão,18,,-23.6752,-49.7989
br,sitio antonio m. minikoski,Sítio Antônio M. Minikoski,18,,-26.0912,-49.4201
br,sitio antonio m. nunes,Sítio Antônio M. Nunes,18,,-25.8157,-49.2401
br,sitio antonio montalvani,Sítio Antônio Montalvani,18,,-23.416349,-50.120524
br,sitio antonio moreira,Sítio Antônio Moreira,18,,-25.8023,-49.5109
br,sitio antonio n. da cruz,Sítio Antônio N. da Cruz,18,,-25.9391,-49.2256
br,sitio antonio neki,Sítio Antônio Neki,18,,-25.8815,-49.3723
br,sitio antonio nero,Sítio Antônio Nero,18,,-23.72956,-50.679812
br,sitio antonio nicao,Sítio Antônio Nicão,18,,-23.837685,-50.651961
br,sitio antonio nossol,Sítio Antônio Nossol,18,,-26.033268,-49.500803
br,sitio antonio nunes morais,Sítio Antônio Nunes Morais,18,,-23.353207,-50.010278
br,sitio antonio nunes,Sítio Antônio Nunes,18,,-23.80295,-50.037196
br,sitio antonio oczkovski,Sítio Antônio Oczkovski,26,,-26.0411,-49.9917
br,sitio antonio o. da cruz,Sítio Antônio O. da Cruz,18,,-25.9018,-49.3673
br,sitio antonio o. da silva,Sítio Antônio O. da Silva,18,,-23.842743,-50.01029
br,sitio antonio o. de lima,Sítio Antônio O. de Lima,18,,-25.9286,-49.3099
br,sitio antonio o. do nascimento,Sítio Antônio O. do Nascimento,18,,-26.172644,-49.614566
br,sitio antonio oliveira,Sítio Antônio Oliveira,18,,-23.86834,-50.078379
br,sitio antonio opolis,Sítio Antônio Opolis,18,,-25.845374,-49.75493
br,sitio antonio oroscki,Sítio Antônio Oroscki,26,,-26.1785,-49.9013
br,sitio antonio ozorio,Sítio Antônio Ozório,18,,-23.743928,-50.040172
br,sitio antonio pandeleque,Sítio Antônio Pandeleque,18,,-25.8753,-49.0911
br,sitio antonio pantoba,Sítio Antônio Pantoba,18,,-25.938333,-49.714722
br,sitio antonio paraiba,Sítio Antônio Paraíba,18,,-23.730451,-50.654332
br,sitio antonio paulino,Sítio Antônio Paulino,18,,-23.656658,-50.010327
br,sitio antonio p. correa,Sítio Antônio P. Correa,18,,-25.814167,-49.7225
br,sitio antonio p. duraes,Sítio Antônio P. Durães,18,,-23.768462,-50.233014
br,sitio antonio pedroti,Sítio Antônio Pedroti,18,,-23.80539,-50.752158
br,sitio antonio pereira fogaca,Sítio Antônio Pereira Fogaca,18,,-24.707831,-48.65984
br,sitio antonio pereira,Sítio Antônio Pereira,18,,-23.575858,-50.641671
br,sitio antonio pereira,Sítio Antônio Pereira,26,,-26.1684,-49.9051
br,sitio antonio piculo,Sítio Antônio Piculo,18,,-23.147931,-50.149445
br,sitio antonio p. machoski,Sítio Antônio P. Machoski,18,,-25.8081,-49.4191
br,sitio antonio polican,Sítio Antônio Polican,18,,-23.867403,-50.259706
br,sitio antonio portugues,Sítio Antônio Português,18,,-23.0714,-50.0314
br,sitio antonio posse,Sítio Antônio Posse,18,,-23.674401,-50.103339
br,sitio antonio prestes,Sítio Antônio Prestes,18,,-23.939454,-50.552208
br,sitio antonio pscheidt,Sítio Antônio Pscheidt,26,,-26.1874,-49.8501
br,sitio antonio quinzinho,Sítio Antônio Quinzinho,18,,-23.601,-49.9955
br,sitio antonio ramos,Sítio Antônio Ramos,18,,-23.639594,-50.172837
br,sitio antonio rampava,Sítio Antônio Rampava,18,,-25.7586,-49.4573
br,sitio antonio r. castanheira,Sítio Antônio R. Castanheira,18,,-23.4567,-49.8515
br,sitio antonio r. da cruz,Sítio Antônio R. da Cruz,18,,-25.8512,-49.3283
br,sitio antonio r. da rosa,Sítio Antônio R. da Rosa,18,,-25.7978,-49.2948
br,sitio antonio r. de assis,Sítio Antônio R. de Assis,18,,-23.374469,-49.970685
br,sitio antonio r. de lima,Sítio Antônio R. de Lima,18,,-26.141289,-49.704004
br,sitio antonio r. de souza,Sítio Antônio R. de Souza,18,,-23.2209,-50.0527
br,sitio antonio ribas,Sítio Antônio Ribas,18,,-25.960556,-49.535833
br,sitio antonio ribas teixeira,Sítio Antônio Ribas Teixeira,18,,-25.7012,-49.9677
br,sitio antonio ribeiro,Sítio Antônio Ribeiro,18,,-23.1866,-50.2115
br,sitio antonio rodrigues,Sítio Antônio Rodrigues,18,,-23.382269,-49.821167
br,sitio antonio rolato,Sítio Antônio Rolato,18,,-25.803327,-49.778338
br,sitio antonio rosario,Sítio Antônio Rosário,18,,-26.046457,-49.523419
br,sitio antonio rosin,Sítio Antônio Rosin,26,,-26.2174,-49.9057
br,sitio antonio r. teixeira,Sítio Antônio R. Teixeira,18,,-23.833854,-50.142783
br,sitio antonio ruthes,Sítio Antônio Ruthes,26,,-26.2121,-49.8443
br,sitio antonio r. zampieri,Sítio Antônio R. Zampieri,18,,-23.1315,-50.128
br,sitio antonio sampaio,Sítio Antônio Sampaio,26,,-26.1143,-49.9738
br,sitio antonio santa rosa,Sítio Antônio Santa Rosa,18,,-23.686304,-50.218704
br,sitio antonio santos cordeiro,Sítio Antônio Santos Cordeiro,18,,-25.145964,-48.961003
br,sitio antonio s. de abreu,Sítio Antônio S. de Abreu,18,,-25.888538,-49.985628
br,sitio antonio s. de lima,Sítio Antônio S. de Lima,18,,-25.935957,-49.128509
br,sitio antonio seidel,Sítio Antônio Seidel,18,,-26.0787,-49.8112
br,sitio antonio selner,Sítio Antônio Selner,26,,-26.1031,-49.921
br,sitio antonio seluski,Sítio Antônio Seluski,18,,-25.900833,-49.590833
br,sitio antonio shegask,Sítio Antônio Shegask,18,,-25.826728,-49.755299
br,sitio antonio silva pinto,Sítio Antônio Silva Pinto,18,,-25.7308,-49.8283
br,sitio antonio silva,Sítio Antônio Silva,18,,-23.418344,-49.831653
br,sitio antonio silvino,Sítio Antônio Silvino,18,,-25.8039,-49.3439
br,sitio antonio siqueira mendes,Sítio Antônio Siqueira Mendes,18,,-25.897,-49.77577
br,sitio antonio,Sítio Antônio,18,,-23.86266,-50.666948
br,sitio antonio,Sítio Antônio,27,,-23.678132,-47.230289
br,sitio antonio s. karan,Sítio Antônio S. Karan,18,,-25.812778,-49.740556
br,sitio antonio sterse,Sítio Antônio Sterse,26,,-26.1449,-49.9342
br,sitio antonio stupp,Sítio Antônio Stupp,26,,-26.2205,-49.824
br,sitio antonio suominski,Sítio Antônio Suominski,18,,-26.1011,-49.329
br,sitio antonio surk,Sítio Antônio Surk,18,,-25.8069,-49.5297
br,sitio antonio susela,Sítio Antônio Susela,18,,-25.844526,-49.785885
br,sitio antonio taborda,Sítio Antônio Taborda,18,,-26.043,-49.4516
br,sitio antonio teixeira,Sítio Antônio Teixeira,18,,-23.820184,-50.04238
br,sitio antonio telma,Sítio Antônio Telma,18,,-26.145,-49.441
br,sitio antonio teofilo,Sítio Antônio Teófilo,18,,-23.2381,-50.1851
br,sitio antonio thomaz,Sítio Antônio Thomaz,18,,-23.758989,-50.173953
br,sitio antonio tiburcio,Sítio Antônio Tibúrcio,18,,-23.5632,-49.9024
br,sitio antonio tozari,Sítio Antônio Tozari,18,,-23.732465,-50.684227
br,sitio antonio turma,Sítio Antônio Turma,18,,-25.6831,-49.8802
br,sitio antonio valerio,Sítio Antônio Valério,26,,-26.1126,-49.8202
br,sitio antonio valesko,Sítio Antônio Valesko,18,,-26.0467,-49.7799
br,sitio antonio v. da silva,Sítio Antônio V. da Silva,18,,-25.8586,-49.0263
br,sitio antonio v. de oliveira,Sítio Antônio V. de Oliveira,18,,-23.902766,-50.463118
br,sitio antonio velhinho,Sítio Antônio Velhinho,27,,-25.031652,-48.564759
br,sitio antonio viana,Sítio Antônio Viana,18,,-25.184154,-48.958088
br,sitio antonio vidal,Sítio Antônio Vidal,18,,-23.79225,-50.086025
br,sitio antonio wagner,Sítio Antônio Wagner,18,,-25.7442,-49.8492
br,sitio antonio wenceslau,Sítio Antônio Wenceslau,18,,-26.198099,-49.492351
br,sitio antonio willner,Sítio Antônio Willner,26,,-26.1324,-49.9832
br,sitio antonio wosniaki,Sítio Antônio Wosniaki,18,,-25.7524,-49.1533
br,sitio antonio z. da silva,Sítio Antônio Z. da Silva,18,,-23.5888,-49.805
br,sitio antonio zebonok,Sítio Antônio Zebonok,18,,-25.850516,-49.759595
br,sitio antonio zizinho,Sítio Antônio Zizinho,18,,-23.0716,-50.2228
br,sitio antonizio cipriano,Sítio Antonízio Cipriano,18,,-23.8562,-50.9748
br,sitio anto wendrechorski,Sítio Anto Wendrechorski,18,,-26.052496,-49.549512
br,sitio anunciato barnabe,Sítio Anunciato Barnabe,27,,-23.125636,-47.560265
br,sitio aparecida b. alves,Sítio Aparecida B. Alves,18,,-23.5538,-49.788
br,sitio aparecida,Sítio Aparecida,27,,-23.059984,-49.830432
br,sitio aparecida xavier,Sítio Aparecida Xavier,18,,-23.6862,-49.9593
br,sitio aparecido abaete,Sítio Aparecido Abaeté,18,,-23.9108,-50.2808
br,sitio aparecido dos santos,Sítio Aparecido dos Santos,18,,-23.919889,-50.259696
br,sitio aparecido mariano,Sítio Aparecido Mariano,18,,-23.440458,-49.826835
br,sitio aparecido roberto,Sítio Aparecido Roberto,18,,-23.718834,-50.037226
br,sitio aparecido,Sítio Aparecido,18,,-23.779591,-50.805218
br,sitio aparecido vidal,Sítio Aparecido Vidal,18,,-25.6355,-48.7999
br,sitio aparicio g. vieira,Sítio Aparício G. Vieira,18,,-23.842797,-50.143459
br,sitio aparicio rodrigues,Sítio Aparicio Rodrigues,18,,-23.907395,-50.462422
br,sitio apa,Sítio Apá,27,,-23.386537,-46.707182
br,sitio apolonia ihavoski,Sítio Apolônia Ihavoski,18,,-25.760505,-49.843409
br,sitio apucaraninha,Sítio Apucaraninha,18,,-23.7534,-50.976
br,sitio apyngorah,Sítio Apyngorah,27,,-23.58018,-47.595358
br,sitio aquarius,Sítio Aquarius,27,,-23.585523,-47.178868
br,sitio aquiles vanzele,Sítio Aquiles Vanzele,18,,-23.816087,-50.079571
br,sitio araci atonhac,Sítio Araci Atonhac,18,,-25.8699,-49.4046
br,sitio araci,Sítio Araci,27,,-23.240833,-46.6725
br,sitio aragao,Sítio Aragão,30,,-7.983333,-36.233333
br,sitio arai,Sítio Arai,18,,-23.553432,-50.724936
br,sitio arapiraca,Sítio Arapiraca,27,,-23.841924,-47.06123
br,sitio arapongas,Sítio Arapongas,27,,-23.9636,-47.0059
br,sitio ararau,Sítio Ararau,04,,-1.683056,-60.162778
br,sitio arariba,Sítio Araribá,18,,-23.806465,-50.193401
br,sitio arariba,Sítio Araribá,27,,-25.032667,-48.581214
br,sitio araucaria,Sítio Araucária,18,,-23.986413,-50.448604
br,sitio arca de noe,Sítio Arca de Noé,18,,-23.400671,-50.055552
br,sitio arcenio ramos,Sítio Arcênio Ramos,18,,-25.5452,-48.8631
br,sitio arci,Sítio Arci,27,,-23.431243,-46.735743
br,sitio arco claro,Sítio Arco Claro,18,,-23.225252,-49.824948
br,sitio arco-iris,Sítio Arco-Iris,27,,-23.781695,-46.714421
br,sitio ardelino gomes,Sítio Ardelino Gomes,18,,-25.9275,-49.3124
br,sitio areadinho,Sítio Areadinho,27,,-24.63114,-48.164438
br,sitio areado,Sítio Areado,27,,-24.553239,-48.036003
br,sitio areao,Sítio Areão,18,,-23.732808,-50.235559
br,sitio areao,Sítio Areão,27,,-23.414088,-46.740212
br,sitio areia branca,Sítio Areia Branca,27,,-23.110278,-46.59
br,sitio areia-preta,Sítio Areia-Preta,27,,-24.689128,-48.153782
br,sitio areia-pretinha,Sítio Areia-Pretinha,27,,-24.685382,-48.146852
br,sitio areia vermelha,Sítio Areia Vermelha,27,,-23.121944,-47.6975
br,sitio argemiro elias,Sítio Argemiro Elias,18,,-26.123524,-49.740082
br,sitio argemiro machado,Sítio Argemiro Machado,18,,-26.204051,-49.617365
br,sitio argemiro ponde,Sítio Argemiro Pondé,18,,-23.6124,-49.8976
br,sitio argemiro ribeiro,Sítio Argemiro Ribeiro,18,,-26.1541,-49.4427
br,sitio argemiro ronchinski,Sítio Argemiro Ronchinski,18,,-25.958097,-49.893906
br,sitio ari a. pereira,Sítio Ari A. Pereira,18,,-26.0783,-49.314
br,sitio ari b. armin,Sítio Ari B. Armin,18,,-25.864,-49.3151
br,sitio ari bernardes,Sítio Ari Bernardes,18,,-23.890214,-50.17247
br,sitio ari carmeri,Sítio Ari Carmeri,18,,-25.22024,-48.940985
br,sitio ari cordeiro dos santos,Sítio Ari Cordeiro dos Santos,18,,-25.079383,-48.872624
br,sitio ari cordeiro,Sítio Ari Cordeiro,18,,-23.837494,-50.105579
br,sitio aricura,Sítio Aricurá,25,,.583333,-61.6
br,sitio ari dibas,Sítio Ari Dibas,18,,-25.7977,-49.3774
br,sitio ari f. da rocha,Sítio Ari F. da Rocha,18,,-25.833092,-49.974557
br,sitio arildo f. dos santos,Sítio Arildo F. dos Santos,18,,-25.309286,-48.936742
br,sitio arildo s. boachak,Sítio Arildo S. Boachak,18,,-23.847138,-50.459912
br,sitio ari mika,Sítio Ari Mika,18,,-25.798,-49.4596
br,sitio ari mila,Sítio Ari Mila,18,,-25.944,-49.0611
br,sitio arineu pereira,Sítio Arineu Pereira,18,,-23.935109,-50.180694
br,sitio ari p. da cruz,Sítio Ari P. da Cruz,18,,-26.0077,-49.2575
br,sitio ari ricardo,Sítio Ari Ricardo,18,,-25.3842,-48.6059
br,sitio ariro,Sítio Ariro,27,,-23.596072,-47.173363
br,sitio aristeo witt,Sítio Aristeo Witt,26,,-26.1381,-49.8982
br,sitio aristeu afonso guimaraes,Sítio Aristeu Afonso Guimarães,18,,-25.75559,-49.893317
br,sitio aristeu coture,Sítio Aristeu Coture,18,,-25.903819,-49.934332
br,sitio aristeu cuture,Sítio Aristeu Cuture,18,,-25.996,-49.9427
br,sitio aristeu junior,Sítio Aristeu Júnior,18,,-23.828934,-50.214111
br,sitio aristeu r. de oliveira,Sítio Aristeu R. de Oliveira,18,,-25.458493,-48.840096
br,sitio aristeu tibes,Sítio Aristeu Tibes,18,,-26.0083,-49.9275
br,sitio aristides a. de souza,Sítio Aristides A. de Souza,18,,-23.992263,-50.283884
br,sitio aristides de oliveira,Sítio Aristides de Oliveira,18,,-23.60088,-50.745729
br,sitio aristides duarte,Sítio Aristides Duarte,18,,-25.5388,-48.809
br,sitio aristides estevao,Sítio Aristides Estêvão,18,,-23.0455,-50.1905
br,sitio aristides f. lima,Sítio Aristides F. Lima,18,,-25.847415,-49.991006
br,sitio aristides fontana,Sítio Aristides Fontana,18,,-23.2288,-50.1893
br,sitio aristides g. ribas,Sítio Aristides G. Ribas,18,,-25.936944,-49.519722
br,sitio aristides henrique,Sítio Aristides Henrique,18,,-25.198278,-48.513686
br,sitio aristides labigalini,Sítio Aristides Labigalini,18,,-25.7558,-49.1683
br,sitio aristides paulino,Sítio Aristides Paulino,18,,-23.4134,-49.8625
br,sitio ariton arbigaus,Sítio Ariton Arbigaus,26,,-26.1597,-49.8949
br,sitio arizona,Sítio Arizona,18,,-23.916414,-50.215214
br,sitio arlindo bassani,Sítio Arlindo Bassani,18,,-23.6794,-49.785
br,sitio arlindo becher,Sítio Arlindo Becher,18,,-25.8198,-49.3148
br,sitio arlindo carvalho,Sítio Arlindo Carvalho,26,,-26.2045,-49.9349
br,sitio arlindo de lima,Sítio Arlindo de Lima,18,,-23.760992,-50.138741
br,sitio arlindo de o. corsi,Sítio Arlindo de O. Corsi,18,,-23.844676,-50.064563
br,sitio arlindo farias,Sítio Arlindo Farias,18,,-23.6948,-49.9424
br,sitio arlindo i. ivasciuk,Sítio Arlindo I. Ivasciuk,18,,-25.802778,-49.747222
br,sitio arlindo lara correia,Sítio Arlindo Lara Correia,18,,-25.840132,-48.782776
br,sitio arlindo p. teixeira,Sítio Arlindo P. Teixeira,18,,-25.5726,-49.9945
br,sitio arlindo,Sítio Arlindo,18,,-25.108691,-48.98836
br,sitio arlindo valle,Sítio Arlindo Valle,18,,-23.5954,-49.9494
br,sitio armador,Sítio Armador,06,,-3.7,-39.616667
br,sitio armando enes,Sítio Armando Enes,18,,-23.528414,-50.007111
br,sitio armando fujimura,Sítio Armando Fujimura,18,,-23.687483,-50.709948
br,sitio armando j. lesco,Sítio Armando J. Lesco,18,,-25.9057,-49.3534
br,sitio armando r. da silva,Sítio Armando R. da Silva,18,,-23.7416,-49.9053
br,sitio armando ribeiro,Sítio Armando Ribeiro,18,,-25.277338,-48.932902
br,sitio armindo portugues,Sítio Armindo Português,18,,-25.191678,-48.936267
br,sitio arnaldo carvalho,Sítio Arnaldo Carvalho,18,,-25.9826,-49.4399
br,sitio arnaldo do f. guedes,Sítio Arnaldo do F. Guedes,18,,-25.840434,-49.986152
br,sitio arnaldo f. de melo,Sítio Arnaldo F. de Melo,18,,-25.9932,-49.184
br,sitio arnaldo leiniker,Sítio Arnaldo Leiniker,18,,-25.835955,-49.759234
br,sitio arnaldo malucelli,Sítio Arnaldo Malucelli,18,,-25.444883,-48.833451
br,sitio arnaldo nobre,Sítio Arnaldo Nobre,18,,-25.4471,-48.7302
br,sitio arnaldo p. dos anjos,Sítio Arnaldo P. dos Anjos,26,,-26.1711,-49.9683
br,sitio arnaldo tirone,Sítio Arnaldo Tirone,18,,-23.1617,-50.1376
br,sitio arnao,Sítio Arnão,18,,-23.82409,-50.496769
br,sitio arno kretschmer,Sítio Arno Kretschmer,18,,-25.861533,-48.78537
br,sitio arnold klene,Sítio Arnold Klene,26,,-26.1723,-49.9106
br,sitio arnoldo bodek,Sítio Arnoldo Bodek,18,,-25.825468,-49.950082
br,sitio arnoldo emples,Sítio Arnoldo Emples,18,,-25.938616,-49.913057
br,sitio arnoldo fernandes,Sítio Arnoldo Fernandes,18,,-26.0225,-49.8726
br,sitio arno rezler,Sítio Arno Rezler,18,,-26.173119,-49.511232
br,sitio aroeira,Sítio Aroeira,06,,-7.15,-39.133333
br,sitio aroldo,Sítio Aroldo,18,,-23.953175,-50.23469
br,sitio arold pozoski,Sítio Arold Pozoski,18,,-25.8326,-49.0429
br,sitio arquilines escandolo,Sítio Arquilines Escandolo,18,,-23.0048,-50.0608
br,sitio arquilino ribeiro,Sítio Arquilino Ribeiro,18,,-23.0895,-50.2388
br,sitio arroio do barreiro,Sítio Arroio do Barreiro,18,,-23.926257,-50.560745
br,sitio arroio do cacador,Sítio Arroio do Caçador,18,,-23.922738,-50.495235
br,sitio arrozal,Sítio Arrozal,18,,-23.912857,-50.218353
br,sitio arruda,Sítio Arruda,18,,-23.372967,-50.058115
br,sitio arsenio leal,Sítio Arsênio Leal,18,,-23.957241,-50.397465
br,sitio artenio rauni,Sítio Artênio Rauni,26,,-26.2207,-49.8981
br,sitio arthur freitas,Sítio Arthur Freitas,18,,-25.508,-48.9998
br,sitio arthur l. de oliveira,Sítio Arthur L. de Oliveira,18,,-23.699,-49.8945
br,sitio arthur moreira,Sítio Arthur Moreira,18,,-25.821389,-49.703611
br,sitio arthur sbonitk,Sítio Arthur Sbonitk,18,,-25.8475,-49.719167
br,sitio artur b. da cruz,Sítio Artur B. da Cruz,18,,-25.7956,-49.2612
br,sitio artur cardoso,Sítio Artur Cardoso,18,,-23.6992,-49.9554
br,sitio artur carneiro,Sítio Artur Carneiro,18,,-23.975863,-50.598219
br,sitio artur galdino,Sítio Artur Galdino,18,,-23.6213,-49.7733
br,sitio arturlino ozica,Sítio Arturlino Ozica,26,,-26.1408,-49.9149
br,sitio artur molim,Sítio Artur Molim,18,,-25.207034,-48.863503
br,sitio artur schroeder,Sítio Artur Schroeder,18,,-26.176994,-49.506527
br,sitio artur zabate,Sítio Artur Zabate,18,,-25.963769,-49.94922
br,sitio aruanda,Sítio Aruanda,27,,-23.2325,-46.562222
br,sitio arvino seidel,Sítio Arvino Seidel,18,,-26.072,-49.4222
br,sitio ary kunze,Sítio Ary Kunze,18,,-26.0838,-49.8257
br,sitio arzilio cordeiro,Sítio Arzílio Cordeiro,18,,-26.00624,-49.651934
br,sitio asairdes de oliveira,Sítio Asairdes de Oliveira,18,,-25.940847,-49.811971
br,sitio ascendino ferreira delles,Sítio Ascendino Ferreira Delles,18,,-25.3922,-48.7177
br,sitio assadi tuvico,Sítio Assadi Tuvico,18,,-23.536878,-50.045331
br,sitio assis bueno,Sítio Assis Bueno,18,,-23.862741,-50.256149
br,sitio assis pires,Sítio Assis Pires,18,,-25.9643,-49.3272
br,sitio assis,Sítio Assis,26,,-26.1741,-49.9555
br,sitio assis,Sítio Assis,27,,-23.563615,-47.710948
br,sitio assuncao,Sítio Assuncão,06,,-3.566667,-39.633333
br,sitio assunta a. de oliveira,Sítio Assunta A. de Oliveira,18,,-23.578519,-49.859977
br,sitio ataide j. pereira,Sítio Ataíde J. Pereira,18,,-25.8522,-49.1655
br,sitio ataide machado,Sítio Ataide Machado,18,,-25.9278,-49.2688
br,sitio atalipio leal,Sitio Atalípio Leal,18,,-25.2536,-48.940488
br,sitio athaide simao,Sítio Athaide Simão,18,,-23.478268,-49.820051
br,sitio atilio cavalare,Sítio Atílio Cavalare,18,,-23.5147,-49.8409
br,sitio atilio domingues,Sítio Atilio Domingues,18,,-23.4351,-49.8703
br,sitio atilio jesse,Sítio Atílio Jessé,18,,-25.7579,-49.1346
br,sitio atilio pinheiro,Sítio Atílio Pinheiro,18,,-23.6708,-49.7626
br,sitio atilio silva,Sítio Atílio Silva,18,,-25.9268,-49.0494
br,sitio atillo godoy,Sítio Atíllo Godoy,18,,-23.423259,-49.841162
br,sitio atras dos montes,Sítio Atrás dos Montes,18,,-25.765875,-49.774166
br,sitio augusta,Sítio Augusta,18,,-23.863184,-50.068364
br,sitio augustinho monteiro,Sítio Augustinho Monteiro,18,,-23.212426,-49.969857
br,sitio augustinho rosa,Sítio Augustinho Rosa,18,,-23.130315,-49.911434
br,sitio augustin kubas,Sítio Augustin Kubas,18,,-26.212293,-49.598076
br,sitio augustin telma,Sítio Augustin Telma,26,,-26.1355,-49.2821
br,sitio augusto alves,Sítio Augusto Alves,18,,-23.7192,-49.9551
br,sitio augusto buba,Sítio Augusto Buba,18,,-26.058334,-49.528198
br,sitio augusto carlos da silva,Sítio Augusto Carlos da Silva,18,,-23.1798,-50.1857
br,sitio augusto crefe,Sítio Augusto Crefe,18,,-25.753384,-49.247994
br,sitio augusto criminacio,Sítio Augusto Criminácio,18,,-25.958805,-48.897765
br,sitio augusto de araujo,Sítio Augusto de Araújo,26,,-26.1069,-49.8296
br,sitio augusto d. siqueira,Sítio Augusto D. Siqueira,18,,-23.770221,-50.23832
br,sitio augusto figura,Sítio Augusto Figura,18,,-25.916389,-49.577222
br,sitio augusto konkl,Sítio Augusto Konkl,26,,-26.1431,-49.9508
br,sitio augusto leoncio,Sítio Augusto Leôncio,18,,-23.434712,-50.13436
br,sitio augusto machado,Sítio Augusto Machado,18,,-23.826756,-50.520313
br,sitio augusto picussa,Sítio Augusto Picussa,18,,-25.8162,-49.2644
br,sitio augusto wilczek,Sítio Augusto Wilczek,18,,-25.935278,-49.586111
br,sitio augusto yassuo kuwaha,Sítio Augusto Yassuo Kuwaha,27,,-23.61623,-47.684863
br,sitio aumari piask,Sítio Aumari Piask,26,,-26.248936,-49.735485
br,sitio aura,Sítio Aura,27,,-23.322326,-46.617497
br,sitio aurelio faganholo,Sítio Aurélio Faganholo,18,,-23.993131,-50.436148
br,sitio aurelio salvador,Sítio Aurélio Salvador,18,,-23.149464,-49.93275
br,sitio aurora da silva,Sítio Aurora da Silva,18,,-25.18018,-48.951819
br,sitio aurora leal,Sítio Aurora Leal,18,,-26.0547,-49.8574
br,sitio auzeu m. tromboski,Sítio Auzeu M. Tromboski,18,,-25.7511,-49.2112
br,sitio avans,Sítio Avans,27,,-23.305766,-46.525067
br,sitio avelino alves de souza,Sítio Avelino Alves de Souza,18,,-25.80246,-49.92559
br,sitio avelino c. de camargo,Sítio Avelino C. de Camargo,18,,-25.8695,-49.1979
br,sitio avelino dos santos,Sítio Avelino dos Santos,18,,-25.134414,-48.865942
br,sitio avelino f. de andrade,Sítio Avelino F. de Andrade,18,,-25.9192,-49.2512
br,sitio avelino goncalves,Sítio Avelino Gonçalves,18,,-23.74482,-50.09254
br,sitio avelino j. taborba,Sítio Avelino J. Taborba,18,,-26.0797,-49.4714
br,sitio avelino pereira,Sítio Avelino Pereira,18,,-23.995797,-50.085295
br,sitio avelino,Sítio Avelino,18,,-23.6736,-49.856
br,sitio ayres libel,Sítio Ayres Libel,26,,-26.1109,-49.8511
br,sitio azalea,Sítio Azálea,27,,-23.709801,-47.015603
br,sitio azevedo,Sítio Azevedo,18,,-23.526389,-50.034883
br,sitio aziz miguel,Sítio Aziz Miguel,27,,-23.698967,-47.527099
br,sitio azumaki,Sítio Azumaki,27,,-23.684507,-47.108144
br,sitio baden baden,Sítio Baden Baden,27,,-23.9469,-47.0026
br,sitio bairro dos coelhos,Sítio Bairro dos Coelhos,27,,-24.537819,-48.940864
br,sitio baixa funda,Sítio Baixa Funda,30,,-7.816667,-38.733333
br,sitio baixas,Sítio Baixas,06,,-4.55,-38.166667
br,sitio baixa verde,Sítio Baixa Verde,20,,-7.716667,-40.833333
br,sitio baixa verde,Sitio Baixa Verde,30,,-7.9,-38.616667
br,sitio baixio,Sítio Baixio,06,,-6.433333,-39.783333
br,sitio baixio,Sítio Baixio,30,,-7.6,-40.216667
br,sitio balanca,Sítio Balança,06,,-3.666667,-39.65
br,sitio balao segundo,Sítio Balão Segundo,18,,-25.536402,-50.525132
br,sitio balao,Sítio Balão,18,,-25.51208,-50.530145
br,sitio balbina figura,Sítio Balbina Figura,18,,-25.8365,-49.5783
br,sitio baldino de o. cruz,Sítio Baldino de O. Cruz,18,,-25.9227,-49.1434
br,sitio baldino,Sítio Baldino,18,,-23.0302,-50.1564
br,sitio balduino de o. lima,Sítio Balduíno de O. Lima,18,,-25.991,-49.0637
br,sitio balislau figura,Sítio Balislau Figura,18,,-25.8508,-49.5466
br,sitio balman,Sítio Balman,18,,-23.882022,-50.286473
br,sitio bambueira,Sítio Bambueira,27,,-24.8379,-48.0938
br,sitio bananal,Sítio Bananal,27,,-23.446311,-46.681175
br,sitio bandeirante,Sítio Bandeirante,27,,-23.680049,-47.338821
br,sitio bandeirantes,Sítio Bandeirantes,18,,-23.951702,-50.395988
br,sitio bandeirantes,Sítio Bandeirantes,27,,-23.247222,-46.609444
br,sitio barao,Sítio Barão,18,,-23.154675,-49.899851
br,sitio barba de bode,Sítio Barba de Bode,18,,-23.807645,-50.097226
br,sitio barbosa,Sítio Barbosa,18,,-23.35747,-50.023161
br,sitio barcelona,Sítio Barcelona,18,,-23.993941,-50.53846
br,sitio barra bonita,Sítio Barra Bonita,18,,-23.7371,-49.9591
br,sitio barracao,Sítio Barracão,27,,-23.627345,-47.173717
br,sitio barra da cruz,Sítio Barra da Cruz,27,,-25.007103,-48.510596
br,sitio barra do cordeiro,Sítio Barra do Cordeiro,18,,-25.172206,-48.526337
br,sitio barra do pinhal,Sítio Barra do Pinhal,27,,-23.016111,-46.693056
br,sitio barra do potinga,Sítio Barra do Potinga,18,,-25.21581,-48.490684
br,sitio barra grande,Sítio Barra Grande,18,,-23.547408,-50.06626
br,sitio barra grande,Sítio Barra Grande,27,,-24.514244,-48.915469
br,sitio barra mansa,Sítio Barra Mansa,27,,-23.9461,-47.127
br,sitio barrao,Sítio Barrão,27,,-23.902316,-46.746648
br,sitio barra velha,Sítio Barra Velha,18,,-23.528565,-50.068613
br,sitio barreirinho,Sítio Barreirinho,18,,-23.109153,-49.993434
br,sitio barreiro,Sítio Barreiro,27,,-23.375725,-46.705945
br,sitio barriguda,Sítio Barriguda,06,,-6.866667,-39.983333
br,sitio barro branco,Sítio Barro Branco,18,,-25.224044,-48.881601
br,sitio barro branco,Sítio Barro Branco,27,,-24.502437,-48.100538
br,sitio barrocada,Sítio Barrocada,27,,-23.413605,-46.574161
br,sitio barroca do fumeiro,Sítio Barroca do Fumeiro,27,,-23.241389,-46.73
br,sitio barrocao,Sítio Barrocão,18,,-23.336184,-50.138669
br,sitio barro preto,Sítio Barro Preto,18,,-23.244199,-49.764039
br,sitio barro,Sítio Barro,27,,-23.741181,-47.089294
br,sitio barro vermelho,Sítio Barro Vermelho,22,,-5.456389,-36.517222
br,sitio barro vermelho,Sítio Barro Vermelho,27,,-24.5562,-48.4226
br,sitio bartollo dalneigre,Sítio Bartollo Dalneigre,18,,-25.493331,-48.859403
br,sitio bartolomeu v. da cunha,Sítio Bartolomeu V. da Cunha,18,,-23.794635,-50.092821
br,sitio basilio ramos,Sítio Basílio Ramos,18,,-25.5445,-48.8618
br,sitio basilio,Sítio Basílio,18,,-23.201922,-52.021453
br,sitio batatal,Sítio Batatal,14,,-14.466667,-57.35
br,sitio batista,Sítio Batista,18,,-23.357365,-50.034988
br,sitio beberibe,Sítio Beberibe,27,,-23.5744,-47.5701
br,sitio beija-flor,Sítio Beija-Flor,18,,-23.749038,-50.686783
br,sitio beija-flor,Sítio Beija-Flor,27,,-23.569966,-47.149106
br,sitio beira de agua,Sítio Beira de Água,27,,-23.023333,-46.6375
br,sitio beira-rio,Sítio Beira-Rio,18,,-23.699278,-50.014099
br,sitio beira rio,Sítio Beira Rio,27,,-23.524905,-47.241721
br,sitio bejamim f. ribeiro,Sítio Bejamim F. Ribeiro,18,,-25.7519,-49.4565
br,sitio bela aurora,Sítio Bela Aurora,18,,-23.296595,-50.226565
br,sitio bela aurora,Sítio Bela Aurora,27,,-23.554509,-47.103684
br,sitio bela manha,Sítio Bela Manha,18,,-23.310004,-49.988678
br,sitio bela napoli,Sítio Bela Napoli,27,,-23.9169,-47.1022
br,sitio bela paisagem,Sítio Bela Paisagem,18,,-23.503701,-50.064128
br,sitio belarmino t. de paulo,Sítio Belarmino T. de Paulo,18,,-25.5438,-49.9245
br,sitio belarnino feliciano,Sítio Belarnino Feliciano,18,,-25.5547,-48.8476
br,sitio bela vista,Sítio Bela Vista,18,,-23.0476,-50.1633
br,sitio bela vista,Sítio Bela Vista,21,,-22.2816,-44.3126
br,sitio bela vista,Sítio Bela Vista,27,,-23.059249,-47.625159
br,sitio belem,Sítio Belém,27,,-22.9984,-45.157
br,sitio belmiro santos,Sítio Belmiro Santos,18,,-25.7954,-49.3061
br,sitio belo horizonte,Sítio Belo Horizonte,18,,-23.560273,-50.531408
br,sitio belo horizonte,Sítio Belo Horizonte,27,,-23.155833,-47.585833
br,sitio belo vale,Sítio Belo Vale,27,,-23.9577,-47.1521
br,sitio bemari cecresqui,Sítio Bemari Cecresqui,18,,-25.94444,-48.905614
br,sitio bem-me-quer,Sítio Bem-Me-Quer,27,,-23.289066,-46.712744
br,sitio bem-te-vi,Sítio Bem-Te-Vi,18,,-25.4242,-48.7437
br,sitio benedita goncalves,Sítio Benedita Gonçalves,18,,-23.6433,-49.9343
br,sitio benedita marcolina,Sítio Benedita Marcolina,18,,-23.812175,-50.204625
br,sitio benedito albergane,Sítio Benedito Albergane,18,,-23.769594,-50.00898
br,sitio benedito amaro,Sítio Benedito Amaro,18,,-23.4365,-49.8818
br,sitio benedito assis,Sítio Benedito Assis,18,,-23.5412,-49.8978
br,sitio benedito a. teixeira,Sítio Benedito A. Teixeira,18,,-25.7034,-49.9692
br,sitio benedito b. da silveira,Sítio Benedito B. da Silveira,18,,-25.851389,-49.730278
br,sitio benedito b. de camargo,Sítio Benedito B. de Camargo,18,,-23.350712,-50.040823
br,sitio benedito braga murbach,Sítio Benedito Braga Murbach,18,,-25.8117,-49.9473
br,sitio benedito branco,Sítio Benedito Branco,18,,-23.398735,-49.986473
br,sitio benedito b. teixeira,Sítio Benedito B. Teixeira,18,,-25.8372,-49.6047
br,sitio benedito b. vieira,Sítio Benedito B. Vieira,18,,-23.882999,-50.019059
br,sitio benedito cardoso,Sítio Benedito Cardoso,18,,-25.8211,-49.5503
br,sitio benedito c. batista,Sítio Benedito C. Batista,18,,-25.8661,-49.6122
br,sitio benedito correia,Sítio Benedito Correia,18,,-26.0436,-49.8431
br,sitio benedito costa,Sítio Benedito Costa,18,,-23.695126,-50.099089
br,sitio benedito da silva,Sítio Benedito da Silva,18,,-23.921966,-50.29299
br,sitio benedito de araujo,Sítio Benedito de Araujo,18,,-23.859389,-50.57111
br,sitio benedito de jesus,Sítio Benedito de Jesus,18,,-25.6584,-49.9656
br,sitio benedito de lima,Sítio Benedito de Lima,18,,-25.6962,-49.8321
br,sitio benedito de oliveira,Sítio Benedito de Oliveira,18,,-23.372385,-50.032926
br,sitio benedito domingos,Sítio Benedito Domingos,18,,-25.2811,-48.5169
br,sitio benedito ferreira,Sítio Benedito Ferreira,18,,-25.679,-49.9846
br,sitio benedito fraga,Sítio Benedito Fraga,18,,-23.5608,-49.9318
br,sitio benedito freitas,Sítio Benedito Freitas,18,,-23.801465,-50.307295
br,sitio benedito g. de paula,Sítio Benedito G. de Paula,18,,-23.8025,-50.8466
br,sitio benedito godoy,Sítio Benedito Godoy,18,,-23.2479,-50.1257
br,sitio benedito gomes,Sítio Benedito Gomes,18,,-23.799677,-50.041346
br,sitio benedito h. goncalves,Sítio Benedito H. Gonçalves,18,,-25.789722,-49.748333
br,sitio benedito j. gomes,Sítio Benedito J. Gomes,18,,-23.4302,-49.8531
br,sitio benedito kolasso,Sítio Benedito Kolasso,18,,-25.755,-49.5785
br,sitio benedito l. de toledo,Sítio Benedito L. de Toledo,18,,-23.7427,-49.7755
br,sitio benedito leite,Sítio Benedito Leite,18,,-23.926929,-50.240427
br,sitio benedito luiz,Sítio Benedito Luiz,18,,-23.800401,-50.153371
br,sitio benedito luiz,Sítio Benedito Luiz,27,,-23.006865,-49.764406
br,sitio benedito marciano,Sítio Benedito Marciano,18,,-23.772233,-50.09526
br,sitio benedito m. da costa,Sítio Benedito M. da Costa,18,,-23.769024,-50.028949
br,sitio benedito m. de souza,Sítio Benedito M. de Souza,18,,-25.8178,-49.5787
br,sitio benedito melo,Sítio Benedito Melo,18,,-23.110671,-49.922942
br,sitio benedito mendes,Sítio Benedito Mendes,18,,-23.994077,-50.411076
br,sitio benedito mendes,Sítio Benedito Mendes,27,,-24.532563,-48.901471
br,sitio benedito mineiro,Sítio Benedito Mineiro,18,,-23.731062,-50.012342
br,sitio benedito moura,Sítio Benedito Moura,18,,-25.8396,-49.4641
br,sitio benedito n. da rosa,Sítio Benedito N. da Rosa,18,,-23.7225,-49.9591
br,sitio benedito onesio e noel,Sítio Benedito Onésio e Noel,18,,-23.88309,-50.277042
br,sitio benedito o. rosa,Sítio Benedito O. Rosa,27,,-23.7204,-47.6039
br,sitio benedito palmezan,Sítio Benedito Palmezan,18,,-23.656739,-50.042114
br,sitio benedito p. da silva,Sítio Benedito P. da Silva,18,,-23.725,-49.9508
br,sitio benedito pereira da silva,Sítio Benedito Pereira da Silva,15,,-22.5014,-45.5233
br,sitio benedito pereira,Sítio Benedito Pereira,18,,-24.712651,-48.663804
br,sitio benedito quita,Sítio Benedito Quita,18,,-23.6618,-49.79
br,sitio benedito r. fernandes,Sítio Benedito R. Fernandes,18,,-23.6056,-49.8672
br,sitio benedito ribeiro,Sítio Benedito Ribeiro,18,,-25.7908,-49.5906
br,sitio benedito sabino,Sítio Benedito Sabino,18,,-23.623639,-49.909341
br,sitio benedito santilho,Sítio Benedito Santilho,18,,-23.7097,-49.7547
br,sitio benedito s. de oliveira,Sítio Benedito S. de Oliveira,27,,-23.73509,-47.617334
br,sitio benedito sebastiao,Sítio Benedito Sebastião,18,,-23.834523,-50.003735
br,sitio benedito semolino,Sítio Benedito Semolino,18,,-23.920607,-50.316666
br,sitio benedito simao,Sítio Benedito Simão,18,,-25.899079,-49.932826
br,sitio benedito siqueira,Sítio Benedito Siqueira,18,,-23.688967,-50.062566
br,sitio benedito,Sítio Benedito,18,,-23.681162,-50.568935
br,sitio benedito,Sítio Benedito,27,,-23.707314,-47.121548
br,sitio benedito s. morato,Sítio Benedito S. Morato,18,,-23.6234,-49.9192
br,sitio benedito soares,Sítio Benedito Soares,18,,-23.1436,-50.1578
br,sitio benedito tavares,Sítio Benedito Tavares,18,,-25.7069,-48.7553
br,sitio benedito venancio,Sítio Benedito Venâncio,18,,-23.4121,-49.8489
br,sitio benedito xavier da silva,Sítio Benedito Xavier da Silva,18,,-23.72201,-50.151399
br,sitio benedito zella,Sítio Benedito Zella,18,,-25.783515,-49.769925
br,sitio benedto ourives de lima,Sítio Benedto Ourives de Lima,15,,-22.5283,-45.5167
br,sitio benenito m. dos santos,Sítio Benenito M. dos Santos,18,,-25.9019,-49.3131
br,sitio beneval m. de oliveira,Sítio Beneval M. de Oliveira,18,,-26.0183,-49.4208
br,sitio benevuto,Sítio Benevuto,27,,-23.518786,-47.076161
br,sitio benicio bardarini,Sítio Benício Bardarini,18,,-23.6937,-49.8452
br,sitio benito camelotte,Sítio Benito Camelotté,26,,-26.248632,-49.702824
br,sitio benito,Sítio Benito,18,,-25.6394,-48.7991
br,sitio benjamim b. da cruz,Sítio Benjamim B. da Cruz,18,,-25.9808,-49.0446
br,sitio benjamim ferreira,Sítio Benjamim Ferreíra,18,,-25.9365,-49.2239
br,sitio benjamim f. lima,Sítio Benjamim F. Lima,18,,-25.9256,-49.1474
br,sitio benjamim junior,Sítio Benjamim Júnior,18,,-26.078186,-49.694311
br,sitio benjamim stchen,Sítio Benjamim Stchen,18,,-25.7223,-49.7632
br,sitio benjamin biscaia,Sítio Benjamin Biscaia,18,,-25.794718,-49.205093
br,sitio ben-te-vi,Sítio Ben-Te-Vi,27,,-23.500661,-47.121067
br,sitio bento a. da silva,Sítio Bento A. da Silva,18,,-26.122177,-49.629874
br,sitio bento a. de lima,Sítio Bento A. de Lima,18,,-26.12,-49.4176
br,sitio bento de jesus taverna,Sítio Bento de Jesus Taverna,18,,-25.166367,-48.985966
br,sitio bento gabardo,Sítio Bento Gabardo,18,,-25.7628,-49.1876
br,sitio bento g. correia,Sítio Bento G. Correia,18,,-25.855491,-48.958524
br,sitio bento goes,Sítio Bento Góes,18,,-23.62,-49.9533
br,sitio bento joao,Sítio Bento João,27,,-24.513172,-48.504093
br,sitio bento martins,Sítio Bento Martins,26,,-26.2428,-49.8199
br,sitio bento nunes,Sítio Bento Nunes,22,,-6.2,-36.066667
br,sitio bento p. de souza,Sítio Bento P. de Souza,18,,-25.9898,-49.2652
br,sitio bento,Sítio Bento,18,,-23.946078,-50.309653
br,sitio benvindo de l. franco,Sítio Benvindo de L. Franco,18,,-25.927743,-49.815599
br,sitio benvindo filla,Sítio Benvindo Filla,18,,-25.815214,-49.425286
br,sitio bernardino l. dias,Sítio Bernardino L. Dias,18,,-25.845193,-49.95029
br,sitio bernardino lourenco,Sítio Bernardino Lourenço,18,,-25.827835,-49.924535
br,sitio bernardino neneve,Sítio Bernardino Neneve,18,,-25.992231,-49.205912
br,sitio bernardo afonso,Sítio Bernardo Afonso,18,,-25.771667,-49.673889
br,sitio bernardo hodecker,Sítio Bernardo Hodecker,18,,-25.6965,-49.8207
br,sitio bernardo psibidviski,Sítio Bernardo Psibidviski,18,,-25.7804,-49.5329
br,sitio bernardo sebo,Sítio Bernardo Sebo,18,,-25.235631,-48.552732
br,sitio bernardo,Sítio Bernardo,18,,-25.8911,-49.028
br,sitio bernardo,Sítio Bernardo,27,,-23.237222,-46.671667
br,sitio bernardo zoellner,Sítio Bernardo Zoellner,26,,-26.1461,-49.3573
br,sitio bernedito v. de paula,Sítio Bernedito V. de Paula,18,,-23.7012,-49.8656
br,sitio bertal,Sítio Bertal,18,,-25.94587,-48.907002
br,sitio bertin,Sítio Bertin,27,,-23.248611,-47.671389
br,sitio bicanor r. de campos,Sítio Bicanor R. de Campos,18,,-25.497646,-48.865927
br,sitio bicci,Sítio Bicci,18,,-25.4474,-48.6186
br,sitio bie,Sítio Bié,27,,-23.204444,-46.576389
br,sitio big valley,Sítio Big Valley,27,,-23.243611,-46.701944
br,sitio biri,Sítio Biri,26,,-26.1665,-49.8721
br,sitio blume,Sítio Blume,27,,-23.591532,-47.486186
br,sitio boa agua,Sítio Boa Água,27,,-23.037222,-47.688889
br,sitio boa aventura,Sítio Boa Aventura,18,,-23.0004,-50.1563
br,sitio boa esperanca,Sítio Boa Esperanca,04,,-1.506111,-60.253333
br,sitio boa esperanca,Sítio Boa Esperança,15,,-22.5919,-45.7355
br,sitio boa esperanca,Sítio Boa Esperança,18,,-23.007285,-52.045229
br,sitio boa esperanca,Sítio Boa Esperança,21,,-22.3437,-44.4672
br,sitio boa esperanca,Sítio Boa Esperança,27,,-23.175278,-46.630278
br,sitio boa-nova,Sitio Boa-nova,20,,-5.3,-42.683333
br,sitio boa sorte,Sítio Boa Sorte,18,,-23.283378,-50.131197
br,sitio boa sorte,Sítio Boa Sorte,27,,-23.283566,-46.715325
br,sitio boa terra,Sítio Boa Terra,27,,-23.569127,-47.154766
br,sitio boa uniao,Sítio Boa União,18,,-23.276824,-50.168959
br,sitio boa ventura,Sítio Boa Ventura,18,,-23.320319,-50.119406
br,sitio boa vista,Sítio Boa Vista,04,,-1.814444,-60.149722
br,sitio boa vista,Sítio Boa Vista,06,,-3.616667,-39.666667
br,sitio boa vista,Sítio Boa Vista,14,,-16.174722,-56.648333
br,sitio boa vista,Sítio Boa Vista,15,,-22.5403,-45.518
br,sitio boa vista,Sitio Boa Vista,17,,-6.916667,-38.266667
br,sitio boa vista,Sítio Boa Vista,18,,-23.133151,-49.917072
br,sitio boa vista,Sítio Boa Vista,21,,-22.4234,-44.2797
br,sitio boa vista,Sítio Boa Vista,27,,-23.013611,-46.506389
br,sitio bocaina,Sítio Bocaina,18,,-23.2773,-49.8
br,sitio boi pintado,Sítio Boi Pintado,18,,-23.345884,-50.155922
br,sitio boitata,Sítio Boitatá,18,,-23.1839,-49.845827
br,sitio bola lisinzg,Sítio Bola Lisinzg,18,,-26.0451,-49.8572
br,sitio bolislau figura,Sítio Bolislau Figura,18,,-25.8356,-49.567
br,sitio bolis resner,Sítio Bolis Resner,18,,-25.921667,-49.516944
br,sitio bolles kuduaveick,Sítio Bolles Kuduaveick,18,,-25.7607,-49.4392
br,sitio bolzani,Sítio Bolzani,18,,-23.934912,-50.549031
br,sitio bom conselho,Sítio Bom Conselho,18,,-23.1367,-50.1864
br,sitio bom-gosto,Sítio Bom-Gòsto,18,,-23.142469,-49.885876
br,sitio bom jardim,Sítio Bom Jardim,18,,-23.348159,-50.112751
br,sitio bom jardim,Sítio Bom Jardim,20,,-7.5,-40.783333
br,sitio bom jardim,Sítio Bom Jardim,27,,-23.021678,-49.888139
br,sitio bom jesus da lapa,Sítio Bom Jesus da Lapa,18,,-23.569,-50.7385
br,sitio bom jesus de pirapora,Sítio Bom Jesus de Pirapora,27,,-23.503152,-47.019986
br,sitio bom jesus dos perdoes,Sítio Bom Jesus dos Perdões,27,,-23.073333,-46.636111
br,sitio bom jesus do tiete,Sítio Bom Jesus do Tietê,27,,-23.098611,-47.673056
br,sitio bom jesus,Sítio Bom Jesus,18,,-23.142277,-49.919419
br,sitio bom jesus,Sítio Bom Jesus,27,,-23.059361,-49.838182
br,sitio bom pastor,Sítio Bom Pastor,18,,-23.5557,-49.8969
br,sitio bom pastor,Sítio Bom Pastor,27,,-23.731748,-47.087791
br,sitio bom presente,Sítio Bom Presente,18,,-23.2422,-50.1945
br,sitio bom retiro,Sítio Bom Retiro,18,,-23.511739,-50.217013
br,sitio bom retiro,Sítio Bom Retiro,21,,-22.7697,-44.167
br,sitio bom retiro,Sítio Bom Retiro,27,,-23.088611,-46.721944
br,sitio bom sucesso,Sítio Bom Sucesso,18,,-23.1517,-50.229
br,sitio bom viver,Sítio Bom Viver,27,,-23.200833,-47.61
br,sitio bonanza,Sítio Bonanza,18,,-25.8927,-49.052
br,sitio bonanza,Sítio Bonanza,27,,-23.033118,-46.665418
br,sitio bondarak,Sítio Bondarak,18,,-23.5587,-49.9502
br,sitio bonfim,Sítio Bonfim,18,,-23.5036,-50.5545
br,sitio bonifacio a. de souza,Sítio Bonifácio A. de Souza,18,,-23.978373,-50.515855
br,sitio bonifacio carreteiro,Sítio Bonifácio Carreteiro,18,,-23.567003,-50.002501
br,sitio bonifacio ramos,Sítio Bonifácio Ramos,18,,-25.8977,-48.72
br,sitio bonifacio,Sítio Bonifácio,27,,-24.8292,-48.06
br,sitio bonito,Sítio Bonito,18,,-25.337763,-48.783504
br,sitio bonito,Sítio Bonito,20,,-5.866667,-41.466667
br,sitio bonito,Sítio Bonito,22,,-5.366389,-36.356389
br,sitio bonito,Sitio Bonito,30,,-7.683333,-40.25
br,sitio bonsucesso,Sítio Bonsucesso,18,,-23.994759,-50.416492
br,sitio boqueirao,Sítio Boqueirao,06,,-4.166667,-38.833333
br,sitio boqueirao,Sítio Boqueirão,18,,-23.927747,-50.284682
br,sitio borges,Sítio Borges,18,,-23.490808,-50.026065
br,sitio bortullo stucato,Sítio Bortullo Stucato,18,,-25.5063,-48.8279
br,sitio botafogo,Sítio Botafogo,18,,-25.7459,-49.9608
br,sitio botija,Sítio Botija,06,,-4.716667,-38.133333
br,sitio botto angelo,Sítio Botto Ângelo,18,,-25.49072,-48.858567
br,sitio botuquara,Sítio Botuquara,27,,-23.424232,-46.721118
br,sitio braco feio,Sítio Braço Feio,27,,-24.8728,-48.216
br,sitio braganca,Sítio Bragança,27,,-23.725118,-47.573555
br,sitio brancao,Sítio Brancão,18,,-23.721396,-50.568336
br,sitio brandine,Sítio Brandine,18,,-23.887783,-50.441777
br,sitio brasao,Sítio Brasao,27,,-23.904833,-46.741806
br,sitio bras de paula pacheco,Sítio Brás de Paula Pacheco,18,,-23.324531,-50.234523
br,sitio brasil v. neto,Sítio Brasil V. Neto,18,,-25.428271,-48.870246
br,sitio bras s. de souza,Sítio Brás S. de Souza,18,,-23.5159,-50.7288
br,sitio bratac,Sítio Bratac,18,,-23.159229,-52.196567
br,sitio braulio henning,Sítio Bráulio Henning,18,,-26.158982,-49.512839
br,sitio braulio p. de melo,Sítio Bráulio P. de Melo,18,,-23.976146,-50.029217
br,sitio braz,Sítio Braz,18,,-23.777335,-50.682935
br,sitio breijao,Sítio Breijão,06,,-7.3,-39.25
br,sitio brigida,Sítio Brigida,18,,-23.813063,-50.072618
br,sitio bristan,Sítio Bristan,27,,-23.161111,-46.693333
br,sitio britador,Sítio Britador,18,,-23.910889,-50.19546
br,sitio brozoski,Sítio Brozoski,26,,-26.211558,-49.717675
br,sitio bruno drusz,Sítio Bruno Drusz,18,,-25.8483,-49.6165
br,sitio bruno kawia,Sítio Bruno Kawia,18,,-26.028726,-49.675952
br,sitio bruno pcobolovisk,Sítio Bruno Pcobolovisk,18,,-25.8083,-49.5292
br,sitio bruno,Sítio Bruno,18,,-25.5165,-49.981
br,sitio bruno wojeik,Sítio Bruno Wojeik,18,,-25.752222,-49.509444
br,sitio bufalo,Sítio Búfalo,27,,-23.836623,-46.680397
br,sitio bulha,Sítio Bulha,27,,-24.547732,-48.056888
br,sitio bumbuca,Sítio Bumbuca,27,,-24.609561,-48.135089
br,sitio buriti,Sítio Buriti,27,,-23.118056,-46.504444
br,sitio burle marx,Sítio Burle Marx,21,,-23.018264,-43.54296
br,sitio buscardim,Sítio Buscardim,18,,-25.6903,-48.8634
br,sitio cabana urutu,Sítio Cabana Urutu,18,,-25.8017,-49.1372
br,sitio cabeca,Sítio Cabeça,22,,-5.328889,-36.128611
br,sitio cabral,Sítio Cabral,15,,-22.5558,-45.7021
br,sitio cabucu,Sítio Cabuçu,27,,-23.410606,-46.54106
br,sitio cacaba,Sítio Caçaba,27,,-23.25979,-46.582002
br,sitio cachoeira branca,Sítio Cachoeira Branca,27,,-23.8369,-47.0374
br,sitio cachoeira do franca,Sítio Cachoeira do França,27,,-23.9473,-47.1682
br,sitio cachoeira do rio dos ventos,Sítio Cachoeira do Rio dos Ventos,27,,-23.9421,-47.0376
br,sitio cachoeira,Sítio Cachoeira,18,,-23.986356,-50.44119
br,sitio cachoeira,Sítio Cachoeira,27,,-23.191891,-47.50882
br,sitio cachoeirinha,Sítio Cachoeirinha,06,,-6.983333,-39.016667
br,sitio cachoeirinha,Sítio Cachoeirinha,27,,-23.261761,-46.507594
br,sitio cacimba,Sítio Cacimba,06,,-6.716667,-39.083333
br,sitio cacimbas,Sítio Cacimbas,06,,-6.783333,-39.733333
br,sitio cacimba velha,Sítio Cacimba Velha,30,,-7.816667,-38.35
br,sitio cacique,Sítio Cacique,27,,-23.594645,-47.228452
br,sitio cadeado,Sítio Cadeado,27,,-23.0875,-46.568611
br,sitio caetano,Sítio Caetano,18,,-23.939916,-50.237943
br,sitio caiacanga,Sítio Caiacanga,18,,-25.5492,-49.8205
br,sitio caiacanga,Sítio Caiacanga,27,,-24.556503,-48.021776
br,sitio caiacoara,Sítio Caiaçoara,27,,-23.193611,-46.652778
br,sitio caiapo,Sítio Caiapó,18,,-23.5844,-49.8356
br,sitio caibros,Sítio Caibros,20,,-7.583333,-40.766667
br,sitio caioe,Sítio Caioé,04,,-1.744722,-61.410278
br,sitio caio,Sítio Caio,27,,-23.504196,-47.15871
br,sitio caiva,Sítio Caiva,18,,-25.9976,-49.1821
br,sitio cajazeira,Sítio Cajazeira,06,,-6.816667,-39.016667
br,sitio cajui,Sítio Cajui,30,,-7.95,-38.25
br,sitio calamanta,Sítio Calamantá,27,,-24.749608,-48.150567
br,sitio caldas de arrego,Sítio Caldas de Arrego,27,,-23.522584,-47.090283
br,sitio calefi,Sítio Calefi,18,,-23.89876,-50.173344
br,sitio calicio do amaral,Sítio Calício do Amaral,18,,-23.1736,-50.1538
br,sitio calico h. sabino,Sítio Calico H. Sabino,18,,-23.6342,-49.9047
br,sitio calino czarneski,Sítio Calino Czarneski,18,,-25.7132,-49.8577
br,sitio calisto rosa,Sítio Calisto Rosa,18,,-23.1742,-50.2332
br,sitio calixto gause,Sítio Calixto Gause,18,,-25.772222,-49.688333
br,sitio caman,Sítio Caman,27,,-23.555036,-47.214714
br,sitio camargo,Sítio Camargo,18,,-23.553872,-50.651749
br,sitio camargo,Sítio Camargo,27,,-23.0507,-47.647764
br,sitio cambara,Sítio Cambará,18,,-23.676506,-50.155201
br,sitio camburi,Sítio Camburi,27,,-23.370265,-46.621117
br,sitio camilo ribeiro,Sítio Camilo Ribeiro,18,,-25.831,-49.4689
br,sitio caminho do ceu,Sítio Caminho do Céu,27,,-23.614741,-47.132455
br,sitio campestre,Sitio Campestre,20,,-5.3,-42.733333
br,sitio campina alegre,Sítio Campina Alegre,18,,-25.9227,-49.1474
br,sitio campina grande,Sítio Campina Grande,17,,-7.216667,-36
br,sitio campina,Sítio Campina,18,,-25.8371,-49.1098
br,sitio campinas,Sítio Campinas,27,,-23.521276,-47.035416
br,sitio campininha,Sítio Campininha,27,,-23.054084,-46.667629
br,sitio campo alegre,Sítio Campo Alegre,06,,-6.283333,-39.5
br,sitio campo alegre,Sítio Campo Alegre,27,,-23.712478,-47.131924
br,sitio campo do aterradinho,Sítio Campo do Aterradinho,27,,-23.636767,-47.192191
br,sitio campos,Sítio Campos,06,,-6.05,-39.983333
br,sitio campos,Sítio Campos,27,,-23.171944,-47.716389
br,sitio canaa,Sítio Canaã,27,,-23.059647,-49.883265
br,sitio cana braba,Sítio Cana Braba,06,,-7.3,-39.133333
br,sitio canaria do pai,Sítio Canária do Pai,04,,-1.723333,-60.152778
br,sitio candida minote,Sítio Cândida Minote,18,,-23.914417,-50.232384
br,sitio candido camargo,Sítio Cândido Camargo,18,,-25.9302,-49.4199
br,sitio candido c. dos santos,Sítio Cândido C. dos Santos,18,,-25.9121,-49.3593
br,sitio candido pereira,Sítio Cândido Pereira,18,,-23.152834,-49.873507
br,sitio candido r. do valle,Sítio Cândido R. do Valle,18,,-25.7945,-49.5889
br,sitio candopi,Sítio Candopi,27,,-23.52114,-47.079797
br,sitio cangao,Sítio Cangão,27,,-23.827999,-46.711015
br,sitio canjica,Sitio Canjica,27,,-24.554598,-48.852508
br,sitio cantagalo,Sítio Cantagalo,27,,-23.41525,-46.553137
br,sitio cantinho do ceu,Sítio Cantinho do Céu,18,,-23.0946,-50.0865
br,sitio cantinho,Sítio Cantinho,27,,-23.745989,-47.186418
br,sitio canto feliz,Sítio Canto Feliz,27,,-23.9454,-47.1511
br,sitio capaiba,Sítio Capaíba,27,,-23.138425,-47.575601
br,sitio capao bonito,Sítio Capão Bonito,18,,-23.918733,-50.459615
br,sitio capao das pombas,Sítio Capão das Pombas,18,,-25.5325,-49.8644
br,sitio capeba,Sítio Capeba,06,,-3.6,-39.533333
br,sitio capela do cedro,Sítio Capela do Cedro,27,,-23.304392,-46.613167
br,sitio capim azedo,Sítio Capim Azedo,27,,-23.671699,-47.199794
br,sitio capricho,Sítio Capricho,27,,-23.558675,-47.117378
br,sitio capricornio,Sítio Capricórnio,27,,-23.153333,-46.738889
br,sitio capuava,Sítio Capuava,27,,-23.09956,-47.503762
br,sitio capuavinha,Sítio Capuavinha,18,,-23.604572,-50.144853
br,sitio capuavinha,Sítio Capuavinha,27,,-23.339826,-46.56322
br,sitio caraguata,Sítio Caraguatá,27,,-23.234099,-47.539573
br,sitio carao,Sítio Carão,22,,-4.95,-37.333333
br,sitio carapara,Sítio Carapara,27,,-25.0655,-48.1011
br,sitio caraubas,Sítio Caraúbas,06,,-6.45,-39.9
br,sitio caravana,Sítio Caravana,27,,-23.169167,-46.6825
br,sitio cardoso,Sítio Cardoso,18,,-23.1837,-50.1848
br,sitio carijo,Sítio Carijó,27,,-23.8945,-47.1144
br,sitio carione,Sítio Carione,27,,-23.546334,-47.256792
br,sitio carlito arbigaus,Sítio Carlito Arbigaus,26,,-26.1575,-49.8859
br,sitio carlito a. shimidt,Sítio Carlito A. Shimidt,18,,-23.529106,-50.729123
br,sitio carlito forgiato,Sítio Carlito Forgiato,18,,-25.9609,-49.3226
br,sitio carlito pereira,Sítio Carlito Pereira,18,,-25.9587,-49.1652
br,sitio carlito,Sítio Carlito,18,,-23.518706,-50.221307
br,sitio carlitos vicente,Sítio Carlitos Vicente,18,,-23.619431,-50.674856
br,sitio carlos a. alves,Sítio Carlos A. Alves,18,,-23.7463,-49.9933
br,sitio carlos a. gnatto,Sítio Carlos A. Gnatto,18,,-25.5043,-48.8895
br,sitio carlos alberto,Sítio Carlos Alberto,18,,-25.491862,-48.799089
br,sitio carlos a. machado,Sítio Carlos A. Machado,18,,-26.151017,-49.573327
br,sitio carlos a. nepp,Sítio Carlos A. Nepp,18,,-26.16221,-49.580487
br,sitio carlos augusto silva,Sítio Carlos Augusto Silva,18,,-25.851628,-49.974757
br,sitio carlos a. varassim,Sítio Carlos A. Varassim,18,,-25.9287,-49.2174
br,sitio carlos bail,Sítio Carlos Bail,26,,-26.1831,-49.415
br,sitio carlos bernardes ribeiro,Sítio Carlos Bernardes Ribeiro,27,,-24.8299,-48.1844
br,sitio carlos b. filho,Sítio Carlos B. Filho,18,,-25.8141,-49.3765
br,sitio carlos bueno,Sítio Carlos Bueno,18,,-26.0189,-49.4909
br,sitio carlos burrocot,Sítio Carlos Burrocot,18,,-25.7688,-49.4956
br,sitio carlos c. de meio,Sítio Carlos C. de Meio,18,,-23.6673,-49.9025
br,sitio carlos charneski,Sítio Carlos Charneski,18,,-25.876191,-49.932279
br,sitio carlos costa,Sítio Carlos Costa,18,,-23.0063,-50.0747
br,sitio carlos dos santos,Sítio Carlos dos Santos,18,,-25.5019,-48.7983
br,sitio carlos d. schroth,Sítio Carlos D. Schroth,18,,-26.1492,-49.3841
br,sitio carlos e. carano,Sítio Carlos E. Carano,18,,-25.77595,-49.79435
br,sitio carlos echstein,Sítio Carlos Echstein,26,,-26.2137,-49.4749
br,sitio carlos f. gertler,Sítio Carlos F. Gertler,18,,-26.134671,-49.526197
br,sitio carlos gouveia,Sítio Carlos Gouveia,18,,-23.7004,-49.9004
br,sitio carlos gurski,Sítio Carlos Gurski,18,,-25.854695,-49.943945
br,sitio carlos ildefonso provezan,Sítio Carlos Ildefonso Provezan,18,,-25.844897,-49.763305
br,sitio carlos kava,Sítio Carlos Kava,26,,-26.2285,-49.8831
br,sitio carlos kondlaski,Sítio Carlos Kondlaski,26,,-26.1761,-49.9581
br,sitio carlos kosdra,Sítio Carlos Kosdra,18,,-25.8272,-49.466
br,sitio carlos krueger,Sítio Carlos Krüeger,18,,-25.5232,-48.8921
br,sitio carlos laska,Sítio Carlos Laska,18,,-25.826142,-48.89079
br,sitio carlos machado,Sítio Carlos Machado,18,,-25.5132,-48.8824
br,sitio carlos meyer,Sítio Carlos Meyer,26,,-26.220723,-49.711821
br,sitio carlos miranda,Sítio Carlos Miranda,18,,-25.8144,-48.5838
br,sitio carlos mirval,Sítio Carlos Mirval,26,,-26.234329,-49.665456
br,sitio carlos pabst,Sítio Carlos Pabst,18,,-25.917569,-48.808359
br,sitio carlos p. da silva,Sítio Carlos P. da Silva,18,,-25.888,-49.6078
br,sitio carlos pires,Sítio Carlos Pires,18,,-23.944868,-50.239658
br,sitio carlos portela,Sítio Carlos Portela,18,,-26.0826,-49.4307
br,sitio carlos previante,Sítio Carlos Previante,26,,-26.2141,-49.7712
br,sitio carlos queiroz,Sítio Carlos Queiroz,18,,-26.0216,-49.9619
br,sitio carlos seidel,Sítio Carlos Seidel,18,,-26.0513,-49.3935
br,sitio carlos shimid,Sítio Carlos Shimid,18,,-23.625546,-50.719392
br,sitio carlos,Sítio Carlos,18,,-23.884257,-50.580082
br,sitio carlos soares,Sítio Carlos Soares,18,,-25.931544,-49.107178
br,sitio carlos tima,Sítio Carlos Tima,18,,-25.463501,-48.85513
br,sitio carlos todoroski,Sítio Carlos Todoroski,26,,-26.1871,-49.8752
br,sitio carlos toledo,Sítio Carlos Toledo,18,,-23.567617,-50.009735
br,sitio carlos t. silva,Sítio Carlos T. Silva,18,,-23.91562,-50.422888
br,sitio carlos vaz,Sítio Carlos Vaz,18,,-23.427507,-50.077942
br,sitio carlos vidal,Sítio Carlos Vidal,18,,-25.5238,-48.7914
br,sitio carlos wck,Sítio Carlos Wck,26,,-26.1314,-49.9704
br,sitio carlos weiss,Sítio Carlos Weiss,18,,-23.5662,-49.8249
br,sitio carlos w. ferreira,Sítio Carlos W. Ferreira,18,,-25.6959,-49.9117
br,sitio carmelia p. cardoso,Sítio Carmélia P. Cardoso,18,,-25.477672,-48.855393
br,sitio carmelina m. goncalves,Sítio Carmelina M. Gonçalves,18,,-23.621,-49.9131
br,sitio carmelino rodrigues,Sítio Carmelino Rodrigues,18,,-23.391669,-50.096923
br,sitio carmelio m. da silva,Sítio Carmélio M. da Silva,18,,-25.8548,-49.3489
br,sitio carmelo maria,Sítio Carmelo Maria,18,,-23.978758,-50.02813
br,sitio carmem dias da luz,Sítio Carmem Dias da Luz,15,,-22.5479,-45.669
br,sitio carmo goncalves da silva,Sítio Carmo Gonçalves da Silva,15,,-22.5255,-45.5337
br,sitio carnauba,Sítio Carnaúba,06,,-6.966667,-39.433333
br,sitio carnauba,Sítio Carnaúba,30,,-7.9,-38.316667
br,sitio carnaubinha,Sítio Carnaúbinha,06,,-7.333333,-38.866667
br,sitio carneiro,Sítio Carneiro,18,,-23.846538,-50.465498
br,sitio carolina k. aguiar,Sítio Carolina K. Aguiar,18,,-25.7261,-49.7708
br,sitio carrapateira,Sítio Carrapateira,06,,-6.816667,-39.183333
br,sitio carrascal,Sítio Carrascal,27,,-23.871096,-47.001116
br,sitio carvaozinho,Sítio Carvãozinho,18,,-23.849803,-50.333854
br,sitio casa branca,Sítio Casa Branca,18,,-23.636415,-50.724774
br,sitio casa branca,Sítio Casa Branca,27,,-23.080833,-46.535278
br,sitio casa de guliver,Sítio Casa de Guliver,27,,-23.835392,-46.711984
br,sitio casa de pedra,Sítio Casa de Pedra,27,,-23.190556,-46.561389
br,sitio casa grande,Sítio Casa Grande,18,,-23.971821,-50.332874
br,sitio casa grande,Sítio Casa Grande,27,,-23.764285,-46.743125
br,sitio casa nova,Sítio Casa Nova,18,,-23.930951,-50.315954
br,sitio casarao,Sítio Casarão,27,,-23.9425,-47.0588
br,sitio casa verde,Sítio Casa Verde,18,,-23.735591,-50.094483
br,sitio cascata,Sítio Cascata,27,,-23.139444,-46.502778
br,sitio cascavel,Sítio Cascavel,27,,-23.752942,-46.661458
br,sitio casemiro kava,Sítio Casemiro Kava,26,,-26.2201,-49.8675
br,sitio casemiro knaut,Sítio Casemiro Knaut,18,,-25.7911,-49.4502
br,sitio casemiro ribeiro,Sítio Casemiro Ribeiro,18,,-25.7959,-49.6069
br,sitio casimiro de abreu,Sítio Casimiro de Abreu,18,,-23.698,-49.7889
br,sitio casimiro mordask,Sítio Casimiro Mordask,18,,-25.6834,-49.8808
br,sitio casimiro nita,Sítio Casimiro Nita,18,,-23.482175,-50.025616
br,sitio casimiro,Sítio Casimiro,18,,-25.275702,-48.939571
br,sitio casimiro zela,Sítio Casimiro Zela,18,,-25.6955,-49.8783
br,sitio cassada,Sítio Cassada,27,,-23.687984,-47.09745
br,sitio cassemiro telma,Sítio Cassemiro Telma,26,,-26.1222,-49.2547
br,sitio cassiano p. bueno,Sítio Cassiano P. Bueno,18,,-25.846693,-49.986994
br,sitio cassiano souza dos santos,Sítio Cassiano Souza dos Santos,18,,-25.065571,-48.572345
br,sitio cassio toledo,Sítio Cássio Toledo,18,,-23.6926,-49.8833
br,sitio castanhal,Sítio Castanhal,04,,-1.935278,-61.444722
br,sitio castanheiros,Sítio Castanheiros,27,,-23.8143,-46.6488
br,sitio castelhanos,Sítio Castelhanos,18,,-25.819425,-48.895053
br,sitio castelo branco,Sítio Castelo Branco,18,,-23.487,-49.7912
br,sitio castilho,Sítio Castilho,18,,-23.139,-50.0914
br,sitio catarina arbigaus,Sítio Catarina Arbigaus,26,,-26.1609,-49.8989
br,sitio catarina burniak,Sítio Catarina Burniak,18,,-25.8166,-49.5364
br,sitio catarina celusniaki,Sítio Catarina Celusniaki,18,,-25.8887,-49.3968
br,sitio catarina rzeczyki,Sítio Catarina Rzeczyki,18,,-25.932222,-49.618889
br,sitio catarina schimidt,Sítio Catarina Schimidt,18,,-26.078474,-49.711483
br,sitio catetinho,Sítio Catetinho,27,,-23.087778,-46.547222
br,sitio catugara,Sítio Catugara,27,,-23.196389,-46.570556
br,sitio cavalo-de agua,Sítio Cavalo-de Água,27,,-24.8027,-48.484
br,sitio caxambu,Sítio Caxambu,27,,-23.060278,-46.570278
br,sitio cebolao,Sítio Cebolão,18,,-23.936187,-50.529283
br,sitio cecilia grebo,Sítio Cecília Grebo,18,,-25.931389,-49.616111
br,sitio cecilia samila,Sítio Cecília Samila,18,,-25.7575,-49.2922
br,sitio cedrinho,Sítio Cedrinho,18,,-25.365284,-48.973774
br,sitio cedrinho,Sítio Cedrinho,27,,-24.9543,-48.5094
br,sitio cedro,Sítio Cedro,30,,-7.616667,-40.033333
br,sitio cedro velho,Sítio Cedro Velho,18,,-23.907553,-50.407208
br,sitio celeste,Sítio Celeste,18,,-23.691006,-50.132444
br,sitio celestina g. galvao,Sítio Celestina G. Galvão,18,,-23.2297,-50.1111
br,sitio celestino pecshel,Sítio Celestino Pecshel,26,,-26.234187,-49.674758
br,sitio celia mustafa,Sítio Célia Mustafá,18,,-23.745294,-50.105837
br,sitio celio peloso,Sítio Célio Peloso,18,,-23.534271,-50.699601
br,sitio celso arcelino silveira,Sítio Celso Arcelino Silveira,18,,-25.105835,-48.740955
br,sitio celso flor,Sítio Celso Flor,18,,-25.803287,-49.918838
br,sitio celso gaspe,Sítio Celso Gaspe,18,,-23.690448,-50.204285
br,sitio celso gomes,Sítio Celso Gomes,18,,-25.833791,-49.900271
br,sitio celso mendes,Sítio Celso Mendes,18,,-26.0457,-49.8088
br,sitio celso minte,Sítio Celso Minte,26,,-26.189894,-49.472915
br,sitio celso m. ritzmann,Sítio Celso M. Ritzmann,18,,-26.108219,-49.51439
br,sitio celso perussu,Sítio Celso Perussu,18,,-23.72892,-50.745263
br,sitio celso portela,Sítio Celso Portela,18,,-26.078572,-49.683006
br,sitio celso siqueira,Sítio Celso Siqueira,18,,-25.773449,-48.969782
br,sitio celso,Sítio Celso,18,,-23.535707,-50.736397
br,sitio cem alqueires,Sítio Cem Alqueires,18,,-23.1737,-50.1337
br,sitio central,Sítio Central,18,,-23.243694,-52.033847
br,sitio centro flora,Sítio Centro Flora,27,,-23.7646,-47.1054
br,sitio centro,Sítio Centro,15,,-22.6495,-45.5571
br,sitio ceramica oxford,Sítio Cerâmica Oxford,26,,-26.2196,-49.2764
br,sitio cerrado,Sítio Cerrado,18,,-23.776962,-50.683706
br,sitio cerro verde,Sítio Cerro Verde,18,,-25.226718,-48.859604
br,sitio cesario lopes,Sítio Cesário Lopes,18,,-23.933568,-50.144456
br,sitio cesario pires,Sítio Cesário Pires,18,,-23.8263,-50.123436
br,sitio cesar krabi,Sítio César Krabi,18,,-23.85238,-50.583564
br,sitio cesar r. de oliveira,Sítio César R. de Oliveira,18,,-23.6264,-49.8642
br,sitio cesar rover,Sítio César Rover,18,,-23.6933,-49.8427
br,sitio cesar s. grasoli,Sítio César S. Grasoli,18,,-25.839722,-49.736111
br,sitio ceu azul,Sítio Céu Azul,18,,-23.544067,-50.623548
br,sitio ceu azul,Sítio Céu Azul,27,,-23.727256,-47.234452
br,sitio cezario,Sítio Cezário,27,,-23.7819,-47.1349
br,sitio chachoeira do tateto,Sítio Chachoeira do Tateto,18,,-23.996236,-50.427778
br,sitio chamine da serra,Sítio Chaminé da Serra,18,,-25.33773,-48.926692
br,sitio chao de estrelas,Sítio Chão de Estrelas,27,,-23.8019,-46.648
br,sitio chapada,Sítio Chapada,06,,-3.65,-39.683333
br,sitio chaparral,Sítio Chaparral,27,,-23.910971,-47.008725
br,sitio chapeco,Sítio Chapecó,18,,-23.922491,-50.158559
br,sitio charneca,Sítio Charneca,06,,-6.716667,-39.316667
br,sitio cheiro-verde,Sítio Cheiro-Verde,27,,-23.575086,-47.160689
br,sitio chiboca,Sítio Chiboca,27,,-23.847528,-46.617039
br,sitio chicao,Sítio Chicão,18,,-25.248582,-48.745209
br,sitio chimarrao,Sítio Chimarrão,18,,-23.268951,-50.069917
br,sitio chimbo,Sítio Chimbo,27,,-23.170556,-47.681667
br,sitio chiquinho,Sítio Chiquinho,27,,-24.600396,-48.214315
br,sitio chiquito nara,Sítio Chiquito Nara,18,,-23.518537,-50.034582
br,sitio chora-ri,Sítio Chora-Ri,27,,-23.9258,-47.0963
br,sitio christmann,Sítio Christmann,18,,-25.5058,-48.7937
br,sitio chupador,Sítio Chupador,06,,-7.116667,-39.25
br,sitio cid alberti,Sítio Cid Alberti,18,,-25.856111,-49.648611
br,sitio cidalia de j. silva,Sítio Cidália de J. Silva,27,,-24.9421,-48.3065
br,sitio ciderli,Sítio Ciderli,27,,-23.711,-47.6102
br,sitio cidionor rocha,Sítio Cidionor Rocha,18,,-25.8057,-49.3545
br,sitio cinco estrelas,Sítio Cinco Estrelas,27,,-23.226548,-47.590869
br,sitio cinco irmaos,Sítio Cinco Irmãos,18,,-23.165248,-49.942496
br,sitio cinco irmaos,Sítio Cinco Irmãos,27,,-23.0528,-46.710454
br,sitio cinco montes,Sítio Cinco Montes,27,,-23.163889,-46.663611
br,sitio cinco palmeiras,Sítio Cinco Palmeiras,27,,-23.540994,-47.215805
br,sitio cinco pontas,Sítio Cinco Pontas,18,,-23.8365,-50.8021
br,sitio cinira litzmayer,Sítio Cinira Litzmayer,26,,-26.2354,-49.4506
br,sitio cipriano percicotte,Sítio Cipriano Percicotte,18,,-25.8873,-49.1158
br,sitio cipriano,Sítio Cipriano,27,,-24.7767,-48.0891
br,sitio cirene hulik,Sítio Cirene Hulik,18,,-26.185034,-49.619141
br,sitio ciriaco da rosa,Sítio Ciríaco da Rosa,18,,-26.016862,-49.748097
br,sitio cirilo goncalves,Sítio Cirilo Gonçalves,18,,-23.45681,-49.799677
br,sitio cirilo,Sítio Cirilo,18,,-23.992179,-50.397474
br,sitio cisnes,Sítio Cisnes,27,,-23.53127,-47.079857
br,sitio city helena,Sítio City Helena,18,,-23.1454,-50.0756
br,sitio city,Sítio City,27,,-23.9178,-47.1146
br,sitio claire m. g. da silva,Sítio Claire M. G. da Silva,26,,-26.1875,-49.9906
br,sitio clara taborda,Sítio Clara Taborda,18,,-25.112615,-48.846991
br,sitio clara telma,Sítio Clara Telma,18,,-26.0221,-49.2842
br,sitio clarice pereira botta,Sítio Clarice Pereira Botta,18,,-23.1958,-50.2208
br,sitio claudete,Sítio Claudete,18,,-23.0971,-50.1999
br,sitio claudino rodrigues,Sítio Claudino Rodrigues,26,,-26.2172,-49.8866
br,sitio claudino,Sítio Claudino,27,,-24.511846,-48.141566
br,sitio claudio a. celibele,Sítio Cláudio A. Celibele,18,,-25.7639,-49.2841
br,sitio claudio alves,Sítio Cláudio Alves,18,,-25.822409,-48.901584
br,sitio claudio costa,Sítio Cláudio Costa,18,,-23.616696,-50.682037
br,sitio claudio froehlich,Sítio Cláudio Froehlich,18,,-25.949829,-48.812488
br,sitio claudio g. nogueira,Sítio Cláudio G. Nogueira,18,,-26.0469,-49.3026
br,sitio claudio knapik,Sítio Cláudio Knapik,18,,-25.777055,-49.814707
br,sitio claudio l. do amaral,Sítio Cláudio L. do Amaral,18,,-25.956389,-49.676111
br,sitio claudio lenine,Sítio Cláudio Lenine,18,,-25.5092,-49.9326
br,sitio claudio rodrigues,Sítio Cláudio Rodrigues,18,,-23.619822,-50.004147
br,sitio clemente d. santos,Sítio Clemente D. Santos,18,,-23.560197,-50.578902
br,sitio clemente janiski,Sítio Clemente Janiski,18,,-25.8859,-49.2254
br,sitio cleomar,Sítio Cleomar,27,,-23.62785,-47.115685
br,sitio cleusa esidio,Sítio Cleúsa Esídio,26,,-26.2378,-49.9075
br,sitio clodomiro costa,Sítio Clodomiro Costa,18,,-25.5264,-48.8333
br,sitio clotario mimergem,Sítio Clotário Mimergem,26,,-26.1563,-49.394
br,sitio clotilde m. nogueira,Sítio Clotilde M. Nogueira,18,,-25.5352,-48.793
br,sitio cloves lourenco,Sítio Cloves Lourenço,26,,-26.1443,-49.7549
br,sitio clovis santos,Sítio Clóvis Santos,18,,-23.536746,-50.743487
br,sitio coitado,Sítio Coitado,20,,-7.666667,-40.933333
br,sitio coivara,Sítio Coivara,18,,-25.4591,-48.7431
br,sitio colibri,Sítio Colibri,27,,-23.575382,-47.059191
br,sitio colina dos coquerros,Sítio Colina dos Coquerros,27,,-23.588399,-47.034614
br,sitio colina perino,Sítio Colina Perino,27,,-23.194722,-46.599444
br,sitio colinas,Sítio Colinas,27,,-23.28295,-46.53176
br,sitio colina verde,Sítio Colina Verde,27,,-23.989372,-47.029622
br,sitio comburir,Sítio Comburir,27,,-23.380011,-46.645149
br,sitio conceicao campos,Sítio Conceição Campos,18,,-23.970664,-50.155438
br,sitio conceicao,Sítio Conceição,27,,-24.681038,-48.123572
br,sitio conchas das pedras,Sítio Conchas das Pedras,27,,-23.200278,-46.548056
br,sitio concordia,Sítio Concordia,18,,-23.799582,-50.835617
br,sitio congonhas grande,Sítio Congonhas Grande,18,,-23.550839,-50.610714
br,sitio congonhas,Sítio Congonhas,27,,-24.81,-48.4896
br,sitio congonhinhas,Sítio Congonhinhas,18,,-23.546242,-50.584396
br,sitio conrado f. de lara,Sítio Conrado F. de Lara,18,,-25.7025,-49.8858
br,sitio constantino ferreira,Sítio Constantino Ferreira,18,,-25.6675,-49.9763
br,sitio constantino,Sítio Constantino,27,,-23.682377,-47.068813
br,sitio continental,Sítio Continental,18,,-23.535554,-50.748927
br,sitio coqueiral,Sítio Coqueiral,18,,-23.350767,-52.725757
br,sitio coqueiro,Sítio Coqueiro,18,,-23.0189,-50.1454
br,sitio coqueiros,Sítio Coqueiros,27,,-24.559226,-48.09763
br,sitio coqueiro velho,Sítio Coqueiro Velho,27,,-23.8278,-46.6029
br,sitio coraj,Sítio Coraj,27,,-23.139736,-46.692775
br,sitio corda,Sítio Corda,27,,-24.6031,-48.3844
br,sitio corrego do monjolo,Sítio Córrego do Monjolo,18,,-24.772819,-48.903608
br,sitio corrego fundo,Sítio Córrego Fundo,27,,-23.243611,-46.6775
br,sitio corrego novo,Sítio Córrego Novo,27,,-24.515493,-48.932217
br,sitio corrego preto,Sítio Córrego Preto,27,,-23.6017,-47.6937
br,sitio cosme e damiao,Sítio Cosme e Damião,27,,-23.68091,-47.238378
br,sitio cosmorama,Sítio Cosmorama,27,,-23.841544,-47.032804
br,sitio couro cru,Sítio Couro Cru,18,,-23.764302,-50.698106
br,sitio craveiro,Sítio Craveiro,18,,-25.204299,-48.912754
br,sitio crescente colar soares,Sítio Crescente Colar Soares,18,,-25.875278,-49.649444
br,sitio crioulo,Sítio Crioulo,06,,-7.35,-39.25
br,sitio crispim r. goncalves,Sítio Crispim R. Gonçalves,18,,-25.110784,-48.843878
br,sitio cristal,Sítio Cristal,18,,-24.710961,-48.870956
br,sitio cristiano chagas,Sítio Cristiano Chagas,18,,-23.186,-50.2067
br,sitio cristiano,Sítio Cristiano,18,,-25.8594,-49.055
br,sitio cristina potek,Sítio Cristina Potek,18,,-25.7796,-49.4455
br,sitio cristina,Sítio Cristina,26,,-26.688831,-49.503749
br,sitio cristo redentor,Sítio Cristo Redentor,27,,-23.218056,-46.672778
br,sitio cristo rei,Sítio Cristo Rei,18,,-23.1766,-50.1651
br,sitio cristo-rei,Sítio Cristo-Rei,27,,-23.2025,-46.5875
br,sitio cristovao,Sítio Cristóvão,27,,-24.552165,-48.095651
br,sitio cruz alta,Sítio Cruz Alta,27,,-24.656134,-48.314526
br,sitio cruzeiro do sul,Sítio Cruzeiro do Sul,18,,-23.898858,-50.14856
br,sitio cruzeiro,Sítio Cruzeiro,18,,-23.4459,-49.8626
br,sitio cuiaba,Sítio Cuiabá,18,,-23.998324,-50.467938
br,sitio cunha,Sítio Cunha,18,,-23.796973,-50.298067
br,sitio cupim,Sítio Cupim,06,,-7.216667,-39.15
br,sitio curimatan,Sítio Curimatan,06,,-6.933333,-39.133333
br,sitio curititaiba,Sítio Curititaíba,18,,-25.386975,-48.780259
br,sitio curral,Sítio Curral,27,,-23.653716,-47.197074
br,sitio curt,Sítio Curt,18,,-25.9791,-48.7071
br,sitio curucutu,Sítio Curucutu,27,,-23.8917,-46.6184
br,sitio curumi,Sítio Curumi,27,,-23.8963,-46.734
br,sitio curva do s,Sítio Curva do S,27,,-24.7001,-48.3304
br,sitio curz,Sítio Curz,06,,-6.4,-39.5
br,sitio custodia c. dos santos,Sítio Custódia C. dos Santos,26,,-26.2062,-49.9349
br,sitio custodio a. santos,Sítio Custódio A. Santos,18,,-23.753886,-50.138906
br,sitio custodio p. batista,Sítio Custódio P. Batista,18,,-25.8994,-49.2683
br,sitio da abadia,Sítio da Abadia,29,,-14.8,-46.266667
br,sitio da aldeia,Sítio da Aldeia,20,,-9.433333,-42.883333
br,sitio da alegria,Sítio da Alegria,27,,-23.696415,-47.058239
br,sitio da amizade,Sítio da Amizade,18,,-25.981269,-48.814488
br,sitio da amizade,Sítio da Amizade,27,,-23.592148,-47.051258
br,sitio da amoreira,Sítio da Amoreira,27,,-23.042859,-46.723193
br,sitio da barranca,Sítio da Barranca,27,,-24.563656,-48.217539
br,sitio da barra,Sítio da Barra,22,,-5.540556,-37.430833
br,sitio da barra,Sítio da Barra,27,,-23.6464,-47.6697
br,sitio d'abbadia,Sitio d'Abbadia,29,,-14.8,-46.266667
br,sitio da boa esperanca,Sítio da Boa Esperança,18,,-23.1591,-50.2422
br,sitio da boa vista,Sítio da Boa Vista,27,,-23.2425,-46.685556
br,sitio da cachoeira,Sítio da Cachoeira,27,,-23.640109,-47.253044
br,sitio da cachoeirinha,Sítio da Cachoeirinha,18,,-23.576804,-50.501954
br,sitio da cantareira,Sítio da Cantareira,27,,-23.393401,-46.615886
br,sitio da chapadinha,Sítio da Chapadinha,27,,-23.9512,-47.0043
br,sitio da conceicao,Sítio da Conceição,05,,-10.65,-38.033333
br,sitio da engorda,Sítio da Engorda,18,,-23.1589,-50.22
br,sitio da escolinha,Sítio da Escolinha,27,,-23.1079,-47.9251
br,sitio da grama,Sítio da Grama,27,,-23.589099,-47.145898
br,sitio da gruta,Sítio da Gruta,18,,-23.788185,-50.075573
br,sitio da igrejinha,Sítio da Igrejinha,18,,-23.8395,-50.8626
br,sitio dair nossolo,Sítio Dair Nossolo,18,,-25.9723,-49.4817
br,sitio da jaqueira,Sítio da Jaqueira,18,,-23.0826,-50.2316
br,sitio da lagoa de pedra,Sitio da Lagoa de Pedra,06,,-7.2,-39.216667
br,sitio da laje,Sitio da Laje,21,,-22.273945,-42.912159
br,sitio dalirio de melo,Sítio Dalírio de Melo,18,,-23.959213,-50.282176
br,sitio dalto r. de oliveira,Sítio Dalto R. de Oliveira,26,,-26.1604,-49.8616
br,sitio dalvino guibarosk,Sítio Dalvino Guibarosk,18,,-25.6971,-49.9151
br,sitio damasio mucial,Sítio Damásio Mucial,18,,-25.8044,-49.4455
br,sitio da mata,Sítio da Mata,27,,-23.198333,-46.591389
br,sitio damiano kurovski,Sítio Damiano Kurovski,18,,-26.0585,-49.4178
br,sitio damiano telma,Sítio Damiano Telma,26,,-26.1579,-49.2826
br,sitio da mimosa,Sítio da Mimosa,27,,-23.670417,-47.065261
br,sitio da montanha,Sítio da Montanha,27,,-23.160556,-46.557778
br,sitio daniel b. dos santos,Sítio Daniel B. dos Santos,18,,-25.9251,-49.3636
br,sitio daniel cardoso,Sítio Daniel Cardoso,18,,-25.985,-49.064
br,sitio daniel correia,Sítio Daniel Correia,18,,-26.0436,-49.8137
br,sitio daniel dias,Sítio Daniel Dias,18,,-25.380475,-48.844319
br,sitio daniel gornieki,Sítio Daniel Gornieki,18,,-26.0726,-49.311
br,sitio daniel grebus,Sítio Daniel Grebus,18,,-26.0046,-49.7813
br,sitio daniel house,Sítio Daniel House,26,,-26.230303,-49.515348
br,sitio daniel maoski,Sítio Daniel Maoski,18,,-25.9601,-49.2286
br,sitio daniel mendes,Sítio Daniel Mendes,18,,-25.4207,-48.6547
br,sitio daniel pereira,Sítio Daniel Pereira,18,,-23.997973,-50.005227
br,sitio daniel rocha dos santos,Sítio Daniel Rocha dos Santos,18,,-25.794,-48.6184
br,sitio daniel rocha,Sítio Daniel Rocha,18,,-25.9587,-49.3249
br,sitio daniel,Sítio Daniel,18,,-25.6954,-49.7562
br,sitio daniel suchy,Sítio Daniel Suchy,18,,-25.839,-49.3165
br,sitio daninho,Sítio Daninho,18,,-25.5864,-48.8116
br,sitio dante malavisi,Sítio Dante Malavisi,18,,-23.1558,-50.1876
br,sitio da onca,Sitio da Onca,20,,-5.916667,-41.183333
br,sitio da paz,Sítio da Paz,18,,-23.818282,-50.215541
br,sitio da paz,Sítio da Paz,27,,-23.795,-47.2362
br,sitio da pedra,Sítio da Pedra,27,,-23.603143,-47.137063
br,sitio da pedrinha,Sítio da Pedrinha,27,,-23.723,-47.9189
br,sitio da pirraca,Sítio da Pirraca,27,,-24.705694,-48.016517
br,sitio darci burgnon,Sítio Darci Burgnon,18,,-23.585,-49.8724
br,sitio darci da costa,Sítio Darci da Costa,18,,-23.86946,-50.318402
br,sitio darci da luz,Sítio Darci da Luz,18,,-23.8564,-50.966
br,sitio darci d. da silveira,Sítio Darci D. da Silveira,18,,-25.7923,-49.6084
br,sitio darci decol,Sítio Darci Decol,18,,-23.961318,-50.027048
br,sitio darci pedroso fogaca,Sítio Darci Pedroso Fogaça,18,,-23.428019,-50.154378
br,sitio darci ribeiro,Sítio Darci Ribeiro,18,,-25.7779,-49.4742
br,sitio darci rocha,Sítio Darci Rocha,18,,-25.8555,-49.1795
br,sitio darci rodrigues,Sítio Darci Rodrigues,26,,-26.1945,-49.866
br,sitio darcy baumgartner,Sítio Darcy Baumgartner,18,,-26.11497,-49.653359
br,sitio darcy de oliveira,Sítio Darcy de Oliveira,18,,-25.7965,-48.5586
br,sitio darcy rodrigues,Sítio Darcy Rodrigues,18,,-23.778528,-50.220832
br,sitio darcy votroba,Sítio Darcy Votroba,18,,-26.154674,-49.531846
br,sitio da ressaca,Sítio da Ressaca,27,,-23.662501,-47.28142
br,sitio da revessa,Sítio da Revessa,27,,-24.520552,-48.132712
br,sitio dario miranda,Sítio Dário Miranda,18,,-25.7472,-48.7632
br,sitio das abelhas,Sítio das Abelhas,27,,-23.8271,-46.6015
br,sitio das aguas nogueiras,Sítio das Águas Nogueiras,27,,-23.779847,-47.046849
br,sitio das alagoas,Sítio das Alagoas,27,,-23.239167,-46.641389
br,sitio das andorinhas,Sítio das Andorinhas,18,,-25.562,-49.9384
br,sitio da saudade,Sítio da Saudade,18,,-25.5476,-48.8659
br,sitio da saude,Sítio da Saúde,27,,-23.118611,-46.603056
br,sitio das cachoeiras,Sítio das Cachoeiras,27,,-23.9634,-47.0966
br,sitio das chagas,Sítio das Chagas,05,,-10.366667,-38.366667
br,sitio da serra grande,Sítio da Serra Grande,20,,-7.533333,-40.716667
br,sitio da serra,Sítio da Serra,27,,-23.205,-46.555556
br,sitio das flores,Sítio das Flores,05,,-10.7,-39.4
br,sitio das flores,Sítio das Flores,27,,-23.925,-47.0443
br,sitio das gemeas,Sítio das Gêmeas,27,,-23.8618,-46.642
br,sitio das lajes,Sítio das Lajes,18,,-23.5783,-49.9545
br,sitio das lajes,Sítio das Lajes,27,,-23.635478,-47.010644
br,sitio das laranjeiras,Sítio das Laranjeiras,27,,-23.9187,-47.0977
br,sitio das macas,Sítio das Maças,30,,-8.366667,-36.583333
br,sitio das mocas,Sítio das Moças,30,,-8.366667,-36.583333
br,sitio das neves,Sítio das Neves,27,,-23.194444,-46.590833
br,sitio das oliveiras,Sítio das Oliveiras,18,,-23.5339,-49.9212
br,sitio das oliveiras,Sítio das Oliveiras,27,,-23.748442,-47.388929
br,sitio das oncas,Sítio das Onças,20,,-6.3,-40.95
br,sitio das pacas,Sítio das Pacas,27,,-23.8684,-47.1825
br,sitio das paineiras,Sítio das Paineiras,18,,-23.2014,-50.1853
br,sitio das palmeiras,Sítio das Palmeiras,18,,-23.670074,-50.140393
br,sitio das palmeiras,Sítio das Palmeiras,27,,-23.017778,-46.633611
br,sitio das pas,Sítio das Pás,17,,-6.416667,-36.466667
br,sitio das pedras de ouru,Sítio das Pedras de Ouru,27,,-23.003889,-46.746667
br,sitio das pedras,Sítio das Pedras,18,,-23.799178,-50.50713
br,sitio das pedras,Sítio das Pedras,27,,-23.9186,-47.0235
br,sitio das quaresmeiras,Sítio das Quaresmeiras,27,,-23.8818,-46.6894
br,sitio das rosas,Sítio das Rosas,27,,-23.5935,-47.042322
br,sitio das tres meninas,Sítio das Três Meninas,27,,-23.659393,-47.131982
br,sitio das vertentes,Sítio das Vertentes,27,,-23.558245,-47.107009
br,sitio da tia paulota,Sítio da Tia Paulota,27,,-23.8843,-46.6691
br,sitio da torre,Sítio da Torre,27,,-23.255703,-46.575697
br,sitio daulirio domingues,Sítio Daulírio Domingues,18,,-25.976,-48.6954
br,sitio da vendinha,Sítio da Vendinha,27,,-23.656762,-47.429596
br,sitio da vertente,Sítio da Vertente,27,,-23.258274,-46.506349
br,sitio davi a. filho,Sítio Davi A. Filho,18,,-26.15168,-49.568995
br,sitio davi da silveira,Sítio Davi da Silveira,18,,-25.783611,-49.651944
br,sitio david blonkoski,Sítio David Blonkoski,26,,-26.2441,-49.8063
br,sitio david f. de melo,Sítio David F. de Melo,18,,-23.94278,-50.136562
br,sitio davidia m. dos santos,Sítio Davídia M. dos Santos,18,,-23.6508,-49.9173
br,sitio david kogeratski,Sítio David Kogeratski,18,,-25.7114,-49.8381
br,sitio david lazarino,Sítio David Lazarino,18,,-26.049845,-49.73162
br,sitio david marcinovisk,Sítio David Marcinovisk,18,,-23.5474,-49.9645
br,sitio david milchesqui,Sítio David Milchesqui,18,,-26.0236,-49.2743
br,sitio david sampaio,Sítio David Sampaio,18,,-25.912418,-49.980835
br,sitio davi kogeratski,Sítio Davi Kogeratski,18,,-25.7614,-49.6232
br,sitio davi krupa,Sítio Davi Krupa,18,,-25.7691,-49.2331
br,sitio davi mordaski,Sítio Davi Mordaski,18,,-25.771389,-49.636111
br,sitio davina f. dos santos,Sítio Davina F. dos Santos,18,,-26.0096,-49.9231
br,sitio da virginia,Sítio da Virgínia,18,,-23.038624,-52.087628
br,sitio davi rosario,Sítio Davi Rosário,18,,-25.9062,-49.0553
br,sitio davi,Sítio Davi,18,,-25.511,-48.7549
br,sitio da vovo marinhinha,Sítio da Vovo Marinhinha,27,,-23.956547,-47.106152
br,sitio da vovo,Sítio da Vovó,27,,-23.089952,-46.674912
br,sitio debeneti da silva,Sítio Debeneti da Silva,27,,-25.1468,-48.1117
br,sitio de cima,Sítio de Cima,20,,-5.216667,-41.1
br,sitio decio laranja quadros,Sítio Décio Laranja Quadros,18,,-23.37272,-50.217222
br,sitio decolores,Sítio Decolores,27,,-23.879,-46.7085
br,sitio de dentro,Sitio de Dentro,06,,-4.816667,-40.05
br,sitio dejair de lima,Sítio Dejair de Lima,18,,-25.805422,-48.896707
br,sitio delcindo tavares,Sítio Delcindo Tavares,18,,-23.6401,-49.9282
br,sitio delfina r. da silva,Sítio Delfina R. da Silva,18,,-23.6935,-49.8749
br,sitio delfino dalton,Sítio Delfino Dalton,18,,-25.8242,-49.5557
br,sitio delfino d. dos santos,Sítio Delfino D. dos Santos,18,,-25.7798,-49.5656
br,sitio delfino mendes,Sítio Delfino Mendes,18,,-25.9521,-49.3863
br,sitio delta,Sítio Delta,18,,-23.289917,-50.127019
br,sitio demanda,Sítio Demanda,18,,-25.93713,-49.202419
br,sitio demerio nogas,Sítio Demério Nogas,18,,-25.762774,-49.227902
br,sitio demicilio r. rosa,Sítio Demicilio R. Rosa,27,,-24.636065,-48.891444
br,sitio dengo,Sítio Dengo,18,,-23.377969,-50.025455
br,sitio denilson marinho,Sítio Denilson Marinho,18,,-23.991569,-50.146046
br,sitio denis lemes,Sítio Denis Lemes,18,,-23.859,-50.9647
br,sitio de noore,Sítio de Noore,20,,-6.933333,-41.2
br,sitio deocleciano paiva do nascimento,Sítio Deocleciano Paiva do Nascimento,18,,-23.8553,-50.9606
br,sitio de pedro ribeiro,Sítio de Pedro Ribeiro,26,,-26.566608,-49.867957
br,sitio dercy,Sítio Dercy,18,,-23.975144,-50.516642
br,sitio derli buligao,Sítio Derli Buligão,26,,-26.2233,-49.8134
br,sitio descoberto,Sítio Descoberto,18,,-25.918,-48.7024
br,sitio desiderio dalpra,Sítio Desidério Dalprá,18,,-23.969307,-50.162919
br,sitio despique,Sítio Despique,18,,-25.90132,-49.878333
br,sitio deti dadergan,Sítio Deti Dadergan,18,,-23.5328,-49.8723
br,sitio de tomaz mendes faria,Sítio de Tomaz Mendes Faria,26,,-26.5371,-48.729
br,sitio deuclecio de lima,Sítio Deuclécio de Lima,18,,-26.050112,-49.717425
br,sitio deuclides r. ponde,Sítio Deuclides R. Pondé,18,,-23.6164,-49.9387
br,sitio deusdedither t. ribas,Sítio Deusdedither T. Ribas,18,,-26.1411,-49.3853
br,sitio deus-e-pai,Sítio Deus-é-pai,24,,-10.768333,-62.103333
br,sitio deus-me-guia,Sítio Deus-me-Guia,22,,-5.3925,-36.324722
br,sitio deuzito de o. furma,Sítio Deuzito de O. Furma,18,,-25.771812,-49.78302
br,sitio devazilio,Sítio Devazílio,18,,-23.70095,-50.134641
br,sitio diamante,Sítio Diamante,27,,-23.005556,-47.690833
br,sitio diamiro rutheis,Sítio Diamiro Rutheis,18,,-26.094532,-49.713666
br,sitio dico tavico,Sítio Dico Tavico,18,,-23.726679,-50.05618
br,sitio didigio f. de lima,Sítio Didigio F. de Lima,18,,-25.9469,-49.3942
br,sitio dilau c. de melo,Sítio Dilau C. de Melo,18,,-25.9531,-49.904832
br,sitio dilceu goncalves,Sítio Dilceu Gonçalves,27,,-23.5325,-47.6583
br,sitio dilvo trentini,Sítio Dilvo Trentini,18,,-26.169404,-49.544388
br,sitio dimas bartes,Sítio Dimas Bartes,18,,-23.855789,-50.052699
br,sitio dimas,Sítio Dimas,18,,-23.614329,-50.130674
br,sitio dina,Sítio Dina,18,,-23.321358,-50.12849
br,sitio dino roque,Sítio Dino Roque,18,,-23.4262,-49.8569
br,sitio dioge f. de paula,Sítio Dioge F. de Paula,18,,-25.8749,-49.008
br,sitio diogo bichesk,Sítio Diogo Bichesk,26,,-26.0303,-49.9898
br,sitio diogo,Sítio Diogo,27,,-25.066109,-48.549367
br,sitio diolino vieira,Sítio Diolino Vieira,18,,-26.0657,-49.4297
br,sitio dionira franca,Sítio Dionira França,18,,-25.5036,-48.8527
br,sitio dionisio d. de oliveira,Sítio Dionísio D. de Oliveira,18,,-26.134237,-49.725559
br,sitio dionisio derneak,Sítio Dionísio Derneak,18,,-25.8808,-49.5596
br,sitio dionisio figura,Sítio Dionísio Figura,18,,-25.786667,-49.6575
br,sitio dionisio kusma,Sítio Dionísio Kusma,18,,-25.778215,-49.22012
br,sitio dionisio pianoski,Sítio Dionísio Pianoski,18,,-25.925833,-49.531667
br,sitio dionisio sanches,Sítio Dionísio Sanches,18,,-23.2057,-50.126
br,sitio dionisio,Sítio Dionísio,18,,-25.976311,-49.759296
br,sitio dionisio troszanosk,Sítio Dionísio Troszanosk,18,,-25.804,-49.5656
br,sitio dirce marreiro,Sítio Dirce Marreiro,18,,-23.475478,-49.898873
br,sitio dirceu a. de paula,Sítio Dirceu A. de Paula,18,,-25.9487,-49.1373
br,sitio dirceu barbosa,Sítio Dirceu Barbosa,18,,-23.5819,-49.8401
br,sitio dirceu bueno,Sítio Dirceu Bueno,18,,-23.7203,-49.7893
br,sitio dirceu macaneiro,Sítio Dirceu Macaneiro,18,,-25.7621,-49.3714
br,sitio dirceu p. de oliveira,Sítio Dirceu P. de Oliveira,18,,-23.990247,-50.38563
br,sitio dirceu p. luz,Sítio Dirceu P. Luz,18,,-23.851099,-50.657034
br,sitio dirceu r. dos santos,Sítio Dirceu R. dos Santos,18,,-23.929044,-50.488844
br,sitio dirceu r. vega,Sítio Dirceu R. Vega,18,,-25.9337,-49.4557
br,sitio dirceu simione,Sítio Dirceu Simione,18,,-25.217318,-48.869767
br,sitio dirceu soter,Sítio Dirceu Soter,18,,-25.403508,-48.773358
br,sitio dirceu valente,Sítio Dirceu Valente,18,,-25.157667,-48.964955
br,sitio dirce v. reis,Sítio Dirce V. Reis,18,,-23.93422,-50.118152
br,sitio dito m. da silva,Sítio Dito M. da Silva,18,,-23.989566,-50.414205
br,sitio dito rocha,Sítio Dito Rocha,18,,-25.9211,-49.1503
br,sitio dito,Sítio Dito,18,,-23.2307,-50.2241
br,sitio dito venancio,Sítio Dito Venâncio,18,,-23.3341,-49.8827
br,sitio dival lorne,Sítio Dival Lorne,18,,-25.6744,-49.8971
br,sitio divancir a. de oliveira,Sítio Divancir A. de Oliveira,18,,-25.971537,-49.104073
br,sitio divaney m. de campo,Sítio Divaney M. de Campo,18,,-26.1085,-49.7558
br,sitio diva pinto bassani,Sítio Diva Pinto Bassani,18,,-25.816157,-49.909214
br,sitio divino bayle,Sítio Divino Bayle,26,,-26.1602,-49.3291
br,sitio djalma correa,Sítio Djalma Correa,18,,-23.435822,-49.80208
br,sitio djalma de moura,Sítio Djalma de Moura,18,,-23.825609,-50.243522
br,sitio djalma guarda,Sítio Djalma Guarda,18,,-23.766933,-50.777044
br,sitio djalma moreira,Sítio Djalma Moreira,18,,-23.5452,-49.7747
br,sitio djalma s. marques,Sítio Djalma S. Marques,18,,-23.826205,-50.216151
br,sitio djalma u. nogueira,Sítio Djalma U. Nogueira,18,,-23.858624,-50.062431
br,sitio do altao,Sítio do Altão,27,,-23.767897,-47.106562
br,sitio do anciao pai manino,Sítio do Ancião Pai Manino,27,,-23.9158,-47.0842
br,sitio do anil,Sítio do Anil,21,,-22.951364,-43.334986
br,sitio do arara,Sítio do Arara,18,,-23.970818,-50.539454
br,sitio do bairro dos veravas,Sítio do Bairro dos Veravas,27,,-23.793889,-47.118056
br,sitio do bairro lajeadinho,Sítio do Bairro Lajeadinho,27,,-23.6958,-47.18748
br,sitio do bambu,Sítio do Bambu,27,,-23.935747,-46.637804
br,sitio do banco,Sítio do Banco,27,,-23.408515,-46.528523
br,sitio do bau,Sítio do Baú,27,,-23.587275,-47.142515
br,sitio do belisario,Sítio do Belisário,14,,-16.2,-59.65
br,sitio do bosque,Sítio do Bosque,27,,-23.573377,-47.150828
br,sitio do bugre,Sítio do Bugre,27,,-23.702948,-47.050931
br,sitio do camarao,Sítio do Camarão,18,,-25.7997,-48.5546
br,sitio do campo,Sítio do Campo,18,,-25.498083,-48.805397
br,sitio do campo verde,Sítio do Campo Verde,27,,-23.644257,-47.267799
br,sitio do cantinho,Sítio do Cantinho,13,,-3.733333,-43.286389
br,sitio do capitao,Sítio do Capitão,27,,-23.181667,-46.6825
br,sitio do carrapicho,Sítio do Carrapicho,06,,-7.016667,-39.3
br,sitio do castanho,Sítio do Castanho,27,,-23.397999,-46.709998
br,sitio do castelo,Sítio do Castelo,27,,-23.529924,-47.030572
br,sitio do cerne,Sítio do Cerne,18,,-25.281582,-48.98253
br,sitio doce,Sítio Doce,27,,-23.740551,-47.036258
br,sitio doce vale,Sítio Doce Vale,27,,-23.171111,-46.738056
br,sitio do colegio,Sítio do Colégio,27,,-23.709871,-47.308519
br,sitio do condor,Sítio do Condor,18,,-25.8639,-49.3016
br,sitio do coqueiro,Sítio do Coqueiro,27,,-23.73442,-47.164597
br,sitio do cunhado,Sítio do Cunhado,27,,-23.359933,-46.630014
br,sitio do cupim,Sítio do Cupim,27,,-23.701266,-47.242684
br,sitio do curral,Sítio do Curral,27,,-23.645201,-47.203365
br,sitio do desengano,Sítio do Desengano,14,,-13.4,-57.483333
br,sitio do encruzado da amora-preta,Sítio do Encruzado da Amora-Preta,18,,-23.886233,-50.274433
br,sitio do engenho,Sítio do Engenho,27,,-24.694421,-48.164872
br,sitio do fogaca,Sítio do Fogaça,27,,-23.734,-47.9897
br,sitio do frade,Sítio do Frade,06,,-3.65,-39.616667
br,sitio do garcia,Sítio do Garcia,27,,-23.698797,-47.392627
br,sitio do gentil,Sítio do Gentil,27,,-23.558879,-47.052855
br,sitio do gurgel,Sítio do Gurgel,27,,-23.743993,-47.336519
br,sitio do honorato,Sítio do Honorato,25,,-2.616667,-60.766667
br,sitio do igarape,Sítio do Igarapé,27,,-23.9116,-47.0947
br,sitio do ildefonso,Sitio do Ildefonso,14,,-14.716667,-57.65
br,sitio do ipe,Sítio do Ipê,21,,-22.4483,-44.4109
br,sitio do ipe,Sítio do Ipê,27,,-23.68336,-47.265654
br,sitio dois amigos,Sítio Dois Amigos,18,,-23.942856,-50.31908
br,sitio dois cedros,Sítio Dois Cedros,18,,-23.1017,-50.1249
br,sitio dois coqueiros,Sítio Dois Coqueiros,18,,-23.6497,-49.9201
br,sitio dois coqueiros,Sítio Dois Coqueiros,27,,-23.728996,-47.091688
br,sitio dois coracoes,Sítio Dois Corações,18,,-25.8221,-49.1443
br,sitio dois corregos,Sítio Dois Córregos,27,,-23.624411,-47.221333
br,sitio dois irmaos,Sítio Dois Irmãos,04,,-1.475833,-60.273611
br,sitio dois irmaos,Sítio Dois Irmãos,18,,-23.540841,-50.702963
br,sitio dois irmaos,Sítio Dois Irmãos,27,,-23.539264,-47.16045
br,sitio dois lagos,Sítio Dois Lagos,27,,-23.182222,-46.670278
br,sitio dois rh,Sítio Dois RH,18,,-23.779468,-50.197831
br,sitio dois socios,Sítio Dois Sócios,18,,-23.803198,-50.710829
br,sitio dois vizinhos,Sítio Dois Vizinhos,18,,-23.510764,-50.00516
br,sitio do jacare,Sítio do Jacaré,27,,-23.258769,-46.703076
br,sitio do japones,Sítio do Japonês,18,,-23.439717,-50.114691
br,sitio do jarito,Sítio do Jarito,27,,-23.288668,-46.544239
br,sitio dokival c. da costa,Sítio Dokival C. da Costa,18,,-25.907,-49.1069
br,sitio do lago,Sítio do Lago,27,,-23.52605,-47.040755
br,sitio do lajeado,Sítio do Lajeado,27,,-23.633246,-47.015716
br,sitio do laranjal,Sítio do Laranjal,27,,-23.6722,-47.5629
br,sitio do limoeiro,Sítio do Limoeiro,27,,-23.7979,-47.2058
br,sitio do luis,Sítio do Luís,30,,-8.8,-36.233333
br,sitio do machado,Sitio do Machado,25,,1.066667,-60.916667
br,sitio do manoel pereira,Sitio do Manoel Pereira,05,,-11.4,-39.766667
br,sitio do martins,Sítio do Martins,05,,-12.233333,-38.75
br,sitio do massakeo,Sítio do Massakeo,27,,-24.8672,-48.1059
br,sitio do mato,Sítio do Mato,05,,-13.083333,-43.466667
br,sitio do matta,Sitio do Matta,05,,-13.083333,-43.466667
br,sitio do matto,Sitio do Matto,05,,-13.083333,-43.466667
br,sitio dom benta,Sítio Dom Benta,18,,-25.9191,-49.2735
br,sitio dom bosco,Sítio Dom Bosco,27,,-23.195278,-46.572222
br,sitio do meio iii,Sítio do Meio III,13,,-3.125556,-43.320278
br,sitio do meio ii,Sítio do Meio II,13,,-3.445556,-43.051111
br,sitio do meio,Sitio do Meio,05,,-11.95,-38.1
br,sitio do meio,Sítio do Meio,06,,-5.066667,-40.366667
br,sitio do meio,Sítio do Meio,13,,-3.600833,-43.295556
br,sitio do meio,Sítio do Meio,18,,-25.768,-48.5783
br,sitio do meio,Sítio do Meio,20,,-3.592222,-42.008611
br,sitio do meio,Sítio do Meio,22,,-5.33,-37.141944
br,sitio do meio,Sítio do Meio,30,,-8.15,-36.666667
br,sitio do mendes,Sítio do Mendes,18,,-23.592062,-50.737833
br,sitio do menino,Sítio do Menino,27,,-23.8452,-47.0227
br,sitio do mestre,Sítio do Mestre,27,,-23.011944,-46.6575
br,sitio domigos r. da rocha,Sítio Domigos R. da Rocha,18,,-25.563,-48.8398
br,sitio do mineiro,Sítio do Mineiro,18,,-23.986426,-50.536639
br,sitio domingos benedito,Sítio Domingós Benedito,18,,-25.7163,-49.8048
br,sitio domingos borges,Sítio Domingos Borges,18,,-25.804209,-49.754388
br,sitio domingos camargo,Sítio Domingos Camargo,18,,-25.7332,-49.7933
br,sitio domingos de freitas,Sítio Domingos de Freitas,18,,-23.890359,-50.096622
br,sitio domingos de p. ferreira,Sítio Domingos de P. Ferreira,18,,-25.651,-49.9636
br,sitio domingos dos santos,Sítio Domingos dos Santos,18,,-26.046818,-49.71683
br,sitio domingos iza,Sítio Domingos Izá,18,,-23.6402,-49.7774
br,sitio domingos joao poli,Sítio Domingos João Poli,18,,-25.206922,-48.995916
br,sitio domingos lunaro,Sítio Domingos Lunaro,26,,-26.2486,-49.8457
br,sitio domingos modesto,Sítio Domingos Modesto,18,,-25.3853,-48.6355
br,sitio domingos r. de souza,Sítio Domingos R. de Souza,18,,-23.99687,-50.088082
br,sitio domingos siqueira,Sítio Domingos Siqueira,18,,-23.693489,-50.093413
br,sitio domingos ulbrich,Sítio Domingos Ulbrich,26,,-26.0724,-49.9816
br,sitio domingues e. ferreira,Sítio Domingues E. Ferreira,18,,-23.3489,-49.854
br,sitio do moinho pacifico,Sítio do Moinho Pacífico,27,,-23.8517,-46.7356
br,sitio do morrao,Sitio do Morrão,05,,-12.3,-45
br,sitio do morro alto,Sítio do Morro Alto,27,,-23.711836,-47.437471
br,sitio do morro,Sítio do Morro,05,,-12.3,-45
br,sitio dona benta,Sítio Dona Benta,27,,-23.9727,-47.0649
br,sitio dona francisca,Sítio Dona Francisca,26,,-26.2008,-49.2943
br,sitio dona julia,Sítio Dona Júlia,18,,-23.798457,-50.496142
br,sitio dona rocina,Sítio Dona Rocina,18,,-23.908003,-50.186441
br,sitio donato cecilio,Sítio Donato Cecílio,18,,-23.8655,-50.9737
br,sitio donato f. da silva,Sítio Donato F. da Silva,18,,-26.0844,-49.3386
br,sitio dona tuna,Sítio Dona Tuna,18,,-23.764698,-50.039965
br,sitio do nunes,Sitio do Nunes,30,,-8.066667,-37.85
br,sitio do oito,Sítio do Oito,18,,-23.984454,-50.642116
br,sitio do papagaio,Sítio do Papagaio,18,,-23.42996,-50.13034
br,sitio do papai,Sítio do Papai,27,,-23.9181,-47.0429
br,sitio do paschoal,Sitio do Paschoal,14,,-14.766667,-57.433333
br,sitio do passarinho,Sítio do Passarinho,06,,-4.833333,-40.066667
br,sitio do pau torto,Sítio do Pau Torto,27,,-23.8369,-46.6676
br,sitio do pavao,Sítio do Pavão,18,,-25.5644,-49.9457
br,sitio do peri,Sítio do Peri,21,,-22.954913,-43.46223
br,sitio do pica-pau-amarelo,Sítio do Pica-Pau-Amarelo,18,,-25.332074,-48.761028
br,sitio do pica-pau-amarelo,Sítio do Pica-Pau-Amarelo,27,,-23.171389,-46.578889
br,sitio do pica-pau,Sítio do Pica-Pau,18,,-23.823502,-50.200968
br,sitio do pinhal,Sítio do Pinhal,27,,-23.779912,-46.733739
br,sitio do pinheirinho,Sítio do Pinheirinho,27,,-23.7635,-47.1844
br,sitio do pinheiro-bravo,Sítio do Pinheiro-Bravo,27,,-22.703,-45.539
br,sitio do pinho,Sítio do Pinho,27,,-23.7942,-47.0697
br,sitio do pino,Sítio do Pino,25,,2.4,-60.816667
br,sitio do portugues,Sítio do Português,18,,-23.984993,-50.365344
br,sitio do portugues,Sítio do Português,27,,-23.821,-46.6629
br,sitio do quinto,Sítio do Quinto,05,,-10.366667,-38.216667
br,sitio doraci k. da silva,Sítio Doraci K. da Silva,18,,-25.6886,-49.9169
br,sitio do rancho velho,Sítio do Rancho Velho,27,,-23.260461,-46.566548
br,sitio do recreio,Sítio do Recreio,27,,-23.206944,-46.575833
br,sitio dores caparo,Sítio Dores Caparo,18,,-23.0047,-50.0158
br,sitio do rey,Sítio do Rey,27,,-23.185,-46.671667
br,sitio do ribeirao jacuba,Sítio do Ribeirão Jacuba,27,,-23.9685,-47.0282
br,sitio dorica de moura,Sítio Dórica de Moura,18,,-25.8331,-49.449
br,sitio doricezar franco,Sítio Doricezar Franco,18,,-23.601504,-50.225393
br,sitio do rio bonito,Sítio do Rio Bonito,27,,-23.9405,-47.2377
br,sitio do rio claro,Sítio do Rio Claro,18,,-23.090979,-52.094621
br,sitio dorison scheffel,Sítio Dorison Scheffel,18,,-26.0627,-49.7637
br,sitio dorival l. marques,Sítio Dorival L. Marques,18,,-23.7423,-49.7562
br,sitio dorival m. da rocha,Sítio Dorival M. da Rocha,18,,-25.9452,-49.2082
br,sitio dorival pierkocz,Sítio Dorival Pierkocz,18,,-26.1011,-49.4419
br,sitio dorival pries,Sítio Dorival Pries,26,,-26.226744,-49.528751
br,sitio doroteia toffanin,Sítio Dorotéia Toffanin,18,,-26.075385,-49.654886
br,sitio doroti c. de freitas,Sítio Doroti C. de Freitas,18,,-26.0252,-49.9258
br,sitio do ruivo,Sítio do Ruivo,27,,-23.7911,-47.2275
br,sitio dorvalino m. ferreira,Sítio Dorvalino M. Ferreira,18,,-23.768234,-50.071851
br,sitio dorvalino p. de lima,Sítio Dorvalino P. de Lima,18,,-25.984,-49.0566
br,sitio dorvalino rocha,Sítio Dorvalino Rocha,18,,-25.9008,-49.3421
br,sitio do sabiapoca,Sítio do Sabiapoca,27,,-23.0812,-47.9624
br,sitio do saci,Sítio do Saci,27,,-23.153889,-46.555
br,sitio dos agapitos,Sítio dos Agapitos,27,,-23.658654,-47.488192
br,sitio do salario,Sítio do Salário,27,,-23.229167,-46.637222
br,sitio do saltinho,Sítio do Saltinho,27,,-24.615391,-48.010944
br,sitio dos amores,Sítio dos Amores,27,,-23.178333,-46.679444
br,sitio dos bagios,Sítio dos Bagios,18,,-25.179846,-48.924393
br,sitio dos bandeirantes,Sítio dos Bandeirantes,18,,-25.152309,-48.964993
br,sitio dos bem-te-vis,Sítio dos Bem-Te-Vis,27,,-23.722594,-47.140658
br,sitio dos brancos,Sítio dos Brancos,27,,-23.9034,-47.114
br,sitio dos bugres,Sítio dos Bugres,27,,-23.396524,-46.506672
br,sitio dos castores,Sítio dos Castores,27,,-23.9245,-47.0141
br,sitio dos cocais,Sítio dos Cocais,27,,-23.685145,-47.322896
br,sitio dos coqueiros,Sítio dos Coqueiros,27,,-23.198333,-46.6025
br,sitio do sellado,Sitio do Sellado,14,,-15.466667,-57.35
br,sitio dos eucaliptos,Sítio dos Eucaliptos,27,,-23.8903,-46.6877
br,sitio dos frias,Sítio dos Frias,27,,-23.5701,-47.6449
br,sitio dos gambas,Sitio dos Gambás,05,,-11.016667,-42.466667
br,sitio dos grilos,Sítio dos Grilos,27,,-23.7907,-47.0541
br,sitio dos haid,Sítio dos Haid,26,,-26.0994,-49.8893
br,sitio dos hirt,Sítio dos Hirt,18,,-26.0577,-49.7826
br,sitio dos lagos,Sítio dos Lagos,27,,-23.945,-47.0027
br,sitio dos maia,Sítio dos Maia,18,,-23.728421,-50.074613
br,sitio dos marcos,Sítio dos Marcos,27,,-23.7685,-46.5875
br,sitio dos maricas,Sítio dos Maricas,05,,-8.95,-39.85
br,sitio dos meninos,Sítio dos Meninos,27,,-23.1775,-46.668333
br,sitio dos moreiras,Sítio dos Moreiras,30,,-7.616667,-39.55
br,sitio dos nunes,Sítio dos Nunes,30,,-8.066667,-37.85
br,sitio do sol,Sítio do Sol,27,,-23.711541,-47.070107
br,sitio do sonho,Sítio do Sonho,27,,-23.661457,-47.246335
br,sitio dos ortizes,Sítio dos Ortizes,27,,-23.713504,-47.358418
br,sitio dos padres,Sítio dos Padres,06,,-5.683333,-38.016667
br,sitio dos pardais,Sítio dos Pardais,27,,-23.877899,-46.697931
br,sitio dos patos,Sítio dos Patos,06,,-3.566667,-39.616667
br,sitio dos paulistas,Sítio dos Paulistas,18,,-23.832129,-50.484709
br,sitio dos piloes,Sítio dos Pilões,27,,-23.232874,-47.582616
br,sitio dos pinheiros,Sítio dos Pinheiros,27,,-23.200278,-46.578889
br,sitio dos portugueses,Sítio dos Portugueses,27,,-23.8693,-47.0676
br,sitio dos quadros,Sítio dos Quadros,27,,-23.8213,-46.6659
br,sitio dos rauen,Sítio dos Rauen,18,,-26.0643,-49.7936
br,sitio dos rauen,Sítio dos Rauen,26,,-26.0983,-49.8373
br,sitio dos remedios,Sítio dos Remedios,27,,-23.7858,-47.1557
br,sitio dos remedios,Sítio dos Remédios,30,,-8.2,-35.85
br,sitio dos sabias,Sítio dos Sabiás,27,,-23.737486,-47.239017
br,sitio dos seis porquinhos,Sítio dos Seis Porquinhos,27,,-23.9862,-47.0641
br,sitio dos sete,Sítio dos Sete,27,,-23.9374,-47.1673
br,sitio dos toquinhos,Sítio dos Toquinhos,27,,-23.259619,-46.539253
br,sitio dos torres,Sítio dos Torres,27,,-23.686538,-47.385905
br,sitio dos valos,Sítio dos Valos,27,,-23.296265,-46.665943
br,sitio do tamby,Sítio do Tamby,27,,-23.305895,-46.545245
br,sitio do taruma,Sítio do Tarumã,25,,2.716667,-60.683333
br,sitio do teimoso,Sítio do Teimoso,27,,-23.9077,-47.0099
br,sitio do thiaguinho,Sítio do Thiaguinho,18,,-23.441147,-50.126321
br,sitio do tonico,Sitio do Tonico,14,,-15.416667,-57.7
br,sitio do tucum,Sítio do Tucum,21,,-22.4917,-44.4449
br,sitio douradinho,Sítio Douradinho,18,,-23.1187,-50.1478
br,sitio dourado,Sítio Dourado,18,,-23.1229,-50.1487
br,sitio dourinho,Sítio Dourinho,27,,-23.503112,-47.066903
br,sitio do urtigao,Sítio do Urtigão,27,,-23.949,-47.0018
br,sitio doutor ari,Sítio Doutor Ari,18,,-25.200405,-48.892418
br,sitio doutor coshi,Sítio Doutor Coshi,18,,-23.590268,-50.679479
br,sitio doutor neros,Sítio Doutor Neros,18,,-25.19714,-48.916373
br,sitio doutor sergio,Sítio Doutor Sérgio,18,,-23.915395,-50.25029
br,sitio dova apolinario,Sítio Dová Apolinário,18,,-23.6366,-49.917
br,sitio do vale,Sítio do Vale,27,,-23.527621,-47.208295
br,sitio do vava,Sítio do Vavá,18,,-23.658449,-50.224524
br,sitio do volo,Sítio do Volo,27,,-23.9858,-47.0315
br,sitio duarte,Sítio Duarte,18,,-23.632025,-50.734755
br,sitio duas irmas,Sítio Duas Irmãs,27,,-23.233611,-46.598611
br,sitio duas meninas,Sítio Duas Meninas,18,,-23.351979,-50.044202
br,sitio duas nascentes,Sítio Duas Nascentes,27,,-23.737532,-47.060978
br,sitio duas voltinhas,Sítio Duas Voltinhas,27,,-23.9502,-47.1561
br,sitio durans,Sítio Durans,18,,-23.521,-50.5404
br,sitio duro,Sítio Duro,27,,-23.54984,-47.146368
br,sitio durvalino correia,Sítio Durvalino Correia,18,,-25.917247,-49.654456
br,sitio durvalino,Sítio Durvalino,27,,-24.603458,-48.112861
br,sitio duvida,Sítio Dúvida,27,,-23.9129,-46.6564
br,sitio ebenezia,Sítio Ebenézia,18,,-25.451948,-48.816865
br,sitio edavino santos,Sítio Edavino Santos,18,,-26.070902,-49.5697
br,sitio edesio j. de oliveira,Sítio Edésio J. de Oliveira,18,,-23.6945,-49.9658
br,sitio edgar f. dos santos,Sítio Edgar F. dos Santos,18,,-25.9513,-49.2333
br,sitio edgar sommer,Sítio Edgar Sommer,26,,-26.149,-49.8157
br,sitio edgar wvil,Sítio Edgar Wvil,18,,-25.781751,-49.751267
br,sitio edilson j. pinto,Sítio Edilson J. Pinto,18,,-25.5231,-48.8874
br,sitio edinho lopes,Sítio Edinho Lopes,18,,-23.5343,-49.9743
br,sitio edino biaobosch,Sítio Edino Biaobosch,26,,-26.1661,-49.3367
br,sitio edir reisr,Sítio Edir Reisr,26,,-26.2096,-49.7856
br,sitio edith bruno,Sítio Edith Bruno,26,,-25.9957,-48.7248
br,sitio edith valoski,Sítio Edith Valoski,18,,-25.92009,-49.121601
br,sitio edmar everses,Sítio Edmar Everses,26,,-26.2214,-49.9461
br,sitio edmilson c. bueno,Sítio Edmilson C. Bueno,18,,-25.9921,-49.1804
br,sitio edson b. barbosa,Sítio Edson B. Barbosa,18,,-25.823056,-49.6225
br,sitio edson faroto,Sítio Edson Faroto,18,,-23.747323,-50.200019
br,sitio edson goncalves,Sítio Edson Gonçalves,18,,-23.2358,-50.1495
br,sitio edson jose,Sítio Edson José,18,,-25.818056,-49.626111
br,sitio edson l. schultz,Sítio Edson L. Schultz,26,,-26.1159,-49.831
br,sitio edson,Sítio Edson,18,,-23.805755,-50.086338
br,sitio edson v. mattge,Sítio Edson V. Mattge,18,,-25.989722,-49.673056
br,sitio eduardo a. dos anjos,Sítio Eduardo A. dos Anjos,18,,-25.8344,-49.4407
br,sitio eduardo agostinho,Sítio Eduardo Agostinho,26,,-26.1823,-49.8235
br,sitio eduardo andrade de lima,Sítio Eduardo Andrade de Lima,18,,-25.905876,-49.900086
br,sitio eduardo badareque,Sítio Eduardo Badareque,18,,-23.5372,-49.8661
br,sitio eduardo belgamann,Sítio Eduardo Belgamann,18,,-25.9042,-49.101
br,sitio eduardo carmceiro,Sítio Eduardo Carmceiro,18,,-23.749627,-50.222508
br,sitio eduardo c. pandolfo,Sítio Eduardo C. Pandolfo,18,,-25.9341,-49.1955
br,sitio eduardo dos s. mendes,Sítio Eduardo dos S. Mendes,18,,-25.7893,-49.4669
br,sitio eduardo ferreira,Sítio Eduardo Ferreira,18,,-25.77004,-48.991896
br,sitio eduardo f. rocha,Sítio Eduardo F. Rocha,18,,-25.310489,-48.935916
br,sitio eduardo gama,Sítio Eduardo Gama,18,,-23.5011,-49.8394
br,sitio eduardo h. de lima,Sítio Eduardo H. de Lima,18,,-26.049,-49.4055
br,sitio eduardo jaros,Sítio Eduardo Jaros,18,,-26.02069,-49.720529
br,sitio eduardo luiz teixeira,Sítio Eduardo Luiz Teixeira,18,,-23.258927,-50.181837
br,sitio eduardo marzur,Sítio Eduardo Marzur,18,,-26.0234,-49.8235
br,sitio eduardo neto,Sítio Eduardo Neto,18,,-26.088471,-49.664923
br,sitio eduardo rotes,Sítio Eduardo Rotes,18,,-25.7889,-49.4465
br,sitio eduardo sampaio,Sítio Eduardo Sampaio,26,,-26.1737,-49.8874
br,sitio eduardo silveira,Sítio Eduardo Silveira,18,,-25.764444,-49.650278
br,sitio eduardo,Sítio Eduardo,18,,-25.5717,-48.8057
br,sitio eduardo trianovski,Sítio Eduardo Trianovski,18,,-25.769497,-49.533458
br,sitio edviges,Sítio Edviges,18,,-23.6058,-50.5106
br,sitio edvino hable,Sítio Edvino Hable,26,,-26.137,-49.8907
br,sitio egidio escorceles,Sítio Egídio Escorceles,18,,-25.8882,-48.7257
br,sitio eladio martins,Sítio Eládio Martins,26,,-26.207538,-49.812269
br,sitio elcio ximenes,Sítio Élcio Ximenes,18,,-23.269763,-50.066847
br,sitio eldorado,Sítio Eldorado,04,,-1.522778,-60.248333
br,sitio eldorado,Sítio Eldorado,18,,-23.415156,-50.158598
br,sitio eleoterio f. andrade,Sítio Eleotério F. Andrade,18,,-25.8521,-49.4907
br,sitio eleoterio rompava,Sítio Eleotério Rompava,18,,-25.8768,-49.4298
br,sitio elias carvalho,Sítio Elias Carvalho,26,,-26.2349,-49.9298
br,sitio elias jorge bikis,Sítio Elias Jorge Bikis,18,,-23.1559,-50.2109
br,sitio elias leite,Sítio Elias Leite,18,,-25.4512,-48.744
br,sitio elias marins,Sítio Elias Marins,18,,-25.5086,-48.754
br,sitio elias p. de moura,Sítio Elias P. de Moura,27,,-24.8049,-48.2638
br,sitio elias rodrigues,Sítio Elias Rodrigues,18,,-23.906929,-50.324591
br,sitio elias siqueira,Sítio Elias Siqueira,18,,-23.376881,-50.164856
br,sitio elias,Sítio Elias,21,,-22.3095,-44.4319
br,sitio elias viscala,Sítio Elias Viscala,18,,-23.496512,-49.968025
br,sitio elidio padilha,Sítio Elídio Padilha,18,,-23.470661,-50.234543
br,sitio eliete,Sítio Eliete,18,,-23.88115,-50.148282
br,sitio eli florentino,Sítio Eli Florentino,18,,-25.236897,-48.540105
br,sitio eliseu p. da silva,Sítio Eliseu P. da Silva,18,,-23.7018,-49.8887
br,sitio eliseu,Sítio Eliseu,18,,-25.5161,-48.8642
br,sitio eliza,Sítio Eliza,18,,-23.409766,-49.835178
br,sitio elizeu scholoschechk,Sítio Elizeu Scholoschechk,26,,-26.1891,-49.7628
br,sitio elizio j. viana,Sítio Elizio J. Viana,18,,-25.7958,-48.5384
br,sitio elmiro antonio,Sítio Elmiro Antônio,26,,-26.2248,-49.7827
br,sitio elmoth grelpl,Sítio Elmoth Grelpl,26,,-26.1495,-49.3221
br,sitio eloi bajo,Sítio Elói Bajo,18,,-26.0247,-49.7607
br,sitio eloi bodanesi,Sítio Elói Bodanesi,18,,-26.031642,-49.602707
br,sitio eloi bueno,Sítio Elói Bueno,18,,-25.9386,-49.1568
br,sitio eloi de p. ferreira,Sítio Elói de P. Ferreira,18,,-25.902,-49.0473
br,sitio eloi dos anjos,Sítio Elói dos Anjos,18,,-25.7946,-49.1972
br,sitio eloi goncalves,Sítio Elói Gonçalves,18,,-25.8894,-49.5322
br,sitio eloina dos s. silva,Sítio Eloína dos S. Silva,18,,-25.7403,-49.804
br,sitio eloi shindar,Sítio Elói Shindar,18,,-25.850039,-49.799137
br,sitio eloriano dranka,Sítio Eloriano Dranka,18,,-25.771,-49.4397
br,sitio eloy kirubim,Sítio Eloy Kirubim,18,,-25.6641,-49.9742
br,sitio elpidio ferraz,Sítio Elpídio Ferraz,18,,-23.6616,-49.8146
br,sitio elpidio marce,Sítio Elpídio Marcé,18,,-23.6244,-49.819
br,sitio elso benedito batista,Sítio Elso Benedito Batista,18,,-23.98359,-50.505877
br,sitio elson,Sítio Elson,27,,-24.8304,-48.1742
br,sitio eluira ribas,Sítio Eluíra Ribas,18,,-26.00065,-49.503677
br,sitio elvira messias,Sítio Elvira Messias,18,,-25.876689,-49.239218
br,sitio elvira pazinatto,Sítio Elvira Pazinatto,18,,-25.5306,-48.8982
br,sitio elza hirt,Sítio Elza Hirt,18,,-26.115951,-49.749803
br,sitio emidio bueno,Sítio Emídio Bueno,18,,-25.921111,-49.511389
br,sitio emilia c. pimentel,Sítio Emília C. Pimentel,18,,-25.901771,-49.794802
br,sitio emilio c. de freitas,Sítio Emílio C. de Freitas,18,,-26.0515,-49.7706
br,sitio emilio justo,Sítio Emílio Justo,18,,-25.8343,-48.5621
br,sitio emilio marzur,Sítio Emílio Marzur,18,,-26.0235,-49.8202
br,sitio emilio schuait,Sítio Emílio Schuait,26,,-26.236141,-49.619825
br,sitio emilio travizan,Sítio Emílio Travizan,18,,-23.489299,-49.988772
br,sitio emilio vertoam,Sítio Emílio Vertoam,18,,-23.402564,-50.167547
br,sitio empanturrado,Sítio Empanturrado,18,,-25.8917,-48.6799
br,sitio encantadas,Sítio Encantadas,18,,-25.4777,-48.6901
br,sitio encantado,Sítio Encantado,27,,-23.8433,-47.0581
br,sitio enedino rodrigues,Sítio Enedino Rodrigues,26,,-26.2465,-49.8421
br,sitio enedir ferreira,Sítio Enedir Ferreira,26,,-26.1968,-49.7978
br,sitio enelio paniche,Sítio Enélio Paniche,18,,-23.494926,-49.839108
br,sitio engelbert ranck,Sítio Engelbert Ranck,26,,-26.1714,-49.8087
br,sitio engenho,Sítio Engenho,27,,-24.525297,-48.068183
br,sitio enio carneiro,Sítio Enio Carneiro,18,,-23.991359,-50.122948
br,sitio enio rezler,Sítio Ênio Rezler,18,,-26.174567,-49.557114
br,sitio enot godoy,Sítio Enot Godoy,18,,-23.695921,-50.548101
br,sitio enrich grams,Sítio Enrich Grams,26,,-26.1238,-49.898
br,sitio entrada do pocinho,Sítio Entrada do Pocinho,18,,-23.589433,-50.737344
br,sitio entre rios,Sítio Entre Rios,18,,-25.411995,-48.877143
br,sitio entre rios,Sítio Entre Rios,27,,-23.0166,-47.8174
br,sitio enxadao,Sítio Enxadão,27,,-23.880434,-47.00511
br,sitio eraldo ferreira,Sítio Eraldo Ferreira,26,,-26.1926,-49.7998
br,sitio ercilia f. cruz,Sítio Ercília F. Cruz,18,,-25.8694,-49.3094
br,sitio eric genochio,Sítio Eric Genochio,18,,-25.751667,-49.685
br,sitio erico echstein,Sítio Érico Echstein,26,,-26.207696,-49.466002
br,sitio erico grosshopf,Sítio Érico Grosshopf,18,,-26.1026,-49.4837
br,sitio erico gruber,Sítio Érico Gruber,26,,-26.1887,-49.4042
br,sitio erico muller,Sítio Érico Müller,26,,-26.2379,-49.7544
br,sitio erico pscheidt,Sítio Erico Pscheidt,26,,-26.198,-49.7642
br,sitio erico,Sítio Érico,26,,-26.2266,-49.3001
br,sitio ermelindo moreira,Sítio Ermelindo Moreira,18,,-23.419443,-50.027798
br,sitio ermelino de souza,Sítio Ermelino de Souza,18,,-23.918347,-50.39897
br,sitio ernani antonio,Sítio Ernâni Antônio,26,,-26.1795,-49.9567
br,sitio ernestino pereira,Sítio Ernestino Pereira,26,,-26.24018,-49.694435
br,sitio ernestino v. de souza,Sítio Ernestino V. de Souza,26,,-26.1441,-49.2992
br,sitio ernesto a. ferreira,Sítio Ernesto A. Ferreira,18,,-25.9252,-49.383
br,sitio ernesto das n. barbosa,Sítio Ernesto das N. Barbosa,18,,-23.6966,-49.8532
br,sitio ernesto dias,Sítio Ernesto Dias,18,,-23.588558,-50.68215
br,sitio ernesto hayse,Sítio Ernesto Hayse,26,,-26.2265,-49.8945
br,sitio ernesto madeira,Sítio Ernesto Madeira,27,,-23.043157,-49.850836
br,sitio ernesto novastski,Sítio Ernesto Novastski,18,,-25.7861,-49.2427
br,sitio ernesto roco,Sítio Ernesto Roco,27,,-23.099167,-47.544722
br,sitio ernesto rooder,Sítio Ernesto Rooder,26,,-25.9839,-48.8822
br,sitio ernesto schuwz,Sítio Ernesto Schuwz,26,,-26.228666,-49.615414
br,sitio ernesto silva,Sítio Ernesto Silva,26,,-26.1848,-49.9584
br,sitio ernesto zanova,Sítio Ernesto Zanova,18,,-25.217749,-48.899831
br,sitio eroaldo kosak,Sítio Eroaldo Kosak,26,,-26.235528,-49.734515
br,sitio erondina goncalves,Sítio Erondina Gonçalves,18,,-23.775962,-50.188265
br,sitio ervino antonio,Sítio Ervino Antônio,18,,-26.1311,-49.4563
br,sitio ervino buba,Sítio Ervino Buba,18,,-26.0742,-49.348
br,sitio ervino c. guinte,Sítio Ervino C. Guinte,18,,-25.9883,-49.36
br,sitio ervino dos santos,Sítio Ervino dos Santos,26,,-26.2114,-49.9477
br,sitio ervino grans,Sítio Ervino Grans,18,,-25.910551,-48.916357
br,sitio ervino grosskopf,Sítio Ervino Grosskopf,18,,-26.179,-49.4929
br,sitio ervino kraschinski,Sítio Ervino Kraschinski,26,,-26.1343,-49.9364
br,sitio ervino luckow,Sítio Ervino Luckow,26,,-26.1124,-49.8508
br,sitio ervino schireda,Sítio Ervino Schireda,18,,-26.124635,-49.54308
br,sitio ervino,Sítio Ervino,18,,-25.813,-49.1426
br,sitio ervino zimer,Sítio Ervino Zimer,18,,-26.11845,-49.54248
br,sitio erwin schmidt,Sítio Erwin Schmidt,18,,-25.918817,-48.916336
br,sitio escondido,Sítio Escondido,27,,-23.857,-47.0167
br,sitio esidio b. do valle,Sítio Esídio B. do Valle,18,,-25.7985,-49.5996
br,sitio esio barbosa,Sítio Ésio Barbosa,18,,-25.219587,-48.454927
br,sitio esmeralda,Sítio Esmeralda,18,,-23.0688,-50.025
br,sitio esmeralda,Sítio Esmeralda,27,,-23.176111,-46.740278
br,sitio esmeraldina de oliveira,Sítio Esmeraldina de Oliveira,18,,-23.785588,-50.172515
br,sitio esperanca,Sítio Esperança,18,,-23.876946,-50.266853
br,sitio esperanca,Sítio Esperança,27,,-22.946563,-45.100642
br,sitio espigao bonito,Sítio Espigão Bonito,18,,-23.809838,-50.503894
br,sitio espigao branco,Sítio Espigão Branco,18,,-25.7158,-49.9767
br,sitio espigao do bugre,Sítio Espigão do Bugre,26,,-26.2338,-49.7903
br,sitio espigao do falcao,Sítio Espigão do Falcão,18,,-23.976566,-50.395467
br,sitio espigao,Sítio Espigão,27,,-23.624699,-47.11149
br,sitio espigaozinho,Sítio Espigãozinho,18,,-25.7457,-49.8896
br,sitio espina,Sítio Espina,27,,-23.215,-46.5875
br,sitio espirito santo,Sítio Espirito Santo,27,,-23.8075,-47.1959
br,sitio estancia triangulo,Sítio Estância Triângulo,27,,-23.7793,-47.2205
br,sitio estanislau baida,Sítio Estanislau Baida,18,,-25.7233,-49.8596
br,sitio estanislau drusz,Sítio Estanislau Drusz,18,,-25.8275,-49.5797
br,sitio estanislau hitner,Sítio Estanislau Hitner,18,,-26.082912,-49.742699
br,sitio estanislau mordask,Sítio Estanislau Mordask,18,,-25.6873,-49.897
br,sitio estefanio kutoscha,Sítio Estefânio Kutoscha,26,,-26.2158,-49.8371
br,sitio estefanio pedro ciben,Sítio Estefânio Pedro Ciben,18,,-25.7205,-49.7882
br,sitio estefanio,Sítio Estefânio,18,,-25.8933,-49.3197
br,sitio estefano hoinaski,Sítio Estefano Hoinaski,18,,-25.5171,-49.9958
br,sitio estefano nogas,Sítio Estéfano Nogas,18,,-25.7537,-49.2321
br,sitio estevao,Sítio Estêvão,18,,-23.9393,-50.4175
br,sitio estevao,Sítio Estevao,22,,-5.4125,-36.865278
br,sitio esteves cava,Sítio Esteves Cava,18,,-23.917671,-50.553853
br,sitio estori palma,Sítio Estori Palma,27,,-23.279498,-46.677872
br,sitio estrela-da alva,Sítio Estrela-da Alva,18,,-25.929288,-49.133018
br,sitio estrela dalva,Sítio Estrela Dalva,27,,-23.883587,-46.732585
br,sitio estrela da manha,Sítio Estrêla da Manhã,27,,-23.8247,-46.6036
br,sitio estrela-de alva,Sítio Estrela-de Alva,27,,-24.9675,-48.4708
br,sitio estrela de belem,Sítio Estréla de Belém,18,,-24.745111,-48.50183
br,sitio estrela,Sítio Estrela,04,,-1.863333,-60.085
br,sitio estrela,Sítio Estrêla,18,,-23.6622,-49.8323
br,sitio estrela,Sítio Estrela,27,,-23.098056,-47.661667
br,sitio esuardo sueng,Sítio Esuardo Sueng,18,,-25.7844,-49.5117
br,sitio etelvina maciel,Sítio Etelvina Maciel,18,,-26.0054,-49.9442
br,sitio eucalipto,Sítio Eucalipto,18,,-23.0242,-50.1381
br,sitio euclides g. da silva,Sítio Euclides G. da Silva,18,,-25.910278,-49.6625
br,sitio euclides grochika,Sítio Euclides Grochika,18,,-25.774278,-48.994761
br,sitio euclides l. filho,Sítio Euclides L. Filho,18,,-25.542,-48.7597
br,sitio euclides r. purga,Sítio Euclides R. Purga,18,,-23.828835,-50.058104
br,sitio euflavio bill,Sítio Euflávio Bill,18,,-25.945751,-49.98573
br,sitio eufrasia de andrade,Sítio Eufrásia de Andrade,18,,-26.0335,-49.8454
br,sitio eufrido fabrasil,Sítio Eufrido Fabrasil,18,,-25.985278,-49.725
br,sitio eugenio bassane,Sítio Eugênio Bassane,18,,-23.6735,-49.7672
br,sitio eugenio caetano,Sítio Eugênio Caetano,18,,-23.6478,-49.7715
br,sitio eugenio carvalho,Sítio Eugênio Carvalho,18,,-25.8232,-49.3127
br,sitio eugenio correia,Sítio Eugênio Correia,18,,-26.0471,-49.8273
br,sitio eugenio costa,Sítio Eugênio Costa,18,,-25.812911,-48.891959
br,sitio eugenio heidegger,Sítio Eugênio Heidegger,18,,-23.876351,-50.313662
br,sitio eugenio menucci,Sítio Eugênio Menucci,18,,-25.9707,-48.8938
br,sitio eugenio obzt,Sítio Eugênio Obzt,18,,-25.9101,-49.4593
br,sitio eugenio porret,Sítio Eugênio Porret,18,,-23.19643,-49.94055
br,sitio eugenio scraba,Sítio Eugênio Scraba,18,,-25.823,-49.4799
br,sitio eugenir ferreira,Sítio Eugenir Ferreira,18,,-25.096137,-48.804878
br,sitio eulampio pereira,Sítio Eulâmpio Pereira,26,,-26.1749,-49.9191
br,sitio eurica hirt,Sítio Eurica Hirt,18,,-26.081558,-49.664214
br,sitio eurico strober,Sítio Eurico Strober,26,,-26.235,-49.8397
br,sitio eurico ziclinski,Sítio Eurico Ziclinski,26,,-26.1743,-49.8613
br,sitio eurides batista,Sítio Eurides Batista,18,,-25.7243,-49.9903
br,sitio eurides c. de oliveira,Sítio Eurides C. de Oliveira,18,,-23.90331,-50.223191
br,sitio eurides h. dos santos,Sítio Eurides H. dos Santos,18,,-26.0439,-49.406
br,sitio eurides miani,Sítio Eurides Miani,18,,-23.6935,-49.8091
br,sitio eurides peichisis,Sítio Eurides Peichisis,26,,-26.0972,-49.9571
br,sitio eurides silva,Sítio Eurides Silva,18,,-26.009,-49.8964
br,sitio eurides tavares bandeira,Sítio Eurides Tavares Bandeira,18,,-25.157359,-48.860117
br,sitio euripedes galdencio,Sítio Eurípedes Galdêncio,18,,-23.3487,-49.9227
br,sitio eusebio da rosa,Sítio Eusébio da Rosa,27,,-23.7233,-47.6196
br,sitio eusebio padilha,Sítio Eusébio Padilha,18,,-25.917426,-49.953017
br,sitio eusebio vieira,Sítio Eusébio Vieira,18,,-25.919167,-49.731111
br,sitio euvino estrobel,Sítio Euvino Estrobel,26,,-26.2094,-49.8365
br,sitio euvira linhares,Sítio Euvira Linhares,18,,-25.8375,-49.730556
br,sitio euzebio ferreira da costa,Sítio Euzébio Ferreira da Costa,18,,-23.762246,-50.61175
br,sitio euzio b. da rocha,Sítio Euzio B. da Rocha,18,,-25.899444,-49.557222
br,sitio evaldo batista,Sítio Evaldo Batista,18,,-26.046575,-49.749641
br,sitio evaldo beker,Sítio Evaldo Beker,26,,-26.1337,-49.9204
br,sitio evaldo dums,Sítio Evaldo Dums,26,,-26.18,-49.4499
br,sitio evaldo konkl,Sítio Evaldo Konkl,26,,-26.1272,-49.9331
br,sitio evaldo lang,Sítio Evaldo Lang,26,,-26.1892,-49.8312
br,sitio evaldo lukow,Sítio Evaldo Lukow,26,,-26.1117,-49.8603
br,sitio evaldo medisck,Sítio Evaldo Medisck,18,,-25.824167,-49.721667
br,sitio evaldo m. filho,Sítio Evaldo M. Filho,26,,-26.2304,-49.7513
br,sitio evaldo nepol,Sítio Evaldo Nepol,26,,-26.2303,-49.4801
br,sitio evaldo schelbauer,Sítio Evaldo Schelbauer,26,,-26.1518,-49.9308
br,sitio evaldo seidel,Sítio Evaldo Seidel,18,,-26.0827,-49.4189
br,sitio evaldo strubr,Sítio Evaldo Strubr,26,,-26.2371,-49.8472
br,sitio evaldo wotroba,Sítio Evaldo Wotroba,26,,-26.1954,-49.4703
br,sitio evandro cavalheiro,Sítio Evandro Cavalheiro,18,,-26.0347,-49.4634
br,sitio evangelico,Sítio Evangélico,18,,-23.583016,-50.74309
br,sitio evanildo deretti,Sítio Evanildo Deretti,18,,-26.157995,-49.532427
br,sitio evaristo ossovski,Sítio Evaristo Ossovski,18,,-25.9719,-49.4405
br,sitio evaristo,Sítio Evaristo,27,,-23.185833,-47.606389
br,sitio everaldo,Sítio Everaldo,18,,-25.878514,-49.226097
br,sitio expedito amancio,Sítio Expedito Amâncio,18,,-23.743964,-50.212008
br,sitio expedito da silva,Sítio Expedito da Silva,18,,-23.5721,-49.8479
br,sitio expedito laurindo da silva,Sítio Expedito Laurindo da Silva,18,,-23.713306,-50.057054
br,sitio ezeguias,Sítio Ezeguias,27,,-24.776,-48.2063
br,sitio ezequiel,Sítio Ezequiel,18,,-23.53204,-50.699479
br,sitio ezequiel v. stoeberl,Sítio Ezequiel V. Stoeberl,18,,-26.165051,-49.476967
br,sitio fabiano schapicski,Sítio Fabiano Schapicski,26,,-26.121,-49.2853
br,sitio fabio da s. santos,Sítio Fábio da S. Santos,18,,-25.410814,-48.826246
br,sitio fabio simplicio,Sítio Fábio Simplício,18,,-23.1975,-50.0766
br,sitio fagundes,Sítio Fagundes,18,,-23.599491,-50.520392
br,sitio faisqueirinha,Sítio Faisqueirinha,18,,-25.407987,-48.77471
br,sitio fanamar,Sítio Fanamar,27,,-23.9535,-47.0866
br,sitio faria,Sítio Faria,18,,-23.895595,-50.448963
br,sitio farinha,Sítio Farinha,17,,-7.15,-36.116667
br,sitio farraz,Sítio Farraz,27,,-24.9696,-48.3618
br,sitio fartura,Sítio Fartura,18,,-25.5188,-48.8868
br,sitio faustino de souza,Sítio Faustino de Souza,18,,-23.1117,-50.1587
br,sitio fausto b. pinto,Sítio Fausto B. Pinto,18,,-23.473582,-49.909586
br,sitio faxinal dos correas,Sítio Faxinal dos Corrêas,18,,-25.7088,-49.8991
br,sitio faxinal dos pintos,Sítio Faxinal dos Pintos,18,,-25.738,-49.8449
br,sitio faxinal,Sítio Faxinal,26,,-26.1883,-49.2771
br,sitio faxina,Sítio Faxina,18,,-25.7746,-49.1728
br,sitio fazendinha,Sítio Fazendinha,18,,-23.126,-50.1903
br,sitio feital,Sítio Feital,27,,-24.8631,-48.2115
br,sitio feliciano m. bandeira,Sítio Feliciano M. Bandeira,18,,-25.160867,-48.940531
br,sitio felipe deda,Sítio Felipe Deda,18,,-25.946458,-49.980626
br,sitio felipe galdencio,Sítio Felipe Galdêncio,18,,-23.319061,-49.89153
br,sitio felipe kmiecik,Sítio Felipe Kmiecik,26,,-26.0793,-49.259
br,sitio felipe soczek,Sítio Felipe Soczek,18,,-25.7827,-49.5848
br,sitio felix boron,Sítio Fèlix Boron,18,,-25.8841,-49.4538
br,sitio felix caja,Sítio Félix Caja,18,,-25.7694,-49.6192
br,sitio felix dudek,Sítio Fèlix Dudek,18,,-25.821312,-49.483346
br,sitio felix durau,Sítio Fèlix Durau,18,,-25.7951,-49.417
br,sitio felix jaros,Sítio Félix Jaros,18,,-26.017,-49.7565
br,sitio felix kowalski,Sítio Félix Kowalski,18,,-23.773339,-50.120939
br,sitio felix krupa,Sítio Félix Krupa,18,,-25.539,-48.8027
br,sitio felix kulevisck,Sítio Félix Kulevisck,18,,-25.7523,-49.5259
br,sitio felix mika,Sítio Félix Mika,18,,-25.8048,-49.4537
br,sitio felix oroscki,Sítio Félix Oroscki,26,,-26.1764,-49.8849
br,sitio felix ruvinski,Sítio Félix Ruvinski,18,,-25.8122,-49.537
br,sitio felix,Sítio Félix,18,,-23.0146,-50.1694
br,sitio felix worgia,Sítio Félix Worgia,18,,-26.021375,-49.602328
br,sitio felix zenato,Sítio Félix Zenato,18,,-25.9284,-49.3903
br,sitio feliz augustim,Sítio Feliz Augustim,18,,-25.9529,-49.2022
br,sitio ferminio de souza,Sítio Ferminio de Souza,26,,-26.2414,-49.834
br,sitio fermino dos santos,Sítio Fermino dos Santos,18,,-26.068,-49.8319
br,sitio fernandes lobo,Sítio Fernandes Lobo,18,,-23.773028,-50.075329
br,sitio fernandes,Sítio Fernandes,18,,-23.466897,-49.770423
br,sitio fernandes,Sítio Fernandes,27,,-23.552009,-47.570441
br,sitio fernando borges,Sítio Fernando Borges,18,,-25.07708,-48.976924
br,sitio fernando brochado,Sítio Fernando Brochado,18,,-23.172055,-49.954195
br,sitio fernando de moura,Sítio Fernando de Moura,18,,-25.8367,-49.4159
br,sitio fernando firmino,Sítio Fernando Firmino,18,,-23.811864,-50.050318
br,sitio fernando justino santana,Sítio Fernando Justino Santana,18,,-23.890639,-50.976343
br,sitio fernando larini,Sítio Fernando Larini,18,,-23.640334,-50.73371
br,sitio fernando laurindo,Sítio Fernando Laurindo,18,,-23.55059,-50.713537
br,sitio fernando marinho,Sítio Fernando Marinho,18,,-26.0853,-49.7534
br,sitio fernando radtke,Sítio Fernando Radtke,18,,-25.5975,-48.8168
br,sitio ferplast,Sítio Ferplast,27,,-23.550711,-47.224432
br,sitio ferradura,Sítio Ferradura,27,,-23.152798,-46.566396
br,sitio ferreira gomes,Sítio Ferreira Gomes,18,,-23.555,-49.7842
br,sitio ferreira,Sítio Ferreira,18,,-23.363052,-49.990839
br,sitio ferreira,Sítio Ferreira,27,,-23.695922,-47.131566
br,sitio figueira branca,Sítio Figueira Branca,18,,-23.927288,-50.508415
br,sitio figueira-branca,Sítio Figueira-Branca,27,,-23.213333,-46.728333
br,sitio figueira do rio branco,Sítio Figueira do Rio Branco,27,,-24.9153,-48.0222
br,sitio figueira grande,Sítio Figueira Grande,18,,-23.5793,-49.934
br,sitio figueira,Sítio Figueira,18,,-23.331097,-50.231671
br,sitio figueira,Sítio Figueira,27,,-23.179175,-46.743055
br,sitio filomena kuzeratsk,Sítio Filomena Kuzeratsk,18,,-25.918889,-49.565833
br,sitio filomena,Sítio Filomena,27,,-24.5736,-48.272
br,sitio filomena venancio,Sítio Filomena Venâncio,18,,-25.84062,-49.792281
br,sitio fim da picada,Sítio Fim da Picada,27,,-23.395765,-46.614294
br,sitio fioravante,Sítio Fioravante,18,,-23.225,-50.2348
br,sitio fioresta,Sítio Fioresta,27,,-23.79627,-46.715149
br,sitio firmino cardoso,Sítio Firmino Cardoso,18,,-25.900738,-49.094393
br,sitio flavia borges,Sítio Flávia Borges,18,,-23.82173,-50.146997
br,sitio flavio betine,Sítio Flávio Betine,18,,-23.0022,-50.02
br,sitio flavio da cruz,Sítio Flávio da Cruz,18,,-25.9031,-49.1205
br,sitio flavio l. dos santos,Sítio Flávio L. dos Santos,18,,-25.9371,-49.1453
br,sitio flavio p. de melo,Sítio Flávio P. de Melo,18,,-25.8844,-49.0682
br,sitio flavio ribeiro,Sítio Flavio Ribeiro,18,,-25.9786,-49.2867
br,sitio flavio t. rocha,Sítio Flávio T. Rocha,18,,-25.9654,-49.47
br,sitio flora lia,Sítio Flora Lia,18,,-23.976842,-50.14654
br,sitio flor da mata,Sítio Flor da Mata,27,,-23.9405,-47.1262
br,sitio flor-da serra,Sítio Flor-da Serra,18,,-25.447302,-48.811528
br,sitio flor do sertao,Sítio Flor do Sertão,18,,-23.7528,-50.978
br,sitio florentina berniak,Sítio Florentina Berniak,18,,-25.8383,-49.5447
br,sitio flores,Sítio Flores,06,,-7.383333,-39.25
br,sitio floresta,Sítio Floresta,18,,-23.314339,-50.240212
br,sitio floresta,Sítio Floresta,27,,-23.7818,-47.216
br,sitio floriano buchner,Sítio Floriano Buchner,18,,-25.917222,-49.613889
br,sitio floriano cardoso,Sítio Floriano Cardoso,18,,-25.52466,-48.893873
br,sitio floriano chimborski,Sítio Floriano Chimborski,18,,-26.0124,-49.7597
br,sitio floriano czaia,Sítio Floriano Czaia,18,,-25.7514,-49.5897
br,sitio floriano deda,Sítio Floriano Deda,18,,-25.7973,-49.4839
br,sitio floriano gaulak,Sítio Floriano Gaulak,18,,-25.9425,-49.585556
br,sitio floriano hoffmann,Sítio Floriano Hoffmann,18,,-25.758889,-49.695833
br,sitio floriano kluka,Sítio Floriano Kluka,18,,-25.8241,-49.4178
br,sitio floriano soares,Sítio Floriano Soares,18,,-25.9285,-48.7285
br,sitio floriano vergenski,Sítio Floriano Vergenski,18,,-25.8001,-49.3896
br,sitio floriano vergensk,Sítio Floriano Vergensk,18,,-25.7855,-49.5414
br,sitio floriano woitschekovski,Sítio Floriano Woitschekovski,18,,-26.0693,-49.268
br,sitio floriario waldieski,Sítio Floriario Waldieski,18,,-25.8197,-49.5514
br,sitio florida,Sítio Flórida,27,,-23.069722,-46.504167
br,sitio florindo constancio,Sítio Florindo Constâncio,18,,-23.6006,-49.9348
br,sitio florindo couto,Sítio Florindo Couto,18,,-23.6352,-49.83
br,sitio florisvaldo j. dos santos,Sítio Florisvaldo J. dos Santos,18,,-25.9038,-49.1578
br,sitio florival de j. vieira,Sítio Florival de J. Vieira,18,,-25.907,-49.4169
br,sitio fluminense,Sítio Fluminense,18,,-23.796133,-50.864178
br,sitio fonte sao jose,Sítio Fonte São José,27,,-23.729477,-47.495439
br,sitio formosa,Sítio Formosa,20,,-7.616667,-40.95
br,sitio formosa,Sítio Formosa,27,,-23.8662,-46.7222
br,sitio formosinho,Sítio Formosinho,27,,-23.116122,-46.746174
br,sitio forquilha,Sítio Forquilha,06,,-5.316667,-39.566667
br,sitio forquilha,Sítio Forquilha,18,,-25.9266,-49.0601
br,sitio fortaleza,Sítio Fortaleza,18,,-23.756087,-50.112483
br,sitio forteski,Sítio Forteski,18,,-26.1179,-49.4844
br,sitio frade,Sítio Frade,06,,-4.283333,-38.7
br,sitio franca,Sítio França,18,,-23.413106,-50.013576
br,sitio francisca brunha,Sítio Francisca Brunha,18,,-25.768,-49.4759
br,sitio francisca messias,Sítio Francisca Messias,18,,-23.6493,-49.7829
br,sitio francisca m. neto,Sítio Francisca M. Neto,18,,-26.012,-49.3979
br,sitio francisca siqueira,Sítio Francisca Siqueira,18,,-25.864167,-49.686111
br,sitio francisco a. amico,Sítio Francisco A. Amico,18,,-25.348913,-48.930655
br,sitio francisco a. da silva,Sítio Francisco A. da Silva,18,,-23.920783,-50.565313
br,sitio francisco a. de assis,Sítio Francisco A. de Assis,18,,-25.8812,-49.3393
br,sitio francisco agular,Sítio Francisco Agular,18,,-25.836622,-49.990204
br,sitio francisco alagoano,Sítio Francisco Alagoano,18,,-23.919179,-50.309124
br,sitio francisco alves cordeiro,Sítio Francisco Alves Cordeiro,18,,-25.7081,-48.7681
br,sitio francisco a. moreira,Sítio Francisco A. Moreira,18,,-25.949897,-49.231136
br,sitio francisco a. nascimento,Sítio Francisco A. Nascimento,04,,-1.5475,-61.464167
br,sitio francisco antoceviz,Sítio Francisco Antoceviz,18,,-25.8636,-49.5455
br,sitio francisco antoni do espirito santo,Sítio Francisco Antoni do Espírito Santo,18,,-23.9834,-50.8613
br,sitio francisco a. pscheidt,Sítio Francisco A. Pscheidt,26,,-26.191,-49.8479
br,sitio francisco arantes da silva,Sítio Francisco Arantes da Silva,18,,-23.2368,-50.1885
br,sitio francisco araujo,Sítio Francisco Araújo,18,,-23.716007,-50.572719
br,sitio francisco a. severo junior,Sítio Francisco A. Severo Júnior,27,,-24.804,-48.0591
br,sitio francisco balbino,Sítio Francisco Balbino,18,,-23.837282,-50.047319
br,sitio francisco becker,Sítio Francisco Becker,18,,-26.089231,-49.605831
br,sitio francisco beker,Sítio Francisco Beker,18,,-25.9101,-49.1124
br,sitio francisco bezerra,Sítio Francisco Bezerra,18,,-23.2062,-50.2324
br,sitio francisco b. lemos,Sítio Francisco B. Lemos,18,,-25.914319,-49.034684
br,sitio francisco b. neto,Sítio Francisco B. Neto,18,,-23.7125,-49.8015
br,sitio francisco bodek,Sítio Francisco Bodek,18,,-25.836943,-49.986874
br,sitio francisco boheneki,Sítio Francisco Boheneki,18,,-25.7701,-49.4135
br,sitio francisco braimer,Sítio Francisco Braimer,18,,-26.173917,-49.523444
br,sitio francisco calixto,Sítio Francisco Calixto,18,,-23.4361,-49.857
br,sitio francisco carneiro,Sítio Francisco Carneiro,18,,-23.548638,-50.589906
br,sitio francisco carvalho,Sítio Francisco Carvalho,26,,-26.2164,-49.9537
br,sitio francisco c. do prado,Sítio Francisco C. do Prado,18,,-23.6929,-49.8898
br,sitio francisco centenarovski,Sítio Francisco Centenarovski,18,,-25.770611,-49.423436
br,sitio francisco cota,Sítio Francisco Cota,18,,-23.6307,-49.752
br,sitio francisco d. de souza,Sítio Francisco D. de Souza,18,,-25.9465,-49.0523
br,sitio francisco de assis,Sítio Francisco de Assis,18,,-25.9991,-49.3146
br,sitio francisco de oliveira,Sítio Francisco de Oliveira,18,,-23.393933,-50.017199
br,sitio francisco de p. cordeira,Sítio Francisco de P. Cordeira,18,,-25.7555,-49.365
br,sitio francisco de souza,Sítio Francisco de Souza,18,,-25.9394,-49.3759
br,sitio francisco dibas,Sítio Francisco Dibas,18,,-25.7707,-49.392
br,sitio francisco doraci,Sítio Francisco Doraci,18,,-23.8754,-50.8505
br,sitio francisco dos santos,Sítio Francisco dos Santos,26,,-26.1063,-49.263
br,sitio francisco do vale,Sítio Francisco do Vale,18,,-23.837392,-50.137795
br,sitio francisco drevek,Sítio Francisco Drevek,26,,-26.0959,-49.2889
br,sitio francisco f. dias,Sítio Francisco F. Dias,18,,-25.453739,-48.819733
br,sitio francisco filla,Sítio Francisco Filla,18,,-25.8462,-49.5119
br,sitio francisco fonseca,Sítio Francisco Fonseca,18,,-25.8916,-49.4914
br,sitio francisco francis,Sítio Francisco Francis,26,,-26.1784,-49.8886
br,sitio francisco furtado,Sítio Francisco Furtado,18,,-26.079614,-49.658168
br,sitio francisco galdino,Sítio Francisco Galdino,26,,-26.2115,-49.9383
br,sitio francisco gavlak,Sítio Francisco Gavlak,18,,-25.907222,-49.597222
br,sitio francisco g. filho,Sítio Francisco G. Filho,26,,-26.1721,-49.9042
br,sitio francisco gomes,Sítio Francisco Gomes,27,,-24.8379,-48.2118
br,sitio francisco goncalves,Sítio Francisco Gonçalves,18,,-23.877534,-50.037676
br,sitio francisco grebusch,Sítio Francisco Grebusch,18,,-26.004741,-49.690171
br,sitio francisco g. ribas,Sítio Francisco G. Ribas,18,,-25.934444,-49.52
br,sitio francisco grossol,Sítio Francisco Grossol,18,,-26.0936,-49.4031
br,sitio francisco gualinhama,Sítio Francisco Gualinhama,18,,-23.1846,-50.199
br,sitio francisco gusmao,Sítio Francisco Gusmão,18,,-23.5474,-49.9398
br,sitio francisco h. ferreira,Sítio Francisco H. Ferreira,18,,-26.0536,-49.3746
br,sitio francisco h. n. da silveira,Sítio Francisco H. N. da Silveira,18,,-25.8632,-49.6059
br,sitio francisco honorato gouveia,Sítio Francisco Honorato Gouveia,18,,-23.8741,-50.9777
br,sitio francisco i. de azevedo,Sítio Francisco I. de Azevedo,18,,-23.6359,-49.9053
br,sitio francisco i. pereira,Sítio Francisco I. Pereira,18,,-25.9441,-49.2113
br,sitio francisco janchkovski,Sítio Francisco Janchkovski,26,,-26.1204,-49.9752
br,sitio francisco j. gomes,Sítio Francisco J. Gomes,27,,-23.7155,-47.5677
br,sitio francisco jose dos santos,Sítio Francisco José dos Santos,18,,-23.8925,-50.9553
br,sitio francisco jose,Sítio Francisco José,18,,-23.5028,-49.9762
br,sitio francisco kaioski,Sítio Francisco Kaioski,18,,-23.0154,-50.0225
br,sitio francisco knaut,Sítio Francisco Knaut,18,,-25.751046,-49.415208
br,sitio francisco knoptkt,Sítio Francisco Knoptkt,18,,-26.058159,-49.642827
br,sitio francisco kobus,Sítio Francisco Kobus,18,,-26.101,-49.3342
br,sitio francisco krachinshi,Sítio Francisco Krachinshi,26,,-26.169,-49.8893
br,sitio francisco kupra,Sítio Francisco Kupra,18,,-25.8012,-49.4755
br,sitio francisco l. dos santos,Sítio Francisco L. dos Santos,18,,-25.9978,-49.214
br,sitio francisco lenartoviski,Sítio Francisco Lenartoviski,18,,-25.763599,-49.424891
br,sitio francisco linzmeyer,Sítio Francisco Linzmeyer,26,,-26.1438,-49.282
br,sitio francisco lipski,Sítio Francisco Lipski,18,,-25.778889,-49.735278
br,sitio francisco marcovicz,Sítio Francisco Marcovicz,18,,-25.7996,-49.4923
br,sitio francisco marques,Sítio Francisco Marques,18,,-23.426277,-50.144517
br,sitio francisco martins,Sítio Francisco Martins,18,,-23.846622,-50.333144
br,sitio francisco marzur,Sítio Francisco Marzur,18,,-26.0132,-49.8137
br,sitio francisco massarute,Sítio Francisco Massarute,18,,-23.5221,-49.9914
br,sitio francisco mavarrete,Sítio Francisco Mavarrete,18,,-23.714776,-50.069132
br,sitio francisco m. ferreira,Sítio Francisco M. Ferreira,18,,-23.90519,-50.144456
br,sitio francisco miller,Sítio Francisco Miller,26,,-26.232996,-49.749592
br,sitio francisco mineiro,Sítio Francisco Mineiro,18,,-23.444064,-49.835216
br,sitio francisco mordaski,Sítio Francisco Mordaski,18,,-25.801389,-49.738333
br,sitio francisco moreira,Sítio Francisco Moreira,26,,-26.2312,-49.9255
br,sitio francisco moreno,Sítio Francisco Moreno,18,,-23.5456,-49.9124
br,sitio francisco m. rodrigues,Sítio Francisco M. Rodrigues,18,,-23.7008,-49.7715
br,sitio francisco neto,Sítio Francisco Neto,18,,-25.052083,-48.969722
br,sitio francisco neto,Sítio Francisco Neto,26,,-26.2366,-49.9405
br,sitio francisco nogueira,Sítio Francisco Nogueira,26,,-26.1327,-49.3112
br,sitio francisco obizut,Sítio Francisco Obizut,18,,-25.9244,-49.1391
br,sitio francisco o. de paulo,Sítio Francisco O. de Paulo,18,,-25.7954,-49.3713
br,sitio francisco o. lima,Sítio Francisco O. Lima,18,,-25.9869,-49.0432
br,sitio francisco osni,Sítio Francisco Osni,18,,-26.0834,-49.2972
br,sitio francisco p. da rocha,Sítio Francisco P. da Rocha,18,,-25.9801,-49.2902
br,sitio francisco p. da silva,Sítio Francisco P. da Silva,18,,-25.9609,-49.3983
br,sitio francisco pecshel,Sítio Francisco Pecshel,26,,-26.23226,-49.673941
br,sitio francisco peres,Sítio Francisco Péres,18,,-23.483564,-49.830424
br,sitio francisco pogeba,Sítio Francisco Pogeba,18,,-25.9649,-49.4826
br,sitio francisco pryzbuk,Sítio Francisco Pryzbuk,18,,-25.8015,-49.6507
br,sitio francisco pscheidt,Sítio Francisco Pscheidt,26,,-26.1482,-49.858
br,sitio francisco qrul,Sítio Francisco Qrul,18,,-25.8509,-49.3368
br,sitio francisco raiz,Sítio Francisco Raiz,18,,-25.95447,-49.955323
br,sitio francisco r. dos santos,Sítio Francisco R. dos Santos,18,,-25.251524,-48.943744
br,sitio francisco ribas,Sítio Francisco Ribas,18,,-25.9429,-49.4379
br,sitio francisco ribeira,Sítio Francisco Ribeira,18,,-25.8372,-49.3876
br,sitio francisco rodrigues filho,Sítio Francisco Rodrigues Filho,18,,-23.600532,-50.040798
br,sitio francisco rozendo,Sítio Francisco Rozendo,18,,-23.833599,-50.102817
br,sitio francisco sarovski,Sítio Francisco Sarovski,18,,-26.0357,-49.3658
br,sitio francisco schelmach,Sítio Francisco Schelmach,26,,-26.2144,-49.8779
br,sitio francisco schimidt,Sítio Francisco Schimidt,18,,-26.088229,-49.718243
br,sitio francisco seve,Sítio Francisco Seve,18,,-25.817676,-49.788007
br,sitio francisco silas proenca,Sítio Francisco Silas Proença,18,,-23.760984,-50.586983
br,sitio francisco siqueira,Sítio Francisco Siqueira,18,,-23.6233,-49.7838
br,sitio francisco,Sítio Francisco,27,,-23.239444,-46.5925
br,sitio francisco s. luz,Sítio Francisco S. Luz,18,,-23.7123,-49.846
br,sitio francisco soczk,Sítio Francisco Soczk,18,,-25.783,-49.5633
br,sitio francisco stanchak,Sítio Francisco Stanchak,26,,-26.164,-49.9327
br,sitio francisco stiagar,Sítio Francisco Stiagar,18,,-25.7794,-49.3979
br,sitio francisco stinga,Sítio Francisco Stinga,18,,-25.7724,-49.5177
br,sitio francisco sumim,Sítio Francisco Sumim,18,,-23.6953,-49.7947
br,sitio francisco teixeira,Sítio Francisco Teixeira,18,,-23.6542,-49.9343
br,sitio francisco telmann,Sítio Francisco Telmann,26,,-26.1944,-49.4794
br,sitio francisco teodoro,Sítio Francisco Teodoro,18,,-23.657,-49.9251
br,sitio francisco torres,Sítio Francisco Torres,27,,-24.5993,-48.2728
br,sitio francisco ukn,Sítio Francisco Ukn,18,,-25.94,-49.527222
br,sitio francisco ulbrich,Sítio Francisco Ulbrich,26,,-26.0604,-49.9888
br,sitio francisco v. de lima,Sítio Francisco V. de Lima,18,,-25.9008,-49.2468
br,sitio francisco ville,Sítio Francisco Ville,18,,-26.035685,-49.721095
br,sitio francisco wojeik,Sítio Francisco Wojeik,18,,-25.751111,-49.514444
br,sitio francisco zanal,Sítio Francisco Zanal,18,,-25.7539,-49.315
br,sitio francisco zandrosk,Sítio Francisco Zandrosk,18,,-25.845533,-49.767757
br,sitio francisquinho,Sítio Francisquinho,18,,-23.1203,-50.1003
br,sitio franco de oliveira,Sítio Franco de Oliveira,18,,-23.187739,-49.914403
br,sitio franco,Sítio Franco,18,,-23.200956,-49.922206
br,sitio frank,Sítio Frank,18,,-23.174764,-49.899003
br,sitio frazao,Sítio Frazão,18,,-23.133454,-49.870672
br,sitio frederica eckil,Sítio Frederica Eckil,26,,-26.224879,-49.651416
br,sitio frederico forteski,Sítio Frederico Forteski,18,,-26.0608,-49.4326
br,sitio frida maia,Sítio Frida Maia,26,,-26.1851,-49.8277
br,sitio fuginaga,Sítio Fuginaga,18,,-23.521676,-50.049248
br,sitio fujio,Sítio Fujio,27,,-23.589438,-47.209111
br,sitio fujiwara,Sítio Fujiwara,18,,-25.35455,-48.998328
br,sitio fumal,Sítio Fumal,18,,-25.171066,-48.937829
br,sitio funchal,Sítio Funchal,27,,-23.129722,-46.710833
br,sitio fundao,Sítio Fundão,27,,-23.196111,-46.604444
br,sitio fundo do paredao,Sítio Fundo do Paredão,27,,-23.102303,-47.601114
br,sitio fundo,Sítio Fundo,06,,-7.3,-39.033333
br,sitio furtozo mochan,Sítio Furtozo Mochan,18,,-23.879325,-50.289469
br,sitio gabiroba,Sítio Gabiroba,18,,-23.2377,-50.1775
br,sitio gabriel hukan,Sítio Gabriel Hukan,18,,-25.7172,-49.9986
br,sitio gabriel krol,Sítio Gabriel Krol,26,,-26.1546,-49.9133
br,sitio gabriel lourenco,Sítio Gabriel Lourenço,18,,-25.8241,-49.5762
br,sitio gabriel paulo,Sítio Gabriel Paulo,18,,-25.909167,-49.562222
br,sitio gabriel pillati,Sítio Gabriel Pillati,26,,-26.17412,-49.71976
br,sitio gabriel p. konkl,Sítio Gabriel P. Konkl,26,,-26.144,-49.9391
br,sitio gabriel ricardo,Sítio Gabriel Ricardo,18,,-23.083743,-49.98312
br,sitio gabriel,Sítio Gabriel,18,,-23.2232,-50.2435
br,sitio gabriel tavares,Sítio Gabriel Tavares,18,,-23.902718,-50.015399
br,sitio gabriel telma,Sítio Gabriel Telma,18,,-26.0711,-49.3383
br,sitio gaivota,Sítio Gaivota,27,,-23.8145,-46.6636
br,sitio galdino,Sítio Galdino,18,,-23.7607,-50.9388
br,sitio galileia,Sítio Galiléia,27,,-23.812,-46.6112
br,sitio galinhao,Sítio Galinhão,27,,-23.831893,-46.745163
br,sitio galo,Sítio Galo,27,,-23.179722,-46.646111
br,sitio galo vermelho,Sítio Galo Vermelho,27,,-23.663287,-47.112538
br,sitio galvao,Sítio Galvão,18,,-25.272498,-48.991595
br,sitio gamboa,Sitio Gamboa,26,,-26.3641,-48.6236
br,sitio gamelao,Sítio Gamelão,18,,-23.987,-50.8018
br,sitio garcia,Sítio Garcia,18,,-23.1146,-50.237
br,sitio gaspar shernak,Sítio Gaspar Shernak,26,,-26.212567,-49.940183
br,sitio gaspar tums,Sítio Gaspar Tums,26,,-26.1882,-49.8576
br,sitio gaucho,Sítio Gaucho,18,,-25.4537,-48.7296
br,sitio gauchos,Sítio Gaúchos,26,,-26.23199,-49.6882
br,sitio gaviao,Sítio Gavião,27,,-24.9445,-48.5679
br,sitio g.b.s.,Sítio G.B.S.,27,,-23.2456,-46.6156
br,sitio gelasio dreveck,Sítio Gelásio Dreveck,26,,-26.1536,-49.3247
br,sitio gelson do couto,Sítio Gelson do Couto,18,,-23.651,-49.8285
br,sitio genario miranda,Sítio Genário Miranda,18,,-25.838709,-48.775925
br,sitio genesio de oliveira,Sítio Genésio de Oliveira,18,,-23.4406,-49.8541
br,sitio genesio estella,Sítio Genésio Estella,18,,-23.90601,-50.232384
br,sitio genho pethes,Sítio Genho Pethes,26,,-26.1805,-49.8588
br,sitio geniel da costa freire,Sítio Geniel da Costa Freire,18,,-25.3342,-48.6444
br,sitio genival negrete,Sítio Genival Negrete,18,,-23.646783,-50.188119
br,sitio genoveva dos santos,Sítio Genoveva dos Santos,18,,-25.786,-49.3862
br,sitio genoveva knapik,Sítio Genoveva Knapik,18,,-25.850378,-49.917397
br,sitio genoveva kraus,Sítio Genoveva Kraus,26,,-26.1995,-49.9985
br,sitio genoveva mazur,Sítio Genoveva Mazur,18,,-25.786389,-49.723611
br,sitio genoveva wjavoski,Sítio Genoveva Wjavoski,18,,-25.763889,-49.629167
br,sitio gentil alduan,Sítio Gentil Alduan,18,,-23.7676,-50.9946
br,sitio gentileza,Sítio Gentileza,27,,-23.534693,-47.673175
br,sitio geogina r. da silva,Sítio Geogina R. da Silva,18,,-23.861772,-50.564077
br,sitio georgius,Sítio Georgius,27,,-23.743477,-47.118024
br,sitio geraldina rodrigues de freitas,Sítio Geraldina Rodrigues de Freitas,18,,-23.359794,-50.051832
br,sitio geraldino stigler,Sítio Geraldino Stigler,26,,-26.2204,-49.4462
br,sitio geraldo amado,Sítio Geraldo Amado,18,,-23.8058,-50.9639
br,sitio geraldo borba,Sítio Geraldo Borba,18,,-25.8455,-49.375
br,sitio geraldo caetano da silva,Sítio Geraldo Caetano da Silva,18,,-23.8935,-50.9676
br,sitio geraldo cartario,Sítio Geraldo Cartário,18,,-25.8107,-49.2717
br,sitio geraldo colla,Sítio Geraldo Colla,26,,-26.1809,-49.9972
br,sitio geraldo de freitas,Sítio Geraldo de Freitas,18,,-26.0077,-49.8664
br,sitio geraldo divino,Sítio Geraldo Divino,18,,-23.733714,-50.029911
br,sitio geraldo dutra de souza,Sítio Geraldo Dutra de Souza,18,,-23.63575,-50.197107
br,sitio geraldo forteski,Sítio Geraldo Forteski,18,,-26.085157,-49.536653
br,sitio geraldo g. medeiros,Sítio Geraldo G. Medeiros,18,,-23.734026,-50.585606
br,sitio geraldo g. muniz,Sítio Geraldo G. Muniz,18,,-23.925562,-50.402663
br,sitio geraldo gruber,Sítio Geraldo Gruber,18,,-26.176326,-49.523153
br,sitio geraldo itake,Sítio Geraldo Itake,18,,-25.8582,-49.5712
br,sitio geraldo j. pereira,Sítio Geraldo J. Pereira,18,,-23.6982,-49.8611
br,sitio geraldo lohr,Sítio Geraldo Lohr,18,,-26.1679,-49.4857
br,sitio geraldo malaquias,Sítio Geraldo Malaquias,18,,-23.5656,-49.7991
br,sitio geraldo martins,Sítio Geraldo Martins,18,,-23.5313,-49.9292
br,sitio geraldo m. da silva,Sítio Geraldo M. da Silva,18,,-23.906161,-50.419451
br,sitio geraldo muller,Sítio Geraldo Müller,26,,-26.223203,-49.525981
br,sitio geraldo rodrigues,Sítio Geraldo Rodrigues,18,,-23.7212,-49.9316
br,sitio geraldo sabatike,Sítio Geraldo Sabatike,18,,-26.0103,-49.9308
br,sitio geraldo stigler,Sítio Geraldo Stigler,26,,-26.219295,-49.473422
br,sitio geraldo vieira,Sítio Geraldo Vieira,18,,-25.198378,-48.959067
br,sitio geral,Sítio Geral,06,,-7.25,-39.033333
br,sitio gereinias f. dos santos,Sítio Gereinias F. dos Santos,18,,-25.9302,-49.4689
br,sitio geremias de campos,Sítio Geremias de Campos,18,,-23.824809,-50.123555
br,sitio geremias de l. mendes,Sítio Geremias de L. Mendes,18,,-25.8181,-49.5053
br,sitio gerhardn,Sítio Gerhardn,26,,-26.1919,-49.8649
br,sitio gerlado mendes,Sítio Gerlado Mendes,18,,-23.6369,-49.8984
br,sitio germano basso,Sítio Germano Basso,18,,-25.997222,-49.664444
br,sitio germano schossig,Sítio Germano Schossig,18,,-26.10241,-49.727523
br,sitio germano streit,Sítio Germano Streit,18,,-26.163728,-49.520089
br,sitio germano zimeler,Sítio Germano Zimeler,18,,-26.0298,-49.8733
br,sitio gerson salustiano da silva,Sítio Gerson Salustiano da Silva,18,,-23.801558,-50.834385
br,sitio gerson t. de melo,Sítio Gerson T. de Melo,18,,-25.965,-49.911675
br,sitio gertrudes liebl,Sítio Gertrudes Liebl,26,,-26.1844,-49.3145
br,sitio gervasio lubas,Sítio Gervásio Lubas,18,,-25.7868,-49.1863
br,sitio getulio de o. santos,Sítio Getúlio de O. Santos,18,,-25.8291,-49.588
br,sitio getulio gomes da silva,Sítio Getúlio Gomes da Silva,18,,-23.9564,-50.8518
br,sitio getulio l. colla,Sítio Getúlio L. Colla,26,,-26.1608,-49.9816
br,sitio getulio l. hack,Sítio Getúlio L. Hack,26,,-26.194816,-49.703444
br,sitio getulio vargas maldonado,Sítio Getúlio Vargas Maldonado,18,,-23.9465,-50.9059
br,sitio giambroni,Sítio Giambroni,27,,-23.5181,-47.6746
br,sitio gildo schroht,Sítio Gildo Schroht,18,,-26.1382,-49.4239
br,sitio gilmar baitala,Sítio Gilmar Baitala,18,,-26.165739,-49.572617
br,sitio ginelio turik,Sítio Ginélio Turik,26,,-26.2227,-49.4847
br,sitio gio pato,Sítio Gio Pato,18,,-23.281712,-50.160848
br,sitio girassol,Sítio Girassol,18,,-23.2249,-50.0569
br,sitio girassol,Sítio Girassol,27,,-23.914368,-46.730437
br,sitio gleba cinco,Sítio Gleba Cinco,18,,-23.2626,-49.9158
br,sitio gleba,Sítio Gleba,20,,-7.783333,-40.95
br,sitio gloria,Sítio Glória,18,,-25.186462,-48.948628
br,sitio godoy,Sítio Godoy,18,,-23.7266,-49.7856
br,sitio goes,Sítio Góes,18,,-23.80679,-50.726776
br,sitio gomes,Sítio Gomes,18,,-23.9544,-50.8741
br,sitio goncalo pimentel,Sítio Gonçalo Pimentel,18,,-23.895844,-50.093482
br,sitio goncalo,Sitio Goncalo,20,,-5.333333,-42.7
br,sitio goncalves simoes,Sítio Gonçalves Simões,18,,-23.63,-49.8113
br,sitio goncalves,Sítio Gonçalves,18,,-23.7144,-49.7805
br,sitio gonsalo m. de souza,Sítio Gonsalo M. de Souza,18,,-23.7036,-49.7525
br,sitio goto,Sítio Goto,27,,-23.8608,-46.663
br,sitio graca,Sítio Graça,27,,-23.640849,-47.070785
br,sitio graciosa,Sítio Graciosa,18,,-25.342869,-48.987197
br,sitio gralha-azul,Sítio Gralha-Azul,26,,-26.2379,-49.901
br,sitio gramado,Sítio Gramado,27,,-23.061111,-46.649444
br,sitio grama,Sítio Grama,27,,-23.247917,-47.537952
br,sitio granada,Sítio Granada,18,,-23.088869,-52.082728
br,sitio grande,Sítio Grande,05,,-12.416667,-45.083333
br,sitio grande,Sítio Grande,27,,-23.366667,-47.6
br,sitio granja trocadero,Sítio Granja Trocadero,27,,-23.530153,-47.18668
br,sitio gravatas,Sítio Gravatas,27,,-23.98971,-47.051355
br,sitio gregorio dos santos,Sítio Gregório dos Santos,18,,-25.8734,-49.2881
br,sitio gregorio francisco,Sítio Gregório Francisco,18,,-25.992262,-49.809138
br,sitio gregorio p. da cruz,Sítio Gregório P. da Cruz,18,,-25.91,-49.3596
br,sitio gregorio p. do valle,Sítio Gregório P. do Valle,18,,-25.898,-49.3472
br,sitio gregorio,Sítio Gregório,18,,-25.5298,-48.9071
br,sitio gregorio zella,Sítio Gregório Zella,18,,-25.798747,-49.756322
br,sitio grilo do brejo,Sítio Grilo do Brejo,27,,-23.35826,-46.61366
br,sitio grotao,Sítio Grotão,18,,-23.5979,-49.821
br,sitio gruber,Sítio Gruber,18,,-26.050918,-49.518131
br,sitio gruta dos jesuitas,Sítio Gruta dos Jesuitas,27,,-23.6902,-47.51
br,sitio guafeu,Sítio Guafeu,18,,-23.1542,-50.1737
br,sitio guaiapa,Sítio Guaiapa,27,,-24.660929,-48.22415
br,sitio guapeva,Sítio Guapeva,27,,-23.982952,-47.147454
br,sitio guapirama,Sítio Guapirama,18,,-23.530678,-50.033834
br,sitio guaraciara,Sítio Guaraciara,18,,-23.668499,-50.14614
br,sitio guaramiama,Sítio Guaramiama,27,,-23.9175,-47.0061
br,sitio guarania,Sítio Guarânia,27,,-23.86437,-47.057021
br,sitio guarani,Sítio Guarani,06,,-6.783333,-39.466667
br,sitio guarani,Sítio Guarani,18,,-23.716068,-50.698494
br,sitio guaratim,Sítio Guaratim,06,,-3.916667,-40.483333
br,sitio guarau,Sítio Guaraú,27,,-24.719766,-48.052912
br,sitio guaribas,Sítio Guaribas,06,,-6.85,-39.366667
br,sitio guarita,Sítio Guaritá,18,,-23.064592,-52.021809
br,sitio guaxinduva,Sítio Guaxinduva,27,,-23.086111,-46.507778
br,sitio guilherme avanco,Sítio Guilherme Avanço,18,,-23.797086,-50.842001
br,sitio guilherme borgnon,Sítio Guilherme Borgnon,18,,-23.6979,-49.8444
br,sitio guilherme fuchs,Sítio Guilherme Fuchs,18,,-26.0353,-49.7733
br,sitio guilherme guaudeline,Sítio Guilherme Guaudeline,18,,-23.187595,-49.858639
br,sitio guilherme miamotto,Sítio Guilherme Miamotto,18,,-23.726192,-50.66138
br,sitio guilherme schimidt,Sítio Guilherme Schimidt,18,,-26.085302,-49.719234
br,sitio guilherme,Sítio Guilherme,18,,-23.7176,-49.803
br,sitio guilherme subira,Sítio Guilherme Subira,18,,-23.889718,-50.179107
br,sitio guilhermina lara,Sítio Guilhermina Lara,18,,-25.829794,-48.792099
br,sitio gumercino calizario,Sítio Gumercino Calizário,18,,-26.0155,-49.504974
br,sitio gunar c. zalite,Sítio Gunar C. Zalite,18,,-25.9496,-49.1375
br,sitio gurski,Sítio Gurski,18,,-25.615184,-50.150236
br,sitio gustavo o. atner,Sítio Gustavo O. Atner,18,,-25.9891,-49.2951
br,sitio haga-2,Sítio Haga-2,27,,-23.578229,-47.193633
br,sitio haga-dois,Sítio Haga-Dois,27,,-23.578229,-47.193633
br,sitio haiti,Sítio Haiti,27,,-23.6028,-47.8242
br,sitio hakai,Sítio Hakai,18,,-25.465923,-48.847157
br,sitio hakirasoto,Sítio Hakirasoto,18,,-23.877306,-50.259097
br,sitio hamilton del ponte,Sítio Hamilton Del Ponte,18,,-25.84776,-49.784931
br,sitio hamilton l. de andrade,Sítio Hamilton L. de Andrade,18,,-25.892915,-49.179253
br,sitio hamilton mendes,Sítio Hamilton Mendes,18,,-25.108742,-48.743969
br,sitio hamilton moreira,Sítio Hamilton Moreira,18,,-25.959444,-49.559444
br,sitio hamilton negrele,Sítio Hamilton Negrele,18,,-25.7657,-49.3972
br,sitio hamilton r. neto,Sítio Hamilton R. Neto,18,,-23.545,-49.7728
br,sitio hamilton rocha,Sítio Hamilton Rocha,18,,-25.9077,-49.4948
br,sitio hamilton valente,Sítio Hamilton Valente,18,,-25.155957,-48.958534
br,sitio hans p. v. reese,Sítio Hans P. V. Reese,26,,-26.1719,-49.3801
br,sitio haroldo de s. melo,Sítio Haroldo de S. Melo,18,,-23.94818,-50.120914
br,sitio haroldo mingotte,Sítio Haroldo Mingotte,18,,-23.926939,-50.199012
br,sitio haroldo parmezan,Sítio Haroldo Parmezan,18,,-23.5974,-49.9025
br,sitio haroldo,Sítio Haroldo,18,,-25.8414,-48.5743
br,sitio hayat yokoo,Sítio Hayat Yokoo,27,,-23.051599,-49.871315
br,sitio heidl,Sítio Heidl,18,,-26.0896,-49.3993
br,sitio heitor ribas,Sítio Heitor Ribas,18,,-25.833056,-49.718056
br,sitio helcio g. gaio,Sítio Hélcio G. Gaio,18,,-25.928889,-49.611667
br,sitio helena batista,Sítio Helena Batista,18,,-23.5889,-49.781
br,sitio helena bianchine,Sítio Helena Bianchine,18,,-23.6114,-49.8506
br,sitio helena bronchetti,Sítio Helena Bronchetti,18,,-23.7306,-49.775
br,sitio helena dos s. maia,Sítio Helena dos S. Maia,18,,-25.779207,-49.788617
br,sitio helena dranka,Sítio Helena Dranka,26,,-26.1885,-49.2882
br,sitio helena gavlak,Sítio Helena Gavlak,18,,-25.911111,-49.594167
br,sitio helena medeiros,Sítio Helena Medeiros,18,,-23.6031,-49.7873
br,sitio helena menemberg,Sítio Helena Menemberg,18,,-25.825975,-49.909834
br,sitio helena v. vagner,Sítio Helena V. Vagner,26,,-26.24231,-49.711375
br,sitio helio czaia,Sítio Hélio Czaia,18,,-25.7537,-49.5835
br,sitio helio eliseu,Sítio Hélio Eliseu,18,,-23.845816,-50.030047
br,sitio helio micherato,Sítio Hélio Micherato,18,,-23.748,-49.7903
br,sitio helio millus,Sítio Hélio Millus,18,,-23.766443,-50.186596
br,sitio helio montanheiro,Sítio Hélio Montanheiro,18,,-23.409105,-49.988713
br,sitio helio p. neto,Sítio Hélio P. Neto,18,,-23.693498,-49.764133
br,sitio helio toiatello,Sítio Hélio Toiatello,18,,-25.4791,-48.7288
br,sitio helio velasques,Sítio Hélio Velasques,18,,-23.6718,-49.7603
br,sitio helmut tischie,Sítio Helmut Tischie,18,,-26.0184,-49.8683
br,sitio heloi lourenco,Sítio Helói Lourenço,26,,-26.147511,-49.749569
br,sitio henricus hendrix,Sítio Henricus Hendrix,18,,-25.904205,-49.767521
br,sitio henrious hendrikx,Sítio Henrious Hendrikx,18,,-25.853889,-49.727778
br,sitio henrique albares,Sítio Henrique Albares,27,,-25.023279,-48.519707
br,sitio henrique arikraschinski,Sítio Henrique Arikraschinski,18,,-26.074,-49.7907
br,sitio henrique d. parma,Sítio Henrique D. Parma,18,,-23.824488,-50.162021
br,sitio henrique herzer,Sítio Henrique Herzer,18,,-26.0845,-49.8155
br,sitio henrique kazati,Sítio Henrique Kazati,18,,-26.068991,-49.695135
br,sitio henrique mikio marumbo,Sítio Henrique Mikio Marumbo,18,,-23.577392,-50.710481
br,sitio henrique m. lechinoski,Sítio Henrique M. Lechinoski,18,,-25.93101,-49.944106
br,sitio henrique muller,Sítio Henrique Müller,26,,-26.1991,-49.4129
br,sitio henrique nigel,Sítio Henrique Nigel,18,,-25.980152,-48.836311
br,sitio henrique pfeffer,Sítio Henrique Pfeffer,26,,-26.169,-49.8414
br,sitio henrique seidel,Sítio Henrique Seidel,18,,-26.038,-49.7753
br,sitio henrique senn,Sítio Henrique Senn,18,,-26.0158,-49.4969
br,sitio henrique,Sítio Henrique,18,,-25.962965,-48.89629
br,sitio henrique valoski,Sítio Henrique Valoski,18,,-25.8935,-49.1211
br,sitio henry,Sítio Henry,26,,-26.2295,-49.8598
br,sitio heraldo p. dos santos,Sítio Heraldo P. dos Santos,18,,-23.878665,-50.403544
br,sitio hera,Sítio Hera,27,,-23.9834,-47.1186
br,sitio herberto geisler,Sítio Herberto Geisler,26,,-26.1268,-49.9685
br,sitio hercilia,Sítio Hercília,18,,-25.9124,-49.3336
br,sitio hercilio simoes,Sítio Hercílio Simões,18,,-26.096122,-49.512384
br,sitio herculano max,Sítio Herculano Max,26,,-26.1904,-49.8336
br,sitio herico auersvaldt,Sítio Herico Auersvaldt,26,,-26.0978,-49.9744
br,sitio herma sebo,Sítio Herma Sebo,18,,-25.231939,-48.555791
br,sitio hermenegildo b. mendes,Sítio Hermenegildo B. Mendes,18,,-23.6463,-49.9038
br,sitio hermenegildo krol,Sítio Hermenegildo Krol,26,,-26.146129,-49.914985
br,sitio herminia pereira,Sítio Hermínia Pereira,26,,-26.2494,-49.7588
br,sitio herminio alves medeiros,Sítio Hermínio Alves Medeiros,27,,-25.042955,-48.552791
br,sitio herminio cardoso,Sítio Hermínio Cardoso,18,,-25.9189,-49.2917
br,sitio higashi,Sítio Higashi,27,,-23.5013,-47.5219
br,sitio higidio costa,Sítio Higidio Costa,18,,-23.7174,-50.6762
br,sitio hilario bergamache,Sítio Hilário Bergamache,18,,-23.984,-50.8282
br,sitio hilario do valle,Sítio Hilário do Valle,18,,-25.8928,-49.5297
br,sitio hilario galan,Sítio Hilário Galan,18,,-23.822581,-50.066287
br,sitio hilario graffe,Sítio Hilário Graffe,18,,-26.159135,-49.565114
br,sitio hilario ruthes,Sítio Hilário Ruthes,26,,-26.2189,-49.8859
br,sitio hilario schreiner,Sítio Hilário Schreiner,18,,-26.088498,-49.537129
br,sitio hilario,Sítio Hilário,27,,-24.610888,-48.281773
br,sitio hilauro nabechima,Sítio Hilauro Nabechima,18,,-23.574374,-50.686713
br,sitio hilda de oliveira,Sítio Hilda de Oliveira,18,,-25.5318,-48.7932
br,sitio hilda schusth,Sítio Hilda Schusth,18,,-25.7036,-49.794
br,sitio hildebrando conachok,Sítio Hildebrando Conachok,18,,-25.905178,-49.935618
br,sitio hildefonso pires,Sítio Hildefonso Pires,18,,-26.008,-49.4176
br,sitio hildo francisquinho,Sítio Hildo Francisquinho,18,,-23.1114,-50.1457
br,sitio hildo r. pereira,Sítio Hildo R. Pereira,18,,-23.7385,-49.7631
br,sitio hiloeu pereira,Sítio Hiloeu Pereira,18,,-23.3032,-49.8638
br,sitio hilton fiori,Sítio Hilton Fiori,18,,-25.825121,-49.925929
br,sitio hipolito delcon,Sítio Hipólito Delcon,18,,-23.6097,-49.7828
br,sitio hiriti uzuki,Sítio Hiriti Uzuki,18,,-25.9186,-49.1408
br,sitio hiroshi fujita,Sítio Hiroshi Fujita,18,,-25.935278,-49.581667
br,sitio hirossi,Sítio Hirossi,27,,-23.675066,-47.127121
br,sitio hishida,Sítio Hishida,27,,-23.583281,-47.183083
br,sitio hitoshi higashi,Sítio Hitoshi Higashi,27,,-23.5299,-47.5276
br,sitio holanda pazinatto,Sítio Holanda Pazinatto,18,,-25.5385,-48.8496
br,sitio homero martins,Sítio Homero Martins,18,,-23.886442,-50.233257
br,sitio homero torres,Sítio Homero Torres,18,,-23.5882,-49.8093
br,sitio honesto strugal,Sítio Honesto Strugal,18,,-25.8694,-49.5193
br,sitio horacio dias sobral,Sítio Horácio Dias Sobral,27,,-24.8142,-48.0637
br,sitio horacio j. de gouveia,Sítio Horácio J. de Gouveia,18,,-23.6911,-49.9006
br,sitio horacio rodrigues,Sítio Horácio Rodrigues,18,,-25.8201,-49.5058
br,sitio horacio xavier,Sítio Horácio Xavier,18,,-23.6562,-49.9212
br,sitio horanai,Sítio Horanai,18,,-23.72704,-50.575099
br,sitio horita,Sítio Horita,18,,-23.062486,-52.219335
br,sitio horizonte,Sítio Horizonte,27,,-23.687053,-47.060738
br,sitio hugo friedrich,Sítio Hugo Friedrich,26,,-26.179,-49.3347
br,sitio hugo lopes,Sítio Hugo Lopes,18,,-23.919461,-50.709391
br,sitio hugo,Sítio Hugo,18,,-23.80467,-50.740497
br,sitio hulino pararim,Sítio Hulino Pararim,18,,-23.0172,-50.1671
br,sitio humberto alaiko,Sítio Humberto Alaiko,18,,-25.6999,-49.9887
br,sitio humberto camargo,Sítio Humberto Camargo,18,,-23.2395,-50.1228
br,sitio humberto grace,Sítio Humberto Grace,18,,-23.5866,-49.8654
br,sitio h-z,Sítio H-Z,27,,-23.251936,-46.631393
br,sitio iapo,Sítio Iapo,27,,-23.534183,-47.016212
br,sitio iara,Sítio Iara,27,,-23.190556,-46.689167
br,sitio ibaca,Sítio Ibacá,27,,-23.510779,-47.128559
br,sitio icarai,Sítio Icaraí,27,,-23.427891,-46.720205
br,sitio ico,Sítio Ico,18,,-23.5082,-49.975
br,sitio idalina dos santos,Sítio Idalina dos Santos,18,,-25.5131,-48.8848
br,sitio ida rador,Sítio Ida Rador,26,,-26.1797,-49.3127
br,sitio idavino barbosa,Sítio Idavino Barbosa,18,,-26.085544,-49.595283
br,sitio idelfonso,Sítio Idelfonso,18,,-25.8034,-48.5546
br,sitio idilho b. da cruz,Sítio Idílho B. da Cruz,18,,-25.8645,-49.0983
br,sitio idmar pscheidt,Sítio Idmar Pscheidt,26,,-26.1955,-49.8622
br,sitio iel mariano,Sítio Iel Mariano,18,,-23.795902,-50.803588
br,sitio iga,Sítio Iga,18,,-23.1062,-50.2177
br,sitio igo,Sítio Igo,18,,-23.74465,-50.624302
br,sitio iguape,Sítio Iguapé,18,,-23.716655,-50.133552
br,sitio iguatemi,Sítio Iguatemi,18,,-23.8362,-50.998
br,sitio iguatemi,Sítio Iguatemi,27,,-24.516237,-48.898292
br,sitio ilario brandt,Sítio Ilário Brandt,26,,-26.2166,-49.4516
br,sitio ilario rischiter,Sítio Ilário Rischiter,18,,-26.0437,-49.7726
br,sitio ilario taschek,Sítio Ilário Taschek,18,,-26.1479,-49.4151
br,sitio ilario tums,Sítio Ilário Tums,26,,-26.1865,-49.8593
br,sitio ildefonso de souza,Sítio Ildefonso de Souza,18,,-26.0235,-49.3197
br,sitio ildefonso pereira,Sítio Ildefonso Pereira,18,,-25.8503,-49.3065
br,sitio ildefonso pires,Sítio Ildefonso Pires,18,,-25.8745,-49.3634
br,sitio ildeu,Sítio Ildeu,18,,-23.895823,-50.270701
br,sitio ilha bela,Sítio Ilha Bela,18,,-25.6662,-48.819
br,sitio ilha bela,Sítio Ilha Bela,27,,-23.9069,-46.7369
br,sitio ilton arantes,Sítio Ilton Arantes,18,,-23.2361,-50.2174
br,sitio iludes camargo,Sítio Iludes Camargo,18,,-25.862,-49.3485
br,sitio imbauba,Sítio Imbaúba,27,,-23.300297,-46.600437
br,sitio imbau,Sítio Imbaú,18,,-23.875724,-50.468617
br,sitio imigrante,Sítio Imigrante,27,,-23.8013,-46.6135
br,sitio imobiliaria 2.000,Sítio Imobiliária 2.000,18,,-25.193301,-48.941535
br,sitio imobiliaria dois mil,Sítio Imobiliária Dois Mil,18,,-25.193301,-48.941535
br,sitio inacio bangnter,Sítio Inácio Bangnter,18,,-26.038258,-49.679986
br,sitio inacio batista,Sítio Inácio Batista,18,,-26.036136,-49.620708
br,sitio inacio da silva,Sítio Inácio da Silva,18,,-26.038,-49.822
br,sitio inacio kogeratski,Sítio Inácio Kogeratski,18,,-25.773333,-49.639722
br,sitio inacio kusma,Sítio Inácio Kusma,18,,-26.019164,-49.695671
br,sitio inacio luiz,Sítio Inácio Luiz,18,,-25.8314,-49.3332
br,sitio inacio romplava,Sítio Inácio Romplava,18,,-25.8189,-49.5174
br,sitio inacio schelbauer,Sítio Inácio Schelbauer,26,,-26.1548,-49.9335
br,sitio inacio sezanoski,Sítio Inácio Sezanoski,18,,-25.7811,-49.2312
br,sitio inacio,Sítio Inácio,18,,-23.340891,-50.035041
br,sitio inacio,Sítio Inácio,30,,-7.6,-40.516667
br,sitio inacio sotigue,Sítio Inácio Sotigue,18,,-25.9788,-49.6762
br,sitio inao lopes,Sítio Inão Lopes,18,,-25.6774,-48.8267
br,sitio indaia,Sítio Indaiá,27,,-23.561381,-47.118669
br,sitio ineldo long,Sítio Ineldo Long,26,,-26.241647,-49.633477
br,sitio iner vanesck,Sítio Iner Vanesck,26,,-26.2344,-49.9245
br,sitio ines c. setin,Sítio Inês C. Setin,18,,-25.7815,-49.1467
br,sitio inez f. ribas,Sítio Inez F. Ribas,18,,-25.834536,-49.979652
br,sitio ingazeiro,Sítio Ingazeiro,27,,-23.411389,-46.50528
br,sitio ingenheiro marcelo grassmam,Sítio Ingenheiro Marçelo Grassmam,18,,-25.797649,-48.90953
br,sitio ingo klietzke,Sítio Ingo Klietzke,26,,-25.983958,-48.817758
br,sitio inhozinho valikoski,Sítio Inhozinho Valikoski,26,,-26.2391,-49.8323
br,sitio inhuma,Sítio Inhuma,20,,-7.816667,-40.966667
br,sitio inocencia c. da rocha,Sítio Inocência C. da Rocha,18,,-25.8581,-49.1025
br,sitio inocencio lenert,Sítio Inocêncio Lenert,18,,-25.887383,-49.983959
br,sitio inocencio,Sítio Inocêncio,17,,-7.233333,-36.116667
br,sitio inta,Sítio Inta,20,,-7.916667,-40.916667
br,sitio inveja,Sítio Inveja,18,,-24.691555,-48.848225
br,sitio iolanda da santa pereira,Sítio Iolanda da Santa Pereira,18,,-23.7427,-49.8907
br,sitio iolanda ramires,Sítio Iolanda Ramires,18,,-25.9265,-49.747
br,sitio ipanema do meio,Sítio Ipanema do Meio,27,,-23.5377,-47.5642
br,sitio ipanore,Sítio Ipanoré,27,,-23.5096,-47.681738
br,sitio ipe-amarelo,Sítio Ipê-Amarelo,27,,-23.073333,-46.536944
br,sitio ipe-branco,Sítio Ipê-Branco,27,,-23.093823,-46.725889
br,sitio ipe da colina,Sítio Ipê da Colina,27,,-23.208611,-46.576389
br,sitio ipe,Sítio Ipê,27,,-23.190833,-46.593056
br,sitio ipioca,Sítio Ipioca,06,,-3.933333,-38.65
br,sitio ipiranga,Sítio Ipiranga,27,,-23.195278,-46.718056
br,sitio ipiranguinha,Sítio Ipiranguinha,18,,-23.889797,-50.130478
br,sitio ipiranguinha,Sítio Ipiranguinha,27,,-25.0302,-48.1387
br,sitio ipueirinha,Sitio Ipueirinha,20,,-7.783333,-40.966667
br,sitio iracema albina solar,Sítio Iracema Albina Solar,18,,-23.2354,-50.1481
br,sitio iracema da silva,Sítio Iracema da Silva,18,,-25.911103,-49.609188
br,sitio iracema marueiro de oliveira,Sítio Iracema Marueiro de Oliveira,18,,-23.1901,-50.1511
br,sitio iraci evaristo,Sítio Iraci Evaristo,18,,-23.6662,-50.00128
br,sitio iraci peres de castro,Sítio Iraci Peres de Castro,18,,-23.316528,-50.105858
br,sitio irena albano de souza,Sítio Irena Albano de Souza,18,,-23.406084,-50.052517
br,sitio ireno c. de souza,Sítio Ireno C. de Souza,18,,-23.946015,-50.159336
br,sitio irere,Sítio Irerê,27,,-23.8483,-46.6359
br,sitio irineu beloti,Sítio Irineu Beloti,18,,-23.436879,-50.093491
br,sitio irineu calegare,Sítio Irineu Calegare,18,,-23.244944,-49.762582
br,sitio irineu hirt,Sítio Irineu Hirt,18,,-25.985771,-49.846215
br,sitio irineu isaias,Sítio Irineu Isaías,18,,-26.146319,-49.535396
br,sitio irineu istingrate,Sítio Irineu Istingrate,18,,-25.765,-49.3439
br,sitio irineu jose rosin,Sítio Irineu José Rosin,18,,-25.960283,-49.921181
br,sitio irineu migliorine,Sítio Irineu Migliorine,18,,-26.0446,-49.8185
br,sitio irineu migroline,Sítio Irineu Migroline,18,,-26.0198,-49.8014
br,sitio irineu ruthes,Sítio Irineu Ruthes,26,,-26.212,-49.8334
br,sitio irineu taiola,Sítio Irineu Taiola,18,,-23.231658,-49.805323
br,sitio irineu vidal,Sítio Irineu Vidal,18,,-23.718091,-50.168663
br,sitio irma muller,Sítio Irmã Müller,18,,-25.4648,-48.7489
br,sitio irmaos andrade,Sítio Irmãos Andrade,18,,-23.5939,-49.9671
br,sitio irmao santana,Sítio Irmão Santana,18,,-23.519879,-50.72153
br,sitio irmaos baiao,Sítio Irmãos Baião,18,,-23.286447,-50.15361
br,sitio irmaos bontorin,Sítio Irmãos Bontorin,18,,-25.5438,-48.7682
br,sitio irmaos cardoso,Sítio Irmãos Cardoso,18,,-23.228963,-52.228338
br,sitio irmaos coragem,Sítio Irmãos Coragem,27,,-23.739663,-47.134638
br,sitio irmaos espanholas,Sítio Irmãos Espanholas,27,,-23.8182,-46.6094
br,sitio irmaos inacio,Sítio Irmãos Inácio,18,,-23.94085,-50.241441
br,sitio irmaos kreutzir,Sítio Irmãos Kreutzir,18,,-25.5437,-48.8576
br,sitio irmaos moura,Sítio Irmãos Moura,18,,-23.700323,-50.235236
br,sitio irmaos petroski,Sítio Irmãos Petroski,18,,-25.931968,-49.206049
br,sitio irmaos pires master,Sítio Irmãos Pires Master,18,,-25.8323,-49.0315
br,sitio irmaos resende,Sítio Irmãos Resende,18,,-23.525949,-50.636977
br,sitio irmaos riepe,Sítio Irmãos Riepe,18,,-25.249098,-48.707189
br,sitio irmaos rodrigues,Sítio Irmãos Rodrigues,18,,-23.838756,-50.101127
br,sitio irmaos vicentini,Sítio Irmãos Vicentini,18,,-23.15187,-52.001305
br,sitio irpes,Sítio Irpes,18,,-23.725995,-50.690968
br,sitio isaac luz,Sítio Isaac Luz,18,,-26.0269,-49.8777
br,sitio isabel iavocks,Sítio Isabel Iavocks,18,,-25.7176,-49.9865
br,sitio isabel teles,Sítio Isabel Teles,18,,-23.439189,-49.822895
br,sitio isaias de souza,Sítio Isaías de Souza,18,,-23.517901,-50.724211
br,sitio isaias f. arruda,Sítio Isaías F. Arruda,04,,-1.799444,-60.144444
br,sitio isaias mariano,Sítio Isaías Mariano,18,,-23.696139,-50.018445
br,sitio isaias m. dos anjos,Sítio Isaías M. dos Anjos,18,,-25.9958,-49.0437
br,sitio isaias t. collaco,Sítio Isaias T. Collaço,18,,-25.9249,-49.4887
br,sitio isaltino a. da silva,Sítio Isaltino A. da Silva,18,,-23.6271,-49.8686
br,sitio isaltino s. de oliveira,Sítio Isaltino S. de Oliveira,18,,-23.794164,-50.38712
br,sitio isaltino s. de souza,Sítio Isaltino S. de Souza,18,,-23.6272,-49.7913
br,sitio isau decol,Sítio Isaú Decol,18,,-23.948338,-50.04162
br,sitio isaura rodrigues,Sítio Isaura Rodrigues,18,,-26.153471,-49.639484
br,sitio isaura v. de lima,Sítio Isaura V. de Lima,18,,-25.931189,-49.817639
br,sitio isauro nunes,Sítio Isauro Nunes,18,,-23.7205,-49.812
br,sitio isauro seidel,Sítio Isauro Seidel,18,,-26.0503,-49.784
br,sitio ishida,Sítio Ishida,27,,-23.594758,-47.174075
br,sitio isidoro bilenke,Sítio Isidoro Bilenke,18,,-25.489444,-48.845992
br,sitio isidoro ioche,Sítio Isidoro Ioche,18,,-25.7975,-49.4583
br,sitio isidoro kogeraski,Sítio Isidoro Kogeraski,18,,-25.7801,-49.5389
br,sitio isidoro krzyzanowski,Sítio Isidoro Krzyzanowski,18,,-25.758852,-49.416696
br,sitio isidoro lechinoski,Sítio Isidoro Lechinoski,18,,-25.93891,-49.933377
br,sitio isidoro sarkis,Sítio Isidoro Sarkis,18,,-25.8256,-49.5792
br,sitio isidoro simonsen,Sítio Isidoro Simonsen,18,,-25.8647,-49.5811
br,sitio isidoro,Sítio Isidoro,18,,-23.741128,-50.217909
br,sitio ismael b. rodrigues,Sítio Ismael B. Rodrigues,18,,-25.2776,-48.7068
br,sitio ismael de l. amorim,Sítio Ismael de L. Amorim,18,,-25.923889,-49.511667
br,sitio ismael f. da silva,Sítio Ismael F. da Silva,18,,-25.7019,-49.9099
br,sitio ismael l. camargo e irmaos,Sítio Ismael L. Camargo e Irmãos,18,,-23.5962,-49.9304
br,sitio ismail carvalho,Sítio Ismail Carvalho,18,,-23.757724,-50.098238
br,sitio ismair,Sítio Ismair,18,,-23.65414,-50.16155
br,sitio isolina batista,Sítio Isolina Batista,18,,-23.925458,-50.228762
br,sitio israel rocha,Sítio Israel Rocha,18,,-25.19644,-48.51931
br,sitio israel,Sítio Israel,27,,-23.738953,-47.12114
br,sitio istanislaw kovaleski,Sítio Istanislaw Kovaleski,26,,-26.1766,-49.9983
br,sitio itaguacu,Sítio Itaguaçu,27,,-23.128056,-47.574444
br,sitio itagua,Sítio Itagua,27,,-23.102845,-47.595617
br,sitio itaim,Sítio Itaim,27,,-23.280665,-46.635045
br,sitio itaipu,Sítio Itaipu,27,,-23.01756,-49.875566
br,sitio itajuba,Sítio Itajubá,18,,-23.882122,-50.053576
br,sitio italia,Sítio Itália,18,,-23.7938,-50.9728
br,sitio itanopa,Sítio Itanopã,27,,-24.596435,-48.217785
br,sitio itapetinga,Sítio Itapetinga,27,,-23.181389,-46.533333
br,sitio itapeti,Sítio Itapeti,27,,-23.213056,-46.565833
br,sitio itapora,Sítio Itaporã,15,,-22.581,-45.5382
br,sitio itapua,Sítio Itapuã,18,,-25.185943,-48.927421
br,sitio itarare,Sítio Itararé,18,,-23.9786,-50.8474
br,sitio itarare,Sítio Itararé,27,,-23.9484,-47.0853
br,sitio itata,Sítio Itatá,27,,-24.6904,-48.3291
br,sitio itinga,Sítio Itinga,27,,-23.5494,-47.5477
br,sitio ito,Sítio Ito,18,,-25.3315,-48.748
br,sitio iva alves siqueira,Sítio Iva Alves Siqueira,18,,-23.2282,-50.2044
br,sitio ivair i. precoma,Sítio Ivair I. Precoma,18,,-25.9482,-49.2122
br,sitio ivanaga,Sítio Ivanaga,18,,-23.55927,-50.730529
br,sitio ivanilda centenarovski,Sítio Ivanilda Centenarovski,18,,-25.769822,-49.405353
br,sitio ivanir a. de andrade,Sítio Ivanir A. de Andrade,18,,-25.911232,-49.246896
br,sitio ivankio,Sítio Ivankio,18,,-25.7825,-49.2905
br,sitio ivaporunduva,Sítio Ivaporunduva,27,,-24.5703,-48.3944
br,sitio ivete ribas bueno,Sítio Ivete Ribas Bueno,18,,-25.802288,-49.87998
br,sitio ivo a. domingos,Sítio Ivo A. Domingos,18,,-23.6,-49.8306
br,sitio ivo balansin,Sítio Ivo Balansin,18,,-23.216,-50.1518
br,sitio ivo bonacim,Sítio Ivo Bonacim,18,,-23.1451,-50.1761
br,sitio ivo bonanci,Sítio Ivo Bonanci,18,,-23.0417,-50.1861
br,sitio ivo bras da silva,Sítio Ivo Brás da Silva,04,,-1.693889,-60.160556
br,sitio ivo camargo,Sítio Ivo Camargo,18,,-25.9168,-49.1534
br,sitio ivo de mello,Sítio Ivo de Mello,18,,-23.494562,-49.961766
br,sitio ivo d. radusk,Sítio Ivo D. Radusk,18,,-25.8944,-49.5494
br,sitio ivo f. do vale,Sítio Ivo F. do Vale,18,,-23.771545,-50.000497
br,sitio ivo f. haubert,Sítio Ivo F. Haubert,26,,-26.2118,-49.8058
br,sitio ivo gassnner,Sítio Ivo Gassnner,26,,-26.1856,-49.4092
br,sitio ivo heiden,Sítio Ivo Heiden,18,,-26.0805,-49.3484
br,sitio ivo kramar,Sítio Ivo Kramar,18,,-25.788069,-48.988432
br,sitio ivo moreno,Sítio Ivo Moreno,18,,-26.0557,-49.4781
br,sitio ivone b. nery,Sítio Ivone B. Nery,18,,-25.7741,-49.2065
br,sitio ivone handosk,Sítio Ivone Handosk,26,,-26.2421,-49.9752
br,sitio ivo nigel,Sítio Ivo Nigel,18,,-25.957061,-48.823205
br,sitio ivo rocha,Sítio Ivo Rocha,18,,-25.194923,-48.526505
br,sitio ivo silveira,Sítio Ivo Silveira,18,,-25.8801,-49.1037
br,sitio ivo,Sítio Ivo,18,,-25.6114,-48.8017
br,sitio iwata,Sítio Iwata,27,,-23.59134,-47.195961
br,sitio izac forui,Sítio Izac Forui,18,,-25.460974,-48.81185
br,sitio izael lopes,Sítio Izael Lopes,18,,-23.6734,-49.9817
br,sitio izair j. da oliveira,Sítio Izair J. da Oliveira,18,,-25.109374,-48.795956
br,sitio izana p. de melo,Sítio Izanã P. de Melo,18,,-23.749695,-50.725972
br,sitio izaude rezler,Sítio Izaude Rezler,18,,-26.160071,-49.53848
br,sitio izau,Sítio Izaú,18,,-23.591549,-50.61355
br,sitio izidoro c. de castro,Sítio Izidoro C. de Castro,18,,-23.80912,-50.000323
br,sitio izidoro gertler,Sítio Izidoro Gertler,18,,-26.132241,-49.515972
br,sitio izidoro gruber,Sítio Izidoro Gruber,18,,-26.179661,-49.52496
br,sitio izidoro senn,Sítio Izidoro Senn,18,,-26.0538,-49.4674
br,sitio jaboticabal,Sítio Jaboticabal,18,,-23.6395,-49.9569
br,sitio jaboticaba,Sítio Jaboticaba,27,,-24.728759,-48.179673
br,sitio jabuticabal,Sítio Jabuticabal,18,,-23.396656,-50.130938
br,sitio jacare,Sítio Jacaré,27,,-23.9793,-47.0778
br,sitio jacarezinho,Sítio Jacarezinho,27,,-24.628342,-48.175678
br,sitio jaci lacerda,Sítio Jaci Lacerda,18,,-26.0287,-49.3277
br,sitio jacinto de avelari moreira,Sítio Jacinto de Avelari Moreira,27,,-25.021543,-48.516842
br,sitio jacir matos,Sítio Jacir Matos,18,,-23.923518,-50.084825
br,sitio jacir mubauer,Sítio Jacir Mubauer,26,,-26.1449,-49.8607
br,sitio jaci vieira da silva,Sítio Jaci Vieira da Silva,18,,-23.491468,-50.035701
br,sitio jackson de paula,Sítio Jackson de Paula,18,,-25.599,-48.8044
br,sitio jacob decol,Sítio Jacob Decol,18,,-23.975564,-50.023255
br,sitio jacob figura,Sítio Jacob Figura,18,,-25.915833,-49.590556
br,sitio jacob kaiss,Sítio Jacob Kaiss,18,,-25.827528,-49.493924
br,sitio jacob laska,Sítio Jacob Laska,18,,-25.7885,-49.4538
br,sitio jacob osvaldo breda,Sítio Jacob Osvaldo Breda,18,,-25.5064,-49.9303
br,sitio jacob prorocki,Sítio Jacob Prorocki,18,,-25.834,-49.4807
br,sitio jacob rompava,Sítio Jacob Rompava,18,,-25.869,-49.4315
br,sitio jacob telma,Sítio Jacob Telma,26,,-26.1189,-49.311
br,sitio jaco pikos,Sítio Jacó Pikos,26,,-26.175808,-49.400918
br,sitio jaco,Sítio Jacó,26,,-26.1704,-49.9729
br,sitio jacupema,Sítio Jacupema,27,,-24.6679,-48.3398
br,sitio jacutinga,Sítio Jacutinga,18,,-23.5752,-49.8289
br,sitio jaguarao,Sítio Jaguarão,18,,-25.751389,-49.571389
br,sitio jaguatirica,Sítio Jaguatirica,18,,-25.120316,-48.838114
br,sitio jaime de melo,Sítio Jaime de Melo,18,,-23.761071,-50.713686
br,sitio jaime ribeiro,Sítio Jaime Ribeiro,18,,-23.1917,-50.2173
br,sitio jaime rutheis,Sítio Jaime Rutheis,18,,-26.135274,-49.709293
br,sitio jaime strubr,Sítio Jaime Strubr,26,,-26.2454,-49.8512
br,sitio jaime v. de souza,Sítio Jaime V. de Souza,18,,-23.3878,-49.8926
br,sitio jaimiro alves de oliveira,Sítio Jaimiro Alves de Oliveira,18,,-23.8908,-50.9619
br,sitio jair bertinadi,Sítio Jair Bertinadi,18,,-23.0618,-50.1246
br,sitio jair borges,Sítio Jair Borges,18,,-23.2217,-50.2402
br,sitio jair costa,Sítio Jair Costa,18,,-23.8799,-50.9822
br,sitio jair de andrade,Sítio Jair de Andrade,18,,-26.0228,-49.9172
br,sitio jair de santa oliveira,Sítio Jair de Santa Oliveira,18,,-23.982017,-50.543263
br,sitio jair de souza,Sítio Jair de Souza,18,,-23.545945,-50.729979
br,sitio jair laurindo,Sítio Jair Laurindo,18,,-23.718742,-50.060592
br,sitio jair leprevosti,Sítio Jair Leprevosti,18,,-25.9429,-49.2236
br,sitio jair negrelle,Sítio Jair Negrelle,18,,-25.961944,-49.6975
br,sitio jair o. da silva,Sítio Jair O. da Silva,18,,-23.6165,-49.7989
br,sitio jairo silva,Sítio Jairo Silva,18,,-26.07417,-49.625916
br,sitio jair pereira,Sítio Jair Pereira,18,,-23.907325,-50.516339
br,sitio jair pintai,Sítio Jair Pintai,18,,-23.57452,-50.717877
br,sitio jair,Sítio Jair,18,,-25.514,-48.8232
br,sitio jair soardes,Sítio Jair Soardes,18,,-23.948209,-50.001553
br,sitio jamaica,Sítio Jamaica,18,,-23.762049,-50.847875
br,sitio jandaia,Sítio Jandaia,27,,-23.8977,-47.1131
br,sitio jandira b. costa,Sítio Jandira B. Costa,18,,-23.947566,-50.163681
br,sitio jandir s. delvino,Sítio Jandir S. Delvino,18,,-23.985419,-50.390714
br,sitio jandito machado,Sítio Jandito Machado,18,,-25.9713,-49.1484
br,sitio jangada,Sítio Jangada,27,,-23.0625,-46.672222
br,sitio jango,Sítio Jango,18,,-23.710625,-50.07524
br,sitio januario,Sítio Januário,27,,-23.719428,-47.094544
br,sitio jaques ferro,Sítio Jaques Ferro,18,,-23.684673,-50.615207
br,sitio jarbas g. filho,Sítio Jarbas G. Filho,18,,-25.7271,-49.7929
br,sitio jarbas liebel,Sítio Jarbas Liebel,26,,-26.248687,-49.654359
br,sitio jardim paraiso,Sítio Jardim Paraíso,18,,-23.6286,-49.9934
br,sitio jardim primavera,Sítio Jardim Primavera,27,,-23.188333,-46.577778
br,sitio jardim,Sítio Jardim,27,,-23.043889,-46.501944
br,sitio jarmin da serra,Sítio Jarmin da Serra,27,,-23.584575,-47.115104
br,sitio jatoba,Sítio Jatobá,27,,-23.5407,-47.5703
br,sitio j. bueno,Sítio J. Bueno,18,,-23.741266,-50.23457
br,sitio jean m. fendrich,Sítio Jean M. Fendrich,26,,-26.20743,-49.718167
br,sitio jeca pereira,Sítio Jeca Pereira,18,,-25.870447,-49.001618
br,sitio jenipapeiro,Sítio Jenipapeiro,06,,-4.4,-38.95
br,sitio jequitiba,Sítio Jequitibá,18,,-23.769,-50.9704
br,sitio jequitiba,Sítio Jequitibá,27,,-23.0925,-46.665556
br,sitio jeriva,Sítio Jerivá,27,,-23.8135,-46.6069
br,sitio jeronimo candido,Sítio Jerônimo Cândido,18,,-23.922476,-50.557181
br,sitio jeronimo couto,Sítio Jerônimo Couto,18,,-23.750872,-50.735082
br,sitio jeronimo d. carbornar,Sítio Jerônimo D. Carbornar,18,,-25.7798,-49.1412
br,sitio jeronimo fogaca,Sítio Jerônimo Fogaça,18,,-24.747746,-48.951557
br,sitio jeronimo s. cortes,Sítio Jerônimo S. Cortes,18,,-25.774,-49.5776
br,sitio jeronimo,Sítio Jerônimo,27,,-24.660316,-48.017485
br,sitio jerusalem,Sítio Jerusalém,18,,-23.854456,-50.645379
br,sitio jesi alves rodrigues,Sítio Jesi Alves Rodrigues,18,,-23.940513,-50.352473
br,sitio jesus lopes de souza,Sítio Jesus Lopes de Souza,18,,-23.71476,-50.025656
br,sitio jesus me deu,Sítio Jesus Me Deu,04,,-1.485833,-60.266389
br,sitio joacir camargo,Sítio Joacir Camargo,18,,-25.847548,-49.759012
br,sitio joana de oliveira,Sítio Joana de Oliveira,18,,-25.8489,-49.1667
br,sitio joana miranda ramos,Sítio Joana Miranda Ramos,18,,-25.5354,-48.8449
br,sitio joanin a. franco,Sítio Joanin A. Franco,18,,-25.891,-49.1772
br,sitio joao a. barbosa,Sítio João A. Barbosa,18,,-23.733674,-50.616928
br,sitio joao abilio,Sítio João Abílio,18,,-23.69517,-50.066334
br,sitio joao a. bonine,Sítio João A. Bonine,18,,-23.7379,-49.9515
br,sitio joao a. borges,Sítio João A. Borges,18,,-25.8872,-49.0972
br,sitio joao acindino martins,Sítio João Acindino Martins,18,,-23.879413,-50.673864
br,sitio joao a. de carvalho,Sítio João A. de Carvalho,18,,-23.9634,-50.9419
br,sitio joao a. de oliveira,Sítio João A. de Oliveira,18,,-23.883155,-50.080148
br,sitio joao a. de souza,Sítio João A. de Souza,18,,-23.985039,-50.525274
br,sitio joao a. dos santos,Sítio João A. dos Santos,18,,-23.5296,-49.9011
br,sitio joao a. ekel,Sítio João A. Ekel,26,,-26.192868,-49.698486
br,sitio joao a. fagundes,Sítio João A. Fagundes,18,,-26.120031,-49.610849
br,sitio joao a. g. de oliveira,Sítio João A. G. de Oliveira,18,,-25.8152,-49.0496
br,sitio joao agostinho,Sítio João Agostinho,18,,-25.8717,-49.0762
br,sitio joao aguiar,Sítio João Aguiar,18,,-25.485093,-48.799348
br,sitio joao alfredo,Sítio João Alfredo,18,,-25.909167,-49.58
br,sitio joao alves dos santos,Sítio João Alves dos Santos,18,,-25.781488,-49.876796
br,sitio joao amadeus,Sítio Joáo Amadeus,18,,-23.3331,-49.8745
br,sitio joao amaro,Sítio João Amaro,18,,-23.6259,-49.8186
br,sitio joao amorim,Sítio João Amorim,18,,-25.755318,-48.766259
br,sitio joao antonio magalhaes,Sítio João Antônio Magalhães,18,,-25.7296,-49.8185
br,sitio joao antunes,Sítio João Antunes,18,,-26.0372,-49.7835
br,sitio joao antunes,Sítio João Antunes,27,,-24.603509,-48.278941
br,sitio joao arbete,Sítio João Arbete,18,,-25.847778,-49.643056
br,sitio joao arcelino,Sítio João Arcelino,18,,-25.9864,-49.4638
br,sitio joao astofani,Sítio João Astofani,18,,-25.827646,-48.787362
br,sitio joao a. tavares,Sítio João A. Tavares,18,,-26.0326,-49.2602
br,sitio joao a. trevisan,Sítio João A. Trevisan,18,,-25.778333,-49.663611
br,sitio joao augustin,Sítio João Augustin,18,,-26.100107,-49.525431
br,sitio joao a. valerio,Sítio João A. Valério,18,,-26.186337,-49.60563
br,sitio joao a. veiga,Sítio João A. Veiga,26,,-26.238363,-49.679051
br,sitio joao bahiano,Sítio João Bahiano,18,,-23.2062,-50.2423
br,sitio joao barbosa,Sítio João Barbosa,18,,-26.025918,-49.635276
br,sitio joao batista mendes,Sítio João Batista Mendes,18,,-25.890062,-49.913447
br,sitio joao batista,Sítio João Batista,18,,-23.7089,-49.9008
br,sitio joao batista,Sítio João Batista,27,,-23.517591,-47.234972
br,sitio joao b. cordeiro,Sítio João B. Cordeiro,18,,-25.979167,-49.512222
br,sitio joao b. da silva,Sítio João B. da Silva,18,,-23.88794,-50.45407
br,sitio joao b. de abreu,Sítio João B. de Abreu,18,,-25.463285,-48.844332
br,sitio joao b. de oliveira,Sítio João B. de Oliveira,18,,-23.908964,-50.237283
br,sitio joao bento,Sítio João Bento,18,,-23.6702,-49.9052
br,sitio joao benvindo,Sítio João Benvindo,18,,-23.60814,-50.527048
br,sitio joao biscorovani,Sítio João Biscorovani,18,,-25.8147,-49.2292
br,sitio joao blaskoski,Sítio João Blaskoski,18,,-26.0574,-49.2803
br,sitio joao b. louzano,Sítio João B. Louzano,18,,-23.6483,-49.8367
br,sitio joao b. marins,Sítio João B. Marins,18,,-23.994025,-50.121111
br,sitio joao boiko,Sítio João Boiko,18,,-25.7678,-49.2749
br,sitio joao bonesgawa,Sítio João Bonesgawa,18,,-25.905,-49.5525
br,sitio joao boreli,Sítio João Boreli,18,,-23.544,-50.5385
br,sitio joao b. popovisk,Sítio João B. Popovisk,18,,-25.8414,-49.22
br,sitio joao bras,Sítio João Brás,18,,-23.69589,-50.11317
br,sitio joao b. rocha,Sítio João B. Rocha,18,,-25.8424,-49.0373
br,sitio joao bueno,Sítio João Bueno,26,,-26.12,-49.9554
br,sitio joao bufalo,Sítio João Búfalo,18,,-23.879502,-50.275101
br,sitio joao caetano,Sítio João Caetano,18,,-23.753454,-50.23849
br,sitio joao c. alves,Sítio João C. Alves,18,,-25.7735,-49.1348
br,sitio joao campineiro,Sítio João Campineiro,18,,-23.893237,-50.412605
br,sitio joao canavarro,Sítio João Canavarro,18,,-23.99452,-50.530553
br,sitio joao candido,Sítio João Cândido,18,,-23.6671,-49.8974
br,sitio joao carao,Sítio João Carão,18,,-25.5781,-48.9874
br,sitio joao cardoso,Sítio João Cardoso,18,,-25.8916,-49.0827
br,sitio joao carlos costa,Sítio João Carlos Costa,18,,-25.313569,-48.751817
br,sitio joao carlos maia,Sítio João Carlos Maia,18,,-25.895399,-49.813528
br,sitio joao carlos wagner,Sítio João Carlos Wagner,18,,-25.731,-49.8471
br,sitio joao carmelino,Sítio João Carmelino,18,,-23.380363,-50.087857
br,sitio joao carneiro,Sítio João Carneiro,18,,-23.910188,-50.568523
br,sitio joao cayali neto,Sítio João Cayali Neto,18,,-25.209145,-48.990986
br,sitio joao c. bronelli,Sítio João C. Bronelli,18,,-23.947933,-50.474216
br,sitio joao c. de carvalho,Sítio João C. de Carvalho,18,,-25.7793,-49.0032
br,sitio joao c. de melo,Sítio João C. de Melo,18,,-23.898368,-50.083546
br,sitio joao c. donizete,Sítio João C. Donizete,18,,-23.6324,-49.7876
br,sitio joao c. dos santos,Sítio João C. dos Santos,26,,-26.1891,-49.9583
br,sitio joao celestino,Sítio João Celestino,18,,-23.6239,-49.7754
br,sitio joao celso,Sítio João Celso,18,,-25.8306,-49.5788
br,sitio joao celuznec,Sítio João Celuznec,18,,-25.7916,-49.3873
br,sitio joao c. filho,Sítio João C. Filho,18,,-25.8306,-49.5409
br,sitio joao chimborski,Sítio João Chimborski,18,,-26.0034,-49.7554
br,sitio joao cidran,Sítio João Cidran,26,,-26.1665,-49.9627
br,sitio joao coladino,Sítio João Coladino,18,,-23.6298,-49.776
br,sitio joao cordeiro,Sítio João Cordeiro,18,,-25.7807,-49.2478
br,sitio joao costa,Sítio João Costa,18,,-25.2668,-48.5851
br,sitio joao cuba,Sítio João Cuba,26,,-26.183,-49.2916
br,sitio joao c. viana,Sítio João C. Viana,18,,-25.176482,-48.967524
br,sitio joao dama de oliveira,Sítio João Dama de Oliveira,18,,-23.829505,-50.542535
br,sitio joao damas,Sítio João Damas,18,,-23.7143,-49.9694
br,sitio joao da silva,Sítio João da Silva,18,,-26.202001,-49.622376
br,sitio joao da s. passos,Sítio João da S. Passos,18,,-25.465462,-48.816432
br,sitio joao da s. vale,Sítio João da S. Vale,18,,-25.7813,-49.6203
br,sitio joao d. de oliveira,Sítio João D. de Oliveira,18,,-23.827215,-50.161335
br,sitio joao d. dos santos,Sítio João D. dos Santos,18,,-23.5947,-49.8321
br,sitio joao de almeida,Sítio João de Almeida,18,,-23.7455,-49.7832
br,sitio joao de a. maciel,Sítio João de A. Maciel,18,,-25.6658,-49.7682
br,sitio joao de azevedo,Sítio João de Azevedo,18,,-23.6151,-49.7954
br,sitio joao de barro,Sítio João de Barro,18,,-23.953543,-50.030194
br,sitio joao-de-barro,Sítio João-de-Barro,18,,-25.8979,-49.5068
br,sitio joao-de-barro,Sítio João-de-Barro,27,,-23.272471,-46.546744
br,sitio joao de camargo,Sítio João de Camargo,27,,-23.729203,-47.50366
br,sitio joao de deus,Sítio João de Deus,18,,-23.6534,-49.9485
br,sitio joao degues sobrinho,Sítio João Degues Sobrinho,18,,-25.8696,-48.7448
br,sitio joao de j. vidal,Sítio João de J. Vidal,18,,-23.7248,-49.9442
br,sitio joao de lima,Sítio João de Lima,18,,-25.8704,-49.1009
br,sitio joao de o. mendes,Sítio João de O. Mendes,18,,-26.091,-49.3723
br,sitio joao de o. santos,Sítio João de O. Santos,18,,-25.086844,-48.82122
br,sitio joao de s. camargo,Sítio João de S. Camargo,18,,-25.8828,-49.5397
br,sitio joao dias,Sítio João Dias,18,,-23.783526,-50.249171
br,sitio joao do lazaro,Sítio João do Lázaro,18,,-23.739,-50.7131
br,sitio joao domingos,Sítio João Domingos,18,,-23.6406,-49.8674
br,sitio joao dos anjos,Sítio João dos Anjos,18,,-25.7871,-49.135
br,sitio joao dranka,Sítio João Dranka,18,,-25.8675,-49.3344
br,sitio joao drucha,Sítio João Drucha,18,,-25.7789,-49.4977
br,sitio joao e. de assis,Sítio João E. de Assis,18,,-23.7356,-49.9518
br,sitio joao e. ferri,Sítio João E. Ferri,18,,-25.5655,-48.8743
br,sitio joao e. g. franco,Sítio João E. G. Franco,18,,-26.0166,-49.3094
br,sitio joao e. machado,Sítio João E. Machado,18,,-25.8472,-49.5435
br,sitio joao espanhol,Sítio João Espanhol,18,,-23.210721,-49.969885
br,sitio joao estaba,Sítio João Estaba,18,,-25.849092,-49.912253
br,sitio joao esteba,Sítio João Esteba,18,,-25.7085,-49.854
br,sitio joao ester,Sítio João Ester,18,,-25.9246,-49.4747
br,sitio joao estrugale,Sítio João Estrugale,18,,-25.6876,-49.988
br,sitio joao fagundes,Sítio João Fagundes,18,,-25.7364,-49.9982
br,sitio joao faot,Sítio João Faot,18,,-25.8376,-49.591
br,sitio joao f. cardoso,Sítio João F. Cardoso,18,,-25.968633,-49.035208
br,sitio joao f. da cruz,Sítio João F. da Cruz,18,,-23.5911,-49.8041
br,sitio joao f. da silva,Sítio João F. da Silva,18,,-23.944703,-50.163316
br,sitio joao f. das neves,Sítio João F. das Neves,18,,-25.9016,-49.123
br,sitio joao felizardo,Sítio João Felizardo,18,,-23.429484,-50.118737
br,sitio joao fernandes,Sítio João Fernandes,18,,-26.0251,-49.8681
br,sitio joao ferreira,Sítio João Ferreira,18,,-25.929512,-49.836547
br,sitio joao festingue,Sítio João Festingue,26,,-26.2018,-49.7702
br,sitio joao figura,Sítio João Figura,18,,-25.7054,-49.8988
br,sitio joao firmino de oliveira,Sítio João Firmino de Oliveira,18,,-23.373565,-50.129873
br,sitio joao francisco da silveira,Sítio João Francisco da Silveira,18,,-25.906648,-49.940211
br,sitio joao g. correa,Sítio João G. Correa,18,,-23.5834,-49.966
br,sitio joao g. domingues,Sítio João G. Domingues,27,,-23.738078,-47.526315
br,sitio joao g. duarte,Sítio João G. Duarte,18,,-25.5456,-48.7903
br,sitio joao g. lopes,Sítio João G. Lopes,18,,-23.6938,-49.8925
br,sitio joao goncalves,Sítio João Gonçalves,18,,-23.523,-49.877
br,sitio joao gonschorovsk,Sítio João Gonschorovsk,18,,-26.0824,-49.3951
br,sitio joao greihs,Sítio João Greihs,26,,-26.2262,-49.8231
br,sitio joao gruber,Sítio João Gruber,26,,-26.1853,-49.4337
br,sitio joao guimaraes,Sítio João Guimarães,18,,-25.783515,-49.753846
br,sitio joao guimetti,Sítio João Guimetti,18,,-25.960556,-49.534722
br,sitio joao handosk,Sítio João Handosk,26,,-26.24,-49.9746
br,sitio joao henrique,Sítio João Henrique,18,,-25.7889,-48.6102
br,sitio joao hinic,Sítio João Hinic,26,,-26.227163,-49.740271
br,sitio joao hukan,Sítio João Hukan,18,,-25.7134,-49.9971
br,sitio joao humenhuk,Sítio João Humenhuk,18,,-25.9149,-49.393
br,sitio joao i. goncalves,Sítio João I. Gonçalves,26,,-26.119851,-49.858278
br,sitio joao i. ribeiro,Sítio João I. Ribeiro,18,,-23.694109,-50.012729
br,sitio joao isaac,Sítio João Isaac,18,,-25.99,-49.1502
br,sitio joao j. colaco,Sítio João J. Colaço,18,,-25.8838,-49.5399
br,sitio joao j. da rocha,Sítio João J. da Rocha,18,,-25.9226,-49.0547
br,sitio joao j. de souza,Sítio João J. de Souza,18,,-25.7574,-49.157
br,sitio joao j. telma e irmaos,Sítio João J. Telma e Irmãos,18,,-26.132611,-49.646831
br,sitio joao junglas,Sítio João Junglas,26,,-26.020306,-49.993681
br,sitio joao justino oliveira,Sítio João Justino Oliveira,18,,-23.882,-50.9688
br,sitio joao kanut,Sítio João Kanut,18,,-25.817032,-49.785836
br,sitio joao klostirmann,Sítio João Klostirmann,18,,-25.942405,-49.801852
br,sitio joao lazinho,Sítio João Lazinho,18,,-23.6468,-49.7692
br,sitio joao l. dos santos,Sítio João L. dos Santos,18,,-25.906213,-49.990592
br,sitio joao leal,Sítio João Leal,18,,-25.8923,-49.5075
br,sitio joao legario,Sítio João Legário,18,,-23.681042,-50.096732
br,sitio joao leonardo,Sítio João Leonardo,18,,-25.7999,-49.7257
br,sitio joao levino goncalves,Sítio João Levino Gonçalves,18,,-23.692757,-50.098906
br,sitio joao linzmeyer,Sítio João Linzmeyer,26,,-26.1549,-49.2584
br,sitio joao lique,Sítio João Lique,18,,-23.6769,-49.9606
br,sitio joao lis,Sítio João Lis,26,,-26.1803,-49.8523
br,sitio joao l. nico,Sítio João L. Nico,18,,-25.874832,-49.219761
br,sitio joao lodatta,Sítio João Lodatta,18,,-25.795278,-49.714167
br,sitio joao lopata,Sítio João Lopata,18,,-26.020465,-49.746708
br,sitio joao lopes,Sítio João Lopes,18,,-23.5708,-49.8483
br,sitio joao lourenco,Sítio João Lourenço,18,,-25.992778,-49.688889
br,sitio joao luis,Sítio João Luís,18,,-23.751124,-50.139263
br,sitio joao machado,Sítio João Machado,18,,-23.6274,-49.9065
br,sitio joao makowicz,Sítio João Makowicz,18,,-25.9512,-49.3513
br,sitio joao malinoski,Sítio João Malinoski,18,,-25.8841,-49.0744
br,sitio joao marcomino,Sítio João Marcomino,18,,-23.783772,-50.30008
br,sitio joao maria brandao,Sítio João Maria Brandão,18,,-23.759979,-50.686307
br,sitio joao maria c. de melo,Sítio João Maria C. de Melo,18,,-25.959959,-49.901304
br,sitio joao maria de lima,Sítio João Maria de Lima,18,,-25.924894,-49.754451
br,sitio joao maria rodrigues,Sítio João Maria Rodrigues,18,,-23.962774,-50.856415
br,sitio joao maria,Sítio João Maria,18,,-23.948324,-50.355935
br,sitio joao marques,Sítio João Marques,18,,-23.543809,-50.216257
br,sitio joao martins,Sítio João Martins,18,,-23.1844,-50.1514
br,sitio joao mascareli,Sítio João Mascareli,18,,-23.455124,-49.837125
br,sitio joao mauro,Sítio João Mauro,18,,-23.696909,-50.083008
br,sitio joao m. camargo,Sítio João M. Camargo,18,,-23.749876,-50.591473
br,sitio joao m. cardoso,Sítio João M. Cardoso,18,,-25.974,-49.0461
br,sitio joao m. claudino,Sítio João M. Claudino,18,,-25.9315,-49.183
br,sitio joao m. da cruz,Sítio João M. da Cruz,18,,-23.5987,-49.7943
br,sitio joao m. da rosa,Sítio João M. da Rosa,18,,-23.720865,-50.170866
br,sitio joao m. da sao reis,Sítio João M. da São Reis,18,,-23.930394,-50.120636
br,sitio joao m. da silveira,Sítio João M. da Silveira,18,,-25.7982,-49.5979
br,sitio joao m. de lima,Sítio João M. de Lima,18,,-25.8735,-49.1024
br,sitio joao m. de oliveira,Sítio João M. de Oliveira,18,,-25.801599,-49.935374
br,sitio joao m. de siqueira,Sítio João M. de Siqueira,18,,-25.8137,-49.5518
br,sitio joao m. do a. alves,Sítio João M. do A. Alves,18,,-25.7928,-49.6078
br,sitio joao m. dos santos,Sítio João M. dos Santos,18,,-25.906111,-49.506111
br,sitio joao melo,Sítio João Melo,18,,-25.9966,-49.1636
br,sitio joao m. ferreira,Sítio João M. Ferreira,18,,-25.899167,-49.519722
br,sitio joao m. freitas,Sítio João M. Freitas,18,,-23.99377,-50.402389
br,sitio joao miestki,Sítio João Miestki,18,,-25.8383,-49.5801
br,sitio joao mika,Sítio João Mika,18,,-25.8449,-49.9585
br,sitio joao milane,Sítio João Milane,18,,-23.0216,-50.1953
br,sitio joao miranda da rocha,Sítio João Miranda da Rocha,18,,-25.836147,-48.787682
br,sitio joao m. machado,Sítio João M. Machado,18,,-25.9324,-49.483
br,sitio joao m. negrelle,Sítio João M. Negrelle,18,,-25.9002,-49.4377
br,sitio joao moises,Sítio João Moisés,18,,-23.857422,-50.461844
br,sitio joao mombini,Sítio João Mombini,18,,-25.977996,-48.832268
br,sitio joao moreira,Sítio João Moreira,18,,-23.6167,-49.8847
br,sitio joao moreira,Sítio João Moreira,26,,-26.1674,-49.9519
br,sitio joao m. p. e irmaos,Sítio João M. P. e Irmãos,18,,-26.135,-49.3877
br,sitio joao m. pinto,Sítio João M. Pinto,18,,-25.762222,-49.694444
br,sitio joao m. prado,Sítio João M. Prado,18,,-25.861,-49.5421
br,sitio joao m. rezende,Sítio João M. Rezende,18,,-25.9,-49.554167
br,sitio joao m. rodrigues,Sítio João M. Rodrigues,18,,-23.6361,-49.7714
br,sitio joao munhoz,Sítio João Munhoz,18,,-23.6822,-49.7918
br,sitio joao m. zaiontz,Sítio João M. Zaiontz,18,,-25.8972,-49.2971
br,sitio joao natalli,Sítio João Natalli,18,,-25.899,-49.3876
br,sitio joao nesr,Sítio João Nesr,18,,-25.931779,-49.850966
br,sitio joao novacosk,Sítio João Novacosk,18,,-25.896,-49.4334
br,sitio joao o. de oliveira,Sítio João O. de Oliveira,18,,-23.416255,-49.764999
br,sitio joao o. sampaio,Sítio João O. Sampaio,26,,-26.231126,-49.734299
br,sitio joao o. schroeder,Sítio João O. Schroeder,26,,-26.197697,-49.44002
br,sitio joao palhano,Sítio João Palhano,18,,-25.997852,-49.937871
br,sitio joao pavenik,Sítio João Pavenik,18,,-25.9545,-49.49
br,sitio joao p. barbosa,Sítio João P. Barbosa,18,,-25.8281,-49.2941
br,sitio joao p. da silva,Sítio João P. da Silva,18,,-25.8184,-49.3772
br,sitio joao p. de andrade,Sítio João P. de Andrade,18,,-25.862502,-48.985187
br,sitio joao p. do vale,Sítio João P. do Vale,18,,-25.8537,-49.171
br,sitio joao pedro a. costa,Sítio Joáo Pedro A. Costa,18,,-23.4481,-49.8485
br,sitio joao pedro de carvalho,Sítio João Pedro de Carvalho,15,,-22.5397,-45.643
br,sitio joao pedro filho,Sítio João Pedro Filho,18,,-23.746185,-50.17168
br,sitio joao pedro rodrigues,Sítio João Pedro Rodrigues,18,,-25.907154,-49.98597
br,sitio joao pedro,Sítio João Pedro,18,,-23.68292,-50.119907
br,sitio joao pereira de moraes,Sítio João Pereira de Moraes,18,,-23.8791,-50.9732
br,sitio joao pereira,Sítio João Pereira,18,,-23.784441,-50.049371
br,sitio joao peres,Sítio João Peres,18,,-23.1274,-50.1225
br,sitio joao peters,Sítio João Peters,26,,-26.2278,-49.955
br,sitio joao pinheiro paz,Sítio João Pinheiro Paz,18,,-25.7322,-49.9561
br,sitio joao pinheiro,Sítio João Pinheiro,18,,-25.7076,-49.7841
br,sitio joao pirachovoski,Sítio João Pirachovoski,18,,-25.9478,-49.4613
br,sitio joao pissakotto,Sítio João Pissakotto,18,,-23.724914,-50.663974
br,sitio joao p. junior,Sítio João P. Júnior,26,,-26.243648,-49.667196
br,sitio joao p. l. dos santos,Sítio João P. L. dos Santos,26,,-26.2003,-49.9478
br,sitio joao poleza,Sítio João Poleza,18,,-25.144748,-48.974454
br,sitio joao prestes,Sítio João Prestes,18,,-25.048073,-48.847586
br,sitio joao prucheski,Sítio João Prucheski,26,,-26.202,-49.3154
br,sitio joao przblovixz,Sítio João Przblovixz,18,,-25.7966,-49.5422
br,sitio joao pszebeuca,Sítio João Pszebeuca,18,,-25.8086,-49.5515
br,sitio joao p. tigre,Sítio João P. Tigre,18,,-23.5826,-49.8692
br,sitio joao p. v. filho,Sítio João P. V. Filho,18,,-23.1705,-50.0948
br,sitio joao radurski,Sítio João Radurski,18,,-26.0287,-49.7692
br,sitio joao ramiro,Sítio João Ramiro,26,,-26.1921,-49.9524
br,sitio joao r. batista,Sítio João R. Batista,18,,-25.9081,-49.4416
br,sitio joao r. cordeiro,Sítio João R. Cordeiro,18,,-25.957,-49.1226
br,sitio joao r. da silva,Sítio João R. da Silva,18,,-23.850276,-50.64836
br,sitio joao r. de carvalho,Sítio João R. de Carvalho,18,,-23.77484,-50.075797
br,sitio joao r. de lima,Sítio João R. de Lima,18,,-26.13825,-49.706202
br,sitio joao r. de souza,Sítio João R. de Souza,18,,-25.457605,-48.806558
br,sitio joao resende,Sítio João Resende,18,,-25.919167,-49.549444
br,sitio joao ribas,Sítio João Ribas,18,,-25.828611,-49.691667
br,sitio joao ribeiro,Sítio João Ribeiro,18,,-23.6774,-49.9095
br,sitio joao r. kuss,Sítio João R. Kuss,26,,-26.1593,-49.8802
br,sitio joao r. nascimento,Sítio João R. Nascimento,18,,-23.536945,-50.620434
br,sitio joao roberto bueno,Sítio João Roberto Bueno,18,,-23.992821,-50.625062
br,sitio joao roberto pires,Sítio João Roberto Pires,18,,-23.83266,-50.599078
br,sitio joao rocha de araujo,Sítio João Rocha de Araújo,18,,-23.632088,-50.214437
br,sitio joao rocha,Sítio João Rocha,18,,-25.091781,-48.894571
br,sitio joao rodrigues,Sítio João Rodrigues,18,,-23.1036,-50.0138
br,sitio joao rodrigues,Sítio João Rodrigues,26,,-26.236,-49.9182
br,sitio joao roque,Sítio João Roque,18,,-23.604443,-50.140757
br,sitio joao rosario,Sítio João Rosário,18,,-25.9173,-49.0953
br,sitio joao rua,Sítio João Rua,18,,-23.807393,-50.37585
br,sitio joao r. valente,Sítio João R. Valente,18,,-25.909038,-49.985714
br,sitio joao r. xavier,Sítio João R. Xavier,18,,-23.6279,-49.8656
br,sitio joao saiad,Sítio João Saiad,26,,-26.1754,-49.9162
br,sitio joao sampaio,Sítio João Sampaio,26,,-26.111,-49.9666
br,sitio joao schafhuzier,Sítio João Schafhuzier,18,,-25.900735,-49.970179
br,sitio joao schingo,Sítio João Schingo,18,,-26.011237,-49.693801
br,sitio joao s. da rocha,Sítio João S. da Rocha,18,,-26.008496,-49.482227
br,sitio joao s. dos santos,Sítio João S. dos Santos,18,,-23.987999,-50.507865
br,sitio joao serrano,Sítio João Serrano,18,,-23.0718,-50.1963
br,sitio joao s. filho,Sítio João S. Filho,26,,-26.1602,-49.9015
br,sitio joao silva,Sítio João Silva,18,,-26.080355,-49.630302
br,sitio joao silveira,Sítio João Silveira,18,,-25.922,-49.4619
br,sitio joao silverio,Sítio João Silvério,18,,-23.7318,-50.09531
br,sitio joao siqueira,Sítio João Siqueira,18,,-23.915563,-50.416212
br,sitio joao,Sítio João,18,,-23.800187,-50.299569
br,sitio joao soares,Sítio João Soares,18,,-23.954968,-50.412037
br,sitio joao sobrinho,Sítio João Sobrinho,18,,-23.682768,-50.059204
br,sitio joao soezzeki,Sítio João Soezzeki,18,,-25.9029,-49.032
br,sitio joao souza porto,Sítio João Souza Porto,18,,-23.1934,-50.1846
br,sitio joao souza,Sítio João Souza,18,,-25.4506,-48.7197
br,sitio joao stabach,Sítio João Stabach,18,,-25.855752,-49.931406
br,sitio joao stoki,Sítio João Stoki,26,,-26.1155,-49.9152
br,sitio joao stracke,Sítio João Stracke,18,,-26.032,-49.3817
br,sitio joao taioka,Sítio João Taioka,18,,-25.8031,-49.4821
br,sitio joao t. borges,Sítio João T. Borges,18,,-25.7593,-49.5205
br,sitio joao t. da rocha,Sítio João T. da Rocha,18,,-25.907,-49.1682
br,sitio joao t. da rosa,Sítio João T. da Rosa,18,,-25.061252,-48.751945
br,sitio joao t. de freitas,Sítio João T. de Freitas,18,,-25.9363,-49.3451
br,sitio joao teles,Sítio João Teles,18,,-23.440792,-49.822294
br,sitio joao teodoro,Sítio João Teodoro,18,,-23.6894,-49.8891
br,sitio joao tocha,Sítio João Tocha,18,,-25.8046,-49.2738
br,sitio joao t. pacheco,Sítio João T. Pacheco,18,,-25.6989,-49.8328
br,sitio joao trianovski,Sítio João Trianovski,18,,-25.7611,-49.533
br,sitio joao turck,Sítio João Turck,26,,-26.241081,-49.565779
br,sitio joao valikoski,Sítio João Valikoski,26,,-26.2175,-49.8462
br,sitio joao valoski,Sítio João Valoski,18,,-25.9155,-49.119
br,sitio joao v. costa,Sítio João V. Costa,18,,-23.6343,-49.7985
br,sitio joao veiga l. pinto,Sítio João Veiga L. Pinto,18,,-25.871926,-48.995586
br,sitio joao vicente,Sítio João Vicente,18,,-23.6315,-49.8403
br,sitio joao vida leal filho,Sítio João Vida Leal Filho,18,,-23.505089,-50.032873
br,sitio joao vitorino,Sítio João Vitorino,18,,-23.74,-50.217479
br,sitio joao vlublesk,Sítio João Vlublesk,18,,-25.754722,-49.620556
br,sitio joao votroba,Sítio João Votroba,18,,-26.095448,-49.724516
br,sitio joao waldir,Sítio João Waldir,18,,-23.2839,-49.7709
br,sitio joao willner,Sítio João Willner,26,,-26.1119,-49.9751
br,sitio joao xavier,Sítio João Xavier,18,,-23.488511,-50.016112
br,sitio joao zavilinsk,Sítio João Zavilinsk,18,,-26.0228,-49.7554
br,sitio joao zela,Sítio João Zela,18,,-25.6903,-49.8798
br,sitio joao zepechouk,Sítio João Zepechouk,18,,-25.8002,-49.334
br,sitio joao zonovelo,Sítio João Zonovelo,18,,-23.1691,-50.0855
br,sitio joao zpechauka,Sítio João Zpechauka,18,,-25.7629,-49.3857
br,sitio joao z. pilho,Sítio João Z. Pilho,18,,-25.7567,-49.3868
br,sitio joaquim abrantes,Sítio Joaquim Abrantes,18,,-23.25867,-50.193607
br,sitio joaquim a. de faria,Sítio Joaquim A. de Faria,18,,-23.889329,-50.294229
br,sitio joaquim alfer,Sítio Joaquim Alfer,18,,-23.947746,-50.055019
br,sitio joaquim antonio,Sítio Joaquim Antônio,18,,-23.8906,-50.9843
br,sitio joaquim a. r. neto,Sítio Joaquim A. R. Neto,18,,-25.981544,-49.033912
br,sitio joaquim azevedo,Sítio Joaquim Azevedo,18,,-23.510747,-50.219007
br,sitio joaquim baldoino,Sítio Joaquim Baldoino,18,,-23.946769,-50.456491
br,sitio joaquim batista,Sítio Joaquim Batista,18,,-25.8464,-49.1533
br,sitio joaquim b. camargo,Sítio Joaquim B. Camargo,18,,-26.0397,-49.404
br,sitio joaquim caetano,Sítio Joaquim Caetano,18,,-23.6457,-49.9637
br,sitio joaquim candido,Sítio Joaquim Cândido,18,,-23.377848,-50.097004
br,sitio joaquim cavalcante,Sítio Joaquim Cavalcante,18,,-25.444615,-48.807113
br,sitio joaquim c. batista,Sítio Joaquim C. Batista,18,,-25.812222,-49.648889
br,sitio joaquim c. de souza,Sítio Joaquim C. de Souza,18,,-23.628,-49.8178
br,sitio joaquim cordeiro,Sítio Joaquim Cordeiro,18,,-25.9547,-49.232756
br,sitio joaquim custodio filho,Sítio Joaquim Custódio Filho,18,,-23.633202,-50.19721
br,sitio joaquim da silva,Sítio Joaquim da Silva,18,,-23.823832,-50.143256
br,sitio joaquim d. da silva,Sítio Joaquim D. da Silva,18,,-23.6115,-49.7865
br,sitio joaquim de assis,Sítio Joaquim de Assis,18,,-23.941265,-50.076459
br,sitio joaquim de o. franco,Sítio Joaquim de O. Franco,18,,-25.5124,-49.9837
br,sitio joaquim de paula,Sítio Joaquim de Paula,18,,-23.768191,-50.018932
br,sitio joaquim do prado,Sítio Joaquim do Prado,18,,-23.5449,-49.7564
br,sitio joaquim f. de melo,Sítio Joaquim F. de Melo,18,,-23.983582,-50.453679
br,sitio joaquim ferraz,Sítio Joaquim Ferraz,18,,-26.0595,-49.2574
br,sitio joaquim firmino,Sítio Joaquim Firmino,18,,-23.338439,-50.054399
br,sitio joaquim florence,Sítio Joaquim Florence,18,,-25.8449,-48.5714
br,sitio joaquim gabriel,Sítio Joaquim Gabriel,18,,-23.470766,-49.948583
br,sitio joaquim galvao,Sítio Joaquim Galvão,18,,-23.98764,-50.397499
br,sitio joaquim gomes,Sítio Joaquim Gomes,18,,-23.8565,-50.8237
br,sitio joaquim goncalves,Sítio Joaquim Gonçalves,18,,-23.5765,-49.8446
br,sitio joaquim gordo,Sítio Joaquim Gordo,18,,-23.6266,-49.7658
br,sitio joaquim inacio,Sítio Joaquim Inácio,18,,-23.7082,-49.813
br,sitio joaquim inocencio,Sítio Joaquim Inocêncio,18,,-23.6733,-49.9109
br,sitio joaquim j. dos santos,Sítio Joaquim J. dos Santos,18,,-23.53042,-50.728482
br,sitio joaquim jeronimo,Sítio Joaquim Jerônimo,18,,-23.6408,-49.7985
br,sitio joaquim liberdade batista,Sítio Joaquím Liberdade Batista,18,,-25.6047,-48.8066
br,sitio joaquim l. simoes,Sítio Joaquim L. Simões,18,,-23.5729,-49.8089
br,sitio joaquim m. alves,Sítio Joaquim M. Alves,18,,-25.8746,-49.1816
br,sitio joaquim marciano,Sítio Joaquim Marciano,18,,-23.5878,-49.8662
br,sitio joaquim m. da rocha,Sítio Joaquim M. da Rocha,18,,-25.937633,-49.218993
br,sitio joaquim m. de carvalho,Sítio Joaquim M. de Carvalho,18,,-23.6463,-49.9297
br,sitio joaquim m. de mello,Sítio Joaquim M. de Mello,18,,-23.6863,-49.9796
br,sitio joaquim n. silveira,Sítio Joaquim N. Silveira,18,,-25.8616,-49.6038
br,sitio joaquim pereira,Sítio Joaquim Pereira,18,,-23.6765,-49.7807
br,sitio joaquim pires,Sítio Joaquim Pires,18,,-25.9987,-49.4282
br,sitio joaquim prado,Sítio Joaquim Prado,18,,-23.6913,-49.7545
br,sitio joaquim p. silva,Sítio Joaquim P. Silva,18,,-23.925111,-50.220177
br,sitio joaquim p. vidal,Sítio Joaquim P. Vidal,18,,-23.6894,-49.9537
br,sitio joaquim r. de freitas,Sítio Joaquim R. de Freitas,18,,-23.6798,-49.756
br,sitio joaquim rodrigues dos santos,Sítio Joaquim Rodrigues dos Santos,18,,-23.935141,-50.501896
br,sitio joaquim sabiao,Sítio Joaquim Sabião,18,,-23.38197,-50.211057
br,sitio joaquim samuel,Sítio Joaquim Samuel,18,,-23.4271,-49.8505
br,sitio joaquim serpa galvao,Sítio Joaquim Serpa Galvão,15,,-22.5591,-45.6207
br,sitio joaquim,Sítio Joaquim,18,,-23.741877,-50.171204
br,sitio joaquim s. neto,Sítio Joaquim S. Neto,18,,-23.892619,-50.164103
br,sitio joaquim tazico,Sítio Joaquim Tazico,18,,-23.6431,-49.7797
br,sitio joaquim t. de carvalho,Sítio Joaquim T. de Carvalho,18,,-26.20406,-49.566536
br,sitio joaquim thomaz,Sítio Joaquim Thomaz,18,,-23.769744,-50.196508
br,sitio joaquim ventura,Sítio Joaquim Ventura,18,,-23.931548,-50.501801
br,sitio joaquim vicente,Sítio Joaquim Vicente,18,,-23.5781,-50.6142
br,sitio joaquim v. menon,Sítio Joaquim V. Menon,18,,-25.889444,-49.683611
br,sitio joaquim wanderlei,Sítio Joaquim Wanderlei,18,,-23.911956,-50.449759
br,sitio joel campanhole,Sítio Joel Campanhole,18,,-25.908056,-49.685556
br,sitio joel cardoso,Sítio Joel Cardoso,18,,-23.801668,-50.002603
br,sitio joel menemberg,Sítio Joel Menemberg,18,,-25.827655,-49.911178
br,sitio joel rodrigues,Sítio Joel Rodrigues,18,,-25.5518,-49.9358
br,sitio joia,Sítio Jóia,18,,-23.7275,-49.7888
br,sitio joia,Sítio Jóia,27,,-23.610672,-47.194904
br,sitio joinville,Sítio Joinville,27,,-23.532193,-47.012445
br,sitio jordao schifel,Sítio Jordão Schifel,26,,-26.239654,-49.713522
br,sitio jorge alves,Sítio Jorge Alves,18,,-26.186097,-49.595871
br,sitio jorge antonio,Sítio Jorge Antônio,18,,-25.9859,-49.4626
br,sitio jorge arruda,Sítio Jorge Arruda,18,,-23.6654,-49.9082
br,sitio jorge bandeira chaves,Sítio Jorge Bandeira Chaves,18,,-25.111837,-48.803642
br,sitio jorge bento,Sítio Jorge Bento,18,,-23.6457,-49.8637
br,sitio jorge bischeski,Sítio Jorge Bischeski,26,,-26.0552,-49.9873
br,sitio jorge b. paula,Sítio Jorge B. Paula,18,,-25.818611,-49.64
br,sitio jorge cassu,Sítio Jorge Cassu,18,,-25.5015,-49.9144
br,sitio jorge c. de oliviera,Sítio Jorge C. de Oliviera,18,,-23.6998,-49.8346
br,sitio jorge celvsniacki,Sítio Jorge Celvsniacki,18,,-26.0088,-49.826
br,sitio jorge chaves,Sítio Jorge Chaves,18,,-25.124143,-48.897821
br,sitio jorge croste,Sítio Jorge Croste,18,,-25.932005,-49.81179
br,sitio jorge de carvalho,Sítio Jorge de Carvalho,18,,-25.8374,-49.2204
br,sitio jorge de lima,Sítio Jorge de Lima,18,,-25.9502,-49.2065
br,sitio jorge de l. mendes,Sítio Jorge de L. Mendes,18,,-25.8157,-49.5062
br,sitio jorge dencki,Sítio Jorge Dencki,18,,-26.1376,-49.4704
br,sitio jorge denki,Sítio Jorge Denki,18,,-26.121787,-49.639957
br,sitio jorge domingos de lima,Sítio Jorge Domingos de Lima,18,,-23.706385,-50.237948
br,sitio jorge domingues,Sítio Jorge Domingues,18,,-23.615937,-50.083364
br,sitio jorge do r. cruz,Sítio Jorge do R. Cruz,18,,-25.906627,-49.090523
br,sitio jorge dos santos,Sítio Jorge dos Santos,18,,-25.923545,-49.993117
br,sitio jorge do vale,Sítio Jorge do Vale,18,,-23.6663,-49.987
br,sitio jorge f. de paula,Sítio Jorge F. de Paula,18,,-25.8397,-49.0459
br,sitio jorge f. dos santos,Sítio Jorge F. dos Santos,18,,-25.8813,-49.0669
br,sitio jorge ferreira,Sítio Jorge Ferreira,18,,-23.95724,-50.0145
br,sitio jorge figueiredo,Sítio Jorge Figueiredo,18,,-23.563691,-50.540837
br,sitio jorge forina,Sítio Jorge Forina,18,,-25.8651,-49.5203
br,sitio jorge garaiani,Sítio Jorge Garaiani,18,,-23.499379,-49.944984
br,sitio jorge garanhane,Sítio Jorge Garanhane,18,,-23.6614,-49.8981
br,sitio jorge gogola,Sítio Jorge Gogola,18,,-25.8185,-49.6107
br,sitio jorge goncalves,Sítio Jorge Gonçalves,18,,-23.6114,-49.9724
br,sitio jorge halaiko,Sítio Jorge Halaiko,18,,-25.7331,-49.8005
br,sitio jorge honorato,Sítio Jorge Honorato,18,,-23.6217,-49.8798
br,sitio jorge lechinski,Sítio Jorge Lechinski,18,,-25.991616,-49.771223
br,sitio jorge m. cardoso,Sítio Jorge M. Cardoso,18,,-25.9852,-49.4114
br,sitio jorge m. de andrade,Sítio Jorge M. de Andrade,18,,-25.9987,-49.0632
br,sitio jorge m. de carvalho,Sítio Jorge M. de Carvalho,18,,-23.634,-49.9236
br,sitio jorge mikus,Sítio Jorge Mikus,18,,-26.0009,-49.3128
br,sitio jorge nakamura,Sítio Jorge Nakamura,18,,-23.528297,-50.661586
br,sitio jorge nakaw,Sítio Jorge Nakaw,18,,-23.906655,-50.335888
br,sitio jorge norato,Sítio Jorge Norato,18,,-23.644432,-49.878154
br,sitio jorge peters,Sítio Jorge Peters,26,,-26.2309,-49.9544
br,sitio jorge pinto,Sítio Jorge Pinto,18,,-25.7087,-49.7998
br,sitio jorge ribeiro,Sítio Jorge Ribeiro,18,,-23.92289,-50.564112
br,sitio jorger maurer,Sítio Jorger Maurer,18,,-25.943826,-49.987591
br,sitio jorge sanao,Sítio Jorge Sanão,18,,-23.0006,-50.0131
br,sitio jorge silsk,Sítio Jorge Silsk,18,,-25.7959,-49.5555
br,sitio jorge,Sítio Jorge,18,,-23.873609,-50.409282
br,sitio jorge strugal,Sítio Jorge Strugal,18,,-25.7566,-49.485
br,sitio jorge takassuma,Sítio Jorge Takassuma,18,,-23.7229,-50.674778
br,sitio jorge willner,Sítio Jorge Willner,26,,-26.1091,-49.981
br,sitio jorge yto,Sítio Jorge Yto,18,,-25.858823,-48.787754
br,sitio jorvino p. da silva,Sítio Jorvino P. da Silva,18,,-23.750436,-50.053351
br,sitio jose a. andre,Sítio José A. André,18,,-23.989111,-50.437128
br,sitio jose a. borges,Sítio José A. Borges,18,,-25.861,-49.0269
br,sitio jose a. bueno,Sítio José A. Bueno,18,,-25.9867,-49.06
br,sitio jose a. camargo,Sítio José A. Camargo,18,,-25.9194,-49.2274
br,sitio jose a. c. lopes,Sítio José A. C. Lopes,18,,-25.8603,-49.3291
br,sitio jose a. correia,Sítio José A. Correia,18,,-26.0322,-49.8665
br,sitio jose a. da silva,Sítio José A. da Silva,18,,-23.6185,-49.9026
br,sitio jose a da silva,Sítio José A da Silva,18,,-23.70818,-50.021824
br,sitio jose a. da silva,Sítio José A. da Silva,18,,-26.0106,-49.3993
br,sitio jose a. de almeida,Sítio José A. de Almeida,18,,-23.911793,-50.238862
br,sitio jose a. de azevedo,Sítio José A. de Azevedo,18,,-23.93574,-50.081168
br,sitio jose a. de lima,Sítio José A. de Lima,18,,-25.9493,-49.3466
br,sitio jose a. de morais,Sítio José A. de Morais,18,,-23.890393,-50.020345
br,sitio jose a. de oliveira,Sítio José A. de Oliveira,18,,-23.996563,-50.434761
br,sitio jose agostinho camilo,Sítio José Agostinho Camilo,18,,-25.5798,-49.9485
br,sitio jose aguiar,Sítio José Aguiar,18,,-23.327381,-49.80256
br,sitio jose airton c. de lima,Sítio José Airton C. de Lima,18,,-25.845859,-49.902843
br,sitio jose albano,Sítio José Albano,18,,-25.5044,-48.8565
br,sitio jose alberto fantin,Sítio José Alberto Fantin,18,,-25.6929,-49.9901
br,sitio jose albino,Sítio José Albino,18,,-23.95243,-50.417984
br,sitio jose alceu fantin,Sítio José Alceu Fantin,18,,-25.7968,-49.9547
br,sitio jose a. leite,Sítio José A. Leite,27,,-23.741928,-47.504097
br,sitio jose alfredo,Sítio José Alfredo,18,,-23.935012,-50.183779
br,sitio jose alildo,Sítio José Alildo,18,,-26.152797,-49.588096
br,sitio jose alisk,Sítio José Alisk,18,,-25.8439,-49.3047
br,sitio jose altair,Sítio José Altair,18,,-25.9811,-49.1731
br,sitio jose a. lustosa,Sítio José A. Lustosa,18,,-25.9712,-49.2405
br,sitio jose alves,Sítio José Alves,18,,-23.8996,-50.073917
br,sitio jose a. mano,Sítio José A. Mano,18,,-23.0037,-50.0108
br,sitio jose a. marques,Sítio José A. Marqués,18,,-25.8073,-49.3366
br,sitio jose andre,Sítio José André,18,,-23.455804,-49.816419
br,sitio jose anselmo,Sítio José Anselmo,18,,-23.955744,-50.612232
br,sitio jose antonio hammerschmidt,Sítio José Antônio Hammerschmidt,18,,-25.919672,-49.818047
br,sitio jose antonio,Sítio José Antônio,18,,-23.232853,-49.885703
br,sitio jose antunes,Sítio José Antunes,18,,-23.7015,-49.9783
br,sitio jose aparecido marquiena,Sítio José Aparecido Marquiena,18,,-23.1137,-50.2481
br,sitio jose a. p. de lima,Sítio José A. P. de Lima,18,,-25.908033,-49.099264
br,sitio jose a. pereira,Sítio José A. Pereira,18,,-23.6845,-49.9047
br,sitio jose araujo,Sítio José Araújo,18,,-23.5051,-49.8589
br,sitio jose ari maia,Sítio José Ari Maia,18,,-25.834652,-49.949153
br,sitio jose a. rodrigues,Sítio José A. Rodrigues,18,,-23.6355,-49.9531
br,sitio jose a. schifel,Sítio José A. Schifel,26,,-26.237523,-49.714852
br,sitio jose a. seixas,Sítio José A. Seixas,18,,-25.8912,-49.5565
br,sitio jose a. tavares,Sítio José A. Tavares,18,,-23.771284,-50.224608
br,sitio jose a. teixeira,Sítio José A. Teixeira,18,,-23.7446,-49.9352
br,sitio jose auersvaldt,Sítio José Auersvaldt,26,,-26.0978,-49.9258
br,sitio jose augusto,Sítio José Augusto,18,,-23.1388,-50.1788
br,sitio jose a. vandosch,Sítio José A. Vandosch,18,,-25.874722,-49.651111
br,sitio jose azevedo,Sítio José Azevedo,18,,-23.954947,-50.059457
br,sitio jose baiano,Sítio José Baiano,18,,-23.886716,-50.29653
br,sitio jose bandeira santos,Sítio José Bandeira Santos,18,,-25.074192,-48.963587
br,sitio jose bandeira,Sítio José Bandeira,18,,-23.7132,-49.8563
br,sitio jose barao,Sítio José Barão,18,,-25.8148,-49.4475
br,sitio jose barbosa,Sítio José Barbosa,18,,-23.274785,-50.148779
br,sitio jose batista,Sítio José Batista,18,,-23.742994,-50.00905
br,sitio jose bayo,Sítio José Bayo,26,,-26.244,-49.4102
br,sitio jose b. de castro,Sítio José B. de Castro,18,,-23.469234,-49.776546
br,sitio jose b. dos santos,Sítio José B. dos Santos,18,,-25.148131,-48.85781
br,sitio jose benedito,Sítio José Benedito,18,,-23.721582,-50.03713
br,sitio jose benedito soares,Sítio José Benedito Soares,18,,-25.908008,-49.932348
br,sitio jose bento pole,Sítio José Bento Pole,18,,-23.9451,-50.9139
br,sitio jose bento,Sítio José Bento,18,,-26.085879,-49.693677
br,sitio jose bernardo,Sítio José Bernardo,18,,-23.726057,-50.019668
br,sitio jose berniak,Sítio José Berniak,18,,-25.8614,-49.5699
br,sitio jose bernini,Sítio José Bernini,18,,-23.7715,-50.3053
br,sitio jose bertoldo,Sítio José Bertoldo,18,,-23.892724,-50.090502
br,sitio jose b. filho,Sítio José B. Filho,18,,-23.5445,-49.8654
br,sitio jose bichesk,Sítio José Bichesk,26,,-26.0328,-49.9964
br,sitio jose bill,Sítio José Bill,18,,-25.805,-49.652222
br,sitio jose blaszkvyovwrsy,Sítio José Blaszkvyovwrsy,26,,-26.1065,-49.2584
br,sitio jose boava,Sítio José Boava,18,,-23.715,-49.8292
br,sitio jose bockne,Sítio José Bockne,18,,-25.943333,-49.535833
br,sitio jose bonifacio da silva,Sítio José Bonifácio da Silva,18,,-23.875215,-50.572278
br,sitio jose borges,Sítio José Borges,18,,-23.802062,-50.018341
br,sitio jose botrova,Sítio José Botrova,18,,-26.174159,-49.547804
br,sitio jose b. p. machado,Sítio José B. P. Machado,18,,-25.9327,-49.2678
br,sitio jose bucco,Sítio José Bucco,18,,-25.878099,-49.232226
br,sitio jose burkt,Sítio José Burkt,18,,-26.005,-49.7867
br,sitio jose cabiuna,Sítio José Cabiúna,18,,-23.6201,-49.8027
br,sitio jose cabral,Sítio José Cabral,18,,-23.911502,-50.496321
br,sitio jose caetano,Sítio José Caetano,18,,-25.9952,-49.2147
br,sitio jose calil,Sítio José Calil,18,,-23.5783,-49.7815
br,sitio jose camargo,Sítio José Camargo,18,,-25.206095,-48.972931
br,sitio jose candido da silva,Sítio José Cândido da Silva,15,,-22.5924,-45.6427
br,sitio jose candido,Sítio José Cândido,18,,-23.6993,-49.8037
br,sitio jose cantana,Sítio José Cantana,18,,-23.720461,-50.077646
br,sitio jose carax,Sítio José Carax,18,,-25.965833,-49.5175
br,sitio jose carazava,Sítio José Carazava,18,,-25.8519,-49.4416
br,sitio jose cardoso amora,Sítio José Cardoso Amora,18,,-23.671404,-50.1167
br,sitio jose cardoso,Sítio José Cardoso,18,,-23.69549,-50.100835
br,sitio jose carlos aciga nascimento,Sítio José Carlos Áciga Nascimento,18,,-25.8932,-48.72
br,sitio jose carlos de souza,Sítio José Carlos de Souza,18,,-23.679018,-50.106791
br,sitio jose carlos,Sítio José Carlos,18,,-23.742136,-50.165948
br,sitio jose carneiro,Sítio José Carneiro,18,,-25.6467,-49.9742
br,sitio jose carpinski,Sítio José Carpinski,18,,-25.878,-49.6138
br,sitio jose carvalho de almeida,Sítio José Carvalho de Almeida,18,,-23.703535,-50.076418
br,sitio jose carvalho dos santos,Sítio José Carvalho dos Santos,27,,-25.060758,-48.555174
br,sitio jose carvalho,Sítio José Carvalho,26,,-26.2379,-49.9338
br,sitio jose casanosch,Sítio José Casanosch,18,,-25.759424,-49.48549
br,sitio jose castanheira,Sítio José Castanheira,18,,-23.736934,-50.041613
br,sitio jose castilho,Sítio José Castilho,18,,-23.481033,-49.818639
br,sitio jose c. bail,Sítio José C. Bail,26,,-26.1964,-49.4316
br,sitio jose c. da silva,Sítio José C. da Silva,18,,-23.851275,-50.645959
br,sitio jose c. de araujo,Sítio José C. de Araújo,18,,-25.233263,-48.284351
br,sitio jose c. de azevedo,Sítio José C. de Azevedo,18,,-23.6697,-49.8434
br,sitio jose c. de gouveia,Sítio José C. de Gouveia,18,,-23.6075,-49.8899
br,sitio jose c. de lima,Sítio José C. de Lima,18,,-23.7452,-50.657
br,sitio jose c. de oliveira,Sítio José C. de Oliveira,18,,-23.5215,-49.7549
br,sitio jose c. dutra,Sítio José C. Dutra,18,,-23.6242,-49.8363
br,sitio jose c. junior,Sítio José C. Júnior,18,,-25.825016,-48.756726
br,sitio jose c. mainard,Sítio José C. Mainard,18,,-23.7408,-49.8921
br,sitio jose c. mendes,Sítio José C. Mendes,18,,-25.8021,-49.6062
br,sitio jose c. moriera,Sítio José C. Moriera,18,,-23.5702,-49.7781
br,sitio jose c. neto,Sítio José C. Neto,18,,-23.926848,-50.280947
br,sitio jose c. n. serafim,Sítio José C. N. Serafim,18,,-26.1377,-49.416
br,sitio jose conte,Sítio José Conte,18,,-25.973726,-48.837327
br,sitio jose corasso,Sítio José Corasso,18,,-23.157389,-49.931923
br,sitio jose cordeiro da cruz,Sítio José Cordeiro da Cruz,18,,-25.072288,-48.829322
br,sitio jose correa,Sítio José Correa,18,,-25.785,-49.721667
br,sitio jose correira,Sítio José Correira,18,,-23.717,-49.9304
br,sitio jose costa,Sítio José Costa,26,,-26.2164,-49.9435
br,sitio jose cotevski,Sítio José Cotevski,18,,-25.858127,-49.957705
br,sitio jose c. pereira,Sítio José C. Pereira,18,,-23.912664,-50.165614
br,sitio jose c. sobrinho,Sítio José C. Sobrinho,26,,-26.203838,-49.961804
br,sitio jose cunha,Sítio José Cunha,18,,-23.845113,-50.586484
br,sitio jose custodio,Sítio José Custódio,18,,-23.7096,-49.8019
br,sitio jose c. v. dias,Sítio José C. V. Dias,18,,-25.7817,-49.6622
br,sitio jose da l. peters,Sítio José da L. Peters,26,,-26.189,-49.9917
br,sitio jose damico,Sítio José Damico,18,,-23.62495,-50.109183
br,sitio jose da sao passos,Sítio José da São Passos,18,,-23.7355,-49.9829
br,sitio jose da silva,Sítio José da Silva,18,,-23.958202,-50.048328
br,sitio jose d. carvalho,Sítio José D. Carvalho,18,,-25.7544,-49.1736
br,sitio jose d. da rocha,Sítio José D. da Rocha,18,,-25.872712,-49.187959
br,sitio jose de carvalho,Sítio José de Carvalho,18,,-23.6107,-49.7813
br,sitio jose de castro,Sítio José de Castro,18,,-23.6279,-50.200604
br,sitio jose de c. filho,Sítio José de C. Filho,18,,-23.6089,-49.8045
br,sitio jose de freitas,Sítio José de Freitas,18,,-23.1365,-50.1788
br,sitio jose de lima,Sítio José de Lima,18,,-26.177933,-49.650209
br,sitio jose de paula bueno,Sítio José de Paula Bueno,18,,-25.796443,-49.876386
br,sitio jose de paula,Sítio José de Paula,18,,-23.848659,-50.109387
br,sitio jose de s. filho,Sítio José de S. Filho,18,,-23.6266,-49.9174
br,sitio jose de s. vieira,Sítio José de S. Vieira,18,,-25.9066,-49.4266
br,sitio jose d. filho,Sítio José D. Filho,18,,-23.6001,-49.8536
br,sitio jose d. mello,Sítio José D. Mello,18,,-23.938286,-50.240169
br,sitio jose d. moura,Sítio José D. Moura,26,,-26.1497,-49.8826
br,sitio jose do carmo,Sítio José do Carmo,18,,-23.6228,-49.9489
br,sitio jose do marco,Sítio José do Marco,18,,-23.780128,-50.247124
br,sitio jose domingos,Sítio José Domingos,18,,-23.276852,-49.986196
br,sitio jose domingues,Sítio José Domingues,18,,-25.317818,-48.928744
br,sitio jose dos santos,Sítio José dos Santos,18,,-23.914822,-50.243781
br,sitio jose dos s. martins,Sítio José dos S. Martins,18,,-25.897611,-49.980749
br,sitio jose dos s. silveira,Sítio José dos S. Silveira,18,,-25.7626,-49.5964
br,sitio jose d. palmas,Sítio José D. Palmas,18,,-23.5395,-49.753
br,sitio jose d. piques,Sítio José D. Piques,26,,-26.2292,-49.7528
br,sitio jose dranka,Sítio José Dranka,18,,-25.7682,-49.4375
br,sitio jose dranka,Sítio José Dranka,26,,-26.1258,-49.3247
br,sitio jose d. zignani,Sítio José D. Zignani,18,,-23.867714,-50.035777
br,sitio jose e. da cunha,Sítio José E. da Cunha,18,,-23.711,-49.9524
br,sitio jose e. da silva,Sítio José E. da Silva,18,,-23.6652,-49.8972
br,sitio jose e. de assis,Sítio José E. de Assis,18,,-25.8651,-49.3373
br,sitio josefa assuncao,Sítio Josefa Assunção,18,,-25.784736,-49.782409
br,sitio josefa sabatike,Sítio Josefa Sabatike,18,,-26.006,-49.9331
br,sitio jose f damaceno,Sítio José F Damaceno,18,,-23.398972,-50.122489
br,sitio jose f. de deus,Sítio José F. de Deus,18,,-25.8786,-49.5263
br,sitio jose f. de lima,Sítio José F. de Lima,18,,-25.968333,-49.737222
br,sitio jose f. dos reis,Sítio José F. dos Reis,18,,-25.9073,-49.0998
br,sitio jose feliciano,Sítio José Feliciano,18,,-23.6216,-49.9166
br,sitio jose felipe,Sítio José Felipe,18,,-23.6929,-49.8185
br,sitio jose felisberto,Sítio José Felisberto,18,,-23.911561,-50.300021
br,sitio jose fernandes,Sítio José Fernandes,18,,-23.158513,-49.827061
br,sitio jose ferreira de melo,Sítio José Ferreira de Melo,18,,-23.1196,-50.2384
br,sitio jose ferreira,Sítio José Ferreira,18,,-26.0196,-49.2605
br,sitio jose f. gordo,Sítio José F. Gordo,18,,-23.6157,-49.759
br,sitio jose fiates,Sítio José Fiates,18,,-23.6333,-49.8705
br,sitio jose fidelis de miranda,Sítio José Fidélis de Miranda,18,,-23.377789,-50.11128
br,sitio jose firtz,Sítio José Firtz,18,,-23.6976,-49.8272
br,sitio jose fleischmann,Sítio José Fleischmann,18,,-26.1598,-49.429
br,sitio jose f. martins,Sítio José F. Martins,18,,-25.841437,-49.993012
br,sitio jose f. muniz,Sítio José F. Muniz,18,,-25.896389,-49.549167
br,sitio jose fogaca,Sítio José Fogaça,18,,-23.6121,-49.7975
br,sitio josef pronko,Sítio Josef Pronko,18,,-23.7001,-49.9704
br,sitio jose galvao,Sítio José Galvão,18,,-23.3747,-50.0467
br,sitio jose g. da cruz,Sítio José G. da Cruz,18,,-25.8918,-49.343
br,sitio jose g. da silva,Sítio José G. da Silva,18,,-23.7059,-49.827
br,sitio jose g. de oliveira,Sítio José G. de Oliveira,18,,-23.7165,-49.9496
br,sitio jose g. dos santos,Sítio José G. dos Santos,18,,-25.202534,-48.982836
br,sitio jose g. filho,Sítio José G. Filho,18,,-23.9012,-50.451181
br,sitio jose gigovski,Sítio José Gigovski,18,,-26.08271,-49.526187
br,sitio jose g. nardo,Sítio José G. Nardo,26,,-26.248951,-49.712551
br,sitio jose godoy,Sítio José Godoy,18,,-23.435572,-50.08536
br,sitio jose gogola,Sítio José Gogola,18,,-25.931194,-49.939329
br,sitio jose goiano,Sítio José Goiano,18,,-23.6934,-49.9629
br,sitio jose gois,Sítio José Góis,18,,-23.532743,-50.74908
br,sitio jose gomes,Sítio José Gomes,18,,-23.49863,-49.858325
br,sitio jose goncalves da costa,Sítio José Gonçalves da Costa,18,,-23.0184,-50.1406
br,sitio jose haid,Sítio José Haid,26,,-26.1066,-49.8904
br,sitio jose hanig,Sítio José Hanig,18,,-25.948057,-49.811609
br,sitio jose hening,Sítio José Hening,18,,-25.997964,-49.940037
br,sitio jose hinguiskiu,Sítio José Hinguiskiu,18,,-25.979071,-49.833554
br,sitio jose hoffmann,Sítio José Hoffmann,18,,-25.7584,-49.699
br,sitio jose hommilgin,Sítio José Hommilgin,26,,-26.242,-49.4504
br,sitio jose h. pedro,Sítio José H. Pedro,18,,-25.7226,-49.8006
br,sitio jose hugo,Sítio José Hugo,18,,-23.5906,-49.8322
br,sitio jose i. da silva,Sítio José I. da Silva,18,,-23.99438,-50.439405
br,sitio jose idazil de castro,Sítio José Idazil de Castro,18,,-23.531745,-50.619109
br,sitio jose inacio,Sítio José Inácio,18,,-23.749672,-50.161254
br,sitio jose ingomar,Sítio José Ingomar,18,,-26.141442,-49.537529
br,sitio jose inneu,Sítio José Inneu,18,,-23.847901,-50.133105
br,sitio jose irineu,Sítio José Irineu,18,,-26.182027,-49.601732
br,sitio jose isaias,Sítio José Isaías,18,,-23.6117,-49.776
br,sitio jose itelac,Sítio José Itelac,18,,-25.8795,-49.5776
br,sitio jose ivaldo rocha,Sítio José Ivaldo Rocha,18,,-25.954356,-49.181173
br,sitio jose jair fantin,Sítio José Jair Fantin,18,,-25.7086,-49.9653
br,sitio jose j. de gouveia,Sítio José J. de Gouveia,18,,-23.65,-49.9075
br,sitio jose jelinski,Sítio José Jelinski,26,,-26.1486,-49.8487
br,sitio jose jesus dias,Sítio José Jesus Dias,18,,-25.82675,-49.940244
br,sitio jose j. kunopka,Sítio José J. Kunopka,26,,-26.169,-49.3191
br,sitio jose joao l. de souza,Sítio José João L. de Souza,18,,-25.986,-49.3606
br,sitio jose joceareli,Sítio José Joceareli,18,,-23.0689,-50.1358
br,sitio jose j. pereira,Sítio José J. Pereira,18,,-25.9195,-49.3316
br,sitio jose j. pimentel,Sítio José J. Pimentel,18,,-25.456611,-48.818933
br,sitio jose j. sene,Sítio José J. Sene,18,,-23.7134,-49.8028
br,sitio jose junqueira dos reis,Sítio José Junqueira dos Reis,18,,-23.0135,-50.1822
br,sitio jose jusviacky,Sítio José Jusviacky,26,,-26.218191,-49.71381
br,sitio jose kmeick,Sítio José Kmeick,18,,-25.953056,-49.525833
br,sitio jose kovausque,Sítio José Kovausque,18,,-25.5774,-49.9982
br,sitio jose krol,Sítio José Krol,26,,-26.1493,-49.9138
br,sitio jose kruk,Sítio José Kruk,18,,-25.8251,-49.4693
br,sitio jose k. taborda,Sítio José K. Taborda,18,,-26.191922,-49.562113
br,sitio jose kuca,Sítio José Kuca,26,,-26.0877,-49.9183
br,sitio jose k. vuce,Sítio José K. Vuce,18,,-25.8289,-49.3896
br,sitio jose lacosk,Sítio José Lacosk,18,,-25.8445,-49.3202
br,sitio jose ladir,Sítio José Ladir,26,,-26.1099,-49.2922
br,sitio jose l. alves,Sítio José L. Alves,18,,-23.6282,-49.8933
br,sitio jose latocheski,Sítio José Latocheski,26,,-26.1869,-49.8191
br,sitio jose lazaro,Sítio José Lázaro,18,,-23.5482,-49.7526
br,sitio jose l. bras,Sítio José L. Brás,18,,-23.870994,-50.303461
br,sitio jose l. cione,Sítio José L. Cione,18,,-25.8301,-48.5785
br,sitio jose l. da fonseca,Sítio José L. da Fonseca,18,,-25.916056,-49.986099
br,sitio jose l. da rocha,Sítio José L. da Rocha,18,,-25.8818,-49.3015
br,sitio jose l. de lima,Sítio José L. de Lima,18,,-25.9427,-49.4011
br,sitio jose l. de mello,Sítio José L. de Mello,18,,-25.9128,-49.3406
br,sitio jose l. de moura,Sítio José L. de Moura,18,,-23.853565,-50.229183
br,sitio jose l. de oliveira,Sítio José L. de Oliveira,18,,-23.916132,-50.403061
br,sitio jose leite,Sítio José Leite,18,,-23.46701,-49.985071
br,sitio jose l. entrauto,Sítio José L. Entrauto,18,,-25.8949,-48.7147
br,sitio jose leshinoski,Sítio José Leshinoski,18,,-25.902778,-49.546944
br,sitio jose liebl,Sítio José Liebl,18,,-26.054,-49.4427
br,sitio jose lopes,Sítio José Lopes,18,,-23.691836,-50.069647
br,sitio jose lourenco,Sítio José Lourenço,18,,-26.0016,-49.9835
br,sitio jose louzado,Sítio José Louzado,18,,-23.268953,-50.171949
br,sitio jose l. pickisius,Sítio José L. Pickisius,26,,-26.245078,-49.7379
br,sitio jose l. taborda,Sítio José L. Taborda,18,,-26.203084,-49.562826
br,sitio jose l. wagner,Sítio José L. Wagner,18,,-26.161669,-49.565504
br,sitio jose machado,Sítio José Machado,26,,-26.1827,-49.3122
br,sitio jose maria amarante,Sítio José Maria Amarante,18,,-25.7282,-49.861
br,sitio jose maria bonruque,Sítio José Maria Bonruque,27,,-24.792,-48.454
br,sitio jose maria rodrigues,Sítio José Maria Rodrigues,18,,-25.907273,-49.93323
br,sitio jose maria,Sítio José Maria,18,,-23.0037,-50.2194
br,sitio jose marinho,Sítio José Marinho,18,,-23.866053,-50.442686
br,sitio jose mario lirio reis,Sítio José Mário Lírio Reis,18,,-25.6038,-48.9577
br,sitio jose mario pacheco,Sítio José Mário Pacheco,18,,-25.7042,-49.8334
br,sitio jose marques,Sítio José Marques,18,,-23.0669,-50.1721
br,sitio jose martins,Sítio José Martins,18,,-26.181073,-49.553573
br,sitio jose matias,Sítio José Matias,18,,-23.646209,-50.018561
br,sitio jose mauro,Sítio José Mauro,18,,-23.4737,-49.8222
br,sitio jose m. de oliveira,Sítio José M. de Oliveira,18,,-23.972049,-50.432507
br,sitio jose m. dos santos,Sítio José M. dos Santos,18,,-23.7103,-49.9086
br,sitio jose medeiros,Sítio José Medeiros,18,,-23.749232,-50.214777
br,sitio jose mendes,Sítio José Mendes,18,,-25.7718,-49.6222
br,sitio jose m. fernandes,Sítio José M. Fernandes,18,,-23.5907,-49.9773
br,sitio jose m. goncalves,Sítio José M. Gonçalves,18,,-25.7024,-49.8137
br,sitio jose mineiro,Sítio José Mineiro,18,,-23.691598,-50.199452
br,sitio jose miranda,Sítio José Miranda,18,,-26.178198,-49.615281
br,sitio jose m. mendes,Sítio José M. Mendes,18,,-23.7061,-49.8197
br,sitio jose moises,Sítio José Moisés,18,,-23.6134,-49.8028
br,sitio jose moraes,Sítio José Moraes,26,,-26.1713,-49.9837
br,sitio jose morais,Sítio José Morais,18,,-23.310903,-50.046429
br,sitio jose moreira,Sítio José Moreira,18,,-25.8775,-49.5912
br,sitio jose morelli,Sítio José Morelli,27,,-23.161607,-47.672566
br,sitio jose moreno,Sítio José Moreno,27,,-23.001018,-49.77193
br,sitio jose moura,Sítio José Moura,18,,-25.7515,-49.2219
br,sitio jose m. rodrigues,Sítio José M. Rodrigues,18,,-23.406055,-49.77571
br,sitio jose m. sobrinho,Sítio José M. Sobrinho,18,,-26.0094,-49.9504
br,sitio jose m. suefeiz,Sítio José M. Suefeiz,26,,-26.1313,-49.8434
br,sitio jose muller,Sítio José Müller,18,,-25.974491,-49.843756
br,sitio jose munhoz,Sítio José Munhoz,18,,-23.5487,-50.7476
br,sitio jose n. cordeiro,Sítio José N. Cordeiro,18,,-25.5454,-48.765
br,sitio jose n. da rosa,Sítio José N. da Rosa,18,,-23.7097,-49.9775
br,sitio jose n. de oliveira,Sítio José N. de Oliveira,18,,-23.934095,-50.305685
br,sitio jose negrinho,Sítio José Negrinho,18,,-23.733321,-50.046158
br,sitio jose n. florenco,Sítio José N. Florenço,18,,-23.519291,-50.028265
br,sitio jose n. hellingr,Sítio José N. Hellingr,18,,-26.0736,-49.8128
br,sitio jose nita,Sítio José Nita,18,,-23.516469,-50.027073
br,sitio jose nogueira,Sítio José Nogueira,18,,-23.841169,-50.063248
br,sitio jose nogueira,Sítio José Nogueira,26,,-26.1265,-49.2955
br,sitio jose n. ribas,Sítio José N. Ribas,18,,-26.0366,-49.4223
br,sitio jose n. rosario,Sítio José N. Rosário,18,,-25.9641,-49.1843
br,sitio jose o. consulim,Sítio José O. Consulim,18,,-23.7216,-49.9196
br,sitio jose o. eusebio,Sítio José O. Eusébio,27,,-24.8015,-48.2568
br,sitio jose o. hidalencio,Sítio José O. Hidalêncio,18,,-25.7702,-49.1923
br,sitio jose oinask,Sítio José Oinask,18,,-26.021101,-49.635865
br,sitio jose oliveira campos,Sítio José Oliveira Campos,18,,-23.146649,-49.876489
br,sitio jose oliveira santos,Sítio José Oliveira Santos,18,,-23.739672,-50.045313
br,sitio jose oliveira,Sítio José Oliveira,18,,-25.9853,-49.1063
br,sitio jose olviar,Sítio José Olviar,18,,-23.935887,-50.191211
br,sitio jose o. pereira,Sítio José O. Pereira,18,,-25.9438,-49.204
br,sitio jose o. rocha,Sítio José O. Rocha,18,,-25.9736,-49.1883
br,sitio jose palt,Sítio José Palt,18,,-25.9553,-49.4517
br,sitio jose parmezan,Sítio José Parmezan,18,,-23.575,-49.8583
br,sitio jose paulino mofardinni,Sítio José Paulino Mofardinni,27,,-24.7727,-48.2183
br,sitio jose p. barbosa,Sítio José P. Barbosa,18,,-23.7037,-49.9436
br,sitio jose p. batista,Sítio José P. Batista,18,,-23.443585,-49.799764
br,sitio jose p. callaco,Sítio José P. Callaço,18,,-25.9887,-49.4654
br,sitio jose p. de lima,Sítio José P. de Lima,18,,-25.9257,-49.2494
br,sitio jose p. dos santos,Sítio José P. dos Santos,18,,-23.903096,-50.011026
br,sitio jose peckos,Sítio José Peckos,18,,-26.1164,-49.4222
br,sitio jose pedro a. cordeiro,Sítio José Pedro A. Cordeiro,18,,-25.917254,-49.975271
br,sitio jose pedro borges,Sítio José Pedro Borges,18,,-25.897421,-49.020197
br,sitio jose pedro de oliveira,Sítio José Pedro de Oliveira,18,,-23.422398,-50.067645
br,sitio jose pedro ramos,Sítio José Pedro Ramos,27,,-25.044886,-48.563187
br,sitio jose pepe,Sítio José Pepe,18,,-25.8128,-49.7108
br,sitio jose pereira,Sítio José Pereira,18,,-23.708832,-50.075512
br,sitio jose pestecolask,Sítio José Pestecolask,18,,-25.8958,-49.4926
br,sitio jose p. filho,Sítio José P. Filho,18,,-26.1227,-49.4012
br,sitio jose pinheiro,Sítio José Pinheiro,18,,-23.606,-49.8012
br,sitio jose pinto,Sítio José Pinto,18,,-25.5309,-48.7633
br,sitio jose p. m. rocha,Sítio José P. M. Rocha,18,,-25.9273,-49.2777
br,sitio jose polly,Sítio José Polly,18,,-25.054573,-48.840491
br,sitio jose polo,Sítio José Polo,18,,-23.144,-50.2012
br,sitio jose portela,Sítio José Portela,18,,-26.089851,-49.722373
br,sitio jose prado,Sítio José Prado,18,,-23.498517,-50.019544
br,sitio jose p. ribeiro,Sítio José P. Ribeiro,18,,-23.808759,-50.082001
br,sitio jose p. santos,Sítio José P. Santos,18,,-25.038683,-48.972286
br,sitio jose pscheidt,Sítio José Pscheidt,18,,-26.113344,-49.519191
br,sitio jose p. sobrinho,Sítio José P. Sobrinho,18,,-23.785963,-50.205812
br,sitio jose p. soezzeki,Sítio José P. Soezzeki,18,,-25.90149,-49.029675
br,sitio jose pzibenha,Sítio José Pzibenha,18,,-25.7793,-49.5338
br,sitio jose rafael,Sítio José Rafael,18,,-23.6391,-49.8932
br,sitio jose raimundo,Sítio José Raimundo,18,,-23.6093,-49.8643
br,sitio jose ramires,Sítio José Ramires,18,,-23.824414,-50.082433
br,sitio jose ramos,Sítio José Ramos,18,,-23.652627,-50.162502
br,sitio jose rauher,Sítio José Rauher,26,,-26.238713,-49.670444
br,sitio jose r. da costa,Sítio José R. da Costa,18,,-23.897935,-50.176325
br,sitio jose r. da r. filho,Sítio José R. da R. Filho,18,,-23.753534,-50.040316
br,sitio jose r. de almeida,Sítio José R. de Almeida,18,,-23.3539,-49.8896
br,sitio jose r. de lima,Sítio José R. de Lima,18,,-25.944021,-49.805714
br,sitio jose reis,Sítio José Reis,18,,-23.6365,-49.8951
br,sitio jose resner,Sítio José Resner,18,,-26.0224,-49.8607
br,sitio jose rezende,Sítio José Rezende,18,,-23.751292,-50.019644
br,sitio jose r. ferraz,Sítio José R. Ferraz,18,,-23.5429,-49.7537
br,sitio jose r. filho,Sítio José R. Filho,18,,-23.6032,-49.9623
br,sitio jose r. geoconde,Sítio José R. Geoconde,18,,-23.915921,-50.452713
br,sitio jose r. ianoski,Sítio José R. Ianoski,26,,-26.1987,-49.9557
br,sitio jose ribas,Sítio José Ribas,18,,-25.7433,-49.7975
br,sitio jose rita,Sítio José Rita,18,,-23.6694,-49.9064
br,sitio jose rodrigues,Sítio José Rodrigues,18,,-23.6419,-49.8185
br,sitio jose rola,Sítio José Rola,18,,-23.7325,-49.9541
br,sitio jose romeiro,Sítio José Romeiro,18,,-23.756097,-50.129313
br,sitio jose rosa,Sítio José Rosa,18,,-23.757227,-50.087786
br,sitio jose r. ribas,Sítio José R. Ribas,26,,-26.2087,-49.9494
br,sitio jose saika,Sítio José Saika,18,,-26.034793,-49.695841
br,sitio jose salvador,Sítio José Salvador,18,,-25.9968,-49.2084
br,sitio jose sampaio,Sítio José Sampaio,26,,-26.1377,-49.9286
br,sitio jose santana,Sítio José Santana,18,,-23.725684,-50.591428
br,sitio jose santos,Sítio José Santos,18,,-26.091534,-49.600845
br,sitio jose s. de lima,Sítio José S. de Lima,18,,-25.86,-49.3025
br,sitio jose s. do nascimento,Sítio José S. do Nascimento,18,,-23.7047,-49.8499
br,sitio jose sebastiao de souza,Sítio José Sebastião de Souza,18,,-23.686346,-50.084888
br,sitio jose senn,Sítio José Senn,18,,-26.054989,-49.518888
br,sitio jose sergipano,Sítio José Sergipano,18,,-23.91903,-50.559012
br,sitio jose serote,Sítio José Serote,18,,-25.8243,-49.3708
br,sitio jose severino,Sítio José Severino,18,,-23.800764,-50.27155
br,sitio jose s. filho,Sítio José S. Filho,18,,-25.7684,-49.5252
br,sitio jose silva,Sítio José Silva,18,,-23.461716,-49.969186
br,sitio jose silvestre,Sítio José Silvestre,18,,-23.724691,-50.101312
br,sitio jose simao,Sítio José Simão,18,,-23.64,-49.8224
br,sitio jose,Sítio José,18,,-23.898208,-50.404708
br,sitio jose sokodosk,Sítio José Sokodosk,26,,-26.2186,-49.9371
br,sitio jose s. oliveira,Sítio José S. Oliveira,18,,-23.88586,-50.263381
br,sitio jose souza,Sítio José Souza,18,,-25.8067,-49.5201
br,sitio jose stanhak,Sítio José Stanhak,26,,-26.1506,-49.9087
br,sitio jose taborda,Sítio José Taborda,18,,-25.7735,-49.5079
br,sitio jose tabordas,Sítio José Tabordas,18,,-26.0532,-49.4829
br,sitio jose teixeira de carvalho,Sítio José Teixeira de Carvalho,18,,-23.693436,-50.236439
br,sitio jose teodoro,Sítio José Teodoro,18,,-23.5726,-49.7517
br,sitio jose terra pinto,Sítio José Terra Pinto,18,,-23.719016,-50.167494
br,sitio jose tonete,Sítio José Tonete,18,,-23.170707,-49.95759
br,sitio jose tonett,Sítio José Tonett,18,,-23.149289,-49.90509
br,sitio jose trovao,Sítio José Trovão,18,,-23.855935,-50.071754
br,sitio jose trozanoski,Sítio José Trozanoski,18,,-25.7799,-49.5807
br,sitio jose valente,Sítio José Valente,18,,-26.0018,-49.9389
br,sitio jose valurita,Sítio José Valurita,18,,-23.904973,-50.468391
br,sitio jose v. da cruz,Sítio José V. da Cruz,18,,-26.0954,-49.4308
br,sitio jose veinsesk,Sítio José Veinsesk,18,,-25.7777,-49.3508
br,sitio jose velasques,Sítio José Velasques,18,,-23.6319,-49.9453
br,sitio jose vermelho,Sítio José Vermelho,18,,-23.0732,-50.1349
br,sitio jose viana,Sítio José Viana,18,,-23.913787,-50.559483
br,sitio jose viberter,Sítio José Viberter,26,,-26.2493,-49.9675
br,sitio jose vichete,Sítio José Vichete,18,,-23.6118,-49.8611
br,sitio jose vidal,Sítio José Vidal,18,,-23.860285,-50.349903
br,sitio jose v. miranda,Sítio José V. Miranda,18,,-25.8385,-49.4775
br,sitio jose v. sabino,Sítio José V. Sabino,18,,-23.6959,-49.9342
br,sitio jose v. tschoki,Sítio José V. Tschoki,18,,-26.1267,-49.4451
br,sitio jose watter,Sítio José Watter,18,,-26.081127,-49.51205
br,sitio jose willner,Sítio José Willner,26,,-26.1309,-49.9885
br,sitio jose wosniak,Sítio José Wosniak,18,,-25.9051,-49.4376
br,sitio jose zara,Sítio José Zara,18,,-23.1079,-50.2092
br,sitio jose zava,Sítio José Zava,18,,-23.1812,-50.1556
br,sitio jose z. filho,Sítio José Z. Filho,18,,-25.8644,-49.219
br,sitio josias machado,Sítio Josias Machado,18,,-23.6371,-49.859
br,sitio josias mauricio,Sítio Josias Mauricio,18,,-25.4613,-48.6938
br,sitio josimar rabaca,Sítio Josimar Rabaça,18,,-25.495923,-48.864127
br,sitio josino azevedo siqueira,Sítio Josino Azevedo Siqueira,18,,-23.729235,-50.089784
br,sitio josino firminos,Sítio Josino Firminos,18,,-23.5741,-49.8729
br,sitio joson h. olsen,Sítio Joson H. Olsen,26,,-26.1613,-49.7528
br,sitio josue o. da silva,Sítio Josué O. da Silva,18,,-23.830118,-50.076948
br,sitio josue p. vicente,Sítio Josué P. Vicente,18,,-23.86949,-50.439192
br,sitio jota efe,Sítio Jota Efe,27,,-23.248611,-46.700556
br,sitio jovanete,Sítio Jovanete,18,,-23.5015,-49.8746
br,sitio jovenal martins,Sítio Jovenal Martins,18,,-25.5114,-49.9392
br,sitio jovina custodia,Sítio Jovina Custódia,18,,-23.672,-49.9228
br,sitio joviniano p. de moura,Sítio Joviniano P. de Moura,18,,-23.955282,-50.014149
br,sitio jovino aires,Sítio Jovino Aires,18,,-25.985872,-49.852689
br,sitio jovino correia,Sítio Jovino Correia,18,,-25.913333,-49.663333
br,sitio jovino de lima,Sítio Jovino de Lima,26,,-26.2379,-49.9741
br,sitio jovino folador,Sítio Jovino Folador,18,,-25.7685,-49.266
br,sitio jovino keche,Sítio Jovino Keche,18,,-25.9771,-49.3618
br,sitio jovino maciel,Sítio Jovino Maciel,18,,-23.6692,-49.7595
br,sitio jovino v. da silva,Sítio Jovino V. da Silva,18,,-25.7632,-49.365
br,sitio jovino zaleski,Sítio Jovino Zaleski,18,,-25.9387,-49.4946
br,sitio js,Sítio JS,27,,-24.635478,-48.032048
br,sitio juanita kimiestz,Sítio Juanita Kimiestz,18,,-25.846111,-49.623056
br,sitio juarez l. dos santos,Sítio Juarez L. dos Santos,18,,-23.993096,-50.017786
br,sitio juarez,Sítio Juarez,18,,-23.644179,-50.18175
br,sitio jua,Sítio Juá,06,,-6.85,-39.516667
br,sitio juca de s. freitas,Sítio Juca de S. Freitas,26,,-26.1783,-49.2867
br,sitio juca jowita,Sítio Juca Jowita,18,,-26.015873,-49.676356
br,sitio jucara,Sítio Juçara,18,,-23.893066,-50.555035
br,sitio juca rauer,Sítio Juca Rauer,26,,-26.1336,-49.772
br,sitio juca,Sítio Juca,18,,-25.848664,-48.941692
br,sitio juclemente camargo,Sítio Juclemente Camargo,18,,-23.711562,-50.708344
br,sitio jucurupava,Sítio Jucurupava,27,,-23.5923,-47.5031
br,sitio judith pereira,Sítio Judith Pereira,18,,-26.0024,-49.9448
br,sitio julia benancio,Sítio Júlia Benâncio,18,,-25.898454,-49.932385
br,sitio julia dos santos,Sítio Júlia dos Santos,18,,-25.953889,-49.529722
br,sitio julia f. maciel,Sítio Júlia F. Maciel,18,,-25.692369,-49.81874
br,sitio julia martins,Sítio Júlia Martins,18,,-23.954257,-50.515524
br,sitio juliana,Sítio Juliana,27,,-24.600605,-48.006045
br,sitio juliano hukan,Sítio Juliano Hukan,18,,-25.7071,-49.9582
br,sitio julieta dalabona,Sítio Julieta Dalabona,18,,-25.562,-49.8931
br,sitio julio c. de camargo,Sítio Júlio C. de Camargo,18,,-23.949509,-50.352078
br,sitio julio da guia,Sítio Júlio da Guia,27,,-24.844203,-48.21503
br,sitio julio fuckner,Sítio Júlio Fuckner,18,,-26.082978,-49.613797
br,sitio julio gogola,Sítio Julio Gogola,18,,-25.8173,-49.5962
br,sitio julio konkel,Sítio Júlio Konkel,26,,-26.0541,-49.9137
br,sitio julio koschak,Sítio Júlio Koschak,18,,-25.6987,-49.8511
br,sitio julio k. sato,Sítio Júlio K. Sato,18,,-25.9462,-49.3367
br,sitio julio o. kuiavski,Sítio Júlio O. Kuiavski,26,,-26.1796,-49.8674
br,sitio julio paluki,Sítio Júlio Paluki,26,,-26.2169,-49.8741
br,sitio julio p. dos santos,Sítio Júlio P. dos Santos,18,,-25.8559,-49.168
br,sitio julio p. ferreira,Sítio Júlio P. Ferreira,18,,-23.91933,-50.258718
br,sitio julio ribeiro dos santos,Sítio Júlio Ribeiro dos Santos,18,,-25.10076,-48.829505
br,sitio julio rodrigues de lima,Sítio Júlio Rodrigues de Lima,27,,-24.8264,-48.2316
br,sitio julio shiago strick,Sítio Júlio Shiago Strick,18,,-25.469033,-48.850008
br,sitio julio t. amaral,Sítio Júlio T. Amaral,18,,-23.403969,-49.78474
br,sitio julio veiga,Sítio Júlio Veiga,18,,-26.12135,-49.739037
br,sitio julio worniaki,Sítio Júlio Worniaki,18,,-25.819,-49.4925
br,sitio jumirim,Sítio Jumirim,27,,-23.0768,-47.8092
br,sitio junior,Sítio Júnior,27,,-24.8553,-48.0724
br,sitio juno,Sítio Juno,27,,-23.656181,-47.323097
br,sitio junqueira,Sítio Junqueira,18,,-23.812186,-50.028866
br,sitio juqueri-mirim,Sítio Juqueri-Mirim,27,,-23.366401,-46.613709
br,sitio jurandir a. da silva,Sítio Jurandir A. da Silva,18,,-23.584146,-50.714607
br,sitio jurandir barros carvalho,Sítio Jurandir Barros Carvalho,27,,-23.039038,-49.846311
br,sitio jurandir carvalho,Sítio Jurandir Carvalho,18,,-23.337181,-50.240567
br,sitio jurandir costa,Sítio Jurandir Costa,18,,-23.6936,-49.8665
br,sitio jurandir i. guerber,Sítio Jurandir I. Guerber,18,,-26.0774,-49.7915
br,sitio jurandir p. de oliveira,Sítio Jurandir P. de Oliveira,18,,-25.9056,-49.3262
br,sitio jurema,Sítio Jurema,18,,-23.712211,-50.072781
br,sitio justina pinto,Sítio Justina Pinto,18,,-23.650454,-50.134677
br,sitio justino b. de lima,Sítio Justino B. de Lima,18,,-25.8517,-49.0329
br,sitio juvenal amaral,Sítio Juvenal Amaral,26,,-26.247,-49.9405
br,sitio juvenal b. cardoso,Sítio Juvenal B. Cardoso,18,,-25.930278,-49.625
br,sitio juvenal b. franco,Sítio Juvenal B. Franco,26,,-26.1205,-49.2985
br,sitio juvenal de s. prestes,Sítio Juvenal de S. Prestes,18,,-25.8845,-49.3651
br,sitio juvenal dos santos,Sítio Juvenal dos Santos,18,,-23.904855,-50.458838
br,sitio juvenal g. santos,Sítio Juvenal G. Santos,18,,-23.153,-50.1931
br,sitio juvenal hining,Sítio Juvenal Hining,18,,-26.0712,-49.8387
br,sitio juvenal vaz,Sítio Juvenal Vaz,18,,-26.15078,-49.564782
br,sitio juvencio kolasso,Sítio Juvêncio Kolasso,18,,-25.829851,-49.916526
br,sitio juvencio moreira,Sítio Juvêncio Moreira,18,,-25.958611,-49.576667
br,sitio juvino martins,Sítio Juvino Martins,18,,-26.1059,-49.4822
br,sitio kanebo,Sítio Kanebo,18,,-23.771848,-50.135941
br,sitio kanie,Sítio Kanie,27,,-23.749203,-47.125131
br,sitio katel,Sítio Katel,27,,-23.563647,-47.051307
br,sitio katsuhiro shiruya,Sítio Katsuhiro Shiruya,18,,-25.5054,-48.7722
br,sitio kawai,Sítio Kawai,27,,-23.041111,-46.506667
br,sitio kawakami,Sítio Kawakami,27,,-23.698499,-47.288903
br,sitio kayama,Sítio Kayama,27,,-23.583333,-47.193111
br,sitio kayoshi,Sítio Kayoshi,18,,-23.0334,-50.1758
br,sitio kazuyuki kawana,Sítio Kazuyuki Kawana,27,,-23.049919,-49.868632
br,sitio keizo horoiwa,Sítio Keizo Horoiwa,18,,-25.47318,-48.855134
br,sitio kelson crisostemo da silva,Sítio Kelson Crisóstemo da Silva,18,,-25.100917,-48.742945
br,sitio kendy,Sítio Kendy,27,,-23.683742,-47.158566
br,sitio kioshi,Sítio Kioshi,27,,-23.61751,-47.200928
br,sitio kioshi takano,Sítio Kioshi Takano,18,,-23.1235,-50.216
br,sitio kitiliano da paz,Sítio Kitilíano da Paz,18,,-23.1536,-50.102
br,sitio kito,Sítio Kito,27,,-23.572513,-47.03339
br,sitio kival b. paqueta,Sítio Kival B. Paquetá,18,,-25.8475,-49.741667
br,sitio klabim,Sítio Klabim,27,,-22.7355,-45.5131
br,sitio koga,Sítio Koga,27,,-23.5582,-47.5243
br,sitio kojiro,Sítio Kojiro,18,,-23.702021,-50.69076
br,sitio komura,Sítio Komura,18,,-23.625002,-50.021921
br,sitio kono,Sítio Kono,27,,-23.686199,-47.066323
br,sitio kosako kowata,Sítio Kosako Kowata,18,,-23.93184,-50.419706
br,sitio kurt plotz,Sítio Kurt Plotz,18,,-25.683,-49.7905
br,sitio la chamade,Sítio Lá Chamade,27,,-23.219167,-46.556389
br,sitio lacridio alves,Sítio Lacrídio Alves,18,,-25.6925,-48.7894
br,sitio ladislau bichesk,Sítio Ladislau Bichesk,26,,-26.0206,-49.9956
br,sitio ladislau chuviskiw,Sítio Ladislau Chuviskiw,18,,-25.7837,-49.4118
br,sitio ladislau dieder,Sítio Ladislau Dieder,18,,-26.144665,-49.502508
br,sitio ladislau escrab,Sítio Ladislau Escrab,18,,-25.8865,-49.368
br,sitio ladislau narich,Sítio Ladislau Narich,26,,-26.2319,-49.2954
br,sitio ladislau p. olavo,Sítio Ladislau P. Olavo,18,,-25.9975,-49.710833
br,sitio ladislau stannilovisck,Sítio Ladislau Stannilovisck,18,,-25.7958,-49.5222
br,sitio laercio facistoso,Sítio Laércio Facistoso,18,,-23.5949,-49.834
br,sitio laercio oliveira fogaca,Sítio Laércio Oliveira Fogaça,18,,-23.648118,-50.199704
br,sitio laercio,Sítio Laércio,26,,-26.163,-49.8331
br,sitio laerte s. lima,Sítio Laerte S. Lima,18,,-25.8065,-49.5964
br,sitio laerte vieira,Sítio Laerte Vieira,18,,-23.1847,-50.1342
br,sitio laerts raismussen,Sítio Laerts Raismussen,18,,-25.842345,-49.921135
br,sitio la fiaca,Sítio La Fiaca,21,,-22.304388,-42.992654
br,sitio lagoa azul,Sítio Lagoa Azul,27,,-23.593521,-47.108072
br,sitio lagoa bonita,Sítio Lagoa Bonita,18,,-23.45796,-49.89008
br,sitio lagoa da pedra,Sítio Lagoa da Pedra,27,,-23.0875,-46.541944
br,sitio lagoa das marrecas,Sítio Lagoa das Marrecas,06,,-6.25,-39.883333
br,sitio lagoa de cima,Sítio Lagoa de Cima,22,,-5.0675,-37.331667
br,sitio lagoa de sao bento,Sítio Lagoa de São Bento,06,,-6.916667,-39.333333
br,sitio lagoa dos salgueiros,Sítio Lagoa dos Salgueiros,27,,-23.970034,-47.008307
br,sitio lagoa fechada,Sítio Lagoa Fechada,30,,-7.766667,-40.433333
br,sitio lagoa seca,Sítio Lagoa Séca,20,,-7.616667,-40.783333
br,sitio lagoa serena,Sítio Lagoa Serena,27,,-23.685699,-47.231612
br,sitio lagoa,Sítio Lagoa,18,,-23.747218,-50.633189
br,sitio lagoa,Sítio Lagoa,20,,-7.516667,-40.95
br,sitio lagoa,Sítio Lagoa,27,,-23.58617,-47.04612
br,sitio lago azul,Sítio Lago Azul,27,,-23.569491,-47.065529
br,sitio lago do ibiuna,Sítio Lago do Ibiúna,27,,-23.675175,-47.305604
br,sitio laguna,Sítio Laguna,18,,-23.109312,-49.777569
br,sitio lajeadinho,Sítio Lajeadinho,18,,-23.2189,-50.158
br,sitio lajeado,Sítio Lajeado,18,,-23.29844,-49.969008
br,sitio lambisqueiro,Sítio Lambisqueiro,18,,-25.7186,-49.8654
br,sitio landi,Sítio Landi,18,,-23.501011,-50.054579
br,sitio laranja-azeda,Sítio Laranja-Azeda,27,,-23.9495,-47.1553
br,sitio laranjal,Sítio Laranjal,18,,-23.834622,-50.033846
br,sitio laranjal,Sítio Laranjal,27,,-23.108682,-47.55848
br,sitio laranjeiras,Sítio Laranjeiras,27,,-23.898,-47.1091
br,sitio laranjinha,Sítio Laranjinha,18,,-23.2449,-50.2434
br,sitio lara,Sítio Lara,18,,-25.7195,-49.75
br,sitio lar de katahara,Sítio Lar de Katahara,27,,-23.644376,-47.172101
br,sitio larecio,Sítio Larecío,27,,-23.5453,-47.5435
br,sitio laredo,Sítio Laredo,27,,-23.793969,-46.730728
br,sitio larindo a. pereira,Sítio Larindo A. Pereira,18,,-23.7323,-49.9294
br,sitio laudelino faria,Sítio Laudelino Faria,26,,-26.0431,-49.9843
br,sitio laudelino nunes,Sítio Laudelino Nunes,18,,-23.421976,-50.106295
br,sitio laudemiro pereira,Sítio Laudemiro Pereira,18,,-25.451306,-48.75598
br,sitio laudivio schroeder,Sítio Laudívio Schroeder,18,,-26.177948,-49.557727
br,sitio laura,Sítio Laura,18,,-23.912759,-50.262872
br,sitio laurentino hoff,Sítio Laurentino Hoff,26,,-26.1914,-49.3089
br,sitio laurentino pereira,Sítio Laurentino Pereira,18,,-25.5378,-48.7932
br,sitio lauri baggio,Sítio Lauri Baggio,18,,-25.002574,-48.812248
br,sitio laurinda s. da rocha,Sítio Laurinda S. da Rocha,18,,-25.5372,-48.7574
br,sitio laurindo buba,Sítio Laurindo Buba,18,,-26.1113,-49.4762
br,sitio laurindo carvalho dos santos,Sítio Laurindo Carvalho dos Santos,27,,-25.071207,-48.549728
br,sitio laurindo goncalves,Sítio Laurindo Gonçalves,18,,-26.0246,-49.261
br,sitio laurindo muller,Sítio Laurindo Müller,26,,-26.2162,-49.7723
br,sitio laurindo palu,Sítio Laurindo Palu,18,,-25.839048,-49.274585
br,sitio laurindo patu,Sítio Laurindo Patu,18,,-25.802846,-48.875943
br,sitio laurindo schifel,Sítio Laurindo Schifel,26,,-26.2432,-49.715785
br,sitio lauro arruda santos,Sítio Lauro Arruda Santos,18,,-23.68403,-50.130516
br,sitio lauro barbosa,Sítio Lauro Barbosa,18,,-23.817382,-50.250298
br,sitio lauro da silva,Sítio Lauro da Silva,18,,-26.154615,-49.572782
br,sitio lauro de j. bueno,Sítio Lauro de J. Bueno,18,,-23.987923,-50.326838
br,sitio lauro do nascimento,Sítio Lauro do Nascimento,18,,-26.169236,-49.618311
br,sitio lauro dzanik,Sítio Lauro Dzanik,18,,-25.7656,-49.5196
br,sitio lauro f. cruz,Sítio Lauro F. Cruz,18,,-25.944529,-49.80092
br,sitio lauro ferreira,Sítio Lauro Ferreira,18,,-23.4115,-49.8581
br,sitio lauro garcia,Sítio Lauro Garcia,18,,-25.8315,-49.1155
br,sitio lauro klosterman,Sítio Lauro Klosterman,18,,-25.945363,-49.991336
br,sitio lauro milchevski,Sítio Lauro Milchevski,18,,-26.1159,-49.4918
br,sitio lauro policarpo,Sítio Lauro Policarpo,18,,-25.386,-48.6428
br,sitio lauro sauer,Sítio Lauro Sauer,26,,-26.1579,-49.8107
br,sitio lauro schelbauer,Sítio Lauro Schelbauer,18,,-26.0994,-49.7636
br,sitio lauro schultz,Sítio Lauro Schultz,26,,-26.0654,-49.8675
br,sitio lauro stafin,Sítio Lauro Stafin,18,,-26.088657,-49.523319
br,sitio lauro stop,Sítio Lauro Stop,18,,-23.529259,-50.710848
br,sitio lauro ulbrich,Sítio Lauro Ulbrich,26,,-26.0505,-49.9834
br,sitio lauro veiga,Sítio Lauro Veiga,18,,-26.063586,-49.700457
br,sitio lauro willner,Sítio Lauro Willner,26,,-26.1245,-49.9544
br,sitio lavras velhas,Sítio Lavras Velhas,27,,-23.6821,-47.5074
br,sitio lavrinha,Sítio Lavrinha,18,,-23.893479,-50.071801
br,sitio lazara p. mendonca,Sítio Lázara P. Mendonça,18,,-23.6843,-49.9108
br,sitio lazaro a. de oliveira,Sítio Lázaro A. de Oliveira,18,,-23.599,-49.9438
br,sitio lazaro euzebio,Sítio Lázaro Euzébio,18,,-23.6201,-49.8768
br,sitio lazaro godoy,Sítio Lázaro Godoy,18,,-23.576224,-50.531458
br,sitio lazaro leonel,Sítio Lázaro Leonel,18,,-23.6595,-49.9421
br,sitio lazaro mineiro,Sítio Lázaro Mineiro,18,,-23.6283,-50.5083
br,sitio lazaro p. krema,Sítio Lázaro P. Krema,26,,-26.1154,-49.8814
br,sitio lazaro silveira,Sítio Lázaro Silveira,18,,-23.846391,-50.131701
br,sitio lazaro,Sítio Lázaro,18,,-23.895332,-50.55639
br,sitio lazaro t. da silva,Sítio Lázaro T. da Silva,18,,-23.7243,-49.9162
br,sitio lazaro x. de godoi,Sítio Lázaro X. de Godói,18,,-23.943411,-50.256702
br,sitio lazinho,Sítio Lazinho,18,,-23.6393,-49.8704
br,sitio lazo de almeida,Sítio Lazo de Almeida,18,,-23.721148,-50.022209
br,sitio leandrina monteiro,Sítio Leandrina Monteiro,18,,-25.918056,-49.659167
br,sitio leao,Sítio Leão,18,,-23.778457,-50.649733
br,sitio lecabanom,Sítio Lecabanom,27,,-23.213611,-46.533056
br,sitio leiria,Sítio Leiria,27,,-23.808517,-46.716458
br,sitio lencol,Sítio Lençol,27,,-24.574504,-48.034777
br,sitio leno munheque,Sítio Leno Munheque,18,,-25.9131,-49.1862
br,sitio leoberto peters,Sítio Leoberto Peters,26,,-26.1209,-49.9594
br,sitio leocadia m. nazachuki,Sítio Leocádia M. Nazachuki,18,,-25.995556,-49.692222
br,sitio leocadio lourenco,Sítio Leocádio Lourenço,18,,-25.801667,-49.712222
br,sitio leodir maans,Sítio Leodir Maans,18,,-26.0285,-49.3728
br,sitio leodorio l. pinto,Sítio Leodório L. Pinto,18,,-25.5344,-48.8048
br,sitio leolindo r. dos santos,Sítio Leolindo R. dos Santos,18,,-23.778647,-50.749872
br,sitio leonardo borene,Sítio Leonardo Borene,18,,-25.914722,-49.550556
br,sitio leonardo cantela,Sítio Leonardo Cantela,18,,-25.8339,-49.5071
br,sitio leonardo de moura,Sítio Leonardo de Moura,18,,-25.8418,-49.4127
br,sitio leonardo dreviniok,Sítio Leonardo Dreviniok,18,,-25.835,-49.3848
br,sitio leonardo g. da costa,Sítio Leonardo G. da Costa,18,,-25.5688,-49.8875
br,sitio leonardo gomes,Sítio Leonardo Gomes,18,,-25.5073,-49.8917
br,sitio leonardo kaiss,Sítio Leonardo Kaiss,18,,-25.8532,-49.4536
br,sitio leonardo karan,Sítio Leonardo Karan,18,,-25.815556,-49.745
br,sitio leonardo kenopick,Sítio Leonardo Kenopick,18,,-25.934644,-49.204679
br,sitio leonardo koduviski,Sítio Leonardo Koduviski,18,,-25.7727,-49.5003
br,sitio leonardo kolasso,Sítio Leonardo Kolasso,18,,-25.7736,-49.552
br,sitio leonardo kuduaviscz,Sítio Leonardo Kuduaviscz,18,,-25.7787,-49.4227
br,sitio leonardo mika,Sítio Leonardo Mika,18,,-25.852229,-49.957304
br,sitio leonardo opaliuski,Sítio Leonardo Opaliuski,18,,-25.8352,-49.4889
br,sitio leonardo potzcek,Sítio Leonardo Potzcek,18,,-25.82,-49.4595
br,sitio leonardo raksa,Sítio Leonardo Raksa,18,,-26.0151,-49.3312
br,sitio leonardo rodrigues,Sítio Leonardo Rodrigues,18,,-23.616846,-50.001777
br,sitio leonardo rzerzutko,Sítio Leonardo Rzerzutko,18,,-25.837,-49.5256
br,sitio leonardo slossmacher,Sítio Leonardo Slossmacher,18,,-26.095108,-49.685545
br,sitio leonardo stannilovisck,Sítio Leonardo Stannilovisck,18,,-25.7915,-49.5199
br,sitio leonardo vante,Sítio Leonardo Vante,18,,-25.7915,-49.4273
br,sitio leonardo zacricrevisch,Sítio Leonardo Zacricrevisch,18,,-25.7738,-49.1426
br,sitio leonardo ziomak,Sítio Leonardo Ziomak,18,,-25.891,-49.4561
br,sitio leoncio corsine,Sítio Leôncio Corsine,18,,-23.2439,-50.1065
br,sitio leonice tersote,Sítio Leonice Tersote,18,,-23.6166,-49.8889
br,sitio leonidas bannack,Sítio Leônidas Bannack,26,,-26.2292,-49.7576
br,sitio leonidas,Sítio Leônidas,18,,-25.9178,-49.173
br,sitio leonides cruz,Sítio Leônides Cruz,18,,-26.0431,-49.4984
br,sitio leonides m. de souza,Sítio Leonides M. de Souza,18,,-26.0268,-49.3579
br,sitio leonilda dietrich,Sítio Leonilda Dietrich,18,,-25.956235,-49.90831
br,sitio leonilda martins,Sítio Leonilda Martins,18,,-25.156717,-48.99197
br,sitio leonildo bonardi,Sítio Leonildo Bonardi,18,,-23.6476,-49.9734
br,sitio leonildo cordeiro,Sítio Leonildo Cordeiro,18,,-25.7158,-48.9987
br,sitio leonildo gassner,Sítio Leonildo Gassner,26,,-26.1818,-49.4309
br,sitio leonir tschoiker,Sítio Leonir Tschoiker,18,,-26.152926,-49.507407
br,sitio leonivaldo g. de oliveira,Sítio Leonivaldo G. de Oliveira,18,,-25.9158,-49.341
br,sitio leonora cordeiro,Sítio Leonora Cordeiro,18,,-26.121876,-49.655258
br,sitio leonor da silva,Sítio Leonor da Silva,18,,-23.394682,-49.800334
br,sitio leonor l. sionon,Sítio Leonor L. Sionon,18,,-25.8897,-49.5737
br,sitio leontina lacerda,Sítio Leontina Lacerda,18,,-25.482454,-48.857814
br,sitio leopoldina ribeiro,Sítio Leopoldina Ribeiro,18,,-25.8392,-49.6812
br,sitio leopoldino b. neto,Sítio Leopoldino B. Neto,18,,-26.0708,-49.8024
br,sitio leopoldo banar,Sítio Leopoldo Banar,18,,-25.9103,-49.1169
br,sitio leopoldo botrova,Sítio Leopoldo Botrova,18,,-26.163543,-49.53355
br,sitio leopoldo cherede,Sítio Leopoldo Cherede,26,,-26.216986,-49.749123
br,sitio leopoldo de m. silva,Sítio Leopoldo de M. Silva,18,,-23.995475,-50.660605
br,sitio leopoldo dibas,Sítio Leopoldo Dibas,18,,-25.7553,-49.3972
br,sitio leopoldo filho,Sítio Leopoldo Filho,18,,-26.096761,-49.503242
br,sitio leopoldo kimaroski,Sítio Leopoldo Kimaroski,18,,-25.920556,-49.555
br,sitio leopoldo lesniovski,Sítio Leopoldo Lesniovski,18,,-26.010804,-49.53473
br,sitio leopoldo l. pereira,Sítio Leopoldo L. Pereira,26,,-26.0199,-49.9879
br,sitio leopoldo maahs,Sítio Leopoldo Maahs,26,,-26.1689,-49.4591
br,sitio leopoldo milzemberg,Sítio Leopoldo Milzemberg,26,,-26.1988,-49.8821
br,sitio leopoldo neumann,Sítio Leopoldo Neumann,26,,-26.190495,-49.705663
br,sitio leopoldo petroschefsky,Sítio Leopoldo Petroschefsky,26,,-26.1849,-49.4675
br,sitio leopoldo potzcek,Sítio Leopoldo Potzcek,18,,-25.826156,-49.464088
br,sitio leopoldo tavschir,Sítio Leopoldo Tavschir,18,,-26.0905,-49.4755
br,sitio leo rezler,Sítio Leo Rezler,18,,-26.170438,-49.524403
br,sitio leo strubr,Sítio Leo Strubr,26,,-26.2436,-49.8466
br,sitio leotilde marques bandeira,Sítio Leotilde Marques Bandeira,18,,-25.145356,-48.959636
br,sitio lered schubauer,Sítio Lered Schubauer,26,,-26.2478,-49.849
br,sitio lernardo pereira,Sítio Lernardo Pereira,18,,-25.450066,-48.762824
br,sitio leucadia cusmam,Sítio Leucádia Cusmam,18,,-25.7598,-49.2289
br,sitio levi braselino,Sítio Levi Braselino,18,,-25.236739,-48.536428
br,sitio levi evangelista,Sítio Levi Evangelista,18,,-23.791371,-50.851144
br,sitio levino de oliveira,Sítio Levino de Oliveira,18,,-23.451598,-49.792722
br,sitio levino faustino,Sítio Levino Faustino,18,,-23.702134,-50.068867
br,sitio levi rasmassi,Sítio Levi Rasmassi,18,,-25.819051,-49.91141
br,sitio levi resende,Sítio Levi Resende,18,,-23.117345,-49.918615
br,sitio liamas,Sítio Liamas,18,,-23.2475,-50.1662
br,sitio liberata c. do nascimento,Sítio Liberata C. do Nascimento,18,,-25.082686,-48.802727
br,sitio libio da c. ribas,Sítio Libio da C. Ribas,18,,-25.9614,-49.4365
br,sitio libio roscheski,Sítio Líbio Roscheski,26,,-26.2039,-49.8467
br,sitio liceu montana,Sítio Liceu Montana,18,,-23.6906,-49.7958
br,sitio licia b. nicolau,Sítio Lícia B. Nicolau,18,,-25.774,-49.1169
br,sitio lico valerio,Sítio Lico Valério,18,,-26.214488,-49.60074
br,sitio licurgo a. nor,Sítio Licurgo A. Nor,26,,-26.1747,-49.8841
br,sitio lidia esperti,Sítio Lídia Esperti,18,,-23.421813,-50.239487
br,sitio lidia moura,Sítio Lidia Moura,18,,-25.8843,-49.5593
br,sitio lidia napper,Sítio Lídia Napper,26,,-26.1873,-49.4844
br,sitio lidio j. centa,Sítio Lidio J. Centa,18,,-25.975556,-49.532222
br,sitio lidio kapps,Sítio Lídio Kapps,18,,-26.088064,-49.731576
br,sitio lido velha,Sítio Lido Velha,26,,-26.1749,-49.8212
br,sitio lili neider,Sítio Lili Neider,26,,-26.224156,-49.626286
br,sitio lili,Sítio Lili,27,,-23.836348,-46.671024
br,sitio lilo viana,Sítio Lilo Viana,18,,-25.5134,-49.9092
br,sitio lima cordeiro,Sítio Lima Cordeiro,18,,-25.760627,-49.249513
br,sitio lima,Sítio Lima,18,,-23.9574,-50.8674
br,sitio limeira,Sítio Limeira,18,,-23.789413,-50.262117
br,sitio limeoeiro,Sítio Limeoeiro,27,,-24.507262,-48.883071
br,sitio limoeiro,Sítio Limoeiro,18,,-23.846395,-50.334934
br,sitio limoeiro,Sítio Limoeiro,23,,-29.9195,-50.887
br,sitio limoeiro,Sítio Limoeiro,27,,-23.006615,-47.605378
br,sitio linco macuta,Sítio Linco Macuta,18,,-23.569997,-50.692786
br,sitio lindolfo klastmann,Sítio Lindolfo Klastmann,18,,-25.957896,-49.833781
br,sitio lindolfo pinheiro,Sítio Lindolfo Pinheiro,18,,-25.8678,-49.4676
br,sitio lindolfo,Sítio Lindolfo,18,,-23.730798,-50.109125
br,sitio lindolfo veiga,Sítio Lindolfo Veiga,18,,-25.933366,-49.828612
br,sitio lino r. dos santos,Sítio Lino R. dos Santos,18,,-25.04963,-48.845205
br,sitio lino sheyd,Sítio Lino Sheyd,26,,-26.2132,-49.8796
br,sitio lirio do vale,Sítio Lírio do Vale,27,,-23.1725,-46.579167
br,sitio lisandro cardoso,Sítio Lisandro Cardoso,18,,-26.0074,-49.4018
br,sitio lisboa,Sítio Lisboa,18,,-23.9696,-50.836
br,sitio lisboa,Sítio Lisboa,27,,-23.014167,-46.645556
br,sitio lizandro miranda,Sítio Lizandro Miranda,18,,-25.788484,-48.773606
br,sitio lizandro ulbrich,Sítio Lizandro Ulbrich,26,,-26.0643,-49.9916
br,sitio lizano lourenco,Sítio Lizano Lourenço,18,,-25.914687,-49.978909
br,sitio lodovico ianovski,Sítio Lodovico Ianovski,26,,-26.056,-49.9108
br,sitio logradouro,Sítio Logradouro,17,,-7.266667,-36.033333
br,sitio lolita rodrigues,Sítio Lolita Rodrigues,18,,-23.6042,-49.9331
br,sitio lombada,Sítio Lombada,18,,-23.838963,-50.508415
br,sitio loraci camargo,Sítio Loraci Camargo,18,,-25.9072,-49.385
br,sitio loracy s. maia,Sítio Loracy S. Maia,18,,-26.0498,-49.3503
br,sitio lorena gomes,Sítio Lorena Gomes,18,,-23.156411,-49.929919
br,sitio lorival p. da cruz,Sítio Lorival P. da Cruz,18,,-25.9555,-49.4046
br,sitio lose l. couto,Sítio Losé L. Couto,18,,-25.482758,-48.849311
br,sitio lotario nepol,Sítio Lotário Nepol,26,,-26.2299,-49.4833
br,sitio lotario strancki,Sítio Lotário Strancki,18,,-26.1066,-49.4402
br,sitio lote nove,Sítio Lote Nove,18,,-23.1344,-50.1106
br,sitio lourdes nossol,Sítio Lourdes Nossol,18,,-26.0339,-49.497
br,sitio lourdes patras,Sítio Lourdes Patras,18,,-25.8059,-49.4356
br,sitio lourenco cardoso,Sítio Lourenço Cardoso,18,,-23.787864,-50.84213
br,sitio lourenco champoski,Sítio Lourenço Champoski,18,,-25.97,-49.1788
br,sitio lourenco lopes,Sítio Lourenço Lopes,18,,-23.173112,-49.962455
br,sitio lourenco megosek,Sítio Lourenço Megosek,18,,-25.893,-49.3664
br,sitio lourenco paiano,Sítio Lourenço Paiano,18,,-26.064479,-49.686866
br,sitio lourenco ribeiro,Sítio Lourenço Ribeiro,18,,-25.5615,-48.8702
br,sitio lourenco thome,Sítio Lourenço Thome,18,,-23.7262,-49.8582
br,sitio lourival a. camargo,Sítio Lourival A. Camargo,18,,-25.9335,-49.2237
br,sitio lourival botrova,Sítio Lourival Botrova,18,,-26.191265,-49.563515
br,sitio lourival da rosa,Sítio Lourival da Rosa,18,,-25.458776,-48.873282
br,sitio lourival dias,Sítio Lourival Dias,18,,-25.777781,-49.833252
br,sitio lourivaldo grossol,Sítio Lourivaldo Grossol,18,,-26.1323,-49.4237
br,sitio lourival dos s. silveira,Sítio Lourival dos S. Silveira,18,,-25.779,-49.5723
br,sitio lourival ferreira,Sítio Lourival Ferreira,18,,-23.348046,-50.016931
br,sitio lourival galvao,Sítio Lourival Galvão,18,,-23.357536,-50.018699
br,sitio lourival krinker,Sítio Lourival Krinker,18,,-25.7644,-49.5602
br,sitio lourival martineli,Sítio Lourival Martineli,18,,-23.5161,-49.8691
br,sitio lourival m. dos anjos,Sítio Lourival M. dos Anjos,18,,-25.998914,-49.04665
br,sitio lourival m. ramos,Sítio Lourival M. Ramos,18,,-25.932005,-49.823262
br,sitio lourival ornig,Sítio Lourival Ornig,18,,-25.761111,-49.651111
br,sitio lourival rodrigues,Sítio Lourival Rodrigues,18,,-25.2231,-48.896971
br,sitio lourival,Sítio Lourival,18,,-25.18936,-48.960757
br,sitio louro borbe,Sítio Louro Borbe,18,,-26.0462,-49.33
br,sitio lucas bugia,Sítio Lucas Bugia,18,,-25.8427,-49.5892
br,sitio lucas castro,Sítio Lucas Castro,18,,-25.3815,-48.6109
br,sitio lucas ruvinski,Sítio Lucas Ruvinski,18,,-25.8341,-49.5224
br,sitio lucia baumgarnner,Sítio Lúcia Baumgarnner,26,,-26.172,-49.7555
br,sitio lucia correa,Sítio Lúcia Corrêa,18,,-25.816111,-49.625556
br,sitio lucia homan,Sítio Lúcia Homan,26,,-26.1936,-49.9781
br,sitio lucia maria mair,Sítio Lúcia Maria Mair,18,,-25.937634,-49.796672
br,sitio luciana,Sítio Luciana,27,,-24.549505,-48.865422
br,sitio luciano adriano,Sítio Luciano Adriano,18,,-23.420407,-49.923325
br,sitio luciano,Sítio Luciano,18,,-23.718987,-50.04843
br,sitio lucia schafaschek,Sítio Lúcia Schafaschek,26,,-26.1732,-49.758
br,sitio lucidio afonso enes,Sítio Lucidio Afonso Enes,18,,-25.127129,-48.892029
br,sitio lucidio c. da cruz,Sítio Lucidio C. da Cruz,18,,-25.073707,-48.827445
br,sitio lucidorio de s. freitas,Sítio Lucidório de S. Freitas,26,,-26.1676,-49.3385
br,sitio lucidorio g. da luz,Sítio Lucidório G. da Luz,18,,-26.0413,-49.2892
br,sitio lucidoro p. da rocha,Sítio Lucidoro P. da Rocha,18,,-25.8983,-49.1772
br,sitio lucidororio de o. lima,Sítio Lucidororio de O. Lima,18,,-25.987237,-49.024432
br,sitio lucio a. da silva,Sítio Lúcio A. da Silva,18,,-23.71,-49.9358
br,sitio lucio krakisk,Sítio Lúcio Krakisk,18,,-25.7058,-49.8094
br,sitio lucio p. filho,Sítio Lúcio P. Filho,18,,-23.5838,-49.8532
br,sitio luci,Sítio Luci,04,,-1.839167,-60.155556
br,sitio lucy ferreira cologi,Sítio Lucy Ferreira Cologi,18,,-25.787439,-49.80124
br,sitio ludegero t. farias,Sítio Ludegero T. Farias,18,,-23.930792,-50.082261
br,sitio ludeka,Sítio Ludeka,27,,-23.667904,-47.044236
br,sitio ludovico ianovski,Sítio Ludovico Ianovski,26,,-26.0855,-49.9342
br,sitio ludovico pokrsch,Sítio Ludovico Pokrsch,18,,-25.76,-49.4748
br,sitio ludovina pikulsk,Sítio Ludovina Pikulsk,18,,-25.7174,-49.7638
br,sitio luis alberto tedesco,Sítio Luís Alberto Tedesco,18,,-25.5534,-49.9333
br,sitio luisa m. dos santos,Sítio Luísa M. dos Santos,18,,-25.798889,-49.710833
br,sitio luis andreoli,Sítio Luis Andreoli,18,,-26.0231,-49.331
br,sitio luis baiano,Sítio Luis Baiano,18,,-23.9988,-50.8999
br,sitio luis brandino,Sítio Luis Brandino,18,,-23.691511,-50.118433
br,sitio luis carlos,Sítio Luís Carlos,18,,-23.923175,-50.670453
br,sitio luis c. de franca,Sítio Luis C. de França,18,,-25.5273,-48.8983
br,sitio luis c. dias,Sítio Luís C. Dias,18,,-23.6537,-49.9008
br,sitio luis f. de azevedo,Sítio Luís F. de Azevedo,18,,-23.6725,-49.8409
br,sitio luis garbilote,Sítio Luis Garbilote,18,,-23.455994,-49.762122
br,sitio luis goncalves,Sítio Luís Gonçalves,18,,-23.6152,-49.9054
br,sitio luis leite,Sítio Luis Leite,18,,-23.706478,-50.118627
br,sitio luis liebl,Sítio Luis Liebl,18,,-26.0604,-49.456
br,sitio luis mariano,Sítio Luís Mariano,18,,-23.6283,-49.9257
br,sitio luis master,Sítio Luís Master,18,,-25.9957,-49.415
br,sitio luis pereira,Sítio Luís Pereira,18,,-23.835179,-50.506678
br,sitio luis,Sítio Luís,18,,-23.604649,-50.526309
br,sitio luis vidal,Sítio Luís Vidal,18,,-23.672568,-50.042322
br,sitio luis vieira da costa,Sítio Luis Vieira da Costa,27,,-24.8251,-48.2338
br,sitio luiza boergehrsauer,Sítio Luíza Boergehrsauer,18,,-25.942042,-48.803759
br,sitio luiza butzke,Sítio Luiza Butzke,26,,-26.2464,-49.4042
br,sitio luiz a. cordeiro,Sítio Luiz A. Cordeiro,18,,-26.0001,-49.9369
br,sitio luiz a. dantas,Sítio Luiz A. Dantas,18,,-25.789444,-49.705556
br,sitio luiz afonso,Sítio Luiz Afonso,18,,-25.9401,-49.3613
br,sitio luiz a. gelbk,Sítio Luiz A. Gelbk,26,,-26.202,-49.9428
br,sitio luiz agianini,Sítio Luiz Agianini,18,,-23.833648,-50.254604
br,sitio luiz aman,Sítio Luiz Aman,26,,-26.0239,-49.9951
br,sitio luiz a. marques,Sítio Luiz A. Marques,18,,-26.0805,-49.8132
br,sitio luiz americo baggio,Sítio Luiz Américo Baggio,18,,-23.721595,-50.133488
br,sitio luiz amorim,Sítio Luiz Amorim,18,,-25.8927,-48.7256
br,sitio luiz a. munaretto,Sítio Luiz A. Munaretto,18,,-25.994,-49.1989
br,sitio luiz antonio f. maia,Sítio Luiz Antônio F. Maia,18,,-25.835659,-49.945268
br,sitio luiz antonio leal,Sítio Luíz Antônio Leal,18,,-25.5423,-48.8536
br,sitio luizao,Sítio Luizão,18,,-23.719745,-50.050936
br,sitio luiza,Sítio Luíza,18,,-25.9002,-48.7006
br,sitio luiz auersvaldt,Sítio Luiz Auersvaldt,26,,-26.0968,-49.9548
br,sitio luiz augusto,Sítio Luiz Augusto,18,,-23.6876,-49.9795
br,sitio luiz a. zigmer,Sítio Luiz A. Zigmer,18,,-26.0078,-49.9796
br,sitio luiz b. da silva,Sítio Luiz B. da Silva,18,,-23.58937,-50.697079
br,sitio luiz bonatto,Sítio Luiz Bonatto,18,,-25.772,-49.1411
br,sitio luiz bressar,Sítio Luiz Bressar,18,,-25.7991,-49.2375
br,sitio luiz bronelli,Sítio Luíz Bronelli,18,,-23.948169,-50.424034
br,sitio luiz cardoso,Sítio Luiz Cardoso,18,,-26.0375,-49.3072
br,sitio luiz carlos dos santos,Sítio Luiz Carlos dos Santos,18,,-23.729182,-50.203394
br,sitio luiz carlos peres,Sítio Luiz Carlos Peres,18,,-25.9,-48.712
br,sitio luiz carlos,Sítio Luiz Carlos,18,,-25.323286,-48.76283
br,sitio luiz c. b. da silveira,Sítio Luiz C. B. da Silveira,18,,-25.853611,-49.729444
br,sitio luiz c. dos santos,Sítio Luiz C. dos Santos,18,,-26.0238,-49.9299
br,sitio luiz c. firmino,Sítio Luíz C. Firmino,18,,-25.5603,-48.8452
br,sitio luiz cibotto,Sítio Luiz Cibotto,18,,-23.585705,-50.718778
br,sitio luiz c. murback,Sítio Luiz C. Murback,18,,-25.856389,-49.698056
br,sitio luiz correa,Sítio Luiz Corrêa,18,,-23.2601,-49.9207
br,sitio luiz c. toczek,Sítio Luiz C. Toczek,18,,-25.8417,-49.2911
br,sitio luiz d. correa,Sítio Luiz D. Corrêa,18,,-25.98633,-49.849532
br,sitio luiz de a. bueno,Sítio Luiz de A. Bueno,18,,-23.792879,-50.198128
br,sitio luiz de carvalho,Sítio Luiz de Carvalho,18,,-23.715918,-50.027392
br,sitio luiz deda,Sítio Luiz Deda,18,,-26.0337,-49.8207
br,sitio luiz de freitas,Sítio Luiz de Freitas,18,,-23.747543,-50.141468
br,sitio luiz de moura,Sítio Luiz de Moura,18,,-25.812219,-48.923215
br,sitio luiz dimbiski,Sítio Luiz Dimbiski,18,,-26.00452,-49.726694
br,sitio luiz d. m. mestre,Sítio Luíz D. M. Mestre,18,,-25.6942,-49.9637
br,sitio luiz dos anjos,Sítio Luiz dos Anjos,26,,-26.1089,-49.2856
br,sitio luiz e. claudino,Sítio Luiz E. Claudino,18,,-25.7513,-49.2858
br,sitio luiz engler,Sítio Luiz Engler,26,,-26.1128,-49.2749
br,sitio luiz espina,Sítio Luiz Espina,18,,-23.5461,-49.8793
br,sitio luiz esteran neto,Sítio Luiz Esteran Neto,18,,-25.823155,-49.760184
br,sitio luiz fagundes,Sítio Luiz Fagundes,18,,-23.5062,-50.5313
br,sitio luiz fernandes,Sítio Luiz Fernandes,18,,-26.071219,-49.638097
br,sitio luiz fernando,Sítio Luiz Fernando,18,,-25.347379,-48.950638
br,sitio luiz f. f. fader,Sítio Luiz F. F. Fader,18,,-23.845357,-50.157324
br,sitio luiz fredigotto,Sítio Luiz Fredigotto,18,,-23.0936,-50.1193
br,sitio luiz garcia,Sítio Luiz Garcia,18,,-25.7093,-48.7519
br,sitio luiz gomes,Sítio Luiz Gomes,18,,-23.788603,-50.03522
br,sitio luiz gonzaga,Sítio Luíz Gonzaga,18,,-25.553,-48.8196
br,sitio luiz grossel,Sítio Luiz Grossel,26,,-26.208102,-49.684349
br,sitio luiz j. pereira,Sítio Luiz J. Pereira,26,,-26.2262,-49.839
br,sitio luiz konkl,Sítio Luiz Konkl,26,,-26.1473,-49.9365
br,sitio luiz krassuski,Sítio Luíz Krassuski,18,,-25.5205,-48.8048
br,sitio luiz laureano,Sítio Luiz Laureano,18,,-23.981366,-50.02026
br,sitio luiz libel,Sítio Luiz Libel,26,,-26.1783,-49.8229
br,sitio luiz lopata,Sítio Luiz Lopata,18,,-26.0189,-49.7614
br,sitio luiz lopes,Sítio Luiz Lopes,18,,-23.740713,-50.700529
br,sitio luiz l. siqueira,Sítio Luiz L. Siqueira,18,,-25.833252,-49.966572
br,sitio luiz ludovico,Sítio Luiz Ludovico,18,,-25.915833,-49.516667
br,sitio luiz marcelo,Sítio Luiz Marcelo,18,,-25.948066,-48.77592
br,sitio luiz mariano,Sítio Luiz Mariano,18,,-23.5337,-49.916
br,sitio luiz martins,Sítio Luiz Martins,18,,-23.390565,-49.789242
br,sitio luiz master,Sítio Luiz Master,18,,-26.0068,-49.3992
br,sitio luiz morquete,Sítio Luiz Morquete,18,,-23.5099,-49.8886
br,sitio luiz ogalha,Sítio Luiz Ogalha,18,,-25.8788,-49.1798
br,sitio luiz paulo,Sítio Luiz Paulo,18,,-23.949301,-50.307416
br,sitio luiz p. da silva,Sítio Luiz P. da Silva,18,,-23.876351,-50.29975
br,sitio luiz pereira dos santos,Sítio Luiz Pereira dos Santos,18,,-23.8793,-50.9968
br,sitio luiz pianoski,Sítio Luiz Pianoski,18,,-25.8634,-49.514
br,sitio luiz picos,Sítio Luiz Picos,18,,-26.1085,-49.3021
br,sitio luiz pires,Sítio Luiz Pires,18,,-26.0663,-49.8255
br,sitio luiz pscheidt,Sítio Luiz Pscheidt,18,,-26.184142,-49.514314
br,sitio luiz r. de castro,Sítio Luiz R. de Castro,18,,-23.753534,-50.073546
br,sitio luiz resende,Sítio Luiz Resende,18,,-26.056653,-49.704213
br,sitio luiz ribeiro,Sítio Luiz Ribeiro,18,,-25.818333,-49.669444
br,sitio luiz rodrigues,Sítio Luiz Rodrigues,18,,-25.7657,-49.5316
br,sitio luiz sadal,Sítio Luiz Sadal,18,,-23.7842,-50.9673
br,sitio luiz schapieski,Sítio Luiz Schapieski,26,,-26.1253,-49.9597
br,sitio luiz s. lima,Sítio Luiz S. Lima,18,,-25.939623,-49.850784
br,sitio luiz sotok,Sítio Luiz Sotok,18,,-25.8475,-49.4914
br,sitio luiz turek,Sítio Luiz Turek,18,,-26.005893,-49.728787
br,sitio luiz vicente,Sítio Luiz Vicente,18,,-25.935713,-49.934222
br,sitio luiz vielevick,Sítio Luiz Vielevick,26,,-26.1833,-49.3581
br,sitio luiz vonzovisk,Sítio Luiz Vonzovisk,18,,-25.7767,-49.4624
br,sitio luiz wosniak,Sítio Luiz Wosniak,18,,-25.898,-49.4376
br,sitio lulu chamine,Sítio Lulu Chaminé,18,,-25.8351,-48.5726
br,sitio luna,Sítio Luna,27,,-23.271985,-46.550274
br,sitio luno,Sítio Luno,27,,-23.793433,-46.668206
br,sitio lupercio a. de faria,Sítio Lupércio A. de Faria,18,,-23.818898,-50.023061
br,sitio macaco,Sítio Macaco,06,,-6.9,-39.033333
br,sitio macal,Sítio Maçal,05,,-15.05,-40.716667
br,sitio maca oda,Sítio Maça Oda,27,,-23.691012,-47.053889
br,sitio macedo,Sítio Macedo,18,,-23.333578,-50.007638
br,sitio madalena f. carvalho,Sítio Madalena F. Carvalho,18,,-23.708,-49.8466
br,sitio madalena peters,Sítio Madalena Peters,26,,-26.179344,-49.981477
br,sitio madalena tobias,Sítio Madalena Tobias,18,,-23.6132,-49.982
br,sitio madeireira fefe,Sítio Madeireira Fefe,18,,-26.0693,-49.784
br,sitio maden,Sítio Maden,18,,-26.117324,-49.721805
br,sitio maeoka,Sítio Maeoka,18,,-23.551538,-50.733249
br,sitio magralia vermelha,Sítio Magrália Vermelha,18,,-23.149142,-49.92142
br,sitio mairilandia,Sítio Mairilândia,27,,-23.273347,-46.504454
br,sitio mairipora,Sítio Mairiporã,27,,-23.31242,-46.517859
br,sitio makamura,Sítio Makamura,27,,-23.72448,-47.204527
br,sitio maka pel,Sítio Maka Pel,27,,-23.533224,-47.204249
br,sitio makla,Sítio Maklá,18,,-23.192037,-52.224481
br,sitio makuda,Sítio Makuda,18,,-23.527395,-50.745353
br,sitio malaca,Sítio Malacá,27,,-23.683804,-47.250916
br,sitio malhada grande,Sítio Malhada Grande,20,,-7.633333,-40.833333
br,sitio malu celer,Sítio Malu Celer,18,,-25.354487,-48.878315
br,sitio malvina cardoso de jesus,Sítio Malvina Cardoso de Jesus,18,,-23.364354,-50.092985
br,sitio mamonal,Sítio Mamonal,27,,-24.5515,-48.4589
br,sitio manaca,Sítio Manacá,27,,-23.777334,-46.673183
br,sitio mandacaru,Sítio Mandacaru,27,,-23.216667,-46.570278
br,sitio mandaguari,Sítio Mandaguari,27,,-23.805,-47.1112
br,sitio mandilas,Sítio Mandilas,27,,-23.8425,-47.0563
br,sitio manecao,Sítio Manecão,18,,-25.33475,-48.786884
br,sitio mane,Sítio Mané,18,,-23.71229,-50.649492
br,sitio mangaratiba,Sítio Mangaratiba,27,,-23.537651,-47.070287
br,sitio mangueira,Sítio Mangueira,18,,-23.313716,-52.729553
br,sitio manoel a. franco,Sítio Manoel A. Franco,18,,-25.8745,-49.4025
br,sitio manoel a. gomes,Sítio Manoel A. Gomes,18,,-23.83744,-50.256921
br,sitio manoel alves pereira,Sítio Manoel Alves Pereira,18,,-25.790205,-48.766496
br,sitio manoel alves,Sítio Manoel Alves,18,,-25.8077,-48.7144
br,sitio manoel antonio alves,Sítio Manoel Antônio Alves,18,,-23.641228,-50.240841
br,sitio manoel a. silva,Sítio Manoel A. Silva,18,,-23.757204,-50.234783
br,sitio manoel bandeira,Sítio Manoel Bandeira,18,,-25.18315,-48.89855
br,sitio manoel barbosa,Sítio Manoel Barbosa,18,,-23.598165,-50.658537
br,sitio manoel bastos,Sítio Manoel Bastos,18,,-23.387093,-49.778765
br,sitio manoel b. de lima,Sítio Manoel B. de Lima,18,,-23.949788,-50.164363
br,sitio manoel biskai,Sítio Manoel Biskai,18,,-25.8045,-49.3823
br,sitio manoel camargo,Sítio Manoel Camargo,18,,-23.555978,-50.664347
br,sitio manoel carmelino,Sítio Manoel Carmelino,18,,-25.7029,-48.7818
br,sitio manoel c. da silva,Sítio Manoel C. da Silva,18,,-25.5087,-48.8592
br,sitio manoel c. de oliveira,Sítio Manoel C. de Oliveira,18,,-25.7164,-49.803
br,sitio manoel coelho,Sítio Manoel Coelho,18,,-25.5711,-49.912
br,sitio manoel costa,Sítio Manoel Costa,18,,-25.4588,-48.6899
br,sitio manoel de almeida,Sítio Manoel de Almeida,18,,-23.7041,-49.9702
br,sitio manoel de carlos,Sítio Manoel de Carlos,18,,-23.828966,-50.154231
br,sitio manoel de moura,Sítio Manoel de Moura,18,,-23.838568,-50.209468
br,sitio manoel de oliveira,Sítio Manoel de Oliveira,18,,-23.4331,-49.8445
br,sitio manoel dos santos,Sítio Manoel dos Santos,04,,-1.463333,-60.285556
br,sitio manoel d. santana,Sítio Manoel D. Santana,18,,-23.8828,-50.9806
br,sitio manoel felipe,Sítio Manoel Felipe,18,,-23.6193,-49.8432
br,sitio manoel fernandes,Sítio Manoel Fernandes,18,,-23.392186,-50.123335
br,sitio manoel garanhane,Sítio Manoel Garanhane,18,,-23.6961,-49.9677
br,sitio manoel godoi,Sítio Manoel Godói,18,,-23.101,-50.0963
br,sitio manoel gomes,Sítio Manoel Gomes,18,,-23.193088,-49.948974
br,sitio manoel goncalves,Sítio Manoel Gonçalves,18,,-23.817289,-50.174675
br,sitio manoel guedes morais,Sítio Manoel Guedes Morais,18,,-23.8846,-50.989
br,sitio manoelino p. dos santos,Sítio Manoelino P. dos Santos,18,,-23.842244,-50.166889
br,sitio manoel j. da costa,Sítio Manoel J. da Costa,18,,-23.6327,-49.8045
br,sitio manoel j. de souza,Sítio Manoel J. de Souza,04,,-1.439722,-60.299722
br,sitio manoel l. da costa,Sítio Manoel L. da Costa,18,,-23.44144,-49.75892
br,sitio manoel m. camargo,Sítio Manoel M. Camargo,18,,-23.923315,-50.506417
br,sitio manoel m. da silva,Sítio Manoel M. da Silva,18,,-23.906742,-50.557377
br,sitio manoel m. de paula,Sítio Manoel M. de Paula,18,,-25.8444,-49.2928
br,sitio manoel messias,Sítio Manoel Messias,18,,-23.6222,-49.8216
br,sitio manoel paulino,Sítio Manoel Paulino,18,,-23.659667,-50.005786
br,sitio manoel pires,Sítio Manoel Pires,18,,-25.36309,-48.974465
br,sitio manoel p. machado,Sítio Manoel P. Machado,18,,-25.8491,-49.3578
br,sitio manoel portugues,Sítio Manoel Português,18,,-23.6773,-49.8278
br,sitio manoel p. primo,Sítio Manoel P. Primo,18,,-23.799818,-50.205742
br,sitio manoel p. rocha,Sítio Manoel P. Rocha,18,,-25.9882,-49.1988
br,sitio manoel quirino,Sítio Manoel Quirino,18,,-25.8245,-49.1416
br,sitio manoel r. da silva,Sítio Manoel R. da Silva,18,,-25.5061,-48.8073
br,sitio manoel r. maia,Sítio Manoel R. Maia,18,,-25.8836,-49.2518
br,sitio manoel rodrigues,Sítio Manoel Rodrigues,18,,-23.1447,-50.1724
br,sitio manoel s. amorim,Sítio Manoel S. Amorim,18,,-25.7763,-48.7165
br,sitio manoel s. da costa,Sítio Manoel S. da Costa,18,,-25.828494,-48.783253
br,sitio manoel silveira,Sítio Manoel Silveira,18,,-25.920905,-48.802938
br,sitio manoel tomaz,Sítio Manoel Tomaz,18,,-23.8591,-50.8221
br,sitio manoel verdelin,Sítio Manoel Verdelin,18,,-25.22384,-48.990082
br,sitio mantovana,Sítio Mantovana,18,,-23.532823,-50.052887
br,sitio mantovanele,Sítio Mantovanele,18,,-23.889911,-50.261314
br,sitio manuel alves,Sítio Manuel Alves,18,,-25.7185,-48.76
br,sitio manuel da silva,Sítio Manuel da Silva,18,,-25.841875,-49.770502
br,sitio manuel de sao frazao,Sítio Manuel de São Frazão,18,,-23.9693,-50.9336
br,sitio manuel g. bandeira,Sítio Manuel G. Bandeira,18,,-25.135495,-48.888711
br,sitio manuelino de moraes,Sítio Manuelino de Moraes,18,,-23.720703,-50.15073
br,sitio manuel l. dias,Sítio Manuel L. Dias,18,,-25.8206,-49.9476
br,sitio manuel luz,Sítio Manuel Luz,18,,-25.797,-49.5656
br,sitio manuel moroira,Sítio Manuel Moroira,27,,-23.6066,-47.6068
br,sitio manuel pedro,Sítio Manuel Pedro,18,,-25.795556,-49.649722
br,sitio manuel pereira,Sitio Manuel Pereira,05,,-11.4,-39.766667
br,sitio manuel rodrigues batista,Sítio Manuel Rodrigues Batista,18,,-25.085837,-48.8393
br,sitio manuel s. de assis,Sítio Manuel S. de Assis,18,,-23.741672,-50.560017
br,sitio manuel,Sítio Manuel,18,,-25.913056,-49.599167
br,sitio manuel veiga,Sítio Manuel Veiga,18,,-25.758013,-48.766898
br,sitio maraba,Sítio Marabá,18,,-23.640226,-50.676288
br,sitio maracana,Sítio Maracanã,18,,-23.30399,-50.136059
br,sitio maracana,Sítio Maracanã,27,,-23.148889,-46.725
br,sitio maracanazinho,Sítio Maracanãzinho,27,,-23.171111,-46.643889
br,sitio maracuja,Sítio Maracujá,27,,-23.572574,-47.13288
br,sitio marafigo,Sítio Marafigo,18,,-25.7956,-49.7526
br,sitio marajo,Sítio Marajó,27,,-23.696333,-47.220971
br,sitio maranata,Sítio Maranata,27,,-23.151944,-46.643611
br,sitio marapa,Sítio Marapá,27,,-23.062787,-46.666852
br,sitio mara,Sítio Mara,18,,-23.80554,-50.799096
br,sitio maravilha,Sítio Maravilha,04,,-1.948611,-61.210278
br,sitio maravilha,Sítio Maravilha,18,,-23.799639,-50.821696
br,sitio marcal nagaky,Sítio Marçal Nagaky,18,,-23.394498,-49.753293
br,sitio marcelino linhares,Sítio Marcelino Linhares,18,,-25.826944,-49.734167
br,sitio marcelino lourenco,Sítio Marcelino Lourenço,18,,-23.6377,-49.8681
br,sitio marcelino rohrbacher,Sítio Marcelino Rohrbacher,18,,-26.0741,-49.4604
br,sitio marcelo f. heiten,Sítio Marcelo F. Heiten,26,,-26.1971,-49.3494
br,sitio marcelo sa filho,Sítio Marcelo Sá Filho,18,,-25.5027,-49.9509
br,sitio marcelo,Sítio Marcelo,18,,-23.525635,-50.032316
br,sitio marcia s. bevka,Sítio Márcia S. Bevka,18,,-25.776111,-49.663611
br,sitio marciho personi,Sítio Marcího Personi,18,,-23.007126,-49.989581
br,sitio marcilio guedes,Sítio Marcílio Guedes,18,,-23.191,-50.1295
br,sitio marcilio neto,Sítio Marcílio Neto,18,,-23.438321,-49.835717
br,sitio marcilio pinto,Sítio Marcílio Pinto,18,,-23.32114,-49.806387
br,sitio marcilio,Sítio Marcílio,18,,-23.527284,-49.775676
br,sitio marcio costabile,Sítio Márcio Costabile,18,,-25.905278,-49.733611
br,sitio marcio karote,Sítio Márcio Karote,18,,-26.1121,-49.755
br,sitio marclino da c. martins,Sítio Marclino da C. Martins,18,,-26.0382,-49.4533
br,sitio marco antonio,Sítio Marco Antônio,18,,-25.057091,-48.841223
br,sitio marcos carvalho,Sítio Marcos Carvalho,18,,-23.698872,-50.12906
br,sitio marcos machoviski,Sítio Marcos Machoviski,18,,-26.0568,-49.818
br,sitio marcos,Sítio Marcos,18,,-25.9155,-49.2359
br,sitio marcos,Sítio Marcos,27,,-24.6141,-48.367
br,sitio marelina,Sítio Marelina,18,,-23.720883,-50.036334
br,sitio marfim,Sítio Marfim,18,,-23.796299,-50.511057
br,sitio margarida de oliveira,Sítio Margarida de Oliveira,18,,-23.955034,-50.018475
br,sitio margarida reiser,Sítio Margarida Reiser,26,,-26.1325,-49.2523
br,sitio maria abilio,Sítio Maria Abílio,18,,-23.957836,-50.166867
br,sitio maria a. b. perico,Sítio Maria A. B. Périco,18,,-23.7135,-49.9172
br,sitio maria a. da rocha,Sítio Maria A. da Rocha,18,,-25.9588,-49.1392
br,sitio maria a. da silva,Sítio Maria A. da Silva,18,,-23.44769,-50.096237
br,sitio maria a. do couto,Sítio Maria A. do Couto,18,,-23.6785,-49.8025
br,sitio maria a. domingues,Sítio Maria A. Domingues,18,,-26.017862,-49.650602
br,sitio maria a. kuss,Sítio María A. Kuss,26,,-26.1592,-49.822
br,sitio maria aparecida,Sítio Maria Aparecida,04,,-1.882222,-60.079167
br,sitio maria aparecida,Sítio Maria Aparecida,18,,-23.522081,-50.006665
br,sitio maria assunta seguro,Sítio Maria Assunta Seguro,18,,-25.5772,-49.9507
br,sitio maria augustin,Sítio Maria Augustin,26,,-26.1971,-49.3822
br,sitio maria botrova,Sítio Maria Botrova,18,,-26.178206,-49.563052
br,sitio maria bpina,Sítio Maria Bpina,18,,-23.468613,-49.798375
br,sitio maria branco,Sítio Maria Branco,18,,-25.782222,-49.652222
br,sitio maria b. ziller,Sítio Maria B. Ziller,18,,-23.5816,-49.9206
br,sitio maria c. de freitas,Sítio Maria C. de Freitas,18,,-26.0217,-49.9282
br,sitio maria clara pimentel,Sítio Maria Clara Pimentel,18,,-25.911498,-49.938888
br,sitio maria c. pereira,Sítio Maria C. Pereira,18,,-25.5028,-48.8576
br,sitio maria cristina,Sítio Maria Cristina,18,,-23.895303,-50.055592
br,sitio maria cuiz,Sítio Maria Cuiz,18,,-25.798374,-49.75449
br,sitio maria da conceicao bier,Sítio Maria da Conceição Bier,18,,-25.830042,-49.950403
br,sitio maria da luz,Sítio Maria da Luz,18,,-25.7833,-49.281
br,sitio maria das dores dos santos,Sítio Maria das Dores dos Santos,18,,-25.8931,-49.1047
br,sitio maria de castro,Sítio Maria de Castro,18,,-23.831495,-50.068713
br,sitio maria de d. l. cavalheiro,Sítio Maria de D. L. Cavalheiro,18,,-25.985,-49.676667
br,sitio maria de freitas,Sítio Maria de Freitas,18,,-23.7007,-49.7686
br,sitio maria de jesus camargo,Sítio Maria de Jesus Camargo,18,,-25.821996,-49.912857
br,sitio maria de jesus,Sítio Maria de Jesus,18,,-23.32466,-50.13266
br,sitio maria de l. malinoski,Sítio Maria de L. Malinoski,18,,-26.173159,-49.651706
br,sitio maria de lourdes,Sítio Maria de Lourdes,18,,-23.918412,-50.31935
br,sitio maria de lurdes machado,Sítio Maria de Lurdes Machado,18,,-25.9766,-49.3223
br,sitio maria de lurdes,Sítio Maria de Lurdes,18,,-25.8965,-49.3383
br,sitio maria de souza,Sítio Maria de Souza,18,,-23.637894,-50.203041
br,sitio maria d. kuch,Sítio Maria D. Kuch,18,,-25.7711,-49.1805
br,sitio maria do carmo popeo,Sítio Maria do Carmo Popeo,18,,-25.982018,-49.865339
br,sitio maria do carmo,Sítio Maria do Carmo,18,,-23.776071,-50.711162
br,sitio maria do lazaro,Sítio Maria do Lázaro,18,,-23.6039,-49.817
br,sitio maria eckil,Sítio Maria Eckil,26,,-26.240126,-49.655816
br,sitio maria estaba,Sítio Maria Estaba,18,,-25.824993,-49.934896
br,sitio maria f. antunes,Sítio Maria F. Antunes,18,,-23.99,-50.9293
br,sitio maria f. de andrade,Sítio Maria F. de Andrade,18,,-25.9357,-49.1195
br,sitio maria ferreira,Sítio Maria Ferreira,18,,-25.7847,-49.2639
br,sitio maria gavazonne,Sítio Maria Gavazonne,18,,-25.228323,-48.509687
br,sitio maria grando,Sítio Maria Grando,18,,-23.443929,-49.793285
br,sitio maria hed,Sítio Maria Hed,18,,-25.986688,-49.863616
br,sitio maria i. mesquita,Sítio Maria I. Mesquita,18,,-26.207643,-49.564918
br,sitio maria inez,Sítio Maria Inez,18,,-23.6047,-49.8554
br,sitio maria j. dos santos,Sítio Maria J. dos Santos,18,,-25.99,-49.524167
br,sitio maria joana,Sítio Maria Joana,18,,-23.951797,-50.519171
br,sitio maria lopes,Sítio Maria Lopes,26,,-26.1237,-49.9653
br,sitio maria madalena,Sítio Maria Madalena,18,,-25.85119,-49.808042
br,sitio maria mazur,Sítio Maria Mazur,18,,-25.794,-49.5362
br,sitio maria m. dos santos,Sítio Maria M. dos Santos,18,,-25.9399,-49.222
br,sitio maria mendes,Sítio Maria Mendes,18,,-25.357768,-48.983539
br,sitio mariana mabile,Sítio Mariana Mabile,18,,-25.8238,-49.5417
br,sitio maria nazareth,Sítio Maria Nazareth,18,,-23.950416,-50.025927
br,sitio mariano amboski,Sítio Mariano Amboski,26,,-26.2292,-49.3147
br,sitio mariano,Sítio Mariano,18,,-23.900424,-50.415644
br,sitio maria parreira,Sítio Maria Parreira,18,,-23.684564,-50.201756
br,sitio maria r. leal,Sítio Maria R. Leal,18,,-23.7192,-49.7608
br,sitio maria r. portela,Sítio Maria R. Portela,18,,-26.168212,-49.554851
br,sitio maria santos,Sítio Maria Santos,26,,-26.0995,-49.9004
br,sitio maria schelbauer,Sítio Maria Schelbauer,26,,-26.1914,-49.8545
br,sitio maria,Sítio Maria,18,,-23.687296,-50.065769
br,sitio maria s. l. ton,Sítio Maria S. L. Ton,18,,-25.7672,-49.5752
br,sitio maria sokodoski,Sítio Maria Sokodoski,26,,-26.1297,-49.9622
br,sitio maria sureck,Sítio Maria Sureck,18,,-25.906944,-49.571667
br,sitio maria t. biskai,Sítio Maria T. Biskai,18,,-25.7683,-49.3837
br,sitio maria teixeira,Sítio Maria Teixeira,18,,-23.6347,-49.878
br,sitio maria trindade,Sítio Maria Trindade,18,,-23.893011,-50.692275
br,sitio maria veiga do prado,Sítio Maria Veiga do Prado,18,,-25.980613,-49.862165
br,sitio maria vicentina de jesus,Sítio Maria Vicentina de Jesus,18,,-23.710064,-50.087546
br,sitio mariazinha,Sítio Mariazinha,27,,-24.8812,-48.4751
br,sitio marilda s. correia,Sítio Marilda S. Correia,18,,-23.980961,-50.509728
br,sitio marilena alves,Sítio Marilena Alves,18,,-25.8858,-49.1814
br,sitio marimbondo,Sítio Marimbondo,18,,-23.695178,-50.208932
br,sitio marines,Sítio Marinês,18,,-23.59594,-50.674348
br,sitio marinho,Sítio Marinho,18,,-23.1668,-50.1198
br,sitio marino,Sítio Marino,27,,-23.863618,-47.003
br,sitio mario a. martins,Sítio Mário A. Martins,18,,-26.15645,-49.647458
br,sitio mario braz de almeida,Sítio Mário Braz de Almeida,18,,-25.995835,-49.903657
br,sitio mario caipira,Sítio Mário Caipira,18,,-23.6406,-50.5588
br,sitio mario c. endo,Sítio Mário C. Endo,18,,-23.865057,-50.324282
br,sitio mario c. machado,Sítio Mário C. Machado,18,,-25.7503,-49.1898
br,sitio mario deda,Sítio Mário Deda,18,,-25.8317,-49.5183
br,sitio mario eckel,Sítio Mário Eckel,26,,-26.0494,-49.9075
br,sitio mario eduardo rossi,Sítio Mário Eduardo Rossi,18,,-23.797984,-50.859661
br,sitio mario estrugale,Sítio Mário Estrugale,18,,-25.6975,-49.8655
br,sitio mario faccin,Sítio Mário Faccin,18,,-25.998673,-49.986166
br,sitio mario ferreira,Sítio Mário Ferreira,26,,-26.109,-49.8714
br,sitio mario gama,Sítio Mário Gama,18,,-25.7153,-48.7609
br,sitio mario ioche,Sítio Mário Ioche,18,,-25.779,-49.454
br,sitio mario kotovicz,Sítio Mário Kotovicz,26,,-26.139,-49.2844
br,sitio mario krinker,Sítio Mário Krinker,18,,-25.7652,-49.555
br,sitio mario leiniker,Sítio Mário Leiniker,18,,-25.847495,-49.761556
br,sitio mario lourenco,Sítio Mário Lourenço,18,,-25.7787,-49.5821
br,sitio mario marinho,Sítio Mário Marinho,18,,-23.985343,-50.145542
br,sitio mario mashita,Sítio Mário Mashita,18,,-23.9741,-50.8378
br,sitio mario m. de carvalho,Sítio Mário M. de Carvalho,18,,-23.6926,-49.76
br,sitio mario negreti,Sítio Mário Negreti,18,,-23.2251,-50.1451
br,sitio mario oliveira,Sítio Mário Oliveira,18,,-23.617645,-50.134837
br,sitio mario oripes oliveira,Sítio Mário Oripes Oliveira,18,,-25.194755,-48.525104
br,sitio mario p. da silva,Sítio Mário P. da Silva,18,,-23.719,-49.8529
br,sitio mario p. de oliveira,Sítio Mario P. de Oliveira,18,,-25.125947,-48.857595
br,sitio mario peres,Sítio Mário Peres,18,,-23.899555,-50.16301
br,sitio mario ribeiro,Sítio Mário Ribeiro,18,,-23.2827,-49.7688
br,sitio mario rogovski,Sítio Mário Rogovski,18,,-25.8677,-49.52
br,sitio mario souza rodrigues,Sítio Mário Souza Rodrigues,18,,-23.873,-50.9794
br,sitio mario viana,Sítio Mário Viana,18,,-25.196407,-48.985258
br,sitio mario vierne,Sítio Mário Vierne,18,,-26.1513,-49.3845
br,sitio mario zappe,Sítio Mário Zappe,18,,-26.1271,-49.3578
br,sitio maripe,Sítio Maripê,18,,-23.367879,-50.214801
br,sitio mari,Sítio Mari,06,,-6.9,-39.233333
br,sitio marlene jung,Sítio Marlene Jung,18,,-26.0676,-49.3774
br,sitio marli bizzoto,Sítio Marli Bizzoto,18,,-25.9308,-49.3453
br,sitio marop fantin,Sítio Marop Fantin,18,,-25.7122,-49.9559
br,sitio marques,Sítio Marques,18,,-23.511484,-50.744518
br,sitio marta gukestein,Sítio Marta Gukestein,26,,-26.139,-49.8875
br,sitio marta lader,Sítio Marta Lader,26,,-26.1173,-49.2854
br,sitio marta muziol,Sítio Marta Muziol,18,,-26.1527,-49.418
br,sitio marta ptachki,Sítio Marta Ptachki,18,,-26.1212,-49.3394
br,sitio martin drever,Sítio Martin Drever,26,,-26.1495,-49.3533
br,sitio martinha cavalheiro,Sítio Martinha Cavalheiro,18,,-26.1209,-49.4088
br,sitio martinho rocha,Sítio Martinho Rocha,18,,-26.0049,-49.2606
br,sitio martinho,Sítio Martinho,27,,-23.077222,-46.635833
br,sitio martinhotelma,Sítio MartinhoTelma,26,,-26.1282,-49.3361
br,sitio martins sebastiao,Sítio Martins Sebastião,18,,-25.6129,-48.802
br,sitio martins,Sítio Martins,27,,-24.5591,-48.409
br,sitio marujo,Sítio Marujo,27,,-23.590045,-47.099861
br,sitio marumbi,Sítio Marumbi,18,,-25.41546,-48.87543
br,sitio mascarelli,Sítio Mascarelli,18,,-23.4614,-49.8537
br,sitio massaru wakayama,Sítio Massaru Wakayama,18,,-23.5494,-49.8956
br,sitio massepe,Sítio Massepê,06,,-7.466667,-39.116667
br,sitio matao,Sítio Matão,27,,-23.072778,-47.620833
br,sitio matecana,Sítio Matecana,18,,-23.0961,-50.0939
br,sitio mateus aliski,Sítio Mateus Aliski,18,,-25.8228,-49.284
br,sitio mateus mavarrete,Sítio Mateus Mavarrete,18,,-23.733382,-50.067614
br,sitio mateus vesoloski,Sítio Mateus Vesoloski,26,,-26.2137,-49.9382
br,sitio matias a. de bastos,Sítio Matias A. de Bastos,18,,-26.0306,-49.4521
br,sitio mato comprido,Sítio Mato Comprido,27,,-23.189444,-46.714722
br,sitio mato dentro,Sítio Mato Dentro,21,,-22.7571,-44.1653
br,sitio mato-dentro,Sítio Mato-Dentro,27,,-23.283428,-46.67322
br,sitio matusalem pinto,Sítio Matusalém Pinto,18,,-23.883764,-50.465346
br,sitio maura ferrachiole,Sítio Maura Ferrachiole,18,,-23.6227,-49.753
br,sitio maurao,Sítio Maurão,18,,-23.5045,-49.9034
br,sitio mauricio m. fujii,Sítio Maurício M. Fujii,18,,-25.9325,-49.1282
br,sitio maurilio schelbauer,Sítio Maurílio Schelbauer,18,,-26.041577,-49.688902
br,sitio mauro abigalisk,Sítio Mauro Abigalisk,26,,-26.2345,-49.8307
br,sitio mauro manzano,Sítio Mauro Manzano,18,,-23.930874,-50.236234
br,sitio mauro pecharki,Sítio Mauro Pecharki,18,,-25.7689,-49.306
br,sitio mauro zanata,Sítio Mauro Zanata,18,,-23.5642,-50.572
br,sitio maximiliano malinosk,Sítio Maximiliano Malinosk,26,,-26.2352,-49.3455
br,sitio max shulzc,Sítio Max Shulzc,26,,-26.1834,-49.326
br,sitio mecmisdck v. dos santos,Sítio Mecmisdck V. dos Santos,18,,-25.497877,-48.878605
br,sitio meireles,Sítio Meireles,18,,-23.0561,-50.1232
br,sitio meleiro,Sítio Meleiro,30,,-7.65,-40.033333
br,sitio melo a. pereira,Sítio Melo A. Pereira,18,,-25.8841,-48.7363
br,sitio melo,Sítio Melo,06,,-7.3,-39.383333
br,sitio melo,Sítio Melo,18,,-23.838054,-50.484344
br,sitio mendes borniak,Sítio Mendes Borniak,18,,-25.8395,-49.5087
br,sitio mendes,Sítio Mendes,18,,-23.63071,-50.124379
br,sitio mercilio,Sítio Mercílio,18,,-25.8746,-49.0449
br,sitio messias da costa,Sítio Messias da Costa,18,,-23.5962,-49.8247
br,sitio messias de siqueira,Sítio Messias de Siqueira,18,,-23.649087,-50.161567
br,sitio messias de souza,Sítio Messias de Souza,18,,-23.6315,-49.7898
br,sitio messias h. de oliveira,Sítio Messias H. de Oliveira,18,,-25.9737,-49.0545
br,sitio meu cantinho,Sítio Meu Cantinho,27,,-23.937783,-47.04105
br,sitio meu paraiso,Sítio Meu Paraíso,27,,-23.214444,-46.560833
br,sitio meu rincao,Sítio Meu Rincão,27,,-23.1875,-46.596667
br,sitio meu xodo,Sítio Meu Xodó,27,,-23.098611,-46.596944
br,sitio michel,Sítio Michel,18,,-23.5218,-49.8966
br,sitio miescelau fergunsaac,Sítio Miescelau Fergunsaac,26,,-26.2181,-49.9977
br,sitio mieteblau p. trzciak,Sítio Mieteblau P. Trzciak,18,,-25.8801,-49.5199
br,sitio migueis padilha,Sítio Migueis Padilha,18,,-26.088023,-49.68666
br,sitio miguel a. de paula,Sítio Miguel A. de Paula,18,,-25.204377,-48.886518
br,sitio miguel a. de souza,Sítio Miguel A. de Souza,18,,-23.403615,-50.050827
br,sitio miguel alves de oliveira,Sítio Miguel Alves de Oliveira,18,,-25.7009,-48.7524
br,sitio miguel andreu,Sítio Miguel Andreu,18,,-25.7863,-49.202
br,sitio miguel balbino,Sítio Miguel Balbino,18,,-23.890216,-50.248722
br,sitio miguel batista,Sítio Miguel Batista,18,,-25.794722,-49.638333
br,sitio miguel b. baena,Sítio Miguel B. Baena,18,,-23.769227,-50.086452
br,sitio miguel buba,Sítio Miguel Buba,18,,-26.112454,-49.547025
br,sitio miguel carax,Sítio Miguel Carax,18,,-25.968056,-49.507778
br,sitio miguel carlo budek,Sítio Miguel Carlo Budek,18,,-25.84424,-49.902567
br,sitio miguel carneiro,Sítio Miguel Carneiro,18,,-23.469297,-49.965747
br,sitio miguel cochiba,Sítio Miguel Cochiba,18,,-25.7945,-49.5161
br,sitio miguel coladino,Sítio Miguel Coladino,18,,-23.6679,-49.7944
br,sitio miguel costa,Sítio Miguel Costa,18,,-23.6988,-49.864
br,sitio miguel da silva bispo,Sítio Miguel da Silva Bispo,27,,-25.049723,-48.566604
br,sitio miguel d. dos santos,Sítio Miguel D. dos Santos,18,,-25.7899,-49.5663
br,sitio miguel de lima,Sítio Miguel de Lima,18,,-25.8885,-49.2545
br,sitio miguel de o. ribas,Sítio Miguel de O. Ribas,18,,-26.0159,-49.4159
br,sitio miguel de paula,Sítio Miguel de Paula,18,,-25.5433,-49.9079
br,sitio miguel dreveki,Sítio Miguel Dreveki,18,,-26.1055,-49.3474
br,sitio miguel drevek,Sítio Miguel Drevek,18,,-26.0964,-49.3301
br,sitio miguel faot,Sítio Miguel Faot,18,,-25.8139,-49.4434
br,sitio miguel f. da silva,Sítio Miguel F. da Silva,18,,-25.776965,-49.823685
br,sitio miguel f. dos santos,Sítio Miguel F. dos Santos,18,,-25.83574,-49.985028
br,sitio miguel grosskopf,Sítio Miguel Grosskopf,26,,-26.154,-49.3538
br,sitio miguel hodmeier,Sítio Miguel Hodmeier,18,,-25.931702,-49.794404
br,sitio miguel ianoski,Sítio Miguel Ianoski,18,,-25.8124,-49.4059
br,sitio miguel iaros,Sítio Miguel Iaros,18,,-23.651,-49.9994
br,sitio miguel idainskai,Sítio Miguel Idainskai,18,,-25.7724,-49.2713
br,sitio miguel junior,Sítio Miguel Júnior,18,,-23.502,-49.8968
br,sitio miguel krischeviscz,Sítio Miguel Krischeviscz,18,,-25.7685,-49.4441
br,sitio miguel kusma,Sítio Miguel Kusma,18,,-26.016367,-49.696975
br,sitio miguel l. da costa,Sítio Miguel L. da Costa,18,,-23.821324,-50.053895
br,sitio miguel lima,Sítio Miguel Lima,26,,-26.2208,-49.87
br,sitio miguel l. pelander,Sítio Miguel L. Pelander,18,,-25.875736,-49.224209
br,sitio miguel lucas,Sítio Miguel Lucas,18,,-23.603,-49.8506
br,sitio miguel muchum,Sítio Miguel Muchum,18,,-26.0892,-49.3342
br,sitio miguel nalevaiko,Sítio Miguel Nalevaiko,18,,-23.782805,-50.123151
br,sitio miguel osorio,Sítio Miguel Osório,18,,-23.736561,-50.016688
br,sitio miguel palt,Sítio Miguel Palt,18,,-25.935775,-49.438815
br,sitio miguel penca,Sítio Miguel Penca,18,,-25.752852,-49.432465
br,sitio miguel psibidviski,Sítio Miguel Psibidviski,18,,-25.7815,-49.5312
br,sitio miguel ribas,Sítio Miguel Ribas,18,,-26.0381,-49.4978
br,sitio miguel rodrigues,Sítio Miguel Rodrigues,18,,-25.471729,-48.879448
br,sitio miguel siedeliski,Sítio Miguel Siedeliski,18,,-25.7756,-49.2848
br,sitio miguel silva,Sítio Miguel Silva,18,,-25.997478,-49.904666
br,sitio miguel simette,Sítio Miguel Simette,26,,-26.1969,-49.8159
br,sitio miguel sitleka,Sítio Miguel Sitleka,18,,-25.758333,-49.635556
br,sitio miguel stafin,Sítio Miguel Stafin,18,,-26.081092,-49.536332
br,sitio miguel taioka,Sítio Miguel Taioka,18,,-25.807082,-49.493063
br,sitio miguel ukan,Sítio Miguel Ukan,18,,-25.7942,-49.403
br,sitio miguel veiga,Sítio Miguel Veiga,18,,-25.9234,-49.4017
br,sitio miguel zpson,Sítio Miguel Zpson,18,,-25.8604,-49.597
br,sitio mijai,Sítio Mijai,27,,-23.705075,-47.176366
br,sitio mikael zacour,Sítio Mikael Zacour,18,,-25.8016,-49.1417
br,sitio milhares,Sítio Milhares,18,,-23.901757,-50.461204
br,sitio milica e basilio de matos,Sítio Milica e Basílio de Matos,18,,-23.808115,-50.485701
br,sitio milton bontosello,Sítio Milton Bontosello,18,,-25.8317,-49.109
br,sitio milton cordeiro,Sítio Milton Cordeiro,18,,-25.815692,-49.870925
br,sitio milton de campos,Sítio Milton de Campos,18,,-25.465577,-48.81862
br,sitio milton de oliveira,Sítio Milton de Oliveira,18,,-23.7149,-49.9186
br,sitio milton ferreira,Sítio Milton Ferreira,18,,-23.955328,-50.364883
br,sitio milton grandim,Sítio Milton Grandim,18,,-25.201115,-48.972886
br,sitio milton luzieto,Sítio Milton Luzieto,18,,-23.1843,-50.1128
br,sitio milton moreira,Sítio Milton Moreira,18,,-25.9234,-49.2136
br,sitio minador,Sítio Minador,14,,-16.125,-56.923611
br,sitio mina grande,Sítio Mina Grande,18,,-23.41976,-49.835659
br,sitio minami,Sítio Minami,27,,-23.66607,-47.130229
br,sitio minas gerais,Sítio Minas Gerais,18,,-23.612303,-50.501871
br,sitio mineiros,Sítio Mineiros,18,,-23.1432,-50.1056
br,sitio minoro nuke,Sítio Minoro Nuke,18,,-23.531153,-50.738689
br,sitio minoro yob,Sítio Minoro Yob,18,,-23.54023,-50.697951
br,sitio minuano,Sítio Minuano,18,,-25.7621,-49.2128
br,sitio mira flores,Sítio Mira Flores,27,,-23.8947,-46.7342
br,sitio miranda ii,Sítio Miranda II,18,,-23.897554,-50.02657
br,sitio miria,Sítio Miriã,18,,-23.86429,-50.316584
br,sitio miro,Sítio Miro,18,,-25.6468,-48.8387
br,sitio mk,Sítio MK,18,,-25.762449,-49.77654
br,sitio moacir carvalho,Sítio Moacir Carvalho,18,,-23.822961,-50.046267
br,sitio moacir chereda,Sítio Moacir Chereda,18,,-26.182948,-49.562368
br,sitio moacir dias,Sítio Moacir Dias,15,,-22.6283,-45.5376
br,sitio moacir f. xavier,Sítio Moacir F. Xavier,18,,-25.922755,-49.158741
br,sitio moacir jorge,Sítio Moacir Jorge,18,,-23.5645,-49.8338
br,sitio moacir marques,Sítio Moacir Marques,18,,-25.597,-48.8076
br,sitio moacir preste,Sítio Moacir Preste,18,,-23.910662,-50.271121
br,sitio moacir rabelo de arruda,Sítio Moacir Rabelo de Arruda,27,,-24.8463,-48.0954
br,sitio moacir,Sítio Moacir,18,,-23.78963,-50.848151
br,sitio mochizawa,Sítio Mochizawa,18,,-23.7967,-50.9626
br,sitio mococa,Sítio Mococa,18,,-23.890578,-50.080804
br,sitio moco da onca,Sítio Mocó da Onça,27,,-23.9499,-47.2019
br,sitio modelo,Sítio Modelo,18,,-23.89035,-50.197717
br,sitio modesto paiscek,Sítio Modesto Paiscek,18,,-25.7937,-49.5467
br,sitio modesto skraba,Sítio Modesto Skraba,18,,-25.7645,-49.4545
br,sitio moinho de vento,Sítio Moinho de Vento,27,,-23.193611,-46.592778
br,sitio moinho,Sítio Moinho,27,,-23.523851,-47.073835
br,sitio moinho velho,Sítio Moinho Velho,27,,-23.106111,-46.5175
br,sitio moises barbosa,Sítio Moisés Barbosa,18,,-23.7307,-49.9176
br,sitio moises c. do vale,Sítio Moisés C. do Vale,18,,-23.794307,-50.130605
br,sitio moises pereira,Sítio Moisés Pereira,18,,-25.5971,-48.8063
br,sitio moises teixeira almeida,Sítio Moisés Teixeira Almeida,18,,-23.430643,-50.151031
br,sitio monjolinho,Sítio Monjolinho,18,,-23.860324,-50.664868
br,sitio monjolinho,Sítio Monjolinho,27,,-23.526708,-47.173904
br,sitio monjolo,Sítio Monjolo,18,,-25.9032,-49.0807
br,sitio monjolo,Sítio Monjolo,27,,-23.28053,-46.514237
br,sitio monjolo velho,Sítio Monjolo Velho,18,,-23.783194,-50.166624
br,sitio monjolo velho,Sítio Monjolo Velho,27,,-23.9673,-47.1709
br,sitio mon plazer,Sítio Mon Plazer,27,,-23.145556,-46.699722
br,sitio monte alegre,Sítio Monte Alegre,06,,-6.883333,-39.45
br,sitio monte alegre,Sítio Monte Alegre,18,,-23.117202,-49.864843
br,sitio monte-alegre,Sítio Monte-Alegre,27,,-23.087222,-46.656944
br,sitio monte alto,Sítio Monte Alto,18,,-23.5469,-49.8907
br,sitio monte azul,Sítio Monte Azul,27,,-23.750172,-46.721931
br,sitio monte belo,Sítio Monte Belo,18,,-23.880353,-50.450485
br,sitio monte carlo,Sítio Monte Carlo,27,,-23.585195,-47.139876
br,sitio monte cristo,Sítio Monte Cristo,18,,-23.954568,-50.524425
br,sitio monte das oliveiras,Sítio Monte das Oliveiras,18,,-23.306671,-52.739612
br,sitio monteplo,Sítio Monteplo,06,,-6.983333,-39.483333
br,sitio montes claros,Sítio Montes Claros,27,,-23.9424,-47.094
br,sitio monte sol,Sítio Monte Sol,18,,-23.807898,-50.117821
br,sitio monte verde,Sítio Monte Verde,27,,-23.556545,-47.069058
br,sitio montreal,Sítio Montreal,27,,-23.262272,-46.574292
br,sitio moquenzinho,Sítio Moquenzinho,18,,-23.5339,-49.9889
br,sitio morada das flores,Sítio Morada das Flores,27,,-23.367479,-46.594972
br,sitio morada do sol,Sítio Morada do Sol,18,,-23.8081,-50.1471
br,sitio morada do sol,Sítio Morada do Sol,27,,-23.013333,-46.6725
br,sitio morada do vento,Sítio Morada do Vento,27,,-23.649932,-47.134521
br,sitio morada graciosa,Sítio Morada Graciosa,18,,-25.321593,-48.923342
br,sitio morais,Sítio Morais,18,,-23.354572,-50.06656
br,sitio moreira,Sítio Moreira,18,,-23.326527,-50.115005
br,sitio morelim,Sítio Morelim,18,,-23.501234,-50.003279
br,sitio morinaga,Sítio Morinaga,18,,-23.7882,-50.9694
br,sitio morita,Sítio Morita,18,,-23.558047,-50.732638
br,sitio mororo-mirim,Sítio Mororó-Mirim,27,,-22.6476,-45.5903
br,sitio morrinho,Sítio Morrinho,18,,-23.6293,-49.9724
br,sitio morrinho,Sítio Morrinho,27,,-24.578256,-48.078674
br,sitio morro alto,Sítio Morro Alto,27,,-23.0187,-47.8529
br,sitio morro aremedia,Sítio Morro Aremedia,27,,-23.8119,-46.7142
br,sitio morro azul,Sítio Morro Azul,27,,-23.2225,-46.656111
br,sitio morro da canela,Sítio Morro da Canela,27,,-24.712532,-48.166572
br,sitio morro da cruz,Sítio Morro da Cruz,18,,-25.5578,-49.9684
br,sitio morro grande,Sítio Morro Grande,27,,-23.467062,-46.696819
br,sitio mosquito,Sítio Mosquito,06,,-4.45,-38.016667
br,sitio mosume,Sítio Mosume,18,,-23.89572,-50.292298
br,sitio mota,Sítio Mota,06,,-6.366667,-39.75
br,sitio motokiyo,Sítio Motokiyo,27,,-23.734579,-47.457812
br,sitio moura norato,Sítio Moura Norato,18,,-25.979555,-48.71227
br,sitio mourao,Sítio Mourão,27,,-23.233611,-46.681944
br,sitio moveis sao leopoldo,Sítio Móveis São Leopoldo,26,,-26.204164,-49.654533
br,sitio moximassa morikava,Sítio Moximassa Morikava,18,,-25.8117,-49.3329
br,sitio mozone,Sítio Mozone,18,,-23.875354,-50.327094
br,sitio mr3,Sítio MR3,27,,-23.638252,-47.248112
br,sitio mulungu,Sítio Mulungu,30,,-7.516667,-39.933333
br,sitio mumbuca,Sítio Mumbuca,17,,-7.166667,-36.016667
br,sitio mumbuca,Sítio Mumbuca,27,,-24.668,-48.3
br,sitio munhoz,Sítio Munhoz,18,,-25.9121,-49.1611
br,sitio municar,Sítio Municar,27,,-23.754323,-46.709827
br,sitio murakame,Sítio Murakame,18,,-23.872794,-50.298941
br,sitio myaio,Sítio Myaio,18,,-23.1037,-50.2143
br,sitio nabor n. dorabiello,Sítio Nabor N. Dorabiello,18,,-26.0586,-49.3211
br,sitio nadir m. da luz,Sítio Nadir M. da Luz,18,,-25.8526,-49.3949
br,sitio nadir o. da cruz,Sítio Nadir O. da Cruz,18,,-25.9409,-49.4155
br,sitio nagata,Sítio Nagata,18,,-23.688083,-50.094549
br,sitio nagel,Sítio Nagel,18,,-23.774007,-50.237764
br,sitio nagibe nunes,Sítio Nagibe Nunes,18,,-23.914257,-50.270302
br,sitio nair b. miranda,Sítio Nair B. Miranda,18,,-23.7401,-49.7978
br,sitio nair carvalho,Sítio Nair Carvalho,26,,-26.2344,-49.9348
br,sitio nair da silva,Sítio Nair da Silva,18,,-23.6406,-49.9655
br,sitio nair de souza,Sítio Nair de Souza,18,,-23.9957,-50.8404
br,sitio nakakira,Sítio Nakakira,27,,-23.679153,-47.133739
br,sitio nakata,Sítio Nakata,18,,-23.7762,-50.9778
br,sitio nakawa,Sítio Nakawa,18,,-23.895635,-50.301643
br,sitio nao encha o saco,Sítio Não Encha o Saco,18,,-25.430613,-48.876313
br,sitio nao-me-toque,Sítio Não-Me-Toque,18,,-23.0129,-50.1407
br,sitio narciso j. da r. filho,Sítio Narciso J. da R. Filho,18,,-25.8545,-49.1514
br,sitio narciso miguel dos santos,Sítio Narciso Miguel dos Santos,18,,-25.948006,-48.805851
br,sitio narciso rodrigues,Sítio Narciso Rodrigues,18,,-26.122345,-49.6605
br,sitio narciso schafascheck,Sítio Narciso Schafascheck,26,,-26.1416,-49.885
br,sitio narciso schelbauer,Sítio Narciso Schelbauer,26,,-26.1996,-49.8444
br,sitio narcizo d. de lima,Sítio Narcizo D. de Lima,18,,-25.9845,-49.1741
br,sitio nascente do vale,Sítio Nascente do Vale,27,,-24.608269,-48.140304
br,sitio nascer do sol,Sítio Nascer do Sol,18,,-23.025159,-50.136594
br,sitio natal cousulin,Sítio Natal Cousulin,18,,-23.745,-49.8897
br,sitio natalia glomba,Sítio Natália Glomba,18,,-23.52006,-50.080418
br,sitio natali alberti,Sítio Natali Alberti,18,,-25.8705,-49.6191
br,sitio natalina belniak,Sítio Natalina Belniak,18,,-25.7945,-49.5667
br,sitio natalina jose eugenio,Sítio Natalina José Eugênio,18,,-23.8749,-50.9898
br,sitio natalina t. da silva,Sítio Natalina T. da Silva,18,,-23.840613,-50.046676
br,sitio natalino ariendt,Sítio Natalino Ariendt,18,,-23.5553,-49.8518
br,sitio natalino hubis,Sítio Natalino Hubis,26,,-26.024,-49.9909
br,sitio natalio c. de matos,Sítio Natálio C. de Matos,18,,-23.7474,-49.7621
br,sitio natalio consulin,Sítio Natálio Consulin,18,,-23.5245,-49.852
br,sitio natalio de jesus maciel,Sítio Natálio de Jesus Maciel,18,,-25.7192,-49.8009
br,sitio natalio h. dos santos,Sítio Natalio H. dos Santos,18,,-25.9104,-49.3517
br,sitio natal,Sítio Natal,18,,-23.840931,-50.582746
br,sitio natanael pereira,Sítio Natanael Pereira,18,,-25.382718,-48.972011
br,sitio nautilio kuhl,Sítio Nautílio Kuhl,18,,-26.023364,-49.733326
br,sitio navatski sobrinho,Sítio Navatski Sobrinho,18,,-25.7764,-49.2471
br,sitio navib picussa,Sítio Navib Picussa,18,,-25.7989,-49.2662
br,sitio nazare j. francisco,Sítio Nazaré J. Francisco,18,,-23.929016,-50.216937
br,sitio nazira terra,Sítio Nazira Terra,18,,-23.712268,-50.107613
br,sitio neblina,Sítio Neblina,18,,-25.92816,-48.90638
br,sitio nei minardi,Sítio Nei Minardi,18,,-23.61033,-50.151704
br,sitio neivas,Sítio Neivas,18,,-25.179684,-48.843819
br,sitio nelevaldo alves,Sítio Nelevaldo Alves,18,,-26.123318,-49.663221
br,sitio nelso favaro,Sítio Nelso Fávaro,18,,-25.913732,-49.813649
br,sitio nelsom barbosa,Sítio Nelsom Barbosa,18,,-25.322272,-48.75593
br,sitio nelson cruz,Sítio Nelson Cruz,18,,-25.9433,-49.1405
br,sitio nelson da s. guimaraes,Sítio Nelson da S. Guimarães,18,,-23.7039,-49.7977
br,sitio nelson de souza,Sítio Nélson de Souza,18,,-23.948868,-50.59614
br,sitio nelson de souza,Sítio Nelson de Souza,26,,-26.0531,-49.9791
br,sitio nelson ferreira,Sítio Nelson Ferreira,18,,-23.692639,-50.139924
br,sitio nelson f. terres,Sítio Nelson F. Terres,18,,-25.978663,-49.838995
br,sitio nelson garcia,Sítio Nelson Garcia,18,,-23.6148,-49.9957
br,sitio nelson groscop,Sítio Nelson Groscop,18,,-26.1288,-49.4477
br,sitio nelson h. ferreira,Sítio Nelson H. Ferreira,18,,-23.5751,-49.9494
br,sitio nelson kipoviski,Sítio Nelson Kipoviski,18,,-26.0253,-49.4736
br,sitio nelson libel,Sítio Nelson Libel,18,,-26.140528,-49.457665
br,sitio nelson miguel,Sítio Nelson Miguel,18,,-23.6097,-49.9496
br,sitio nelson morais,Sítio Nelson Morais,18,,-23.377837,-49.971848
br,sitio nelson moreira,Sítio Nelson Moreira,18,,-23.950748,-50.361714
br,sitio nelson morinaga,Sítio Nelson Morinaga,18,,-23.7926,-50.9669
br,sitio nelson p. bueno,Sítio Nelson P. Bueno,18,,-23.900946,-50.193356
br,sitio nelson prendim,Sítio Nelson Prendim,18,,-25.7721,-49.1741
br,sitio nelson ribas,Sítio Nelson Ribas,18,,-25.3639,-48.6312
br,sitio nelson ribeiro,Sítio Nelson Ribeiro,18,,-23.6606,-49.9617
br,sitio nelson sanches,Sítio Nelson Sanches,18,,-23.7458,-49.9645
br,sitio nelson,Sítio Nelson,18,,-23.134945,-49.872637
br,sitio nelson umlauf,Sítio Nelson Umlauf,26,,-25.990254,-48.882484
br,sitio nelson w. da silva,Sítio Nelson W. da Silva,18,,-25.9321,-49.0482
br,sitio neno bordinhao,Sítio Neno Bordinhão,18,,-25.8229,-49.1285
br,sitio neno,Sítio Neno,18,,-23.773653,-50.706273
br,sitio neoptolemo de alcantara,Sítio Neoptolemo de Alcântara,18,,-25.2659,-48.7386
br,sitio nercio bonettes,Sítio Nércio Bonettes,26,,-26.2225,-49.864
br,sitio nercisa cadena,Sítio Nercisa Cadena,18,,-26.0132,-49.9582
br,sitio nereu dranka,Sítio Nereu Dranka,18,,-25.780833,-49.634167
br,sitio nereu j. miguel,Sítio Nereu J. Miguel,26,,-26.1746,-49.9336
br,sitio nery gueker,Sítio Nery Gueker,26,,-26.152352,-49.733086
br,sitio nestalio de p. teixeira,Sítio Nestalio de P. Teixeira,18,,-25.7037,-49.9648
br,sitio nestor roem,Sítio Nestor Roem,18,,-25.4596,-48.7465
br,sitio neu mingotti,Sítio Neu Mingotti,18,,-23.668029,-50.664323
br,sitio neuri lacerda,Sítio Neuri Lacerda,18,,-26.0276,-49.329
br,sitio neusa,Sítio Neusa,18,,-23.505846,-50.05732
br,sitio neuza do rocio,Sítio Neuza do Rocio,18,,-25.935,-49.1456
br,sitio nevecinio r. wanderley,Sítio Nevecinio R. Wanderley,26,,-26.1673,-49.8481
br,sitio newton birski,Sítio Newton Birski,18,,-25.8474,-49.1425
br,sitio nha deas nho joao,Sítio Nhá Deas Nhô João,27,,-23.690849,-47.155094
br,sitio nhunguara,Sítio Nhunguara,27,,-24.5818,-48.4098
br,sitio nicanor ribeiro,Sítio Nicanor Ribeiro,18,,-23.6529,-49.807
br,sitio niceia,Sítio Nicéia,18,,-23.913518,-50.290134
br,sitio nicola,Sítio Nicola,18,,-25.8527,-49.0296
br,sitio nicolau fuckner,Sítio Nicolau Fuckner,18,,-26.078265,-49.61973
br,sitio nicolau g. lopes,Sítio Nicolau G. Lopes,18,,-23.90094,-50.246517
br,sitio nicolau ivanko,Sítio Nicolau Ivanko,26,,-26.1066,-49.9831
br,sitio nicolau peichisis,Sítio Nicolau Peichisis,26,,-26.0939,-49.9699
br,sitio nicolau riston,Sítio Nicolau Riston,18,,-25.102682,-48.814536
br,sitio nico simone,Sítio Nico Simone,18,,-23.0086,-50.2317
br,sitio nidenir francisco,Sítio Nidenir Francisco,18,,-25.7681,-49.5799
br,sitio nilo buml e irmaos,Sítio Nilo Buml e Irmãos,18,,-26.1289,-49.4765
br,sitio nilo piratelo,Sítio Nilo Piratelo,18,,-23.5724,-49.8953
br,sitio nilson a. e irmao,Sítio Nilson A. e Irmão,18,,-23.5974,-49.9652
br,sitio nilson arantes,Sítio Nilson Arantes,18,,-23.2346,-50.2142
br,sitio nilson c. de sousa,Sítio Nílson C. de Sousa,04,,-1.586111,-61.488333
br,sitio nilson kinopik,Sítio Nilson Kinopik,18,,-26.0501,-49.498
br,sitio nilson pires,Sítio Nilson Pires,18,,-23.1329,-50.2319
br,sitio nilson,Sítio Nilson,18,,-25.191036,-48.933267
br,sitio nilson spitzner,Sítio Nilson Spitzner,26,,-26.2047,-49.4925
br,sitio nilson vandolini,Sítio Nilson Vandolini,18,,-25.8176,-48.5537
br,sitio nilson wengraynski,Sítio Nilson Wengraynski,18,,-25.7503,-49.3273
br,sitio nilton luiz cavassim,Sítio Nilton Luiz Cavassim,18,,-25.44615,-48.820205
br,sitio nilton r. da costa,Sítio Nilton R. da Costa,18,,-23.285575,-50.169019
br,sitio nilton ribas,Sítio Nilton Ribas,18,,-25.781907,-49.806999
br,sitio nilton,Sítio Nilton,18,,-23.896701,-50.283404
br,sitio nilton vilas boas,Sítio Nilton Vilas Boas,18,,-23.379848,-50.101558
br,sitio nilton weber,Sítio Nilton Weber,18,,-26.051051,-49.65618
br,sitio nisio duarte,Sítio Nísio Duarte,18,,-25.5377,-48.7984
br,sitio nisio kolasso,Sítio Nísio Kolasso,18,,-25.7721,-49.5768
br,sitio nivalao pereira,Sítio Nivalão Pereira,26,,-26.127,-49.9061
br,sitio nivaldo de lima,Sítio Nivaldo de Lima,18,,-25.961342,-49.853596
br,sitio nivaldo de s. lisboa,Sítio Nivaldo de S. Lisboa,18,,-26.0936,-49.2993
br,sitio nivaldo f. de moraes,Sítio Nivaldo F. de Moraes,18,,-23.747799,-50.660722
br,sitio nivaldo f. dos santos,Sítio Nivaldo F. dos Santos,18,,-25.9667,-49.1558
br,sitio nivaldo f. fastinoni,Sítio Nivaldo F. Fastinoni,18,,-23.5737,-49.8554
br,sitio nivaldo f. terres,Sítio Nivaldo F. Terres,18,,-25.923246,-49.972575
br,sitio nivaldo l. dos santos,Sítio Nivaldo L. dos Santos,26,,-26.2024,-49.9472
br,sitio nivaldo morro,Sítio Nivaldo Morro,18,,-23.80085,-50.724866
br,sitio nivaldo nunes,Sítio Nivaldo Nunes,18,,-23.929678,-50.150164
br,sitio nivaldo pavani,Sítio Nivaldo Pavani,18,,-23.886677,-50.204526
br,sitio nivaldo pereira,Sítio Nivaldo Pereira,18,,-25.83414,-49.910403
br,sitio nivaldo sao santos,Sítio Nivaldo São Santos,26,,-26.2093,-49.8777
br,sitio nivaldo stebert,Sítio Nivaldo Stebert,26,,-26.2486,-49.4171
br,sitio nivaldo tums,Sítio Nivaldo Tums,26,,-26.1848,-49.8592
br,sitio nivaldo vanesck,Sítio Nivaldo Vanesck,26,,-26.2497,-49.9385
br,sitio nivaldo wck,Sítio Nivaldo Wck,26,,-26.1293,-49.9698
br,sitio niveldo lazarine,Sítio Niveldo Lazarine,18,,-26.0792,-49.8188
br,sitio no de pinho,Sítio Nó de Pinho,18,,-25.341594,-48.772097
br,sitio noel barbarino,Sítio Noel Barbarino,18,,-23.5606,-49.8011
br,sitio noel landi,Sítio Noel Landi,18,,-23.504061,-50.067731
br,sitio noel rodrigues de jesus,Sítio Noel Rodrigues de Jesus,18,,-23.899787,-50.646457
br,sitio noel t. de godoy,Sítio Noel T. de Godoy,18,,-23.710514,-49.788062
br,sitio noel torres,Sítio Noel Torres,18,,-23.903346,-50.191327
br,sitio noemia dias,Sítio Noémia Dias,18,,-23.892442,-50.429676
br,sitio noe siqueira,Sítio Noé Siqueira,18,,-23.706078,-50.037125
br,sitio nogueira,Sítio Nogueira,18,,-23.633216,-50.536883
br,sitio nogueira velha,Sítio Nogueira Velha,26,,-26.1655,-49.2845
br,sitio noibel,Sítio Noibel,18,,-25.171684,-48.853791
br,sitio noirto sherede,Sítio Noirto Sherede,26,,-26.1603,-49.2781
br,sitio nomai,Sítio Nomai,18,,-23.464097,-50.019206
br,sitio nono vaz,Sítio Nonô Vaz,26,,-26.1919,-49.3905
br,sitio norato t. ferreira,Sítio Norato T. Ferreira,18,,-25.8898,-49.4861
br,sitio norberto sutil,Sítio Norberto Sutil,18,,-23.742959,-50.687208
br,sitio norberto vebra,Sítio Norberto Vêbra,18,,-25.852782,-48.931376
br,sitio norli s. farias,Sítio Norlí S. Farias,18,,-25.941366,-49.232188
br,sitio nossa senhora aparecida,Sítio Nossa Senhora Aparecida,15,,-22.5722,-45.6243
br,sitio nossa senhora aparecida,Sítio Nossa Senhora Aparecida,18,,-23.0021,-50.1208
br,sitio nossa senhora aparecida,Sítio Nossa Senhora Aparecida,27,,-23.036154,-49.905186
br,sitio nossa senhora da conceicao,Sítio Nossa Senhora da Conceição,04,,-1.561389,-60.225
br,sitio nossa senhora da conceicao,Sítio Nossa Senhora da Conceição,18,,-23.91366,-50.499697
br,sitio nossa senhora da gloria,Sítio Nossa Senhora da Glória,18,,-23.491243,-49.886387
br,sitio nossa senhora da guia,Sítio Nossa Senhora da Guia,18,,-23.580345,-50.634871
br,sitio nossa senhora da luz,Sítio Nossa Senhora da Luz,18,,-23.884051,-50.059509
br,sitio nossa senhora da salete,Sítio Nossa Senhora da Salete,15,,-22.5486,-45.5635
br,sitio nossa senhora da salete,Sítio Nossa Senhora da Salete,18,,-23.74094,-50.738598
br,sitio nossa senhora das brotas,Sítio Nossa Senhora das Brotas,18,,-23.885706,-50.609008
br,sitio nossa senhora das brotas,Sítio Nossa Senhora das Brotas,27,,-23.141944,-46.595556
br,sitio nossa senhora das dores,Sítio Nossa Senhora das Dores,18,,-23.811587,-50.485754
br,sitio nossa senhora das gracas,Sítio Nossa Senhora das Graças,18,,-23.7951,-50.2708
br,sitio nossa senhora das gracas,Sítio Nossa Senhora das Graças,27,,-23.939504,-46.652966
br,sitio nossa senhora das neves,Sítio Nossa Senhora das Neves,18,,-23.866417,-50.024494
br,sitio nossa senhora de fatima,Sítio Nossa Senhora de Fátima,04,,-1.458611,-60.293056
br,sitio nossa senhora de fatima,Sítio Nossa Senhora de Fátima,18,,-23.5861,-49.9907
br,sitio nossa senhora de fatima,Sítio Nossa Senhora de Fátima,27,,-23.231667,-46.588611
br,sitio nossa senhora de lourdes,Sítio Nossa Senhora de Lourdes,18,,-23.381747,-49.796709
br,sitio nossa senhora de lourdes,Sítio Nossa Senhora de Lourdes,27,,-23.280404,-46.687409
br,sitio nossa senhora do carmo,Sítio Nossa Senhora do Carmo,18,,-23.0905,-50.1009
br,sitio nossa senhora do carmo,Sítio Nossa Senhora do Carmo,27,,-23.230556,-46.685833
br,sitio nossa senhora do divino amor,Sítio Nossa Senhora do Divino Amor,27,,-23.642026,-47.123032
br,sitio nossa senhora do perpetuo socorro,Sítio Nossa Senhora do Perpétuo Socorro,18,,-23.1582,-50.1843
br,sitio nossa senhora do progresso,Sítio Nossa Senhora do Progresso,18,,-23.789097,-50.389339
br,sitio nossa senhora do rosario,Sítio Nossa Senhora do Rosário,18,,-23.2421,-50.1195
br,sitio nossa senhora do rosario,Sítio Nossa Senhora do Rosário,27,,-23.9124,-46.6817
br,sitio nossa senhora dos remedios,Sítio Nossa Senhora dos Remédios,27,,-23.262918,-46.532222
br,sitio nossa toca,Sítio Nossa Toca,27,,-23.9904,-47.1268
br,sitio nossa toca um,Sítio Nossa Toca Um,27,,-23.9904,-47.1268
br,sitio nosso cantinho,Sítio Nosso Cantinho,27,,-23.193611,-47.635278
br,sitio nosso ninho,Sítio Nosso Ninho,27,,-23.587503,-47.123489
br,sitio nosso ranchinho,Sítio Nosso Ranchinho,27,,-23.220278,-46.7275
br,sitio nosso recanto,Sítio Nosso Recanto,18,,-25.50619,-50.4667
br,sitio nosso recanto,Sítio Nosso Recanto,27,,-23.198056,-46.718889
br,sitio nosso refugio,Sítio Nosso Refúgio,27,,-23.607119,-47.161508
br,sitio nosso sonho,Sítio Nosso Sonho,27,,-23.079722,-46.515278
br,sitio nova america,Sítio Nova América,27,,-23.033333,-46.626111
br,sitio nova aurora,Sítio Nova Aurora,18,,-23.603117,-50.655963
br,sitio nova era,Sítio Nova Era,27,,-23.996,-47.1018
br,sitio nova esperanca,Sítio Nova Esperança,18,,-23.706135,-50.062355
br,sitio nova esperanca,Sítio Nova Esperança,22,,-5.291111,-36.359167
br,sitio nova esperanca,Sítio Nova Esperança,27,,-23.12,-47.5725
br,sitio nova fronteira,Sítio Nova Fronteira,27,,-23.891202,-47.019987
br,sitio nova java,Sítio Nova Java,27,,-23.054167,-47.608889
br,sitio nova olmda,Sítio Nova Olmda,06,,-4.233333,-38.783333
br,sitio nove irmaos,Sítio Nove Irmãos,18,,-23.364359,-50.027197
br,sitio novo de goias,Sítio Novo de Goiás,31,,-5.518333,-47.461111
br,sitio novo do grajau,Sítio Novo do Grajaú,13,,-5.85,-46.716667
br,sitio novo do tocantins,Sítio Novo do Tocantins,31,5787,-5.518333,-47.461111
br,sitio novo horizonte,Sítio Novo Horizonte,18,,-23.11398,-52.056181
br,sitio novo horizonte,Sítio Novo Horizonte,27,,-23.231111,-46.631389
br,sitio novo jardim,Sítio Novo Jardim,18,,-23.64751,-50.19556
br,sitio novo mundo,Sítio Novo Mundo,18,,-23.0696,-50.1935
br,sitio novo nascimento,Sítio Novo Nascimento,18,,-23.667941,-50.192713
br,sitio novo oriente,Sítio Novo Oriente,04,,-1.489722,-60.264167
br,sitio novo,Sítio Novo,05,,-10.916667,-43.133333
br,sitio novo,Sítio Novo,06,,-3.616667,-39.55
br,sitio novo,Sítio Novo,13,,-4.983333,-46.583333
br,sitio novo,Sítio Novo,14,,-15.966667,-54.283333
br,sitio novo,Sítio Novo,15,,-16.05,-41.233333
br,sitio novo,Sítio Novo,20,,-7.383333,-41.433333
br,sitio novo,Sítio Nôvo,22,,-5.283333,-36.3
br,sitio novo,Sítio Novo,27,,-23.099167,-47.514722
br,sitio novo,Sítio Nôvo,30,,-7.9,-40.266667
br,sitio nunes,Sítio Nunes,18,,-23.344561,-50.010383
br,sitio nunes,Sitio Nunes,30,,-8.066667,-37.85
br,sitio nutrimental,Sítio Nutrimental,18,,-25.7667,-49.1341
br,sitio oca oripaba,Sítio Oca Oripaba,27,,-23.165278,-47.605833
br,sitio oca,Sítio Oca,18,,-23.239439,-52.219686
br,sitio ocion,Sítio Ocion,27,,-23.429259,-46.617687
br,sitio octacilio madeira,Sítio Octacílio Madeira,18,,-23.98957,-50.111998
br,sitio odazir n. duarte,Sítio Odazir N. Duarte,18,,-25.5525,-48.7839
br,sitio odenir pereira,Sítio Odenir Pereira,18,,-25.4758,-48.875982
br,sitio odete bueno,Sítio Odete Bueno,18,,-25.796064,-49.884103
br,sitio odete poli,Sítio Odete Poli,18,,-25.197803,-48.988136
br,sitio odilon dutra,Sítio Odilon Dutra,18,,-25.8017,-49.603
br,sitio odilon m. junior,Sítio Odilon M. Júnior,18,,-25.5423,-48.8329
br,sitio odilon r. da silva,Sítio Odilon R. da Silva,26,,-26.1971,-49.9979
br,sitio odilon,Sítio Odilon,18,,-23.264787,-50.053666
br,sitio odilon strugala,Sítio Odilon Strugala,18,,-25.7614,-49.5089
br,sitio odine m. teixeira,Sítio Odine M. Teixeira,26,,-26.2038,-49.7835
br,sitio odinir pinheiro,Sítio Odinir Pinheiro,18,,-26.093198,-49.728578
br,sitio odorico melo santana,Sítio Odorico Melo Santana,18,,-25.232657,-48.923622
br,sitio ogair raimundo,Sítio Ogair Raimundo,18,,-25.3861,-48.6531
br,sitio ogata,Sítio Ogata,18,,-23.529228,-50.676359
br,sitio ogata,Sítio Ogata,27,,-23.748361,-47.464662
br,sitio ohrains petrus,Sítio Ohrains Petrus,18,,-25.788611,-49.722778
br,sitio oito irmaos,Sítio Oito Irmãos,27,,-23.201111,-47.712222
br,sitio oiuri,Sítio Oiuri,27,,-23.686524,-47.171552
br,sitio okabi,Sítio Okabi,27,,-23.690533,-47.160352
br,sitio okada,Sítio Okada,18,,-23.861762,-50.333229
br,sitio okubo,Sítio Okubo,27,,-23.695527,-47.114919
br,sitio oladir carvalho,Sítio Oladir Carvalho,26,,-25.987693,-48.87926
br,sitio olaria,Sítio Olaria,18,,-23.556,-49.7829
br,sitio olaria velha,Sítio Olaria Velha,18,,-25.421309,-48.762768
br,sitio olavo kurovski,Sítio Olavo Kurovski,18,,-26.038718,-49.533981
br,sitio oldenei mendes,Sítio Oldenei Mendes,18,,-25.8122,-49.5031
br,sitio olga botzek,Sítio Olga Botzek,18,,-25.8845,-49.4716
br,sitio olho d'agua,Sitio Olho d'Agua,06,,-3.616667,-39.616667
br,sitio olho d'agua,Sitio Olho d'Agua,17,,-7.6,-36.133333
br,sitio olho de agua,Sítio Olho de Água,18,,-23.2071,-50.1488
br,sitio olho-de agua,Sítio Olho-de Água,18,,-23.754068,-50.662779
br,sitio olho de agua,Sítio Olho de Água,18,,-23.928179,-50.25782
br,sitio olho de agua,Sítio Olho de Água,26,,-26.1905,-49.995
br,sitio olho-de agua,Sítio Olho-de Água,27,,-23.516818,-47.096419
br,sitio olicio c. dos santos,Sítio Olício C. dos Santos,18,,-25.8984,-49.1571
br,sitio olimpiada,Sítio Olimpíada,27,,-23.207222,-46.556667
br,sitio olimpia,Sítio Olimpia,27,,-23.9898,-47.0424
br,sitio olimpio agostinho,Sítio Olímpio Agostinho,26,,-26.2285,-49.8022
br,sitio olimpio b. de oliveira,Sítio Olímpio B. de Oliveira,18,,-25.171387,-48.866331
br,sitio olimpio da silva,Sítio Olímpio da Silva,18,,-25.5494,-48.7512
br,sitio olimpio f. salalha,Sítio Olímpio F. Salalha,18,,-26.0387,-49.3266
br,sitio olimpio gorniak,Sítio Olímpio Gorniak,18,,-26.08,-49.3169
br,sitio olimpio pedro,Sítio Olímpio Pedro,26,,-26.247,-49.9674
br,sitio olimpio radoll,Sítio Olimpio Radoll,26,,-26.0633,-49.9238
br,sitio olimpio ronschka,Sítio Olímpio Ronschka,18,,-26.091409,-49.518402
br,sitio olimpio,Sítio Olímpio,18,,-23.13214,-49.905828
br,sitio olinda,Sítio Olinda,27,,-23.545199,-47.074276
br,sitio olivani,Sítio Olivani,27,,-23.526946,-47.059905
br,sitio oliveira b. antonio,Sítio Oliveira B. Antônio,18,,-23.428254,-49.83542
br,sitio oliveira ferreira costa,Sítio Oliveira Ferreira Costa,18,,-23.717197,-50.121728
br,sitio oliveira guerreiro de paula,Sítio Oliveira Guerreiro de Paula,18,,-23.905582,-50.649751
br,sitio oliveira rovilher,Sítio Oliveira Rovilher,18,,-23.5729,-49.8737
br,sitio oliveira,Sítio Oliveira,18,,-23.412004,-50.156459
br,sitio oliveiras,Sítio Oliveiras,18,,-23.3714,-50.0425
br,sitio olivia lengovski,Sítio Olívia Lengovski,26,,-26.2062,-49.7844
br,sitio olivino i. marinho,Sítio Olivino I. Marinho,18,,-26.0538,-49.3509
br,sitio olivino j. carneiro,Sítio Olivino J. Carneiro,18,,-23.98343,-50.395855
br,sitio olivino rodrigues,Sítio Olivino Rodrigues,18,,-26.0408,-49.4546
br,sitio olivio a. de almeida,Sítio Olivio A. de Almeida,18,,-23.997443,-50.399141
br,sitio olivio bayer,Sítio Olívio Bayer,18,,-26.216056,-49.507804
br,sitio olivio carvalho,Sítio Olívio Carvalho,26,,-26.1279,-49.9441
br,sitio olivio dos sao ferreira,Sítio Olívio dos São Ferreira,26,,-26.2009,-49.9406
br,sitio olivio pazinatto,Sítio Olívio Pazinatto,18,,-25.5015,-48.817
br,sitio olivio pscheidt,Sítio Olívio Pscheidt,18,,-26.179858,-49.516681
br,sitio olivio train,Sítio Olívio Train,18,,-26.154985,-49.50362
br,sitio olivio trombino,Sítio Olívio Trombino,27,,-23.037509,-49.876328
br,sitio onca branca,Sítio Onça Branca,18,,-23.87743,-50.47081
br,sitio onesio a. toledo,Sítio Onésio A. Toledo,18,,-23.1338,-50.1539
br,sitio onesio toledo,Sítio Onésio Toledo,18,,-23.1502,-50.1252
br,sitio onestario s. pinto,Sítio Onestário S. Pinto,18,,-25.7473,-49.8721
br,sitio onofre caetano,Sítio Onofre Caetano,18,,-23.455686,-49.821448
br,sitio onofre f. dos santos,Sítio Onofre F. dos Santos,18,,-23.998271,-50.127341
br,sitio onofre pasda,Sítio Onofre Pasda,18,,-25.9467,-49.3571
br,sitio onofre rodrigues,Sítio Onofre Rodrigues,18,,-23.89504,-50.005147
br,sitio onofre,Sítio Onofre,18,,-25.872608,-49.935035
br,sitio onofre zanardine,Sítio Onofre Zanardine,18,,-25.503,-49.9204
br,sitio oralndo f. pirito,Sítio Oralndo F. Pirito,18,,-23.6107,-49.9677
br,sitio oravia da cruz,Sítio Orávia da Cruz,18,,-25.9005,-49.1193
br,sitio ordevina dos santos,Sítio Ordevina dos Santos,18,,-25.9019,-49.3104
br,sitio orestes de andrade,Sítio Orestes de Andrade,18,,-23.411874,-50.128286
br,sitio orfeu diana,Sítio Orfeu Diana,27,,-23.029022,-49.871637
br,sitio oriando camargo,Sítio Oriando Camargo,18,,-25.9213,-49.2778
br,sitio oria s. da silveira,Sítio Oria S. da Silveira,18,,-23.808533,-50.04383
br,sitio orides auersvaldt,Sítio Orides Auersvaldt,26,,-26.1104,-49.9646
br,sitio orides balbino,Sítio Orides Balbino,18,,-23.6147,-49.8833
br,sitio orides maciel,Sítio Orides Maciel,18,,-25.220858,-48.878966
br,sitio oridio justino,Sítio Orídio Justino,18,,-23.6781,-49.9742
br,sitio oridio matioli,Sítio Orídio Matioli,18,,-23.925935,-50.186014
br,sitio oriental,Sítio Oriental,18,,-23.536054,-50.036711
br,sitio oriente barbosa,Sítio Oriente Barbosa,18,,-23.6794,-49.7934
br,sitio orivaldo martins,Sítio Orivaldo Martins,18,,-23.643312,-50.178141
br,sitio orland friedrich,Sítio Orland Friedrich,26,,-26.1857,-49.3473
br,sitio orlando alves,Sítio Orlando Alves,18,,-25.243571,-48.552516
br,sitio orlando antonio reis,Sítio Orlando Antônio Reis,18,,-23.934507,-50.671457
br,sitio orlando avanco,Sítio Orlando Avanço,18,,-23.992586,-50.448367
br,sitio orlando dranka,Sítio Orlando Dranka,18,,-26.1336,-49.4486
br,sitio orlando fernandes,Sítio Orlando Fernandes,18,,-23.1161,-50.1588
br,sitio orlando gil,Sítio Orlando Gil,18,,-23.8367,-50.8587
br,sitio orlando j. da cruz,Sítio Orlando J. da Cruz,18,,-26.0525,-49.2875
br,sitio orlando jorge,Sítio Orlando Jorge,18,,-23.972244,-50.151086
br,sitio orlando k. sato,Sítio Orlando K. Sato,18,,-25.945,-49.3372
br,sitio orlando kutz,Sítio Orlando Kutz,18,,-25.808686,-49.788244
br,sitio orlando mansur,Sítio Orlando Mansur,18,,-23.494693,-49.847727
br,sitio orlando m. branco,Sítio Orlando M. Branco,18,,-23.965062,-50.379077
br,sitio orlando miranda,Sítio Orlando Miranda,18,,-25.831951,-48.758759
br,sitio orlando paiva,Sítio Orlando Paiva,18,,-23.877182,-50.302754
br,sitio orlando pavenik,Sítio Orlando Pavenik,18,,-25.9686,-49.4902
br,sitio orlando silveira,Sítio Orlando Silveira,18,,-25.7841,-49.5766
br,sitio orlando,Sítio Orlando,18,,-23.6568,-49.8342
br,sitio orlando stafin,Sítio Orlando Stafin,18,,-26.1017,-49.4607
br,sitio orlando telmann,Sítio Orlando Telmann,26,,-26.1839,-49.431
br,sitio orlando vaz,Sítio Orlando Vaz,18,,-25.996111,-49.560278
br,sitio orlando zilo,Sítio Orlando Zilo,18,,-26.124,-49.4772
br,sitio orozino da silva,Sítio Orozino da Silva,18,,-23.951083,-50.544369
br,sitio oscalino goncalves,Sítio Oscalino Gonçalves,18,,-23.629,-49.9174
br,sitio oscar cholze,Sítio Oscar Cholze,26,,-26.1356,-49.8447
br,sitio oscar maia,Sítio Oscar Maia,18,,-25.8623,-49.9785
br,sitio oscar p. da silva,Sítio Oscar P. da Silva,18,,-23.386307,-50.049973
br,sitio oscar pinto,Sítio Oscar Pinto,18,,-25.7716,-49.6058
br,sitio oscar p. valim,Sítio Oscar P. Valim,18,,-23.418799,-49.767846
br,sitio oscar rodrigues ramos,Sítio Oscar Rodrigues Ramos,18,,-23.0822,-50.1521
br,sitio oscar schader,Sítio Oscar Schader,26,,-26.2074,-49.3962
br,sitio oscar s. filho,Sítio Oscar S. Filho,18,,-23.7128,-49.8611
br,sitio oscar stock,Sítio Oscar Stock,18,,-26.17983,-49.647046
br,sitio osidoro pedro,Sítio Osidoro Pedro,26,,-26.2447,-49.9775
br,sitio osires oliveira borges,Sítio Osires Oliveira Borges,18,,-23.8855,-50.9655
br,sitio osiris p. machado,Sítio Osiris P. Machado,18,,-25.9703,-49.3769
br,sitio osmam p. de andrade,Sítio Osmam P. de Andrade,18,,-23.7015,-49.8084
br,sitio osmar balma,Sítio Osmar Balma,18,,-25.971103,-48.83403
br,sitio osmar brotollin,Sítio Osmar Brotollin,18,,-25.427887,-48.873318
br,sitio osmar ficher,Sítio Osmar Ficher,18,,-26.0559,-49.8041
br,sitio osmar f. santos,Sítio Osmar F. Santos,18,,-23.787529,-50.298295
br,sitio osmar garcia,Sítio Osmar Garcia,18,,-23.861167,-50.039927
br,sitio osmario de camargo,Sítio Osmário de Camargo,18,,-25.9905,-49.2351
br,sitio osmario maia,Sítio Osmário Maia,18,,-25.841397,-49.982019
br,sitio osmar j. prado,Sítio Osmar J. Prado,18,,-23.2293,-50.0751
br,sitio osmar radoll,Sítio Osmar Radoll,26,,-26.1898,-49.3127
br,sitio osmar rosina,Sítio Osmar Rosina,18,,-25.493071,-48.849927
br,sitio osmar sampaio,Sítio Osmar Sampaio,18,,-23.982243,-50.146004
br,sitio osmildo tulio,Sítio Osmildo Túlio,18,,-25.464948,-48.866728
br,sitio osni budal,Sítio Osni Budal,18,,-25.916585,-48.917859
br,sitio osni caroni,Sítio Osni Caroni,18,,-25.764722,-49.694167
br,sitio osni carvalho,Sítio Osni Carvalho,18,,-25.6117,-48.8004
br,sitio osni liber,Sítio Osni Liber,26,,-26.2236,-49.4721
br,sitio osni p. weul,Sítio Osni P. Weul,26,,-26.230712,-49.715869
br,sitio osni santana,Sítio Osni Santana,18,,-25.966,-49.1591
br,sitio osni valikoski,Sítio Osni Valikoski,26,,-26.218611,-49.848611
br,sitio osorio c. secon,Sítio Osório C. Secon,18,,-25.838,-49.1399
br,sitio osorio fagundes,Sítio Osório Fagundes,18,,-26.087172,-49.62235
br,sitio osvaldino,Sítio Osvaldino,18,,-23.8066,-50.759902
br,sitio osvaldo aparecido,Sítio Osvaldo Aparecido,18,,-23.4744,-49.8124
br,sitio osvaldo bair,Sítio Osvaldo Bair,18,,-26.082497,-49.539424
br,sitio osvaldo d. dos santos,Sítio Osvaldo D. dos Santos,18,,-25.8021,-49.5593
br,sitio osvaldo de almeida,Sítio Osvaldo de Almeida,18,,-23.47493,-49.860062
br,sitio osvaldo de andrade,Sítio Osvaldo de Andrade,18,,-23.882271,-50.586391
br,sitio osvaldo de oliveira,Sítio Osvaldo de Oliveira,27,,-24.8141,-48.2216
br,sitio osvaldo dos santos,Sítio Osvaldo dos Santos,18,,-25.925558,-49.407374
br,sitio osvaldo gogola,Sítio Osvaldo Gogola,18,,-25.8297,-49.5982
br,sitio osvaldo grosshofp,Sítio Osvaldo Grosshofp,18,,-26.0836,-49.3756
br,sitio osvaldo leal,Sítio Osvaldo Leal,18,,-23.957203,-50.079718
br,sitio osvaldo lustosa,Sítio Osvaldo Lustosa,18,,-25.9606,-49.2254
br,sitio osvaldo m. de almeida,Sítio Osvaldo M. de Almeida,18,,-25.948056,-49.535278
br,sitio osvaldo neumann,Sítio Osvaldo Neumann,26,,-26.206176,-49.715067
br,sitio osvaldo nigri,Sítio Osvaldo Nigri,18,,-23.800613,-50.817371
br,sitio osvaldo schelbauer,Sítio Osvaldo Schelbauer,18,,-26.079,-49.8016
br,sitio osvaldo seidel,Sítio Osvaldo Seidel,26,,-26.1717,-49.8209
br,sitio osvaldo vrensk,Sítio Osvaldo Vrensk,18,,-25.7884,-49.5536
br,sitio osvaldo wollner,Sítio Osvaldo Wollner,18,,-26.1308,-49.3755
br,sitio osvaldo zimmer,Sítio Osvaldo Zimmer,18,,-26.1529,-49.4762
br,sitio oswald konkl,Sítio Oswald Konkl,26,,-26.1356,-49.8615
br,sitio oswaldo arantes,Sítio Oswaldo Arantes,18,,-23.215,-50.176
br,sitio oswaldo bugiaki,Sítio Oswaldo Bugiaki,18,,-25.969409,-49.804212
br,sitio oswaldo colaco,Sítio Oswaldo Colaço,18,,-25.8158,-49.5389
br,sitio oswaldo correia,Sítio Oswaldo Correia,18,,-23.1839,-50.1199
br,sitio oswaldo c. paulista,Sítio Oswaldo C. Paulista,18,,-25.859,-49.6127
br,sitio oswaldo de matos,Sítio Oswaldo de Matos,18,,-23.6051,-49.9492
br,sitio oswaldo de m. bueno,Sítio Oswaldo de M. Bueno,18,,-23.830184,-50.25437
br,sitio oswaldo estaffin,Sítio Oswaldo Estaffin,18,,-26.160342,-49.573374
br,sitio oswaldo farias,Sítio Oswaldo Farias,18,,-23.7161,-49.9541
br,sitio oswaldo ferreira,Sítio Oswaldo Ferreira,18,,-23.6045,-49.7689
br,sitio oswaldo filho,Sítio Oswaldo Filho,18,,-23.864546,-50.307892
br,sitio oswaldo f. minardi,Sítio Oswaldo F. Minardi,18,,-23.888075,-50.543941
br,sitio oswaldo hermann,Sítio Oswaldo Hermann,26,,-26.1149,-49.8506
br,sitio oswaldo lubski,Sítio Oswaldo Lubski,18,,-25.984205,-49.800672
br,sitio oswaldo maia,Sítio Oswaldo Maia,18,,-25.840026,-49.935408
br,sitio oswaldo martins,Sítio Oswaldo Martins,18,,-26.009551,-49.479778
br,sitio oswaldo mertiolli,Sítio Oswaldo Mertiolli,18,,-23.5213,-50.5307
br,sitio oswaldo nascimento,Sítio Oswaldo Nascimento,18,,-23.6371,-49.9427
br,sitio oswaldo romulo,Sítio Oswaldo Rômulo,18,,-23.721778,-50.586249
br,sitio oswaldo sampaio,Sítio Oswaldo Sampaio,26,,-26.1151,-49.9782
br,sitio oswaldo,Sítio Oswaldo,18,,-25.488639,-48.873747
br,sitio oswaldo strubr,Sítio Oswaldo Strubr,26,,-26.2401,-49.85
br,sitio oswaldo togashi,Sítio Oswaldo Togashi,18,,-23.834491,-50.263381
br,sitio oswaldo vinte,Sítio Oswaldo Vinte,26,,-26.2186,-49.4791
br,sitio otacilio escudaller,Sítio Otacílio Escudaller,18,,-23.62612,-50.735278
br,sitio otacilio moura,Sítio Otacílio Moura,18,,-23.721671,-50.240512
br,sitio otacilio prestes,Sítio Otacílio Prestes,18,,-23.96085,-50.01337
br,sitio otacilio s. de lima,Sítio Otacílio S. de Lima,18,,-25.9093,-49.2687
br,sitio otacilio silva,Sítio Otacilio Silva,18,,-23.2243,-50.185
br,sitio otacilio,Sítio Otacílio,18,,-25.885,-49.0437
br,sitio otacilio zanett,Sítio Otacílio Zanett,18,,-23.1652,-50.185
br,sitio ota,Sítio Ota,18,,-23.53405,-50.032491
br,sitio otaviano da rossi,Sítio Otaviano da Rossi,18,,-25.936111,-49.715556
br,sitio otaviano de barros,Sítio Otaviano de Barros,27,,-23.7433,-47.5813
br,sitio otaviano v. de souza,Sítio Otaviano V. de Souza,18,,-23.962823,-50.5893
br,sitio otavio a. de faria,Sítio Otávio A. de Faria,18,,-25.8633,-49.1556
br,sitio otavio bonfim,Sítio Otávio Bonfim,18,,-23.918343,-50.186016
br,sitio otavio bonotto,Sítio Otávio Bonotto,18,,-23.5837,-49.9071
br,sitio otavio canuti,Sítio Otávio Canuti,18,,-23.6257,-49.7766
br,sitio otavio c. camargo,Sítio Otávio C. Camargo,18,,-25.9235,-49.3345
br,sitio otavio cordeiro,Sítio Otávio Cordeiro,18,,-25.9225,-49.3131
br,sitio otavio costa,Sítio Otávio Costa,18,,-25.8302,-49.295
br,sitio otavio konkl,Sítio Otávio Konkl,26,,-26.1328,-49.8554
br,sitio otavio licea,Sítio Otávio Licea,18,,-25.7853,-48.92033
br,sitio otavio maia da silva,Sítio Otávio Maia da Silva,18,,-23.9869,-50.8523
br,sitio otavio neneve,Sítio Otávio Nenevê,26,,-26.084,-49.2759
br,sitio otavio p. da cruz,Sítio Otávio P. da Cruz,18,,-25.9481,-49.4135
br,sitio otavio rodrigues,Sítio Otávio Rodrigues,18,,-23.0015,-50.0787
br,sitio otavio rosario,Sítio Otávio Rosário,18,,-25.8988,-49.0857
br,sitio otavio salvi,Sítio Otávio Salvi,18,,-23.5193,-49.872
br,sitio otavio soczeki,Sítio Otávio Soczeki,18,,-25.7104,-49.8498
br,sitio otavio szholtz,Sítio Otávio Szholtz,18,,-25.951111,-49.580833
br,sitio otavio w. batista,Sítio Otávio W. Batista,18,,-25.812,-49.3231
br,sitio otavio zigmer,Sítio Otávio Zigmer,18,,-26.0044,-49.9709
br,sitio otilio de o. castro,Sítio Otilio de O. Castro,18,,-23.517638,-50.726981
br,sitio otto gruber,Sítio Otto Gruber,26,,-26.2305,-49.9525
br,sitio otto kohlbeck,Sítio Otto Kohlbeck,26,,-26.1918,-49.765
br,sitio otto medes,Sítio Otto Medes,18,,-25.7943,-49.4687
br,sitio ouro branco,Sítio Ouro Branco,18,,-23.861932,-50.31951
br,sitio ouro-fino,Sítio Ouro-Fino,18,,-23.210813,-49.804543
br,sitio ouro fino,Sítio Ouro Fino,18,,-23.757362,-50.0753
br,sitio ouro grande,Sítio Ouro Grande,18,,-23.066408,-49.906455
br,sitio ouro leve,Sítio Ouro Leve,27,,-24.5877,-48.2926
br,sitio ouro preto,Sítio Ouro Preto,27,,-23.8182,-47.1834
br,sitio ouro verde,Sítio Ouro Verde,04,,-1.804167,-60.149444
br,sitio ouro verde,Sítio Ouro Verde,18,,-23.047,-50.11
br,sitio ouro verde,Sítio Ouro Verde,27,,-23.044365,-49.90226
br,sitio ovander schubauer,Sítio Ovander Schubauer,26,,-26.2481,-49.8518
br,sitio ovidio c. de paula,Sítio Ovídio C. de Paula,18,,-25.935,-49.595833
br,sitio ovidio ferreira,Sítio Ovídio Ferreira,18,,-25.927154,-49.847338
br,sitio ovidio g. menino,Sítio Ovídio G. Menino,18,,-23.6295,-49.8918
br,sitio ozawa,Sítio Ozawa,18,,-23.827291,-50.417307
br,sitio pacaembu,Sítio Pacaembu,27,,-23.186944,-46.523333
br,sitio paca,Sítio Paca,27,,-23.272344,-46.515547
br,sitio pacatuba,Sítio Pacatuba,22,,-6.4,-38.166667
br,sitio paciencia,Sítio Paciência,18,,-23.1174,-50.1133
br,sitio pacifico de souza,Sítio Pacifico de Souza,18,,-25.497161,-48.816572
br,sitio pacuare,Sítio Paçuare,27,,-23.8593,-47.123
br,sitio padia,Sítio Pádia,18,,-25.802049,-48.912405
br,sitio padre andre,Sítio Padre André,27,,-24.611941,-48.022233
br,sitio padre cicero,Sítio Padre Cicero,27,,-24.7928,-48.0438
br,sitio padre rebete,Sítio Padre Rebete,18,,-23.135966,-49.891181
br,sitio pagani,Sítio Pagani,18,,-23.748865,-50.179903
br,sitio pai jacob,Sítio Pai Jacob,27,,-23.233056,-46.718333
br,sitio paineira,Sítio Paineira,18,,-23.646483,-50.092936
br,sitio paineiras,Sítio Paineiras,18,,-23.5812,-49.9285
br,sitio paineiras,Sítio Paineiras,27,,-23.372936,-46.577535
br,sitio paiol grande,Sítio Paiol Grande,27,,-23.736001,-47.182187
br,sitio paiol,Sítio Paiol,18,,-25.7016,-49.8778
br,sitio paiol,Sítio Paiol,27,,-23.6313,-47.204351
br,sitio paiol velho,Sítio Paiol Velho,18,,-25.997324,-49.871447
br,sitio paiol velho,Sítio Paiol Velho,27,,-23.713329,-47.027913
br,sitio paiquere,Sítio Paiquerê,27,,-23.7656,-46.6449
br,sitio paixao,Sítio Paixão,18,,-23.844215,-50.48732
br,sitio palestina,Sítio Palestina,27,,-23.9693,-47.0875
br,sitio palhoca,Sítio Palhoca,27,,-24.510609,-48.101464
br,sitio palmares,Sítio Palmares,27,,-23.158333,-46.566389
br,sitio palmeira,Sítio Palmeira,22,,-5.275,-36.307778
br,sitio palmeira,Sítio Palmeira,27,,-23.373397,-46.621938
br,sitio palmeiras,Sítio Palmeiras,18,,-23.0361,-50.1897
br,sitio palmeiras,Sítio Palmeiras,21,,-22.3168,-44.3478
br,sitio palmeiras,Sítio Palmeiras,27,,-23.2025,-46.728611
br,sitio palmeirinha,Sítio Palmeirinha,18,,-23.68453,-50.198525
br,sitio palmira do nascimento,Sítio Palmira do Nascimento,18,,-25.9389,-49.1192
br,sitio palmital,Sítio Palmital,18,,-23.274422,-50.068508
br,sitio palmital,Sítio Palmital,27,,-23.243196,-47.510479
br,sitio pamonhas,Sítio Pamonhas,27,,-23.9546,-47.0469
br,sitio pampano,Sítio Pâmpano,18,,-23.166817,-49.871485
br,sitio panela cheia,Sítio Panela Cheia,18,,-23.755423,-50.780385
br,sitio panema,Sítio Panema,06,,-6.4,-39.8
br,sitio panorama,Sítio Panorama,27,,-23.577725,-47.17256
br,sitio pantanal,Sítio Pantanal,18,,-25.5142,-48.8527
br,sitio papagaio,Sítio Papagaio,27,,-23.155833,-46.646389
br,sitio papagaio,Sítio Papagaio,30,,-7.933333,-40.183333
br,sitio papo-amarelo,Sítio Papo-Amarelo,27,,-23.976316,-47.095888
br,sitio paquinha,Sítio Paquinha,18,,-23.905769,-50.270881
br,sitio paradise,Sítio Paradise,18,,-25.9536,-48.6372
br,sitio parafuso,Sítio Parafuso,27,,-24.625367,-48.178949
br,sitio paraiso das montanhas verdes,Sítio Paraíso das Montanhas Verdes,27,,-23.9628,-47.1435
br,sitio paraiso da vovo,Sítio Paraíso da Vovó,27,,-23.893409,-47.014521
br,sitio paraiso,Sítio Paraíso,18,,-23.523791,-50.694543
br,sitio paraiso,Sítio Paraíso,27,,-23.564955,-47.120054
br,sitio parana,Sítio Parana,18,,-23.1146,-50.1173
br,sitio parana,Sítio Paraná,24,,-10.619444,-62.327778
br,sitio para-vento,Sítio Pára-Vento,18,,-23.587682,-50.5037
br,sitio paredao,Sítio Paredão,27,,-23.056423,-49.876707
br,sitio parente,Sítio Parente,27,,-23.7515,-47.1213
br,sitio parque da serra,Sítio Parque da Serra,27,,-23.175,-46.545833
br,sitio parracinha,Sítio Parracinha,27,,-23.206111,-46.599444
br,sitio pasgal de prizio,Sítio Pasgal de Prizío,27,,-23.6047,-47.5149
br,sitio passa-dois,Sítio Passa-Dois,18,,-25.775006,-49.771761
br,sitio passariuvas,Sítio Passariúvas,27,,-23.8106,-46.6673
br,sitio passo fundo,Sítio Passo Fundo,18,,-25.503084,-50.047465
br,sitio passos de pedra,Sítio Passos de Pedra,18,,-25.357305,-48.98107
br,sitio passuare,Sítio Passuare,27,,-23.9427,-47.1538
br,sitio pasto limpo,Sítio Pasto Limpo,18,,-23.542,-49.8847
br,sitio pastorello,Sítio Pastorello,27,,-23.570212,-47.211128
br,sitio pati,Sítio Patí,27,,-23.727411,-47.613511
br,sitio pau arcado,Sítio Pau Arcado,27,,-23.2325,-46.730556
br,sitio pau-brasil,Sítio Pau-Brasil,27,,-23.7517,-47.0703
br,sitio paula chicoria,Sítio Paula Chicória,18,,-25.8345,-49.4019
br,sitio paula r. ferreira,Sítio Paula R. Ferreira,26,,-26.2025,-49.811
br,sitio pauli augustin,Sítio Pauli Augustin,26,,-26.103,-49.2594
br,sitio paulina kudoaviski,Sítio Paulina Kudoaviski,18,,-25.8327,-49.5623
br,sitio paulina oleskovicz,Sítio Paulina Oleskovicz,18,,-25.902222,-49.620556
br,sitio paulino benech,Sítio Paulino Benech,26,,-26.1433,-49.8692
br,sitio paulino buzalto,Sítio Paulino Buzalto,18,,-25.5445,-48.7838
br,sitio paulino kataka,Sítio Paulino Kataka,18,,-25.490075,-48.876021
br,sitio paulino marcus,Sítio Paulino Marcus,18,,-25.7027,-49.975
br,sitio paulino maurer,Sítio Paulino Maurer,18,,-25.9438,-49.9943
br,sitio paulino maurier,Sítio Paulino Maurier,18,,-26.0046,-49.9781
br,sitio paulino paes,Sítio Paulino Paes,26,,-26.0667,-49.8621
br,sitio paulino,Sítio Paulino,18,,-23.794772,-50.300127
br,sitio paulista,Sítio Paulista,18,,-23.57183,-50.742631
br,sitio paulista,Sítio Paulista,26,,-26.1492,-49.3081
br,sitio paulo b. de morais,Sítio Paulo B. de Morais,18,,-23.6017,-49.9192
br,sitio paulo beil,Sítio Paulo Beil,18,,-26.106586,-49.520159
br,sitio paulo bonfim,Sítio Paulo Bonfim,18,,-25.234989,-48.696966
br,sitio paulo bortolam,Sítio Paulo Bortolam,18,,-25.7736,-49.1293
br,sitio paulo bosson,Sítio Paulo Bosson,18,,-25.925975,-49.811427
br,sitio paulo branco,Sítio Paulo Branco,18,,-23.712529,-50.727904
br,sitio paulo camillo,Sítio Paulo Camillo,18,,-23.943271,-50.609699
br,sitio paulo c. claudino,Sítio Paulo C. Claudino,18,,-25.9321,-49.1146
br,sitio paulo c. couto,Sítio Paulo C. Couto,18,,-25.485952,-48.819738
br,sitio paulo coladino,Sítio Paulo Coladino,18,,-23.6387,-49.7556
br,sitio paulo cordeiro,Sítio Paulo Cordeiro,18,,-23.777978,-50.618377
br,sitio paulo corsine,Sítio Paulo Corsine,18,,-23.2128,-50.2194
br,sitio paulo dranka,Sítio Paulo Dranka,18,,-25.8742,-49.384
br,sitio paulo dums,Sítio Paulo Dums,26,,-26.1929,-49.461
br,sitio paulo echstein,Sítio Paulo Echstein,26,,-26.2148,-49.4709
br,sitio paulo eischiter,Sítio Paulo Eischiter,18,,-26.053751,-49.542246
br,sitio paulo fergunsaac,Sítio Paulo Fergunsaac,26,,-26.2162,-49.9946
br,sitio paulo figura,Sítio Paulo Figura,18,,-25.852189,-49.991167
br,sitio paulo filete,Sítio Paulo Filete,18,,-23.456575,-49.76298
br,sitio paulo franca,Sítio Paulo França,26,,-26.2141,-49.9624
br,sitio paulo francisquinho,Sítio Paulo Francisquinho,18,,-23.1671,-50.0751
br,sitio paulo fujita,Sítio Paulo Fujita,18,,-23.601568,-50.677752
br,sitio paulo fukner,Sítio Paulo Fukner,18,,-25.966024,-49.81535
br,sitio paulo gandunski,Sítio Paulo Gandunski,18,,-25.899444,-49.536111
br,sitio paulo gogolo,Sítio Paulo Gogolo,18,,-25.841741,-49.456168
br,sitio paulo groosl,Sítio Paulo Groosl,26,,-26.1614,-49.8371
br,sitio paulo hable,Sítio Paulo Hable,26,,-26.1534,-49.9313
br,sitio paulo herzer,Sítio Paulo Herzer,18,,-26.0619,-49.8285
br,sitio paulo holtman,Sítio Paulo Holtman,18,,-25.7703,-49.1897
br,sitio paulo kais,Sítio Paulo Kais,18,,-26.0553,-49.7676
br,sitio paulo k. filho,Sítio Paulo K. Filho,18,,-25.8878,-49.0489
br,sitio paulo klisievicz,Sítio Paulo Klisievicz,18,,-25.812874,-49.480812
br,sitio paulo knaut,Sítio Paulo Knaut,18,,-25.847117,-49.928375
br,sitio paulo kochan,Sítio Paulo Kochan,18,,-26.0544,-49.2832
br,sitio paulo kossoski,Sítio Paulo Kossoski,18,,-25.813877,-49.782952
br,sitio paulo kudoaviski,Sítio Paulo Kudoaviski,18,,-25.8261,-49.5574
br,sitio paulo lachoviski,Sítio Paulo Lachoviski,18,,-26.0534,-49.8166
br,sitio paulo lachoviz,Sítio Paulo Lachoviz,18,,-26.0363,-49.8017
br,sitio paulo lasca,Sítio Paulo Lasca,18,,-25.9413,-49.0344
br,sitio paulo levandoski,Sítio Paulo Levandoski,18,,-25.817846,-49.750216
br,sitio paulo lopes,Sítio Paulo Lopes,18,,-23.5687,-49.8229
br,sitio paulo m. de souza,Sítio Paulo M. de Souza,18,,-23.911174,-50.604265
br,sitio paulo mendonca,Sítio Paulo Mendonça,18,,-23.6869,-49.9167
br,sitio paulo muraro,Sítio Paulo Muraro,18,,-23.6152,-49.9
br,sitio paulo pereira santos,Sítio Paulo Pereira Santos,18,,-25.031684,-48.971343
br,sitio paulo portela,Sítio Paulo Portela,18,,-25.844,-49.0911
br,sitio paulo potzcek,Sítio Paulo Potzcek,18,,-25.8109,-49.4706
br,sitio paulo quadros,Sítio Paulo Quadros,18,,-23.618386,-50.724879
br,sitio paulo r. da nova,Sítio Paulo R. da Nova,18,,-25.751,-49.2185
br,sitio paulo richter,Sítio Paulo Richter,18,,-26.155242,-49.522805
br,sitio paulo sauer,Sítio Paulo Sauer,26,,-26.225457,-49.726378
br,sitio paulo sayto,Sítio Paulo Sayto,18,,-23.425023,-49.765467
br,sitio paulo schelbauer,Sítio Paulo Schelbauer,26,,-26.240839,-49.641146
br,sitio paulo schubauer,Sítio Paulo Schubauer,26,,-26.2462,-49.8533
br,sitio paulo scrabra,Sítio Paulo Scrabra,18,,-25.9453,-49.472
br,sitio paulo sergio,Sítio Paulo Sérgio,18,,-26.1323,-49.3695
br,sitio paulo s. faria,Sítio Paulo S. Faria,18,,-23.928407,-50.086315
br,sitio paulo,Sítio Paulo,18,,-23.987606,-50.436816
br,sitio paulo ubida,Sítio Paulo Ubida,18,,-23.5634,-49.7934
br,sitio paulo vlublesk,Sítio Paulo Vlublesk,18,,-25.7568,-49.6191
br,sitio paulo vosenhaki,Sítio Paulo Vosenhaki,18,,-25.8146,-49.5193
br,sitio paulo v. porcino,Sítio Paulo V. Porcino,18,,-23.6879,-49.7971
br,sitio paulo wibbelz,Sítio Paulo Wibbelz,26,,-26.1862,-49.9684
br,sitio paulo zanata,Sítio Paulo Zanata,18,,-23.1776,-50.1777
br,sitio paulo zella,Sítio Paulo Zella,18,,-25.802953,-49.763887
br,sitio paulo zepson,Sítio Paulo Zepson,18,,-26.0092,-49.9773
br,sitio paulo zpson,Sítio Paulo Zpson,18,,-25.8802,-49.6024
br,sitio pau sentado,Sítio Pau Sentado,26,,-26.23059,-49.674836
br,sitio pavao bonito,Sítio Pavão Bonito,27,,-23.048217,-47.515474
br,sitio pavao,Sítio Pavão,18,,-23.903982,-50.195242
br,sitio pavao,Sítio Pavão,27,,-23.632859,-47.163227
br,sitio pavoseki,Sítio Pavoseki,18,,-25.776944,-49.6775
br,sitio pe-da-serra,Sítio Pé-da-Serra,18,,-25.5536,-48.8021
br,sitio pe-de-canela,Sítio Pé-de-Canela,18,,-23.701517,-50.023754
br,sitio pedra alta,Sítio Pedra Alta,18,,-23.151839,-49.902173
br,sitio pedra amiga,Sítio Pedra Amiga,27,,-23.176389,-46.748333
br,sitio pedra branca,Sítio Pedra Branca,17,,-7.783333,-36.316667
br,sitio pedra branca,Sítio Pedra Branca,18,,-23.346529,-49.978951
br,sitio pedra branca,Sítio Pedra Branca,27,,-23.8355,-46.5736
br,sitio pedra chica,Sítio Pedra Chica,27,,-23.146111,-46.504722
br,sitio pedra da figueira,Sítio Pedra da Figueira,27,,-23.314581,-46.631454
br,sitio pedra-de-fogo,Sítio Pedra-de-Fogo,18,,-23.516908,-50.008295
br,sitio pedra fria,Sítio Pedra Fria,27,,-23.266589,-46.588689
br,sitio pedra grande,Sítio Pedra Grande,18,,-23.802509,-50.532852
br,sitio pedra grande,Sítio Pedra Grande,27,,-23.1575,-46.544444
br,sitio pedralina souza miranda,Sítio Pedralina Souza Miranda,18,,-23.8836,-50.9996
br,sitio pedrao,Sítio Pedrão,18,,-23.679987,-50.192986
br,sitio pedra selada,Sítio Pedra Selada,21,,-22.2762,-44.439
br,sitio pedreira,Sítio Pedreira,18,,-23.91935,-50.264849
br,sitio pedrinho cunha,Sítio Pedrinho Cunha,18,,-23.3318,-49.8713
br,sitio pedro a. batista,Sítio Pedro A. Batista,18,,-25.8904,-49.1764
br,sitio pedro a. correa,Sítio Pedro A. Corrêa,18,,-25.8202,-49.622
br,sitio pedro a. da silva,Sítio Pedro A. da Silva,26,,-26.2365,-49.8061
br,sitio pedro a. de almeida,Sítio Pedro A. de Almeida,18,,-26.1068,-49.4067
br,sitio pedro a. de souza,Sítio Pedro A. de Souza,18,,-25.9206,-49.3641
br,sitio pedro a. ferreira,Sítio Pedro A. Ferreira,18,,-23.997188,-50.44743
br,sitio pedro a. gomes,Sítio Pedro A. Gomes,18,,-23.4454,-49.873
br,sitio pedro alves dos santos,Sítio Pedro Alves dos Santos,18,,-25.751672,-49.900742
br,sitio pedro alves,Sítio Pedro Alves,18,,-26.079136,-49.56011
br,sitio pedro alves,Sítio Pedro Alves,26,,-26.22,-49.9601
br,sitio pedro amarante,Sítio Pedro Amarante,18,,-25.877539,-49.94831
br,sitio pedro aparecido leite,Sítio Pedro Aparecido Leite,18,,-23.967014,-50.547123
br,sitio pedro askaski,Sítio Pedro Askaski,18,,-25.8258,-49.6045
br,sitio pedro banak,Sítio Pedro Banak,18,,-25.8959,-49.0881
br,sitio pedro barao,Sítio Pedro Barão,18,,-25.8085,-49.4394
br,sitio pedro b. de oliveira,Sítio Pedro B. de Oliveira,18,,-23.808094,-50.054351
br,sitio pedro b. filho,Sítio Pedro B. Filho,18,,-25.954495,-49.836547
br,sitio pedro bichesk,Sítio Pedro Bichesk,26,,-26.033,-49.9841
br,sitio pedro bineke,Sítio Pedro Bineke,18,,-25.93471,-49.977962
br,sitio pedro b. junglas,Sítio Pedro B. Junglas,26,,-26.0292,-49.9961
br,sitio pedro b. neto,Sítio Pedro B. Neto,18,,-25.7632,-49.3441
br,sitio pedro brambilli,Sítio Pedro Brambilli,18,,-23.556672,-50.172071
br,sitio pedro b. ribeiro,Sítio Pedro B. Ribeiro,18,,-23.6807,-49.7521
br,sitio pedro camargo,Sítio Pedro Camargo,18,,-25.81,-49.5254
br,sitio pedro cardoso,Sítio Pedro Cardoso,18,,-23.1432,-50.1833
br,sitio pedro carilote,Sítio Pedro Carilote,18,,-23.1823,-50.1703
br,sitio pedro carneiro ribas,Sítio Pedro Carneiro Ribas,18,,-25.6433,-49.9628
br,sitio pedro carono,Sítio Pedro Carono,18,,-25.487273,-48.870217
br,sitio pedro carrao,Sítio Pedro Carrão,18,,-25.911111,-49.506389
br,sitio pedro carvalho,Sítio Pedro Carvalho,18,,-25.7535,-49.1826
br,sitio pedro c. de souza,Sítio Pedro C. de Souza,18,,-26.111,-49.3449
br,sitio pedro c. dos santos,Sítio Pedro C. dos Santos,18,,-23.961286,-50.030349
br,sitio pedro chinski,Sítio Pedro Chinski,26,,-26.1639,-49.9612
br,sitio pedro c. lagostine,Sítio Pedro C. Lagostine,18,,-25.8535,-49.6191
br,sitio pedro clemer,Sítio Pedro Clemer,18,,-23.0034,-50.1536
br,sitio pedro c. mendes,Sítio Pedro C. Mendes,18,,-25.889281,-49.906006
br,sitio pedro colaco,Sítio Pedro Colaço,18,,-25.8423,-49.6102
br,sitio pedro coloski,Sítio Pedro Coloski,18,,-25.9178,-49.3734
br,sitio pedro columeira,Sítio Pedro Columeira,18,,-23.9835,-50.8661
br,sitio pedro cordeiro mendes,Sítio Pedro Cordeiro Mendes,18,,-25.807455,-49.904921
br,sitio pedro correia,Sítio Pedro Correia,18,,-25.915,-49.666111
br,sitio pedro costa,Sítio Pedro Costa,18,,-23.6461,-49.8519
br,sitio pedro da veiga amaral,Sítio Pedro da Veiga Amaral,18,,-25.814101,-48.809229
br,sitio pedro d. bento,Sítio Pedro D. Bento,18,,-23.7158,-49.8526
br,sitio pedro de abreu,Sítio Pedro de Abreu,18,,-23.6754,-49.7623
br,sitio pedro de andrade,Sítio Pedro de Andrade,18,,-25.5378,-48.773
br,sitio pedro de j. cardoso,Sítio Pedro de J. Cardoso,18,,-25.785556,-49.745833
br,sitio pedro de o. cuba,Sítio Pedro de O. Cuba,18,,-23.424093,-50.051771
br,sitio pedro do rosario,Sítio Pedro do Rosário,18,,-25.8942,-49.0829
br,sitio pedro dos anjos,Sítio Pedro dos Anjos,18,,-25.904,-49.4997
br,sitio pedro dos santos,Sítio Pedro dos Santos,18,,-25.8428,-49.5574
br,sitio pedro drusz,Sítio Pedro Drusz,18,,-25.838,-49.6025
br,sitio pedro d. santos,Sítio Pedro D. Santos,18,,-23.534897,-50.578944
br,sitio pedro dutra,Sítio Pedro Dutra,18,,-25.3842,-48.6094
br,sitio pedro dzakner,Sítio Pedro Dzakner,18,,-25.7823,-49.5314
br,sitio pedro eloy,Sítio Pedro Eloy,18,,-23.371048,-49.974591
br,sitio pedro esperling,Sítio Pedro Esperling,18,,-25.8501,-49.1796
br,sitio pedro estaba,Sítio Pedro Estaba,18,,-25.851939,-49.877621
br,sitio pedro fabianski,Sítio Pedro Fabianski,18,,-25.814722,-49.638056
br,sitio pedro farias,Sítio Pedro Farias,18,,-25.9975,-49.1989
br,sitio pedro faulote,Sítio Pedro Faulote,18,,-25.7818,-49.4741
br,sitio pedro f. de souza,Sítio Pedro F. de Souza,18,,-25.9436,-49.3876
br,sitio pedro ferraz,Sítio Pedro Ferraz,18,,-26.0703,-49.3627
br,sitio pedro ferreira,Sítio Pedro Ferreira,18,,-25.8749,-49.505
br,sitio pedro ferreira,Sítio Pedro Ferreira,26,,-26.226597,-49.624676
br,sitio pedro f. gomes,Sítio Pédro F. Gomes,18,,-25.462853,-48.872948
br,sitio pedro fiatt,Sítio Pedro Fiatt,18,,-23.713,-49.7561
br,sitio pedro ficzoski,Sítio Pedro Ficzoski,18,,-25.8584,-49.5094
br,sitio pedro francisquine,Sítio Pedro Francisquine,18,,-23.0636,-50.0141
br,sitio pedro frandine,Sítio Pedro Frandine,18,,-23.5755,-49.7514
br,sitio pedro frutadi,Sítio Pedro Frutadi,18,,-25.49465,-48.802257
br,sitio pedro furma,Sítio Pedro Furma,18,,-25.8075,-49.727778
br,sitio pedro gandosk,Sítio Pedro Gandosk,18,,-25.7627,-49.5328
br,sitio pedro garanhane,Sítio Pedro Garanhane,18,,-23.6117,-49.7709
br,sitio pedro garcia,Sítio Pedro Garcia,18,,-25.7918,-49.1536
br,sitio pedro gogola,Sítio Pedro Gogola,18,,-25.8149,-49.5965
br,sitio pedro goncalves mendes,Sítio Pedro Gonçalves Mendes,27,,-24.8232,-48.1763
br,sitio pedro goncalves,Sítio Pedro Gonçalves,18,,-23.946491,-50.541585
br,sitio pedro grano,Sítio Pedro Grano,18,,-23.4496,-49.8713
br,sitio pedro gren,Sítio Pedro Gren,26,,-26.2243,-49.8836
br,sitio pedro grocha,Sítio Pedro Grocha,18,,-25.811074,-48.884991
br,sitio pedro guazinsk,Sítio Pedro Guazinsk,18,,-26.177225,-49.544701
br,sitio pedro guermiro,Sítio Pedro Guermiro,18,,-23.700714,-50.007033
br,sitio pedro hones,Sítio Pedro Hones,26,,-26.1179,-49.8903
br,sitio pedro i. gomes,Sítio Pedro I. Gomes,26,,-26.1727,-49.9706
br,sitio pedro jardim,Sítio Pedro Jardim,18,,-23.84603,-50.510438
br,sitio pedro jaros,Sítio Pedro Jaros,18,,-26.018546,-49.720529
br,sitio pedro josino,Sítio Pedro Josino,18,,-23.727411,-50.110097
br,sitio pedro juventino siqueira,Sítio Pedro Juventino Siqueira,18,,-23.748893,-50.054086
br,sitio pedro knopk,Sítio Pedro Knopk,18,,-25.8455,-49.6163
br,sitio pedro leal,Sítio Pedro Leal,26,,-26.0502,-49.9788
br,sitio pedro leandro silvano filho,Sítio Pedro Leandro Silvano Filho,27,,-25.051794,-48.540615
br,sitio pedro leite de oliveira,Sítio Pedro Leite de Oliveira,18,,-25.8855,-48.7428
br,sitio pedro leme,Sítio Pedro Leme,18,,-23.925362,-50.25696
br,sitio pedro leshinoski,Sítio Pedro Leshinoski,18,,-25.903889,-49.542222
br,sitio pedrolina f. dos santos,Sítio Pedrolina F. dos Santos,18,,-23.6893,-49.9639
br,sitio pedro lopes,Sítio Pedro Lopes,18,,-23.6831,-49.8499
br,sitio pedro lourenco machado,Sítio Pedro Lourenço Machado,18,,-25.998076,-49.753234
br,sitio pedro machoki,Sítio Pedro Machoki,18,,-25.7962,-49.4039
br,sitio pedro marciano,Sítio Pedro Marciano,18,,-23.69962,-50.021621
br,sitio pedro martins,Sítio Pedro Martins,18,,-23.7106,-49.9474
br,sitio pedro m. dos santos,Sítio Pedro M. dos Santos,18,,-25.892347,-49.96132
br,sitio pedro miranda,Sítio Pedro Miranda,18,,-25.6962,-48.7872
br,sitio pedro murba cibe,Sítio Pedro Murba Cibe,18,,-25.828317,-49.973473
br,sitio pedro norberto silva,Sítio Pedro Norberto Silva,15,,-22.627098,-45.659887
br,sitio pedro novaski,Sítio Pedro Novaski,18,,-25.8176,-49.2591
br,sitio pedro oislosqi,Sítio Pedro Oislosqi,18,,-25.9215,-49.3824
br,sitio pedro olsho,Sítio Pedro Olsho,18,,-25.803188,-49.456556
br,sitio pedro ossovst,Sítio Pedro Ossovst,18,,-26.1505,-49.4415
br,sitio pedro pascoalinoto,Sítio Pedro Pascoalinoto,18,,-23.9345,-50.8721
br,sitio pedro paulo pampiona,Sítio Pedro Paulo Pampiona,18,,-25.245228,-48.712092
br,sitio pedro pavenik,Sítio Pedro Pavenik,18,,-25.9634,-49.4865
br,sitio pedro p. da silva,Sítio Pedro P. da Silva,18,,-23.7326,-49.7954
br,sitio pedro p. de carvalho,Sítio Pedro P. de Carvalho,18,,-25.199461,-48.896824
br,sitio pedro penca,Sítio Pedro Penca,18,,-25.7839,-49.3872
br,sitio pedro peroba,Sítio Pedro Peroba,18,,-23.640231,-50.017619
br,sitio pedro pinto,Sítio Pedro Pinto,18,,-23.95439,-50.534185
br,sitio pedro pscheidt,Sítio Pedro Pscheidt,26,,-26.1994,-49.7516
br,sitio pedro p. valerio,Sítio Pedro P. Valério,18,,-26.207536,-49.596301
br,sitio pedro rafael,Sítio Pedro Rafael,18,,-23.765485,-50.133297
br,sitio pedro ribas,Sítio Pedro Ribas,18,,-25.9122,-49.4789
br,sitio pedro ribeiro,Sítio Pedro Ribeiro,18,,-25.8132,-49.2296
br,sitio pedro richesk,Sítio Pedro Richesk,18,,-25.855083,-48.793711
br,sitio pedro rita,Sítio Pedro Rita,18,,-23.6513,-49.8886
br,sitio pedro rivelino,Sítio Pedro Rivelino,18,,-23.452403,-49.845762
br,sitio pedro rocha,Sítio Pedro Rocha,18,,-23.905561,-50.544735
br,sitio pedro rodrigues,Sítio Pedro Rodrigues,18,,-25.8641,-49.6104
br,sitio pedro rosa,Sítio Pedro Rosa,18,,-25.228834,-48.560438
br,sitio pedro rui,Sítio Pedro Rui,18,,-23.0589,-50.1535
br,sitio pedro ruvinski,Sítio Pedro Ruvinski,18,,-25.8108,-49.4045
br,sitio pedro salesbram,Sítio Pedro Salesbram,18,,-25.8994,-49.3614
br,sitio pedro sarvego,Sítio Pedro Sarvego,18,,-23.5366,-49.9184
br,sitio pedro scheko,Sítio Pedro Scheko,18,,-26.0314,-49.782
br,sitio pedro schermank,Sítio Pedro Schermank,26,,-26.1816,-49.8522
br,sitio pedro schuloger,Sítio Pedro Schuloger,26,,-26.1804,-49.3022
br,sitio pedro schuminski,Sítio Pedro Schuminski,18,,-26.0479,-49.3679
br,sitio pedro s. de oliveira,Sítio Pedro S. de Oliveira,18,,-23.47641,-49.977184
br,sitio pedro selene,Sítio Pedro Selene,18,,-25.863056,-49.678056
br,sitio pedro selisneaq,Sítio Pedro Selisneaq,18,,-25.8878,-49.5927
br,sitio pedro sena,Sítio Pedro Sena,18,,-26.0172,-49.4897
br,sitio pedro sendeski,Sítio Pedro Sendeski,18,,-25.7842,-49.3992
br,sitio pedro s. filho,Sítio Pedro S. Filho,26,,-26.1828,-49.8551
br,sitio pedro,Sítio Pedro,18,,-25.627,-48.8006
br,sitio pedro staguer,Sítio Pedro Staguer,18,,-23.997245,-50.490946
br,sitio pedro suzek,Sítio Pedro Suzek,18,,-25.9044,-49.0701
br,sitio pedro taborda ribeiro,Sítio Pedro Taborda Ribeiro,18,,-25.226835,-48.905888
br,sitio pedro taborda,Sítio Pedro Taborda,18,,-26.200812,-49.559507
br,sitio pedro tarachuca,Sítio Pedro Tarachuca,18,,-25.765105,-49.24284
br,sitio pedro t. barros,Sítio Pedro T. Barros,18,,-25.8244,-49.4063
br,sitio pedro t. dos santos,Sítio Pedro T. dos Santos,26,,-26.1127,-49.3097
br,sitio pedro terra,Sítio Pedro Terra,18,,-23.843758,-50.61798
br,sitio pedro theodoro,Sítio Pedro Theodoro,18,,-23.913858,-50.300839
br,sitio pedro valerio,Sítio Pedro Valério,18,,-26.163551,-49.592606
br,sitio pedro vantum,Sítio Pedro Vantum,18,,-25.7859,-49.4204
br,sitio pedro v. da silva,Sítio Pedro V. da Silva,18,,-23.6845,-49.8529
br,sitio pedro v. de lima,Sítio Pedro V. de Lima,18,,-25.900156,-49.248485
br,sitio pedro vergensoli,Sítio Pedro Vergensoli,18,,-25.8801,-49.4126
br,sitio pedro voitschoski,Sítio Pedro Voitschoski,18,,-26.0554,-49.2657
br,sitio pedro wiegosz,Sítio Pedro Wiegosz,18,,-25.931361,-48.909354
br,sitio pedro zanai,Sítio Pedro Zanai,18,,-23.0049,-50.1255
br,sitio pedro zanata,Sítio Pedro Zanata,18,,-23.014,-50.1547
br,sitio pedro zela,Sítio Pedro Zela,18,,-25.695,-49.8854
br,sitio pelado,Sítio Pelado,06,,-6.933333,-39.866667
br,sitio pendencia,Sítio Pendência,17,,-7.15,-36.483333
br,sitio pequeno mundo,Sítio Pequeno Mundo,27,,-23.194444,-46.600833
br,sitio percilio nogueira,Sítio Percílio Nogueira,18,,-23.837613,-50.581858
br,sitio pereira,Sítio Pereira,18,,-23.831827,-50.078916
br,sitio pereira,Sítio Pereira,27,,-23.9494,-47.1915
br,sitio periquito,Sítio Periquito,18,,-23.288147,-49.76374
br,sitio perone,Sítio Perone,27,,-23.531199,-47.111676
br,sitio peroval,Sítio Peroval,18,,-23.944252,-50.235346
br,sitio peruano,Sítio Peruano,18,,-25.458235,-48.75812
br,sitio pessegueiro,Sítio Pessegueiro,18,,-25.529596,-50.163336
br,sitio pessegueiro,Sítio Pessegueiro,27,,-23.576573,-47.124195
br,sitio pessegueiros,Sítio Pessegueiros,15,,-22.6041,-45.5227
br,sitio pia-gui,Sítio Pia-Gui,27,,-23.611608,-47.226484
br,sitio pica-pau-amarelo,Sítio Pica-Pau-Amarelo,27,,-23.292582,-46.532403
br,sitio pica-pau,Sítio Pica-Pau,18,,-23.7281,-49.76
br,sitio pica-pau,Sítio Pica-Pau,27,,-23.321683,-46.573524
br,sitio pico da serra,Sítio Pico da Serra,27,,-24.550185,-48.874702
br,sitio picola mondo,Sítio Picola Mondo,27,,-23.9457,-47.0964
br,sitio picurricche,Sítio Picurricche,18,,-23.804034,-50.753779
br,sitio pinhalzinho,Sítio Pinhalzinho,18,,-23.105728,-49.978723
br,sitio pinhao,Sítio Pinhão,27,,-23.707159,-47.096175
br,sitio pinheirai,Sítio Pinheirai,27,,-23.7669,-46.6447
br,sitio pinheira,Sítio Pinheira,27,,-23.711349,-47.193414
br,sitio pinheirinho,Sítio Pinheirinho,18,,-25.5687,-48.7645
br,sitio pinheirinho,Sítio Pinheirinho,27,,-23.1975,-46.578333
br,sitio pinheiro,Sítio Pinheiro,27,,-23.083611,-46.649167
br,sitio pinheiro solitario,Sítio Pinheiro Solitário,18,,-25.4544,-48.7161
br,sitio pinheiros,Sítio Pinheiros,27,,-23.69475,-47.217719
br,sitio pinus,Sítio Pinus,27,,-23.9711,-47.102
br,sitio pirajucara,Sítio Pirajuçara,27,,-23.554384,-47.120663
br,sitio piraporinha,Sítio Piraporinha,27,,-23.733145,-47.35098
br,sitio piratininga,Sítio Piratininga,27,,-23.081667,-46.563889
br,sitio piratuba,Sítio Piratuba,27,,-23.645904,-47.330826
br,sitio pires a,Sítio Pires A,27,,-24.528849,-48.866038
br,sitio pires,Sítio Pires,18,,-23.979624,-50.428663
br,sitio pires zacarias,Sítio Pires Zacarias,18,,-23.622683,-50.213985
br,sitio pirico,Sítio Pirico,22,,-6.016667,-36.816667
br,sitio pitombeira,Sítio Pitombeira,20,,-7.133333,-41.2
br,sitio pitombeira,Sítio Pitombeira,22,,-7.1,-41.216667
br,sitio pituca,Sítio Pituca,27,,-23.540821,-47.07743
br,sitio pixoxo-estrela,Sítio Pixoxó-Estrela,18,,-25.35928,-48.768027
br,sitio placido gaissler,Sítio Plácido Gaissler,26,,-26.1444,-49.769
br,sitio placido valulhky,Sítio Plácido Valulhky,18,,-26.0792,-49.2954
br,sitio planal,Sítio Planal,27,,-23.0473,-46.706469
br,sitio planalto,Sítio Planalto,18,,-23.419326,-52.66606
br,sitio platina,Sítio Platina,18,,-23.325645,-50.006773
br,sitio pocinho,Sítio Pocinho,18,,-23.577973,-50.698837
br,sitio poco comprido,Sítio Poço Comprido,30,,-7.966667,-36.316667
br,sitio poco do juazeiro,Sítio Poço do Juazeiro,20,,-7.483333,-40.9
br,sitio poco grande,Sítio Poço Grande,27,,-24.5402,-48.4957
br,sitio poco,Sítio Poço,30,,-7.883333,-40.45
br,sitio poeirao,Sítio Poeirão,18,,-23.4654,-49.8546
br,sitio pomar das chacaras,Sítio Pomar das Chácaras,26,,-26.628198,-49.734874
br,sitio pompeia,Sítio Pompéia,18,,-23.195315,-49.983669
br,sitio ponderosa,Sítio Ponderosa,18,,-23.177975,-49.891041
br,sitio ponta de tabua,Sítio Ponta de Tábua,27,,-23.303848,-46.722761
br,sitio ponte alta,Sítio Ponte Alta,18,,-23.4724,-49.7571
br,sitio ponte alta,Sítio Ponte Alta,27,,-23.050278,-46.673889
br,sitio ponte preta,Sítio Ponte Preta,18,,-23.664533,-50.099111
br,sitio ponte seca,Sítio Ponte Seca,27,,-23.917632,-46.729496
br,sitio ponto chic,Sítio Ponto Chic,27,,-23.8718,-47.0874
br,sitio porcina camargo,Sítio Porcina Camargo,18,,-25.913,-49.3868
br,sitio porfirio de franca,Sítio Porfírio de França,18,,-25.8811,-49.327
br,sitio porfirio dos santos,Sítio Porfírio dos Santos,26,,-25.9988,-48.7297
br,sitio porfirio goulart,Sítio Porfírio Goulart,18,,-23.754731,-50.098309
br,sitio porfirio s. da cruz,Sítio Porfírio S. da Cruz,18,,-25.9224,-49.23
br,sitio porta do sol,Sítio Porta do sol,27,,-23.531112,-47.202145
br,sitio portal da serra,Sítio Portal da Serra,27,,-23.9141,-46.6366
br,sitio portal,Sítio Portal,27,,-23.2275,-46.585278
br,sitio porteira da tradicao,Sítio Porteira da Tradição,18,,-23.880864,-50.196835
br,sitio porteiro,Sítio Porteiro,18,,-25.831327,-48.901074
br,sitio porto alegre,Sítio Porto Alegre,18,,-23.495974,-52.604027
br,sitio porto de moz,Sítio Porto de Moz,18,,-23.0026,-50.2008
br,sitio porto praia,Sítio Porto Praia,27,,-23.7898,-46.5557
br,sitio possanga,Sítio Possanga,27,,-23.852,-46.6599
br,sitio posse,Sítio Posse,27,,-24.600657,-48.117373
br,sitio posto ina,Sítio Posto Iná,27,,-23.117727,-46.732045
br,sitio potiguar,Sítio Potiguar,27,,-24.8779,-48.5419
br,sitio potro serrinha,Sítio Potro Serrinha,27,,-24.578102,-48.194628
br,sitio pouca prosa,Sítio Pouca Prosa,18,,-23.108929,-49.997312
br,sitio pousada del rey,Sítio Pousada Del Rey,27,,-23.9681,-47.1648
br,sitio pousada de sol,Sítio Pousada de Sol,27,,-23.97,-47.1326
br,sitio pousada dos leoes,Sítio Pousada dos Leões,27,,-23.538971,-47.084277
br,sitio pouso alto,Sítio Pouso Alto,27,,-23.533151,-47.044097
br,sitio pouso triste,Sítio Pouso Triste,18,,-25.772,-49.2181
br,sitio prado,Sítio Prado,18,,-23.996847,-50.494355
br,sitio praia grande,Sítio Praia Grande,27,,-23.055833,-47.706667
br,sitio praia mansa,Sítio Praia Mansa,27,,-23.8114,-46.6426
br,sitio prainha,Sítio Prainha,18,,-23.799447,-50.394469
br,sitio prateado,Sítio Prateado,18,,-23.008967,-49.989685
br,sitio primavera,Sítio Primavera,18,,-23.0426,-50.0954
br,sitio primavera,Sítio Primavera,27,,-23.066667,-46.650278
br,sitio prisca e. radins,Sítio Prisca E. Radins,18,,-26.173811,-49.511995
br,sitio procopio,Sítio Procópio,18,,-25.407781,-48.824441
br,sitio progresso,Sítio Progresso,18,,-23.314893,-52.748897
br,sitio prosperidade,Sítio Prosperidade,27,,-23.168611,-46.747778
br,sitio protasio vanderriede,Sítio Protásio Vanderriede,26,,-26.2404,-49.9072
br,sitio proteu,Sítio Proteu,18,,-25.210525,-48.870013
br,sitio pruciano de vargas,Sítio Pruciano de Vargas,18,,-25.9505,-49.1836
br,sitio prudentinha,Sítio Prudentinha,18,,-23.775291,-50.085534
br,sitio pscheidt,Sítio Pscheidt,26,,-26.2043,-49.7721
br,sitio pununduva,Sítio Pununduva,27,,-23.695994,-47.042786
br,sitio purina,Sítio Purina,27,,-23.0736,-46.5604
br,sitio puxa-palha,Sítio Puxa-Palha,27,,-23.210278,-46.531944
br,sitio quatambu,Sítio Quatambu,27,,-23.589997,-47.222768
br,sitio quatro irmaos,Sítio Quatro Irmãos,18,,-23.739023,-50.237811
br,sitio quatro irmaos,Sítio Quatro Irmãos,27,,-23.557041,-47.102464
br,sitio quatro rios,Sítio Quatro Rios,27,,-23.943473,-47.11876
br,sitio queimados,Sítio Queimados,18,,-25.9968,-49.3593
br,sitio queiros,Sítio Queirós,18,,-23.658638,-50.162804
br,sitio quentak,Sítio Quentak,18,,-23.951836,-50.655997
br,sitio querencia amada,Sítio Querência Amada,18,,-23.7323,-49.8498
br,sitio querencia,Sítio Querência,27,,-23.9585,-47.0249
br,sitio quielude,Sítio Quielude,27,,-23.597853,-47.128372
br,sitio quietude,Sítio Quietude,27,,-23.57703,-47.157642
br,sitio quilombo,Sítio Quilombo,21,,-22.3131,-44.3911
br,sitio quilombo,Sítio Quilombo,27,,-23.7553,-47.1357
br,sitio quimbara,Sítio Quimbará,27,,-23.195833,-46.5875
br,sitio quim,Sítio Quim,18,,-23.1882,-50.2139
br,sitio quinta do nino,Sítio Quinta do Nino,27,,-23.562245,-47.130911
br,sitio quinta do sol,Sítio Quinta do Sol,18,,-26.0749,-49.8256
br,sitio quinta ouro verde,Sítio Quinta Ouro Verde,27,,-23.569053,-47.530146
br,sitio quinta santiago,Sítio Quinta Santiago,18,,-25.5276,-48.7533
br,sitio quirino miranda,Sítio Quirino Miranda,18,,-25.754336,-48.765012
br,sitio quiriri,Sítio Quiriri,18,,-25.9666,-48.8964
br,sitio quiri,Sítio Quiri,27,,-23.8726,-46.6297
br,sitio quixaba,Sitio Quixaba,22,,-6.016667,-36.1
br,sitio racz,Sítio Racz,27,,-24.657562,-48.030043
br,sitio rafael c. contador,Sítio Rafael C. Contador,18,,-25.7956,-49.1242
br,sitio rafael greco,Sítio Rafael Greco,18,,-25.7769,-48.6
br,sitio rafael mor,Sítio Rafael Mor,18,,-25.8965,-49.5988
br,sitio rafael pillati,Sítio Rafael Pillati,26,,-26.172833,-49.715141
br,sitio rafael r. de lima,Sítio Rafael R. de Lima,18,,-25.494828,-48.811071
br,sitio rafael,Sítio Rafael,18,,-23.476095,-49.932449
br,sitio rafael zen,Sítio Rafael Zen,18,,-25.8751,-49.1156
br,sitio raia velha,Sítio Raia Velha,18,,-26.0891,-49.4288
br,sitio raimundo crukre,Sítio Raimundo Crukre,18,,-25.344654,-48.979241
br,sitio raimundo jose heppe,Sítio Raimundo José Heppe,26,,-26.226,-49.4384
br,sitio raimundo ziglin,Sítio Raimundo Ziglin,18,,-25.763,-49.1829
br,sitio rainha do ceu,Sítio Rainha do Céu,27,,-23.683856,-47.129526
br,sitio rainha,Sítio Rainha,26,,-26.5155,-48.7254
br,sitio ramalhete,Sítio Ramalhete,30,,-7.666667,-40.366667
br,sitio ramelo,Sítio Ramelo,18,,-25.8626,-49.1048
br,sitio ramires p. da rocha,Sítio Ramires P. da Rocha,18,,-26.0203,-49.3065
br,sitio ramiro branco de oliveira,Sítio Ramiro Branco de Oliveira,18,,-25.851281,-49.799608
br,sitio ramiro dias pereira,Sítio Ramiro Dias Pereira,18,,-25.4041,-48.6994
br,sitio ramiro p. gomes,Sítio Ramiro P. Gomes,18,,-23.792786,-50.229792
br,sitio ramon kossoski,Sítio Ramón Kossoski,18,,-25.816251,-49.777897
br,sitio rancharia,Sítio Rancharia,27,,-23.553014,-47.17268
br,sitio rancho alegre,Sítio Rancho Alegre,18,,-23.136573,-49.917594
br,sitio rancho alegre,Sítio Rancho Alegre,27,,-23.571189,-47.129454
br,sitio rancho do oeste,Sítio Rancho do Oeste,27,,-23.552108,-47.15716
br,sitio rancho grande,Sítio Rancho Grande,27,,-23.8923,-47.1317
br,sitio rancho santa teresa,Sítio Rancho Santa Teresa,27,,-23.545682,-47.090709
br,sitio rancho santo antonio,Sítio Rancho Santo Antônio,27,,-23.545677,-47.11016
br,sitio rancho velho,Sítio Rancho Velho,18,,-25.363112,-48.979196
br,sitio rancho verde,Sítio Rancho Verde,18,,-23.811641,-50.823107
br,sitio raposao,Sítio Raposão,27,,-23.9362,-47.13
br,sitio raposo,Sítio Raposo,27,,-23.553074,-47.128078
br,sitio raul a. borges,Sítio Raul A. Borges,18,,-25.9204,-49.0484
br,sitio raul barbosa,Sítio Raul Barbosa,18,,-23.957229,-50.232762
br,sitio raul bonino,Sítio Raul Bonino,18,,-23.7155,-49.9442
br,sitio raul c. junior,Sítio Raul C. Júnior,26,,-26.1992,-49.9897
br,sitio raul da luz,Sítio Raul da Luz,26,,-26.0441,-49.9787
br,sitio raul dias,Sítio Raul Dias,18,,-25.835147,-49.927765
br,sitio raul emtez,Sítio Raul Emtez,18,,-25.961,-49.9138
br,sitio raul francolino,Sítio Raul Francolino,18,,-23.5695,-49.7881
br,sitio raulino m. ribeiro,Sítio Raulino M. Ribeiro,18,,-26.114272,-49.508425
br,sitio raul pereira,Sítio Raul Pereira,18,,-25.9066,-49.3002
br,sitio raul rosa,Sítio Raul Rosa,18,,-23.0064,-50.0689
br,sitio raul schelbauer,Sítio Raul Schelbauer,26,,-26.1062,-49.9328
br,sitio raul zaifert,Sítio Raul Zaifert,26,,-26.2447,-49.8357
br,sitio real,Sítio Real,18,,-23.738738,-50.219799
br,sitio recantinho,Sítio Recantinho,27,,-23.711403,-47.222966
br,sitio recanto a,Sítio Recanto A,27,,-23.1794,-47.5859
br,sitio recanto da cotinha,Sítio Recanto da Cotinha,27,,-23.9519,-47.0707
br,sitio recanto da paz,Sítio Recanto da Paz,27,,-24.5048,-48.126492
br,sitio recanto da rocha,Sítio Recanto da Rocha,18,,-25.763604,-49.133222
br,sitio recanto das palmeiras,Sítio Recanto das Palmeiras,27,,-23.691849,-47.240089
br,sitio recanto de agua,Sítio Recanto de Água,27,,-23.283609,-46.580035
br,sitio recanto de sao jorge,Sítio Recanto de São Jorge,27,,-24.685696,-48.008762
br,sitio recanto do artista,Sítio Recanto do Artista,27,,-23.182222,-46.688056
br,sitio recanto do jacare,Sítio Recanto do Jacaré,18,,-23.1932,-50.0613
br,sitio recanto do mel,Sítio Recanto do Mel,27,,-23.663038,-47.158994
br,sitio recanto do papis,Sítio Recanto do Papis,27,,-23.647311,-47.193939
br,sitio recanto do sabia,Sítio Recanto do Sabiá,18,,-23.906483,-50.16464
br,sitio recanto dos lagos,Sítio Recanto dos Lagos,27,,-23.949,-47.0346
br,sitio recanto dos neonhos,Sítio Recanto dos Neonhos,27,,-23.0848,-46.717695
br,sitio recanto dos netos,Sítio Recanto dos Netos,27,,-23.5283,-47.7142
br,sitio recanto do sol,Sítio Recanto do Sol,27,,-23.56104,-47.168231
br,sitio recanto do sossego,Sítio Recanto do Sossego,18,,-25.8519,-49.1791
br,sitio recanto do uba,Sítio Recanto do Ubá,18,,-23.2382,-50.0396
br,sitio recanto do xororo,Sítio Recanto do Xororó,18,,-23.903803,-50.164002
br,sitio recanto feliz,Sítio Recanto Feliz,18,,-23.340112,-50.040163
br,sitio recanto nova esperanca,Sítio Recanto Nova Esperança,27,,-23.241111,-46.692222
br,sitio recanto santa teresa,Sítio Recanto Santa Teresa,27,,-24.7968,-48.2411
br,sitio recanto,Sítio Recanto,18,,-23.2111,-50.0462
br,sitio recanto,Sítio Recanto,27,,-23.5886,-47.07401
br,sitio recreio do canto,Sítio Recreío do Canto,27,,-23.8399,-46.7414
br,sitio recreio,Sítio Recreio,18,,-23.0622,-50.1767
br,sitio recreio,Sítio Recreio,27,,-23.116111,-46.5975
br,sitio refugio dos pinheirinhos,Sítio Refúgio dos Pinheirinhos,27,,-23.9125,-47.1003
br,sitio refugio dos pinheiros,Sítio Refúgio dos Pinheiros,27,,-23.731434,-47.135122
br,sitio regina dumps,Sítio Regina Dumps,26,,-26.2061,-49.8806
br,sitio regina konkl,Sítio Regina Konkl,26,,-26.1372,-49.8633
br,sitio reginaldo andrade,Sítio Reginaldo Andrade,18,,-23.179731,-49.861893
br,sitio reginaldo auersvaldt,Sítio Reginaldo Auersvaldt,26,,-26.1044,-49.9746
br,sitio regina,Sítio Regina,27,,-23.2475,-46.615
br,sitio reinadlo de barros,Sítio Reinadlo de Barros,18,,-23.166457,-49.95169
br,sitio reinaldo chofa,Sítio Reinaldo Chofa,18,,-23.765111,-50.843715
br,sitio reinaldo dibiguelfe,Sítio Reinaldo Dibiguelfe,18,,-25.496355,-48.861246
br,sitio reinaldo grossol,Sítio Reinaldo Grossol,18,,-26.117832,-49.514656
br,sitio reinaldo korn,Sítio Reinaldo Korn,18,,-25.907095,-48.918801
br,sitio reinaldo marcolim,Sítio Reinaldo Marcolim,18,,-23.0163,-50.0357
br,sitio reinaldo polleto,Sítio Reinaldo Polleto,18,,-23.72303,-50.134954
br,sitio reinaldo r. leonel,Sítio Reinaldo R. Leonel,18,,-23.6129,-49.8571
br,sitio reinaldo r. santos,Sítio Reinaldo R. Santos,18,,-25.945835,-49.859989
br,sitio reinaldo t. de carvalho,Sítio Reinaldo T. de Carvalho,18,,-23.6351,-49.8105
br,sitio relva,Sítio Relva,17,,-7.416667,-36.15
br,sitio remadejo,Sítio Remadejo,27,,-23.745677,-47.041791
br,sitio remanso,Sítio Remanso,27,,-23.9734,-47.051
br,sitio remy burgnon,Sítio Remy Burgnon,18,,-23.575,-49.8972
br,sitio renan,Sítio Renan,18,,-23.915122,-50.20013
br,sitio renato barbosa,Sítio Renato Barbosa,18,,-23.349357,-49.973153
br,sitio renato barone,Sítio Renato Barone,18,,-25.350428,-48.989842
br,sitio renato caia,Sítio Renato Caia,18,,-25.8718,-49.4162
br,sitio renato carneiro,Sítio Renato Carneiro,18,,-25.916993,-49.796939
br,sitio renato dos santos,Sítio Renato dos Santos,18,,-25.8901,-49.0746
br,sitio renato f. de melo,Sítio Renato F. de Melo,18,,-25.9596,-49.2243
br,sitio renato martins,Sítio Renato Martins,18,,-26.06616,-49.536624
br,sitio renato senn,Sítio Renato Senn,18,,-26.122884,-49.508019
br,sitio renato s. maier,Sítio Renato S. Máier,18,,-25.8938,-49.513
br,sitio renato strober,Sítio Renato Strober,26,,-26.232,-49.8397
br,sitio rene h. da silva,Sítio René H. da Silva,26,,-26.230941,-49.625955
br,sitio rene n. batista,Sítio Renê N. Batista,18,,-25.5465,-48.7841
br,sitio renerio leite,Sítio Renério Leite,18,,-23.821,-50.1948
br,sitio rene santos,Sítio René Santos,18,,-25.23269,-48.9354
br,sitio reno ferrari,Sítio Reno Ferrari,18,,-23.769238,-50.288191
br,sitio resende,Sítio Resende,18,,-23.550457,-50.573276
br,sitio reta grande,Sítio Reta Grande,18,,-23.926671,-50.562694
br,sitio retiro,Sítio Retiro,18,,-23.7405,-49.9283
br,sitio riacho da furna,Sítio Riacho da Furna,06,,-4.716667,-38.133333
br,sitio riacho do gado,Sítio Riacho do Gado,06,,-6.433333,-39.6
br,sitio riacho grande,Sítio Riacho Grande,27,,-23.8545,-46.5892
br,sitio ribeirao bonito,Sítio Ribeirão Bonito,18,,-23.381806,-50.128949
br,sitio ribeirao bonito,Sítio Ribeirão Bonito,27,,-23.101111,-47.588333
br,sitio ribeirao claro,Sítio Ribeirão Claro,18,,-23.3511,-49.8909
br,sitio ribeirao da anta,Sítio Ribeirão da Anta,18,,-23.871425,-50.011636
br,sitio ribeirao da batata,Sítio Ribeirão da Batata,27,,-24.9009,-48.0917
br,sitio ribeirao da marreca,Sítio Ribeirão da Marreca,27,,-24.8778,-48.0893
br,sitio ribeirao das bananas,Sítio Ribeirão das Bananas,27,,-24.8217,-48.0792
br,sitio ribeirao do meio,Sítio Ribeirão do Meio,18,,-23.745709,-50.244521
br,sitio ribeirao do meio,Sítio Ribeirão do Meio,27,,-24.7673,-48.4335
br,sitio ribeirao dos pires,Sítio Ribeirão dos Pires,18,,-23.820389,-50.248981
br,sitio ribeirao engano,Sítio Ribeirão Engano,18,,-23.818388,-50.230459
br,sitio ribeirao grande,Sítio Ribeirão Grande,18,,-23.7373,-49.9995
br,sitio ribeirao pedro,Sítio Ribeirão Pedro,27,,-24.8889,-48.0864
br,sitio ribeirao,Sítio Ribeirão,26,,-26.2179,-49.946
br,sitio ribeirao vermelho,Sítio Ribeirão Vermelho,27,,-23.8677,-46.6862
br,sitio ribeiro carreteiro,Sítio Ribeiro Carreteiro,18,,-23.5606,-49.9662
br,sitio ribeiro,Sítio Ribeiro,18,,-23.41791,-50.106771
br,sitio ribeiro ventura,Sítio Ribeiro Ventura,18,,-23.5143,-49.7983
br,sitio ribel,Sítio Ribel,06,,-3.65,-39.533333
br,sitio ricardo azzoline,Sítio Ricardo Azzoline,18,,-23.5566,-49.922
br,sitio ricardo dums,Sítio Ricardo Dums,26,,-26.2176,-49.8959
br,sitio ricardo purcerviski,Sítio Ricardo Purcerviski,18,,-26.0626,-49.7996
br,sitio ricardo reinute,Sítio Ricardo Reinute,18,,-23.639157,-50.208095
br,sitio ricardo ribeiro,Sítio Ricardo Ribeiro,18,,-25.883,-49.2483
br,sitio ricardo schrueder,Sítio Ricardo Schrueder,18,,-26.08257,-49.559326
br,sitio ricardo seidel,Sítio Ricardo Seidel,26,,-26.1677,-49.8368
br,sitio ricardo,Sítio Ricardo,18,,-25.835409,-48.750609
br,sitio riciere sigulin,Sítio Riciere Sigulin,26,,-26.1756,-49.9105
br,sitio ricordi,Sítio Ricordi,18,,-23.462198,-49.764097
br,sitio ridinei rai,Sítio Ridinei Rai,18,,-25.825556,-49.748889
br,sitio rinaldo b. dos santos,Sítio Rinaldo B. dos Santos,18,,-25.161272,-48.945935
br,sitio rincao alegre,Sítio Rincão Alegre,18,,-23.1466,-50.1276
br,sitio rincao do vale,Sítio Rincão do Vale,27,,-23.967722,-47.010139
br,sitio rincao mineiro,Sítio Rincão Mineiro,18,,-23.771099,-50.056829
br,sitio rincao,Sítio Rincão,18,,-25.8232,-49.1309
br,sitio rinegedo,Sítio Rinegedo,18,,-25.855015,-49.797222
br,sitio rinkichi kumata,Sítio Rinkichi Kumata,18,,-23.609137,-50.704603
br,sitio rio abaixo,Sítio Rio Abaixo,27,,-23.063611,-46.645556
br,sitio rio acima palmital,Sítio Rio Acima Palmital,27,,-24.545018,-48.80879
br,sitio rio acima,Sítio Rio Acima,27,,-23.236667,-46.673333
br,sitio riocokismi watana,Sítio Riocokismi Watana,18,,-23.1474,-50.1776
br,sitio rio das almas,Sítio Rio das Almas,18,,-25.50417,-50.44485
br,sitio rio das pedras,Sítio Rio das Pedras,27,,-24.557134,-48.875601
br,sitio rio do meio,Sítio Rio do Meio,18,,-25.351107,-48.946014
br,sitio rio dos patos,Sítio Rio dos Patos,18,,-25.886389,-49.686667
br,sitio rio grande,Sítio Rio Grande,18,,-23.226985,-52.200193
br,sitio rio guarau,Sítio Rio Guaraú,27,,-24.7584,-48.1035
br,sitio rio mata,Sítio Rio Mata,18,,-25.5106,-48.8107
br,sitio rio vermelho,Sítio Rio Vermelho,27,,-24.9724,-48.5102
br,sitio rita chaves,Sítio Rita Chaves,26,,-26.2035,-49.9446
br,sitio rita l. de carvalho,Sítio Rita L. de Carvalho,26,,-26.2245,-49.8377
br,sitio rita r. p. forteski,Sítio Rita R. P. Forteski,18,,-26.0542,-49.3946
br,sitio rivadavia r. da silva,Sítio Rivadavia R. da Silva,18,,-23.6879,-49.8885
br,sitio roberta,Sítio Roberta,27,,-23.514127,-47.034543
br,sitio roberto a. pires,Sítio Roberto A. Pires,18,,-25.387096,-48.976486
br,sitio roberto calisto,Sítio Roberto Calisto,18,,-23.919174,-50.519004
br,sitio roberto drevek,Sítio Roberto Drevek,18,,-26.149327,-49.40099
br,sitio roberto f. carvalho,Sítio Roberto F. Carvalho,18,,-23.965885,-50.40183
br,sitio roberto g. andrade,Sítio Roberto G. Andrade,18,,-25.9646,-49.9151
br,sitio roberto g. inifeldis,Sítio Roberto G. Inifeldis,18,,-25.8059,-49.2237
br,sitio roberto gluber,Sítio Roberto Gluber,18,,-26.145916,-49.559065
br,sitio roberto godoy,Sítio Roberto Godoy,18,,-23.7164,-49.8166
br,sitio roberto j. r. junior,Sítio Roberto J. R. Júnior,18,,-25.884,-49.6031
br,sitio roberto l. de abreu,Sítio Roberto L. de Abreu,18,,-25.452946,-48.807189
br,sitio roberto madeira,Sítio Roberto Madeira,18,,-23.1875,-50.0714
br,sitio roberto metode,Sítio Roberto Metóde,18,,-25.9377,-49.0417
br,sitio roberto miller,Sítio Roberto Miller,26,,-26.1715,-49.9754
br,sitio roberto nalama,Sítio Roberto Nalama,18,,-25.896229,-49.400656
br,sitio roberto n. alves,Sítio Roberto N. Alves,18,,-25.5578,-48.7716
br,sitio roberto pedro,Sítio Roberto Pedro,18,,-23.5052,-49.9593
br,sitio roberto rodrigues,Sítio Roberto Rodrigues,18,,-25.8808,-49.6051
br,sitio roberto,Sítio Roberto,18,,-25.488232,-48.778696
br,sitio roberto vale,Sítio Roberto Vale,18,,-23.5245,-49.9034
br,sitio roberto vales,Sítio Roberto Vales,18,,-23.960106,-50.16584
br,sitio roberto venhart,Sítio Roberto Venhart,18,,-25.794676,-49.782104
br,sitio roberto zizinho,Sítio Roberto Zizinho,18,,-23.0722,-50.2266
br,sitio rochedo,Sítio Rochedo,27,,-23.588369,-47.106883
br,sitio rodeio,Sítio Rodeio,18,,-25.8773,-49.1233
br,sitio roderick s. hunlher,Sítio Roderick S. Hunlher,18,,-23.941486,-50.246111
br,sitio rodolfo denk,Sítio Rodolfo Denk,18,,-26.183267,-49.636909
br,sitio rodolfo denk,Sítio Rodolfo Denk,26,,-26.2418,-49.3984
br,sitio rodolfo fernandes,Sítio Rodolfo Fernandes,18,,-23.1621,-50.0791
br,sitio rodolfo godofredo,Sítio Rodolfo Godofredo,18,,-26.0858,-49.4463
br,sitio rodolfo pichait,Sítio Rodolfo Pichait,26,,-26.219395,-49.870827
br,sitio rodrigues carrao,Sítio Rodrigues Carrão,18,,-25.9038,-49.5487
br,sitio rogerio messias,Sítio Rogério Messias,18,,-23.464556,-49.888187
br,sitio rogerio millar,Sítio Rogério Millar,26,,-26.1934,-49.9498
br,sitio rogerio,Sítio Rogério,18,,-25.5614,-48.766
br,sitio rogerio s. pinto,Sítio Rogério S. Pinto,18,,-23.83658,-50.077657
br,sitio rogue ferreira de moraes,Sítio Rogue Ferreira de Moraes,18,,-23.878,-50.969
br,sitio rokui lesniovski,Sítio Rokui Lesniovski,18,,-25.997222,-49.54
br,sitio romalino martins,Sítio Romalino Martins,18,,-25.9158,-49.0982
br,sitio romano drusccz,Sítio Romano Drusccz,18,,-25.7944,-49.5189
br,sitio romansa,Sítio Romansa,27,,-23.398514,-46.619669
br,sitio romao barao,Sítio Romão Barão,18,,-25.8796,-49.426
br,sitio romao burcate,Sítio Romão Burcate,18,,-26.025237,-49.657591
br,sitio romao celusniaki,Sítio Romão Celusniaki,18,,-25.84,-49.5478
br,sitio romao engler,Sítio Romão Engler,26,,-26.1283,-49.3062
br,sitio romao mika,Sítio Romão Mika,18,,-25.839832,-49.957064
br,sitio romao preissler,Sítio Romão Preissler,18,,-26.125945,-49.507388
br,sitio romao scrobot,Sítio Romão Scrobot,18,,-25.8707,-49.5846
br,sitio romao,Sítio Romão,18,,-25.406246,-48.871437
br,sitio romario brassanni,Sítio Romário Brassanni,26,,-25.989915,-48.838924
br,sitio romario friedrich,Sítio Romário Friedrich,26,,-26.1792,-49.3513
br,sitio roma,Sítio Roma,27,,-23.181667,-46.720833
br,sitio romeu cariolatt,Sítio Romeu Cariolatt,26,,-26.2173,-49.9021
br,sitio romeu ganssole,Sítio Romeu Ganssole,18,,-25.5455,-49.9445
br,sitio romeu gren,Sítio Romeu Gren,26,,-26.1115,-49.9141
br,sitio romeu peters,Sítio Romeu Peters,26,,-26.173078,-49.721394
br,sitio romilda r. rosa,Sítio Romilda R. Rosa,18,,-25.978889,-49.733056
br,sitio romildo a. coelhe,Sítio Romildo A. Coelhe,18,,-26.0437,-49.3046
br,sitio romildo mendes,Sítio Romildo Mendes,18,,-25.233627,-48.534088
br,sitio romildo seccon,Sítio Romildo Seccon,18,,-25.196521,-48.981839
br,sitio romilio l. moreira,Sítio Romílio L. Moreira,18,,-23.897638,-50.643443
br,sitio romoaldo vidal,Sítio Romoaldo Vidal,18,,-25.8189,-49.657
br,sitio romualdo apolinario,Sítio Romualdo Apolinário,18,,-25.5235,-48.8422
br,sitio ronald e. perly,Sítio Ronald E. Perly,18,,-25.8265,-49.0738
br,sitio roque bonato,Sítio Roque Bonato,18,,-23.2635,-49.8001
br,sitio roque chavera,Sítio Roque Chavera,18,,-23.607935,-50.193806
br,sitio roque r. de carvalho,Sítio Roque R. de Carvalho,18,,-23.6105,-49.8209
br,sitio roque schmitz,Sítio Roque Schmitz,26,,-26.2145,-49.8833
br,sitio rosa bela,Sítio Rosa Bela,27,,-23.156111,-46.656111
br,sitio rosa carneiro,Sítio Rosa Carneiro,18,,-25.969213,-48.889439
br,sitio rosa chicora,Sítio Rosa Chicora,18,,-25.8362,-49.541
br,sitio rosa dos vantos,Sítio Rosa dos Vantos,27,,-23.91241,-46.741658
br,sitio rosa e branco,Sítio Rosa e Branco,27,,-23.266766,-46.55252
br,sitio rosa kava,Sítio Rosa Kava,26,,-26.2342,-49.8693
br,sitio rosa klisievicz,Sítio Rosa Klisievicz,18,,-25.8179,-49.4766
br,sitio rosa kograki,Sítio Rosa Kograki,18,,-25.8655,-49.4891
br,sitio rosalena,Sítio Rosalena,18,,-23.929212,-50.125505
br,sitio rosalina da cruz minatovicz,Sítio Rosalina da Cruz Minatovicz,18,,-25.77874,-49.211488
br,sitio rosalina kresisinski,Sítio Rosalina Kresisinski,26,,-26.2131,-49.8409
br,sitio rosalina n. do vale,Sítio Rosalina N. do Vale,18,,-25.8808,-49.0684
br,sitio rosalina peixoto,Sítio Rosalina Peixoto,18,,-25.8257,-49.3596
br,sitio rosalina r. alegre,Sítio Rosalina R. Alegre,18,,-25.226667,-48.932943
br,sitio rosalino c. de miranda,Sítio Rosalino C. de Miranda,18,,-25.840556,-49.628333
br,sitio rosa machado,Sítio Rosa Machado,18,,-25.9122,-49.2414
br,sitio rosamario m. rodrigues,Sítio Rosamário M. Rodrigues,18,,-23.936838,-50.357613
br,sitio rosa nossol,Sítio Rosa Nossol,18,,-26.0732,-49.2902
br,sitio rosaria cardoso,Sítio Rosária Cardoso,18,,-26.176857,-49.561774
br,sitio rosa s. da silva,Sítio Rosa S. da Silva,18,,-25.087256,-48.825065
br,sitio rosa,Sítio Rosa,27,,-23.686051,-47.181465
br,sitio rosa vieira,Sítio Rosa Vieira,26,,-26.2441,-49.9745
br,sitio roseiral,Sítio Roseiral,27,,-23.153056,-46.684722
br,sitio roseira,Sítio Roseira,18,,-25.912156,-49.759918
br,sitio roseira,Sítio Roseira,27,,-23.571472,-47.224847
br,sitio rosell,Sítio Rosell,18,,-25.2679,-48.5902
br,sitio rosilda charneschi,Sítio Rosilda Charneschi,18,,-25.905556,-49.683889
br,sitio rossa cassu,Sítio Rossa Cassu,18,,-25.5084,-49.8968
br,sitio rouxinol,Sítio Rouxinol,27,,-23.216944,-46.7075
br,sitio rubens bernadele,Sítio Rubens Bernadele,18,,-23.0034,-50.0144
br,sitio rubens cadoso,Sítio Rubens Cadoso,18,,-25.5237,-48.8614
br,sitio rubens de barros,Sítio Rubens de Barros,18,,-25.9202,-49.1538
br,sitio rubens dos santos,Sítio Rubens dos Santos,18,,-25.346748,-48.982723
br,sitio rubens hattenhaeur,Sítio Rubens Hattenhaeur,26,,-25.985533,-48.837072
br,sitio rubens joaquim mendes,Sítio Rubens Joaquim Mendes,18,,-23.389451,-50.11704
br,sitio rubens kolasso,Sítio Rubens Kolasso,18,,-25.7725,-49.5967
br,sitio rubens teixeira,Sítio Rubens Teixeira,18,,-23.6038,-49.9836
br,sitio rubens vieira,Sítio Rubens Vieira,26,,-26.150804,-49.749172
br,sitio rufino biaobock,Sítio Rufino Biaobock,26,,-26.148,-49.3606
br,sitio rufino de carvalho,Sítio Rufino de Carvalho,18,,-23.5864,-49.7865
br,sitio rufino telmann,Sítio Rufino Telmann,26,,-26.1444,-49.3543
br,sitio rufino zivsk,Sítio Rufino Zivsk,18,,-26.0961,-49.3612
br,sitio rui barbosa,Sítio Rui Barbosa,18,,-23.865894,-50.268096
br,sitio rui c. da silveira,Sítio Rui C. da Silveira,18,,-25.7936,-49.607
br,sitio rui coller,Sítio Rui Coller,18,,-25.814444,-49.700278
br,sitio rui de freitas,Sítio Rui de Freitas,18,,-26.0058,-49.8675
br,sitio rui fonseca pereira,Sítio Rui Fonseca Pereira,18,,-25.161466,-48.980039
br,sitio rui fonseca,Sítio Rui Fonseca,18,,-25.173903,-48.956134
br,sitio rui f. pereira,Sítio Rui F. Pereira,18,,-25.137555,-48.898828
br,sitio rui sampaio,Sítio Rui Sampaio,18,,-25.8139,-49.2854
br,sitio rui santos,Sítio Rui Santos,18,,-25.5247,-48.8332
br,sitio rui schreiner,Sítio Rui Schreiner,18,,-26.119053,-49.575599
br,sitio ruth fornazari,Sítio Ruth Fornazari,18,,-25.7506,-49.0844
br,sitio ruth m. reiner,Sítio Ruth M. Reiner,18,,-25.9345,-49.1597
br,sitio sabia,Sítio Sabiá,27,,-23.215833,-46.739444
br,sitio sabina,Sítio Sabina,18,,-25.8222,-48.5795
br,sitio sabininho a. lima,Sítio Sabininho A. Lima,18,,-25.8356,-49.2258
br,sitio sabino dos santos,Sítio Sabino dos Santos,18,,-23.0672,-50.1083
br,sitio saburo mamokuro,Sítio Saburo Mamokuro,18,,-23.520055,-50.73898
br,sitio saco dos antunes,Sítio Saco dos Antunes,06,,-6.666667,-39.816667
br,sitio sadi c. de abreu,Sítio Sadi C. de Abreu,18,,-25.5028,-48.8147
br,sitio sady da silva,Sítio Sady da Silva,18,,-26.130075,-49.615456
br,sitio sagrada familia,Sítio Sagrada Familia,27,,-23.54798,-47.029972
br,sitio sagrado coracao de jesus,Sítio Sagrado Coração de Jesus,18,,-23.786417,-50.299519
br,sitio saito,Sítio Saito,27,,-23.701635,-47.186097
br,sitio sakamoto,Sítio Sakamoto,18,,-23.195,-50.243
br,sitio salarium,Sítio Salarium,27,,-23.618778,-47.183311
br,sitio salim antonio,Sítio Salim Antônio,18,,-23.7226,-49.9732
br,sitio salmo 91,Sítio Salmo 91,18,,-23.233611,-52.184165
br,sitio salmo noventa e um,Sítio Salmo Noventa e Um,18,,-23.233611,-52.184165
br,sitio saltinho,Sítio Saltinho,18,,-23.602618,-50.177633
br,sitio salto boa vista,Sítio Salto Boa Vista,18,,-25.9639,-49.1814
br,sitio salto grande,Sítio Salto Grande,18,,-23.806286,-50.380537
br,sitio salute,Sítio Salute,27,,-23.732584,-47.108132
br,sitio salvador b. de lima,Sítio Salvador B. de Lima,18,,-25.903611,-49.519167
br,sitio salvador biskai,Sítio Salvador Biskai,18,,-25.7951,-49.3845
br,sitio salvador bueno,Sítio Salvador Bueno,18,,-23.928857,-50.415985
br,sitio salvador da silva,Sítio Salvador da Silva,18,,-23.6859,-49.9287
br,sitio salvador de goes,Sítio Salvador de Goes,18,,-26.212129,-49.583011
br,sitio salvador lacerda,Sítio Salvador Lacerda,18,,-25.977,-49.2371
br,sitio salvador luqui,Sítio Salvador Luqui,18,,-23.995744,-50.402365
br,sitio salvador psibovis,Sítio Salvador Psibovis,18,,-25.8287,-49.5477
br,sitio salvador,Sítio Salvador,18,,-23.431544,-50.187245
br,sitio salvador,Sítio Salvador,20,,-6.8,-41.2
br,sitio salvador taborda,Sítio Salvador Taborda,18,,-26.157538,-49.553337
br,sitio salvador t. de deus,Sítio Salvador T. de Deus,18,,-25.8782,-49.5297
br,sitio salviana bizarro,Sítio Salviana Bizarro,18,,-23.784307,-50.008806
br,sitio salvino beuther,Sítio Salvino Beuther,18,,-26.099273,-49.518473
br,sitio salvino pedroso,Sítio Salvino Pedroso,18,,-25.8365,-49.0433
br,sitio samambaia,Sítio Samambaia,27,,-23.553746,-47.097108
br,sitio samambala,Sítio Samambala,27,,-23.9082,-47.0557
br,sitio samanau,Sítio Samanaú,22,,-6.466667,-36.983333
br,sitio samanta,Sítio Samanta,27,,-23.164722,-46.613056
br,sitio samir de souza,Sítio Samir de Souza,26,,-25.9975,-48.7066
br,sitio sampaio,Sítio Sampaio,27,,-23.665715,-47.701187
br,sitio samuel a. de souza,Sítio Samuel A. de Souza,18,,-23.840217,-50.083222
br,sitio samuel barbosa,Sítio Samuel Barbosa,27,,-22.6371,-45.5866
br,sitio sandoval,Sítio Sandoval,27,,-23.736255,-47.669715
br,sitio sandra,Sítio Sandra,18,,-23.5601,-49.8424
br,sitio sangradouro,Sítio Sangradouro,30,,-7.7,-40.4
br,sitio sano mollo,Sítio Sano Mollo,18,,-25.5123,-49.9131
br,sitio santa adelia,Sítio Santa Adelia,27,,-23.346773,-46.644941
br,sitio santa amelia,Sítio Santa Amélia,18,,-23.255,-50.1732
br,sitio santa amelia,Sítio Santa Amelia,27,,-23.004722,-47.673611
br,sitio santa angelina,Sítio Santa Angelina,18,,-23.113,-50.2192
br,sitio santa apolonia,Sítio Santa Apolônia,27,,-23.7743,-46.6827
br,sitio santa barbara,Sítio Santa Bárbara,18,,-23.0082,-50.1913
br,sitio santa barbara,Sítio Santa Bárbara,27,,-23.218333,-46.556667
br,sitio santa carmelita,Sítio Santa Carmelita,18,,-23.2148,-50.1808
br,sitio santa carmem,Sítio Santa Carmem,27,,-23.514894,-47.145259
br,sitio santa carolina,Sítio Santa Carolina,18,,-23.0934,-50.2078
br,sitio santa catarina,Sítio Santa Catarina,18,,-23.472113,-50.094479
br,sitio santa catarina,Sítio Santa Catarina,27,,-23.675252,-47.03673
br,sitio santa cecilia,Sítio Santa Cecília,18,,-23.276767,-50.157623
br,sitio santa cecilia,Sítio Santa Cecilia,27,,-23.008889,-46.507778
br,sitio santa cilene,Sítio Santa Cílene,18,,-23.799038,-50.836848
br,sitio santa clara,Sítio Santa Clara,18,,-23.352342,-49.825591
br,sitio santa clara,Sítio Santa Clara,27,,-23.224167,-46.746389
br,sitio santa cruz,Sítio Santa Cruz,06,,-3.616667,-40.4
br,sitio santa cruz,Sítio Santa Cruz,15,,-22.5848,-45.6244
br,sitio santa cruz,Sítio Santa Cruz,18,,-23.238201,-50.113601
br,sitio santa cruz,Sítio Santa Cruz,27,,-23.174167,-46.678056
br,sitio santa edna,Sítio Santa Edna,18,,-23.1185,-50.2106
br,sitio santa efigenia,Sítio Santa Efigênia,18,,-23.552446,-50.168951
br,sitio santa efigenia,Sítio Santa Efigênia,27,,-23.185278,-46.726111
br,sitio santa elisa,Sítio Santa Elisa,18,,-23.1675,-50.1823
br,sitio santa eliza,Sítio Santa Eliza,18,,-23.243061,-52.065809
br,sitio santa ercilia,Sítio Santa Ercília,18,,-23.0635,-50.1802
br,sitio santa estela,Sítio Santa Estela,18,,-23.625826,-50.149814
br,sitio santa felicidade,Sítio Santa Felicidade,18,,-23.928643,-50.698374
br,sitio santa fe,Sítio Santa Fé,18,,-23.0914,-50.0979
br,sitio santa filomena,Sítio Santa Filomena,27,,-23.154167,-46.568333
br,sitio santa gertrudes,Sítio Santa Gertrudes,18,,-23.846225,-50.492749
br,sitio santa gertrudes,Sítio Santa Gertrudes,27,,-23.168333,-46.645
br,sitio santa helena,Sítio Santa Helena,18,,-23.0298,-50.1279
br,sitio santa helena,Sítio Santa Helena,27,,-23.106667,-46.605
br,sitio santa ilda,Sítio Santa Ilda,18,,-23.238166,-49.809899
br,sitio santa ines,Sítio Santa Inês,18,,-23.1065,-50.2121
br,sitio santa ines,Sítio Santa Inês,27,,-23.685182,-47.197681
br,sitio santa iracema,Sítio Santa Iracema,18,,-23.0297,-50.1531
br,sitio santa isabel,Sítio Santa Isabel,18,,-23.2028,-50.1541
br,sitio santa isabel,Sítio Santa Isabel,27,,-23.266774,-46.69515
br,sitio santa joana,Sítio Santa Joana,18,,-23.0438,-50.0862
br,sitio santa julia,Sítio Santa Júlia,18,,-23.595794,-50.687469
br,sitio santa julia,Sítio Santa Julia,27,,-23.018889,-46.506944
br,sitio santa julieta,Sítio Santa Julieta,27,,-23.634933,-47.165184
br,sitio santa laura,Sítio Santa Laura,27,,-23.249167,-46.725833
br,sitio santa leocadia,Sítio Santa Leocádia,18,,-26.0256,-49.8932
br,sitio santa lucia,Sítio Santa Lúcia,04,,-1.664722,-60.173611
br,sitio santa lucia,Sítio Santa Lúcia,18,,-23.1534,-50.2093
br,sitio santa lucia,Sítio Santa Lúcia,27,,-23.123333,-46.734722
br,sitio santa luisa,Sítio Santa Luísa,27,,-23.165,-46.5749
br,sitio santa luizia,Sítio Santa Luizia,18,,-23.493737,-49.951985
br,sitio santa luzia,Sítio Santa Luzia,18,,-23.0113,-50.1772
br,sitio santa luzia,Sítio Santa Luzia,26,,-26.093,-49.9609
br,sitio santa luzia,Sítio Santa Luzia,27,,-23.001111,-46.506944
br,sitio santa manoelina,Sítio Santa Manoelina,18,,-23.435954,-52.669114
br,sitio santa maria de lurdes,Sítio Santa Maria de Lurdes,18,,-23.464797,-49.832629
br,sitio santa mariana,Sítio Santa Mariana,18,,-23.29155,-50.14796
br,sitio santa maria,Sítio Santa Maria,04,,-1.656111,-60.182778
br,sitio santa maria,Sítio Santa Maria,18,,-23.0089,-50.1517
br,sitio santa maria,Sítio Santa Maria,27,,-23.023647,-49.86032
br,sitio santa marina,Sítio Santa Marina,18,,-23.1864,-50.1504
br,sitio santa marta,Sítio Santa Marta,18,,-23.420881,-49.791096
br,sitio santa marta,Sítio Santa Marta,27,,-23.177338,-47.653518
br,sitio santa matilde,Sítio Santa Matilde,27,,-23.109722,-46.609444
br,sitio santa monica,Sítio Santa Môníca,27,,-23.054167,-46.565278
br,sitio santana do rosario,Sítio Santana do Rosario,27,,-23.196111,-46.566667
br,sitio santana,Sítio Santana,04,,-1.871389,-60.08
br,sitio santana,Sítio Santana,06,,-7.233333,-39.2
br,sitio santana,Sítio Santana,18,,-23.115955,-49.868474
br,sitio sant'ana,Sitio Sant'Ana,18,,-23.8044,-50.8702
br,sitio santana,Sítio Santana,18,,-23.96,-50.8634
br,sitio santana,Sítio Santana,27,,-22.756181,-45.202623
br,sitio santa rafaela,Sítio Santa Rafaela,27,,-23.912788,-46.746363
br,sitio santa regina,Sítio Santa Regina,18,,-23.1024,-50.0909
br,sitio santa rita de cassia,Sítio Santa Rita de Cássia,18,,-25.828,-49.7459
br,sitio santa rita de cassia,Sítio Santa Rita de Cássia,27,,-23.261306,-46.696186
br,sitio santa rita e sao joao,Sítio Santa Rita e São João,18,,-23.300315,-50.157207
br,sitio santa rita,Sítio Santa Rita,06,,-7.35,-39.316667
br,sitio santa rita,Sítio Santa Rita,18,,-23.1085,-50.1935
br,sitio santa rita,Sitio Santa Rita,20,,-5.033333,-42.666667
br,sitio santa rita,Sítio Santa Rita,27,,-22.643,-45.5087
br,sitio santa rosalia,Sítio Santa Rosália,27,,-23.182778,-46.560556
br,sitio santa rosa,Sítio Santa Rosa,18,,-23.0737,-50.244
br,sitio santa rosa,Sítio Santa Rosa,27,,-23.688572,-47.023335
br,sitio santa teresa,Sítio Santa Teresa,18,,-23.0334,-50.0473
br,sitio santa teresa,Sítio Santa Teresa,27,,-23.534539,-47.095251
br,sitio santa teresina,Sítio Santa Teresina,18,,-23.781614,-50.132314
br,sitio santa teresinha,Sítio Santa Teresinha,18,,-23.0158,-50.1453
br,sitio santa teresinha,Sítio Santa Teresinha,26,,-26.1376,-49.2925
br,sitio santa teresinha,Sítio Santa Teresinha,27,,-23.056667,-47.715
br,sitio santa terezinha,Sítio Santa Terezinha,18,,-23.198705,-52.002439
br,sitio santa theresinha,Sítio Santa Theresinha,18,,-23.7801,-50.9667
br,sitio santa vicente,Sítio Santa Vicente,18,,-23.642895,-50.731411
br,sitio santiago,Sítio Santiago,18,,-23.890231,-50.238289
br,sitio santiago,Sítio Santiago,27,,-23.716537,-47.090582
br,sitio santiago tavares da rosa,Sítio Santiago Tavares da Rosa,18,,-25.164577,-48.860712
br,sitio santina de assis pereira,Sítio Santina de Assis Pereira,26,,-25.989037,-48.876971
br,sitio santina luz,Sítio Santina Luz,18,,-25.8498,-49.031
br,sitio santinha,Sítio Santinha,27,,-23.140556,-46.573611
br,sitio santino martins,Sítio Santino Martins,18,,-25.3864,-48.6398
br,sitio santinor c. nogueira,Sítio Santinor C. Nogueira,18,,-26.0334,-49.3132
br,sitio santo afonso,Sítio Santo Afonso,18,,-23.13,-50.1252
br,sitio santo agostinho,Sítio Santo Agostinho,18,,-23.878787,-50.470114
br,sitio santo agostinho,Sítio Santo Agostinho,26,,-26.226,-49.8063
br,sitio santo agostinho,Sítio Santo Agóstinho,27,,-23.098611,-47.730833
br,sitio santo aleixo,Sítio Santo Aleixo,27,,-23.170278,-46.581111
br,sitio santo alfredo,Sítio Santo Alfredo,18,,-23.0855,-50.1126
br,sitio santo amaro,Sítio Santo Amaro,27,,-23.549626,-47.102073
br,sitio santo andre,Sítio Santo André,18,,-23.0096,-50.2043
br,sitio santo angelo,Sítio Santo Ângelo,18,,-23.673421,-50.113647
br,sitio santo antonio da lagoa,Sítio Santo Antônio da Lagoa,27,,-23.233889,-46.631389
br,sitio santo antonio da posse,Sítio Santo Antônio da Posse,27,,-24.613624,-48.13276
br,sitio santo antonio de padua,Sítio Santo Antônio de Pádua,18,,-23.154957,-52.191958
br,sitio santo antonio de padua,Sítio Santo Antônio de Pádua,27,,-23.062778,-46.511667
br,sitio santo antonio,Sítio Santo Antônio,18,,-23.0132,-50.0249
br,sitio santo antonio,Sitio Santo Antônio,20,,-5.866667,-42.416667
br,sitio santo antonio,Sítio Santo Antônio,27,,-23.016225,-47.631482
br,sitio santo benedito,Sítio Santo Benedito,18,,-23.15272,-49.923221
br,sitio santo emilio,Sítio Santo Emilio,27,,-23.016594,-47.601902
br,sitio santo expedito,Sítio Santo Expedito,18,,-23.803622,-50.070631
br,sitio santo inacio,Sítio Santo Inácio,18,,-23.89323,-50.454661
br,sitio santo inacio,Sítio Santo Inácio,27,,-23.564232,-47.151437
br,sitio santo otavio,Sítio Santo Otávio,18,,-23.598999,-50.705737
br,sitio santo,Sítio Santo,18,,-23.44072,-50.099801
br,sitio santos pinto,Sítio Santos Pinto,18,,-25.9521,-49.399
br,sitio santos,Sítio Santos,18,,-23.788999,-50.839135
br,sitio santo steklain,Sítio Santo Steklain,18,,-25.7161,-49.7852
br,sitio sao adele,Sítio São Adele,27,,-23.348401,-46.637849
br,sitio sao antonio,Sítio São Antônio,18,,-23.781053,-50.085422
br,sitio sao barbara,Sítio São Bárbara,18,,-23.1274,-50.2395
br,sitio sao bartolomeu,Sítio São Bartolomeu,18,,-23.988098,-50.448878
br,sitio sao benedito,Sítio São Benedito,15,,-22.5179,-45.7067
br,sitio sao benedito,Sítio São Benedito,18,,-23.0198,-50.197
br,sitio sao benedito,Sítio São Benedito,27,,-23.003056,-46.516667
br,sitio sao bento,Sítio São Bento,06,,-6.166667,-39.9
br,sitio sao bento,Sitio São Bento,14,,-15.233333,-57.7
br,sitio sao bento,Sítio São Bento,18,,-23.1323,-50.2453
br,sitio sao bento,Sítio São Bento,27,,-23.020718,-46.680409
br,sitio sao bernardo,Sítio São Bernardo,18,,-25.417073,-48.872704
br,sitio sao bernardo,Sítio São Bernardo,27,,-23.038611,-46.531111
br,sitio sao bom jesus,Sítio São Bom Jesus,18,,-23.329015,-49.984126
br,sitio sao candido,Sítio São Cândido,18,,-23.985412,-50.545726
br,sitio sao carlos,Sítio São Carlos,18,,-23.1072,-50.002
br,sitio sao carlos,Sítio São Carlos,27,,-23.074253,-46.659887
br,sitio sao cristovao,Sítio São Cristóvão,21,,-22.8033,-44.1862
br,sitio sao cristovao,Sítio São Cristóvão,27,,-23.7818,-47.0383
br,sitio sao domingos,Sítio São Domingos,18,,-23.0202,-50.206
br,sitio sao domingos,Sítio São Domingos,27,,-23.133333,-47.687222
br,sitio sao estevao,Sítio São Estêvão,18,,-23.912155,-50.549318
br,sitio sao fernando,Sítio São Fernando,18,,-23.181055,-49.914108
br,sitio sao filipe,Sítio São Filipe,18,,-23.127251,-49.910749
br,sitio sao filipe,Sítio São Filipe,27,,-23.015461,-47.643216
br,sitio sao francisco da cachoeira,Sítio São Francisco da Cachoeira,18,,-23.216341,-49.950592
br,sitio sao francisco de assis,Sítio São Francisco de Assis,18,,-23.786506,-50.301639
br,sitio sao francisco de paula,Sítio São Francisco de Paula,18,,-25.600301,-49.972958
br,sitio sao francisco,Sítio São Francisco,04,,-1.790833,-60.142778
br,sitio sao francisco,Sítio São Francisco,18,,-23.0149,-50.1172
br,sitio sao francisco,Sítio São Francisco,22,,-5.229167,-36.378889
br,sitio sao francisco,Sítio São Francisco,27,,-23.000789,-49.776786
br,sitio sao gabriel,Sítio São Gabriel,15,,-22.5123,-45.6358
br,sitio sao gabriel,Sítio São Gabriel,18,,-23.1191,-50.1017
br,sitio sao gabriel,Sítio São Gabriel,27,,-23.57989,-47.092465
br,sitio sao george,Sítio São George,27,,-23.9853,-47.0195
br,sitio sao geraldo,Sítio São Geraldo,18,,-23.1655,-50.2424
br,sitio sao geraldo,Sítio São Geraldo,24,,-10.031111,-62.980556
br,sitio sao geraldo,Sítio São Geraldo,27,,-23.026491,-47.682071
br,sitio sao goncalo,Sítio São Gonçalo,18,,-23.405151,-50.14111
br,sitio sao isabel,Sítio São Isabel,18,,-23.783569,-50.524715
br,sitio sao jaoquim,Sítio São Jaoquim,27,,-23.810546,-46.722141
br,sitio sao jeremias,Sítio São Jeremias,27,,-23.739668,-47.247625
br,sitio sao jeronimo,Sítio São Jerônimo,18,,-23.49699,-49.945666
br,sitio sao jeronimo,Sítio São Jerônimo,27,,-23.9575,-47.2194
br,sitio sao joao batista,Sítio São João Batista,18,,-23.1173,-50.1261
br,sitio sao joao batista,Sítio São João Batista,27,,-23.269637,-46.546053
br,sitio sao joao bosco,Sítio São João Bosco,27,,-23.21785,-46.690691
br,sitio sao joao,Sítio São João,18,,-23.012,-50.2025
br,sitio sao joao,Sítio São João,27,,-23.046981,-47.628096
br,sitio sao joao velho,Sítio São João Velho,27,,-23.761,-47.026
br,sitio sao joaozinho felix,Sítio São Joãozinho Félix,18,,-25.444997,-48.763218
br,sitio sao joaozinho feliz,Sítio São Joãozinho Feliz,18,,-25.425083,-48.772738
br,sitio sao joaquim,Sítio São Joaquim,18,,-23.281737,-50.054297
br,sitio sao joaquim,Sítio São Joaquim,27,,-23.028889,-46.687778
br,sitio sao jonas,Sítio São Jonas,18,,-23.715991,-50.193214
br,sitio sao jorge,Sítio São Jorge,15,,-22.652,-45.5611
br,sitio sao jorge,Sítio São Jorge,18,,-23.098,-50.2308
br,sitio sao jorge,Sítio São Jorge,26,,-26.1232,-49.8641
br,sitio sao jorge,Sítio São Jorge,27,,-23.053264,-49.8633
br,sitio sao jose de goiana,Sítio São José de Goianã,27,,-23.5438,-47.146074
br,sitio sao jose,Sítio São José,06,,-3.566667,-39.5
br,sitio sao jose,Sítio São José,14,,-16.852778,-56.607222
br,sitio sao jose,Sítio São José,18,,-23.0061,-50.1878
br,sitio sao jose,Sítio São José,22,,-6.266667,-38.15
br,sitio sao jose,Sítio São José,27,,-23.0346,-46.6803
br,sitio sao judas,Sítio São Judas,27,,-23.505014,-47.007546
br,sitio sao judas tadeu,Sítio São Judas Tadeu,18,,-23.095966,-49.807308
br,sitio sao judas tadeu,Sítio São Judas Tadeu,27,,-23.078056,-46.536667
br,sitio sao juliao,Sítio São Julião,27,,-23.541827,-47.049787
br,sitio sao lasaro,Sítio São Lásaro,27,,-23.245833,-46.686111
br,sitio sao lazaro,Sítio São Lázaro,18,,-23.007167,-52.034766
br,sitio sao lazaro,Sítio São Lázaro,27,,-23.039167,-46.623889
br,sitio sao lourenco,Sítio São Lourenço,18,,-23.67288,-50.127344
br,sitio sao lourenco,Sítio São Lourenço,27,,-23.247656,-47.663414
br,sitio sao lucas,Sítio São Lucas,18,,-23.047466,-52.186755
br,sitio sao luis,Sítio São Luís,18,,-23.0053,-50.2481
br,sitio sao luis,Sítio São Luís,27,,-23.0149,-46.6267
br,sitio sao manoel,Sítio São Manoel,18,,-23.409447,-49.793403
br,sitio sao manuel,Sítio São Manuel,18,,-23.096,-50.1966
br,sitio sao manuel,Sítio São Manuel,27,,-23.024722,-46.510278
br,sitio sao marcos da paciencia,Sítio São Marcos da Paciência,18,,-23.1238,-50.1114
br,sitio sao marcos,Sítio São Marcos,27,,-23.0325,-47.713056
br,sitio sao mateus,Sítio São Mateus,18,,-23.9153,-50.9984
br,sitio sao miguel arcanjo,Sítio São Miguel Arcanjo,18,,-23.0967,-50.1217
br,sitio sao miguel,Sítio São Miguel,04,,-1.885556,-60.078056
br,sitio sao miguel,Sítio São Miguel,18,,-23.0031,-50.2468
br,sitio sao miguel,Sítio São Miguel,27,,-23.071175,-49.817317
br,sitio sao nicolau,Sítio São Nicolau,18,,-23.923955,-50.152177
br,sitio sao paulino,Sítio São Paulino,18,,-23.8628,-50.614475
br,sitio sao paulo,Sítio São Paulo,04,,-1.716389,-60.152778
br,sitio sao paulo,Sítio São Paulo,18,,-23.065236,-52.191733
br,sitio sao paulo,Sítio São Paulo,27,,-23.182222,-46.725556
br,sitio sao pedrinho,Sítio São Pedrinho,27,,-25.023132,-48.5625
br,sitio sao pedro do turvo,Sítio São Pedro do Turvo,27,,-23.284297,-47.930582
br,sitio sao pedro,Sítio São Pedro,18,,-23.0102,-50.1788
br,sitio sao pedro,Sítio São Pedro,27,,-23.000556,-46.725
br,sitio sao protazio,Sítio São Protázio,18,,-23.919775,-50.245693
br,sitio sao rafael,Sítio São Rafael,18,,-23.864685,-50.512008
br,sitio sao rafael,Sítio São Rafael,27,,-23.57103,-47.032824
br,sitio sao raimundo,Sítio São Raimundo,04,,-1.644722,-60.184722
br,sitio sao roberto,Sítio São Roberto,27,,-23.111111,-46.614444
br,sitio sao rogue,Sítio São Rogue,18,,-23.900679,-50.426353
br,sitio sao roque do pico,Sítio São Roque do Pico,18,,-23.740949,-50.244977
br,sitio sao roque,Sítio São Roque,18,,-23.1121,-50.1918
br,sitio sao roque,Sítio São Roque,27,,-22.6439,-45.5169
br,sitio sao salvador,Sítio São Salvador,18,,-23.147138,-49.906801
br,sitio sao salvador,Sítio São Salvador,27,,-23.223333,-46.659722
br,sitio sao sansao,Sítio São Sansão,27,,-23.2488,-47.7706
br,sitio sao sebastiao carapataro,Sítio São Sebastião Carapataro,27,,-23.004159,-46.659435
br,sitio sao sebastiao do paraiso,Sítio São Sebastião do Paraíso,18,,-23.783217,-50.386612
br,sitio sao sebastiao,Sítio São Sebastião,18,,-23.0567,-50.1184
br,sitio sao sebastiao,Sítio São Sebastião,27,,-23.029795,-46.700613
br,sitio sao simao,Sítio São Simão,27,,-23.243056,-46.593333
br,sitio sao teresinha,Sítio São Teresinha,18,,-23.544104,-50.591729
br,sitio sao tomas,Sítio São Tomás,18,,-23.760131,-50.181093
br,sitio sao tomas,Sítio São Tomás,27,,-23.7618,-47.0524
br,sitio sao vicente,Sítio São Vicente,18,,-23.0639,-50.1541
br,sitio sao vicente,Sítio São Vicente,27,,-23.344005,-46.615702
br,sitio sao vito,Sítio São Vito,27,,-23.019444,-46.697778
br,sitio sapateiro,Sítio Sapateiro,27,,-23.551099,-47.115206
br,sitio sapatu,Sítio Sapatu,27,,-24.6001,-48.3635
br,sitio sapopema,Sítio Sapopema,18,,-23.910013,-50.513174
br,sitio saramandaia,Sítio Saramandaia,18,,-23.168105,-49.831015
br,sitio saramandaia,Sítio Saramandaia,27,,-23.159167,-46.728333
br,sitio sato,Sítio Sato,27,,-23.5361,-47.6056
br,sitio saudade,Sítio Saudade,27,,-23.615341,-47.028033
br,sitio sauna ii,Sítio Sauna II,27,,-23.261106,-46.517432
br,sitio sauna segunda,Sítio Sauna Segunda,27,,-23.261106,-46.517432
br,sitio savio nogueira,Sítio Savio Nogueira,26,,-26.1307,-49.2895
br,sitio sayto,Sítio Sayto,27,,-23.524739,-47.174873
br,sitios boa vista,Sítios Boa Vista,18,,-23.698457,-50.241443
br,sitio s. dirce,Sítio S. Dirce,18,,-23.69522,-50.21333
br,sitios do bairro dos paes,Sítios do Bairro dos Paes,27,,-23.684572,-47.235545
br,sitio sebastao fernandes,Sítio Sebastão Fernandes,18,,-25.034083,-48.980333
br,sitio sebastiana do r. luz,Sítio Sebastiana do R. Luz,18,,-25.8918,-49.0351
br,sitio sebastiana dos santos,Sítio Sebastiana dos Santos,18,,-26.090651,-49.605831
br,sitio sebastiana lourenco,Sítio Sebastiana Lourenço,18,,-25.5465,-48.7532
br,sitio sebastiao a. da silva,Sítio Sebastião A. da Silva,18,,-23.937536,-50.179466
br,sitio sebastiao a. de oliveira,Sítio Sebastião A. de Oliveira,18,,-23.833336,-50.058338
br,sitio sebastiao aires,Sítio Sebastião Aires,18,,-25.985108,-49.852234
br,sitio sebastiao alves,Sítio Sebastião Alves,18,,-23.710787,-50.195393
br,sitio sebastiao b. anhaia,Sítio Sebastião B. Anhaia,18,,-23.996572,-50.008416
br,sitio sebastiao barbarino,Sítio Sebastião Barbarino,18,,-23.5936,-49.8443
br,sitio sebastiao barbosa,Sítio Sebastião Barbosa,18,,-23.990941,-50.130559
br,sitio sebastiao batista,Sítio Sebastião Batista,18,,-25.041596,-48.930147
br,sitio sebastiao becker,Sítio Sebastião Becker,18,,-25.4462,-48.6354
br,sitio sebastiao b. nascimento,Sítio Sebastião B. Nascimento,18,,-23.372314,-49.793144
br,sitio sebastiao cardoso,Sítio Sebastião Cardoso,18,,-23.437637,-49.792127
br,sitio sebastiao carvalho justino dos santos,Sítio Sebastião Carvalho Justino dos Santos,27,,-25.056202,-48.552875
br,sitio sebastiao carvalho,Sítio Sebastião Carvalho,26,,-26.2342,-49.8221
br,sitio sebastiao c. bueno,Sítio Sebastião C. Bueno,18,,-25.796064,-49.89082
br,sitio sebastiao c. da mota,Sítio Sebastião C. da Mota,18,,-23.7112,-49.8356
br,sitio sebastiao c. da silva,Sítio Sebastião C. da Silva,18,,-23.944796,-50.261122
br,sitio sebastiao c. de castro,Sítio Sebastião C. de Castro,18,,-25.792077,-49.77974
br,sitio sebastiao c. de freitas,Sítio Sebastião C. de Freitas,18,,-26.019,-49.9111
br,sitio sebastiao c. de lima,Sítio Sebastião C. de Lima,18,,-25.5102,-48.8781
br,sitio sebastiao c. de oliveira,Sítio Sebastião C. de Oliveira,18,,-23.9639,-50.9472
br,sitio sebastiao colacon,Sítio Sebastião Colacon,18,,-25.8548,-49.5765
br,sitio sebastiao cortano,Sítio Sebastião Cortano,18,,-23.999432,-50.451065
br,sitio sebastiao costa,Sítio Sebastião Costa,18,,-23.764289,-50.48116
br,sitio sebastiao custodio,Sítio Sebastião Custódio,18,,-23.663,-49.9107
br,sitio sebastiao dalcisio,Sítio Sebastião Dalcísio,18,,-23.7411,-49.7737
br,sitio sebastiao d. da silva,Sítio Sebastião D. da Silva,18,,-23.6927,-49.7532
br,sitio sebastiao de andrade,Sítio Sebastião de Andrade,18,,-25.9174,-49.4622
br,sitio sebastiao de oliveira,Sítio Sebastião de Oliveira,18,,-23.766862,-50.195435
br,sitio sebastiao de p. pereira,Sítio Sebastião de P. Pereira,18,,-23.6854,-49.7841
br,sitio sebastiao dias pinto,Sítio Sebastião Dias Pinto,18,,-25.7269,-49.8476
br,sitio sebastiao dias,Sítio Sebastião Dias,18,,-25.871083,-49.982691
br,sitio sebastiao divino de freitas,Sítio Sebastião Divino de Freitas,18,,-23.733476,-50.094115
br,sitio sebastiao divino,Sítio Sebastião Divino,18,,-23.74157,-50.02948
br,sitio sebastiao do couto,Sítio Sebastião do Couto,18,,-23.745,-49.9021
br,sitio sebastiao domingos,Sítio Sebastião Domingos,18,,-23.5228,-49.9866
br,sitio sebastiao dos santa rosa,Sítio Sebastião dos Santa Rosa,18,,-23.937091,-50.42968
br,sitio sebastiao dos santos,Sítio Sebastião dos Santos,18,,-23.819392,-50.644406
br,sitio sebastiao dos s. ribas,Sítio Sebastião dos S. Ribas,18,,-25.831711,-49.94908
br,sitio sebastiao entraut,Sítio Sebastião Entraut,18,,-25.871942,-48.787655
br,sitio sebastiao f. de souza,Sítio Sebastião F. de Souza,18,,-23.972277,-50.443784
br,sitio sebastiao ferreira,Sítio Sebastião Ferreira,18,,-23.1641,-50.1267
br,sitio sebastiao firmino,Sítio Sebastião Firmino,18,,-23.811923,-50.02042
br,sitio sebastiao fortes,Sítio Sebastião Fortes,18,,-23.7181,-49.8152
br,sitio sebastiao f. pereira,Sítio Sebastião F. Pereira,18,,-23.6538,-49.8523
br,sitio sebastiao francisco m. de souza,Sítio Sebastião Francisco M. de Souza,18,,-25.824373,-49.909343
br,sitio sebastiao galvao,Sítio Sebastião Galvão,18,,-23.721749,-50.197526
br,sitio sebastiao garcia de oliveira,Sítio Sebastião Garcia de Oliveira,18,,-23.977,-50.8603
br,sitio sebastiao gomes,Sítio Sebastião Gomes,18,,-23.1913,-50.1196
br,sitio sebastiao goncalves,Sítio Sebastião Gonçalves,18,,-23.771134,-50.128232
br,sitio sebastiao h. azevedo,Sítio Sebastião H. Azevedo,18,,-23.950366,-50.117814
br,sitio sebastiao h. cardoso,Sítio Sebastião H. Cardoso,18,,-25.912119,-49.973517
br,sitio sebastiao hirlt,Sítio Sebastião Hirlt,18,,-25.938353,-49.844391
br,sitio sebastiao inacio,Sítio Sebastião Inácio,18,,-23.761162,-50.046453
br,sitio sebastiao j. maciel,Sítio Sebastião J. Maciel,18,,-23.574,-49.9973
br,sitio sebastiao jonas,Sítio Sebastião Jonas,18,,-23.572,-49.8072
br,sitio sebastiao jose do amarantes,Sítio Sebastião José do Amarantes,18,,-25.833726,-49.937092
br,sitio sebastiao lameu,Sítio Sebastião Lameu,18,,-23.778005,-50.069904
br,sitio sebastiao laurindo,Sítio Sebastião Laurindo,18,,-23.0651,-50.2082
br,sitio sebastiao leite,Sítio Sebastião Leite,18,,-23.9989,-50.8898
br,sitio sebastiao leme,Sítio Sebastião Leme,18,,-25.9238,-49.05
br,sitio sebastiao lima,Sítio Sebastião Lima,18,,-23.175,-50.0698
br,sitio sebastiao lopes dias,Sítio Sebastião Lopes Dias,15,,-22.562,-45.5608
br,sitio sebastiao luiz de souza,Sítio Sebastião Luiz de Souza,18,,-23.697236,-50.102727
br,sitio sebastiao maia,Sítio Sebastião Maia,18,,-23.9734,-50.8622
br,sitio sebastiao m. assumpcao,Sítio Sebastião M. Assumpção,18,,-26.0029,-49.9394
br,sitio sebastiao mendes,Sítio Sebastião Mendes,18,,-25.933803,-49.936243
br,sitio sebastiao messias,Sítio Sebastião Messias,18,,-23.905095,-50.197249
br,sitio sebastiao mineiro,Sítio Sebastião Mineiro,18,,-23.879913,-50.546058
br,sitio sebastiao moraes,Sítio Sebastião Moraes,18,,-23.242631,-49.91899
br,sitio sebastiao o. de oliveira,Sítio Sebastião O. de Oliveira,18,,-25.930209,-49.210184
br,sitio sebastiao o. nogueira,Sítio Sebastião O. Nogueira,18,,-25.777903,-48.928092
br,sitio sebastiao paiva,Sítio Sebastião Paiva,26,,-26.2269,-49.9162
br,sitio sebastiao parmezan,Sítio Sebastião Parmezan,18,,-23.5326,-49.9773
br,sitio sebastiao pereira,Sítio Sebastião Pereira,18,,-23.359808,-49.82341
br,sitio sebastiao pinheiro de oliveira,Sítio Sebastião Pinheiro de Oliveira,18,,-23.9712,-50.7842
br,sitio sebastiao potine,Sítio Sebastião Potine,18,,-23.65893,-50.044836
br,sitio sebastiao prado,Sítio Sebastião Prado,18,,-25.8591,-49.5416
br,sitio sebastiao ribas,Sítio Sebastião Ribas,18,,-26.06071,-49.703294
br,sitio sebastiao r. paz,Sítio Sebastião R. Paz,18,,-25.7024,-49.8554
br,sitio sebastiao santos,Sítio Sebastião Santos,18,,-26.082431,-49.620655
br,sitio sebastiao schreiner,Sítio Sebastião Schreiner,18,,-26.088299,-49.550051
br,sitio sebastiao,Sítio Sebastião,18,,-25.795,-49.701667
br,sitio sebastiao s. lopes,Sítio Sebastião S. Lopes,18,,-23.731717,-50.070196
br,sitio sebastiao s. maia,Sítio Sebastião S. Maia,18,,-25.8805,-49.1059
br,sitio sebastiao teixeira,Sítio Sebastião Teixeira,18,,-25.862926,-49.795433
br,sitio sebastiao tiburcio,Sítio Sebastião Tibúrcio,18,,-23.6565,-49.7924
br,sitio sebastiao tomas,Sítio Sebastião Tomás,18,,-23.6057,-49.8377
br,sitio sebastiao tomazonas,Sítio Sebastião Tomazonas,26,,-26.1409,-49.8439
br,sitio sebastiao totene,Sítio Sebastião Totene,18,,-23.5596,-49.969
br,sitio sebastiao t. silva,Sítio Sebastião T. Silva,18,,-23.6816,-49.9077
br,sitio sebastiao vicente de paula,Sítio Sebastião Vicente de Paula,18,,-23.2333,-50.2432
br,sitio sebastiao vicente,Sítio Sebastião Vicente,18,,-25.963177,-49.905363
br,sitio sebastiao vieira,Sítio Sebastião Vieira,18,,-23.615,-49.7509
br,sitio sebastiao v. neto,Sítio Sebastião V. Neto,18,,-23.5996,-49.7527
br,sitio sebastiao zanine,Sítio Sebastião Zanine,18,,-23.5182,-49.987
br,sitio seco,Sítio Sêco,14,,-15.666667,-56.533333
br,sitio seco,Sítio Sêco,22,,-5.118056,-36.407778
br,sitio seda s. bratac,Sítio Seda S. Bratac,18,,-23.784941,-50.075281
br,sitio segredo,Sítio Segredo,06,,-6.733333,-39.416667
br,sitio seis irmaos,Sítio Seis Irmãos,18,,-23.863909,-50.145648
br,sitio seitoro kuratsu,Sítio Seitoro Kuratsu,18,,-23.0145,-50.0245
br,sitio s. elizabeth,Sítio S. Elizabeth,18,,-23.825126,-50.159857
br,sitio selva de pedra,Sítio Selva de Pedra,04,,-1.890278,-60.070556
br,sitio semeador,Sítio Semeador,18,,-23.2409,-50.1384
br,sitio seminario de lapa,Sítio Seminário de Lapa,18,,-25.805556,-49.720278
br,sitio seminario,Sítio Seminário,27,,-23.448667,-46.657082
br,sitio senhor bom jesus,Sítio Senhor Bom Jesus,18,,-23.83294,-50.547395
br,sitio seno arentz,Sítio Seno Arentz,26,,-26.1727,-49.3177
br,sitio serafim de bastos,Sítio Serafim de Bastos,18,,-25.968056,-49.689722
br,sitio sereia,Sítio Sereia,18,,-23.776237,-50.666976
br,sitio serelepe,Sítio Serelepe,27,,-23.639223,-47.128449
br,sitio sereno,Sítio Sereno,27,,-23.561153,-47.05394
br,sitio sergio andrade,Sítio Sérgio Andrade,18,,-23.730896,-50.019834
br,sitio sergio a. pires,Sítio Sérgio A. Pires,18,,-25.8265,-49.3455
br,sitio sergio colaco,Sítio Sérgio Colaço,18,,-25.7628,-49.5213
br,sitio sergio de dalorti,Sítio Sérgio de Dalorti,18,,-23.828337,-50.610737
br,sitio sergio drust,Sítio Sérgio Drust,18,,-25.7853,-49.5642
br,sitio sergio faeda,Sítio Sérgio Faeda,18,,-23.1554,-50.1654
br,sitio sergio goncalves,Sítio Sérgio Gonçalves,18,,-23.81624,-50.183445
br,sitio sergio i. rodrigues,Sítio Sérgio I. Rodrigues,18,,-23.89694,-50.070293
br,sitio sergio j. leka,Sítio Sérgio J. Leka,18,,-25.7884,-49.4847
br,sitio sergio kipoviski,Sítio Sérgio Kipoviski,18,,-26.0282,-49.4734
br,sitio sergio kubitschek,Sítio Sérgio Kubitschek,18,,-23.526228,-50.005699
br,sitio sergio mazur,Sítio Sérgio Mazur,18,,-25.788,-49.5196
br,sitio sergio oscar,Sítio Sérgio Oscar,18,,-25.242249,-48.746459
br,sitio sergio r. martins,Sítio Sérgio R. Martins,18,,-25.576,-49.9114
br,sitio sergio r. ribas,Sítio Sérgio R. Ribas,18,,-25.942222,-49.523333
br,sitio sergio sanches,Sítio Sérgio Sanches,18,,-23.956192,-50.40965
br,sitio sergio schaider,Sítio Sérgio Schaider,26,,-26.225623,-49.693336
br,sitio sergio yukimasa sanada,Sítio Sérgio Yukimasa Sanada,18,,-25.4021,-48.777724
br,sitio seriema,Sítio Seriema,27,,-23.168889,-46.567222
br,sitio seroa,Sítio Serôa,18,,-25.56,-48.7671
br,sitio serra alta,Sítio Serra Alta,27,,-23.198056,-46.540278
br,sitio serra da figueira,Sítio Serra da Figueira,18,,-23.389,-49.8953
br,sitio serra do boi,Sítio Serra do Boi,30,,-7.783333,-36.166667
br,sitio serra grande,Sítio Serra Grande,18,,-23.801415,-50.52707
br,sitio serrania,Sítio Serrania,06,,-6.633333,-39.533333
br,sitio serrano,Sítio Serrano,27,,-23.241944,-46.583889
br,sitio serra palma,Sitio Serra Palma,20,,-7.5,-40.7
br,sitio serra verde,Sítio Serra Verde,18,,-25.925928,-48.804796
br,sitio serra vermelha,Sítio Serra Vermelha,06,,-4.25,-38.8
br,sitio serrinha,Sítio Serrinha,18,,-23.157327,-49.867463
br,sitio serrinha,Sítio Serrinha,21,,-22.2929,-44.4087
br,sitio serrinha,Sítio Serrinha,27,,-24.559808,-48.875383
br,sitio serrinha,Sítio Serrinha,30,,-7.583333,-40.383333
br,sitio serrote,Sítio Serrote,06,,-6.783333,-39.333333
br,sitio sertaozinho,Sítio Sertãozinho,18,,-23.1647,-50.2462
br,sitio sesmaria,Sítio Sesmaria,18,,-25.451526,-48.819821
br,sitio sete colinas,Sítio Sete Colinas,27,,-23.9395,-47.1826
br,sitio sete curvas,Sítio Sete Curvas,27,,-23.867,-46.7415
br,sitio sete estrelas,Sítio Sete Estrêlas,27,,-23.789003,-46.693164
br,sitio sete lagoas,Sítio Sete Lagoas,27,,-23.801265,-46.695946
br,sitio sete pinheiros,Sítio Sete Pinheiros,18,,-23.107371,-49.88708
br,sitio setimo ceu,Sítio Sétimo Céu,18,,-25.7942,-49.2983
br,sitio setubal,Sítio Setúbal,27,,-23.605532,-47.192475
br,sitio severino paluski,Sítio Severino Paluski,18,,-26.0541,-49.4454
br,sitio sezinando chaves,Sítio Sezinando Chaves,18,,-25.8856,-49.9844
br,sitio sezinando f. rocha,Sítio Sezinando F. Rocha,18,,-25.8895,-49.0368
br,sitio shandoa,Sítio Shandoá,26,,-26.1858,-49.831
br,sitio shangri-la,Sítio Shangri-Lá,18,,-23.983073,-50.510245
br,sitio shibata,Sítio Shibata,27,,-23.035965,-49.880149
br,sitio shike yoshi,Sítio Shike Yoshi,18,,-23.523609,-50.583677
br,sitio shimitti coinhoshi,Sítio Shimitti Coinhoshi,18,,-23.0047,-50.0096
br,sitio shimuda,Sítio Shimuda,27,,-23.72677,-47.20916
br,sitio shirayshi,Sítio Shirayshi,27,,-23.593378,-47.209858
br,sitio shyrleu l. carneiro,Sítio Shyrleu L. Carneiro,18,,-23.995573,-50.121051
br,sitio sidnei cirilo,Sítio Sidnei Cirilo,18,,-23.529106,-50.732057
br,sitio sidnei ferreira,Sítio Sidnei Ferreira,18,,-23.233149,-49.818338
br,sitio sidnei mano,Sítio Sidnei Mano,18,,-23.0034,-50.0162
br,sitio siegfied hutinger,Sítio Siegfied Hutinger,26,,-26.0932,-49.9229
br,sitio silvanir,Sítio Silvanir,18,,-23.883601,-50.539943
br,sitio silveira miranda,Sítio Silveira Miranda,18,,-25.833241,-48.791541
br,sitio silverio nogueira,Sítio Silvério Nogueira,26,,-26.1465,-49.8417
br,sitio silverio p. carneiro,Sítio Silvério P. Carneiro,18,,-23.950395,-50.44084
br,sitio silverio p. dos santos,Sítio Silvério P. dos Santos,18,,-25.456363,-48.845507
br,sitio silverio,Sítio Silvério,18,,-25.82675,-49.905132
br,sitio silverio vitanca,Sítio Silvério Vitanca,18,,-23.372495,-50.040377
br,sitio silvestre berniak,Sítio Silvestre Berniak,18,,-25.8361,-49.5172
br,sitio silvestre filipack,Sítio Silvestre Filipack,18,,-25.8996,-49.4729
br,sitio silvestre kuduavski,Sítio Silvestre Kuduavski,18,,-25.7767,-49.432283
br,sitio silvestre kuschisk,Sítio Silvestre Kuschisk,18,,-25.6787,-49.9767
br,sitio silvestre liebl,Sítio Silvestre Liebl,18,,-26.045836,-49.505206
br,sitio silvestre schmidt,Sítio Silvestre Schmidt,18,,-26.068067,-49.730752
br,sitio silvestre simoes,Sítio Silvestre Simões,18,,-23.6518,-49.8171
br,sitio silvestre,Sítio Silvestre,18,,-23.9413,-50.8979
br,sitio silvestre,Sítio Silvestre,27,,-23.8213,-46.668
br,sitio silvestre telma,Sítio Silvestre Telma,26,,-26.1331,-49.3355
br,sitio silvino domingues,Sítio Silvino Domingues,18,,-23.63079,-50.126694
br,sitio silvino priollo,Sítio Silvino Priollo,18,,-23.409,-49.9092
br,sitio silvino,Sítio Silvino,18,,-25.5018,-48.8946
br,sitio silvio a. biegene,Sítio Silvio A. Biegene,18,,-26.150101,-49.640982
br,sitio silvio a. santos,Sítio Silvio A. Santos,18,,-25.871251,-48.979894
br,sitio silvio ferreira,Sítio Silvio Ferreira,18,,-23.230065,-49.814407
br,sitio silvio garanhane,Sítio Silvio Garanhane,18,,-23.7101,-49.831
br,sitio silvio henrique grohs,Sítio Sílvio Henrique Grohs,18,,-25.956672,-49.840129
br,sitio silvio j. kormann,Sítio Silvio J. Kormann,18,,-25.5427,-48.7541
br,sitio silvio martins,Sítio Silvio Martins,18,,-25.542,-48.7624
br,sitio silvio n. da cruz,Sítio Silvio N. da Cruz,18,,-25.9043,-49.267
br,sitio silvio ruthes,Sítio Silvio Ruthes,18,,-26.071366,-49.68662
br,sitio silvio sena,Sítio Sílvio Sena,18,,-26.0208,-49.4739
br,sitio silvio,Sítio Silvio,18,,-25.955,-49.3228
br,sitio simal de oliveira,Sítio Simal de Oliveira,18,,-25.8419,-49.3529
br,sitio simao dos santos,Sítio Simão dos Santos,18,,-25.907754,-49.967183
br,sitio simeao dutra,Sítio Simeão Dutra,18,,-25.3847,-48.6033
br,sitio simiao ribas de paula,Sítio Simião Ribas de Paula,18,,-25.5686,-49.9742
br,sitio sinesio i. ferreira,Sítio Sinésio I. Ferreira,18,,-23.916416,-50.409424
br,sitio sinesio oliveira,Sítio Sinésio Oliveira,18,,-23.849644,-50.069912
br,sitio s. ines,Sítio S. Inês,18,,-23.724663,-50.074299
br,sitio sinildo friedrik,Sítio Sinildo Friedrik,26,,-26.1602,-49.3478
br,sitio sinoju h. kotsui,Sítio Sinoju H. Kotsui,18,,-23.917992,-50.156333
br,sitio sinozaka,Sítio Sinozaka,27,,-23.584366,-47.211841
br,sitio sinuelo,Sítio Sinuelo,18,,-23.662976,-50.569967
br,sitio siqueira,Sítio Siqueira,18,,-23.931261,-50.221906
br,sitio,Sítio,02,,-9.35,-37.266667
br,sitio,Sítio,05,,-10.216667,-39.916667
br,sitio,Sítio,06,,-5,-40.116667
br,sitio,Sítio,13,,-3.860556,-42.817778
br,sitio,Sítio,14,,-16.295833,-56.565833
br,sitio,Sítio,15,,-17.416667,-43.8
br,sitio,Sítio,16,,-.916667,-50.4
br,sitio,Sítio,20,,-3.4325,-42.040556
br,sitio,Sítio,22,,-6.45,-38.533333
br,sitio,Sitio,30,,-8.066667,-37.85
br,sitio sitio sao luis,Sítio Sítio São Luís,27,,-23.279098,-46.705687
br,sitio sizenando do r. rocha,Sítio Sizenando do R. Rocha,18,,-25.9718,-49.1867
br,sitio s. lucia,Sítio S. Lúcia,18,,-23.824773,-50.05711
br,sitios novos de cima,Sítios Novos de Cima,06,,-3.816667,-38.983333
br,sitios novos,Sítios Novos,05,,-9.1,-38.416667
br,sitios novos,Sítios Novos,06,,-3.733333,-38.95
br,sitios novos,Sítios Novos,30,,-7.933333,-38.55
br,sitio soares,Sítio Soares,18,,-23.856117,-50.459651
br,sitio soares,Sítio Soares,27,,-23.655164,-47.181209
br,sitio soberanqui,Sítio Soberanqui,18,,-23.5824,-49.9946
br,sitio sodeque,Sítio Sodeque,18,,-23.0683,-50.1172
br,sitio soeli,Sítio Soeli,18,,-25.833739,-49.757379
br,sitio soestona,Sítio Soestona,27,,-23.8989,-47.111
br,sitio sofhia zenskoski,Sítio Sofhia Zenskoski,18,,-25.526,-48.7956
br,sitio sofia alves,Sítio Sofia Alves,18,,-25.914167,-49.615
br,sitio sofia cordeiro,Sítio Sofia Cordeiro,18,,-25.8921,-49.5609
br,sitio sofia hernning,Sítio Sofia Hernning,26,,-26.168,-49.3646
br,sitio sofia jagielski,Sítio Sofia Jagielski,26,,-25.995133,-48.839778
br,sitio sofia lenoneke,Sítio Sofia Lenoneke,18,,-23.873978,-50.418882
br,sitio sofia thrstaba,Sítio Sofia Thrstaba,18,,-25.766389,-49.638889
br,sitio solar da montanha,Sítio Solar da Montanha,27,,-23.218056,-46.545
br,sitio solar dos arcos,Sítio Solar dos Arcos,27,,-23.283899,-46.730004
br,sitio soledado,Sítio Soledado,22,,-6.116667,-36.95
br,sitio solidao,Sítio Solidão,18,,-25.64114,-50.094003
br,sitio solidao,Sítio Solidão,27,,-23.263803,-46.678704
br,sitio solta,Sítio Solta,30,,-7.916667,-40.05
br,sitio sombrio,Sítio Sombrio,30,,-7.616667,-40.083333
br,sitio sonhado,Sítio Sonhado,27,,-23.18,-46.679167
br,sitio sonho azul,Sítio Sonho Azul,18,,-25.8428,-49.1079
br,sitio sonho azul,Sítio Sonho Azul,27,,-23.124,-46.6458
br,sitio sonho meu,Sítio Sonho Meu,18,,-25.885904,-49.768917
br,sitio sonho,Sítio Sonho,27,,-23.721004,-47.173929
br,sitio sonia,Sítio Sônia,18,,-25.494308,-48.876896
br,sitio sonicato,Sítio Sonicato,27,,-23.174444,-46.578889
br,sitio sonolandia,Sítio Sonolândia,26,,-26.2217,-49.2793
br,sitio sorocaba,Sítio Sorocaba,18,,-23.763127,-50.084174
br,sitio sorocabucu,Sítio Sorocabuçu,27,,-23.727231,-47.180571
br,sitio soroca mirim,Sítio Soroca Mirim,27,,-23.618476,-47.133279
br,sitio sororoca,Sítio Sororoca,25,,.716667,-61.516667
br,sitio sorriso,Sítio Sorriso,18,,-23.834229,-50.155787
br,sitio sossego,Sítio Sossêgo,06,,-6.8,-39
br,sitio sossego,Sítio Sossego,27,,-23.093889,-46.511944
br,sitio souto gomes,Sítio Souto Gomes,18,,-25.3871,-48.6499
br,sitio standislaw,Sítio Standislaw,18,,-25.921528,-49.220093
br,sitio stanislau figura,Sítio Stanislau Figura,18,,-25.7893,-49.5958
br,sitio stanislau piravoscki,Sítio Stanislau Piravoscki,18,,-25.8228,-49.4397
br,sitio stanislau prussaki,Sítio Stanislau Prussaki,18,,-26.0416,-49.3889
br,sitio stanislau wrobel,Sítio Stanislau Wrobel,18,,-26.032545,-49.717527
br,sitio stefanio gren,Sítio Stefanio Gren,26,,-26.2261,-49.8848
br,sitio stefano betellim,Sítio Stefano Betellim,18,,-26.0163,-49.9219
br,sitio s. teresinha,Sítio S. Teresinha,18,,-23.263622,-50.226793
br,sitio stivan e irmaos,Sítio Stivan e Irmãos,18,,-23.554,-49.9854
br,sitio stoebert,Sítio Stoebert,18,,-26.141553,-49.512715
br,sitio sueli t. krause,Sítio Sueli T. Krause,26,,-26.1425,-49.3418
br,sitio suely olimpio rodrigues,Sítio Suely Olímpio Rodrigues,18,,-23.600264,-50.16232
br,sitio sufia mantzar,Sítio Sufia Mantzar,18,,-26.045737,-49.675205
br,sitio sul brasil reflorestadora,Sítio Sul Brasil Reflorestadora,18,,-25.9476,-48.6083
br,sitio sulina,Sítio Sulina,27,,-23.698325,-47.033228
br,sitio sumauma,Sítio Sumaúma,27,,-23.558814,-47.162172
br,sitio supercilio,Sítio Supercílio,18,,-23.920031,-50.31428
br,sitio susu mikiache,Sítio Susu Mikiache,18,,-25.271,-48.7282
br,sitio suzuki,Sítio Suzuki,18,,-23.7807,-50.9748
br,sitio tabuao,Sítio Tabuáo,18,,-23.714652,-50.673617
br,sitio tachyro,Sítio Tachyro,18,,-23.0072,-50.2002
br,sitio tadashi,Sítio Tadashi,18,,-23.569783,-50.727687
br,sitio tadeu deda,Sítio Tadeu Deda,18,,-25.797865,-49.759545
br,sitio tadeu dudeki,Sítio Tadeu Dudeki,18,,-25.8382,-49.5071
br,sitio tadeu jurlinski,Sítio Tadeu Jurlinski,18,,-25.999444,-49.723611
br,sitio tadeu karan,Sítio Tadeu Karan,18,,-25.830618,-49.750278
br,sitio tadeu kossoski,Sítio Tadeu Kossoski,18,,-25.819305,-49.779356
br,sitio tadeu krinker,Sítio Tadeu Krinker,18,,-25.7655,-49.5572
br,sitio tadeu kurka,Sítio Tadeu Kurka,18,,-25.76,-49.638333
br,sitio tadeu machniviscz,Sítio Tadeu Machniviscz,18,,-25.7616,-49.4545
br,sitio tadeu macinack,Sítio Tadeu Macinack,18,,-25.4537,-48.722
br,sitio tadeu mordask,Sítio Tadeu Mordask,18,,-25.7164,-49.8531
br,sitio tadeu obzut,Sítio Tadeu Obzut,18,,-25.919722,-49.553333
br,sitio tadeu opelenki,Sítio Tadeu Opelenki,18,,-25.8116,-49.5503
br,sitio tadeu prezubek,Sítio Tadeu Prezubek,18,,-25.8408,-49.5208
br,sitio tadeu przybeuca,Sítio Tadeu Przybeuca,18,,-25.7835,-49.5249
br,sitio tadeu saia,Sítio Tadeu Saia,18,,-25.8395,-49.5916
br,sitio tadeu strugava,Sítio Tadeu Strugava,18,,-25.7207,-49.836
br,sitio takamasha,Sítio Takamasha,18,,-23.867812,-50.304
br,sitio takanaka,Sítio Takanaka,27,,-24.542344,-48.816021
br,sitio takazaka,Sítio Takazaka,18,,-23.540597,-50.730835
br,sitio takeo,Sítio Takeo,18,,-23.290544,-50.242072
br,sitio takigushi,Sítio Takigushi,27,,-24.53115,-48.807414
br,sitio tamandare,Sítio Tamandaré,27,,-23.9615,-47.1568
br,sitio tamandua,Sítio Tamanduá,18,,-23.930857,-50.533495
br,sitio tancredo a. moreira,Sítio Tancredo A. Moreira,26,,-26.1684,-49.9618
br,sitio tangara,Sítio Tangará,27,,-23.8323,-46.599
br,sitio tanque,Sítio Tanque,30,,-7.583333,-40.083333
br,sitio tanquinho,Sítio Tanquinho,27,,-23.5067,-47.6379
br,sitio tapera,Sítio Tapera,27,,-23.748457,-47.023948
br,sitio taperinha,Sítio Taperinha,27,,-23.391377,-46.706413
br,sitio tapia,Sítio Tapiá,18,,-25.112844,-48.863561
br,sitio taquara branca,Sítio Taquara Branca,18,,-23.6813,-49.7844
br,sitio taquaral,Sítio Taquaral,18,,-23.1175,-50.2039
br,sitio taquarucu,Sítio Taquaruçu,18,,-25.618731,-50.121072
br,sitio taquarucu,Sítio Taquaruçu,27,,-24.511443,-48.907437
br,sitio taquaruvu,Sítio Taquaruvu,18,,-25.917052,-48.79839
br,sitio tarakichi ogawa,Sítio Tarakichi Ogawa,18,,-23.435704,-50.112552
br,sitio tarcilio v. dos santos,Sítio Tarcílio V. dos Santos,18,,-25.7795,-49.1926
br,sitio tarcisio mendonca,Sítio Tarcísio Mendonça,18,,-23.6627,-49.8478
br,sitio targino da s. brizola,Sítio Targino da S. Brizola,18,,-23.865277,-50.670102
br,sitio tavares,Sítio Tavares,27,,-24.533468,-48.506563
br,sitio tavico,Sítio Tavico,18,,-25.7128,-48.7602
br,sitio tecla nogas,Sítio Tecla Nogas,18,,-25.7684,-49.2484
br,sitio tedeschu,Sítio Tedeschu,18,,-25.6097,-48.8046
br,sitio teixeira,Sítio Teixeira,18,,-23.900038,-50.049835
br,sitio tejadamaro,Sítio Tejadamaro,18,,-23.587424,-50.516341
br,sitio tele,Sítio Telê,18,,-23.317708,-50.054102
br,sitio telesmar borges sampaio,Sítio Telesmar Borges Sampaio,18,,-23.785689,-50.77106
br,sitio teodoro caetano,Sítio Teodoro Caetano,26,,-26.1384,-49.7685
br,sitio teodoro deda,Sítio Teodoro Deda,18,,-25.8413,-49.5039
br,sitio teodoro fiszt,Sítio Teodoro Fiszt,18,,-25.7893,-49.6091
br,sitio teodoro kamoa,Sítio Teodoro Kamoa,18,,-25.5352,-49.9366
br,sitio teodoro kanut,Sítio Teodoro Kanut,18,,-25.816014,-49.780849
br,sitio teodoro lipski,Sítio Teodoro Lipski,18,,-25.795,-49.744444
br,sitio teodoro mordaski,Sítio Teodoro Mordaski,18,,-25.8126,-49.4909
br,sitio teodoro schafascheck,Sítio Teodoro Schafascheck,26,,-26.177993,-49.74973
br,sitio teodoro vieira,Sítio Teodoro Vieira,18,,-25.931667,-49.558611
br,sitio teodoro x. pais,Sítio Teodoro X. Pais,26,,-26.1666,-49.9006
br,sitio teodosio nogas,Sítio Téodósio Nogas,18,,-25.7619,-49.2304
br,sitio teodosio,Sítio Teodósio,18,,-25.4654,-48.6916
br,sitio teofila dubiella,Sítio Teófila Dubiella,18,,-25.8949,-49.5933
br,sitio teofilo kusma,Sítio Teófilo Kusma,18,,-25.7744,-49.2251
br,sitio teofilo laskosk,Sítio Teófilo Laskosk,18,,-25.8585,-49.4649
br,sitio teolindos g. da cruz,Sítio Teolindos G. da Cruz,18,,-25.9333,-49.3573
br,sitio teresa borges,Sítio Teresa Borges,18,,-23.82148,-50.487085
br,sitio teresa l. barbosa,Sítio Teresa L. Barbosa,18,,-23.156069,-49.927939
br,sitio teresinha de lourdes,Sítio Teresinha de Lourdes,18,,-25.855524,-49.977029
br,sitio teresinha kava,Sítio Teresinha Kava,26,,-26.214,-49.8623
br,sitio tereza carpinsk,Sítio Tereza Carpinsk,18,,-25.868,-49.5929
br,sitio tereza de jesus,Sítio Tereza de Jesus,18,,-25.8797,-49.4719
br,sitio tereza drevinaki,Sítio Tereza Drevinaki,18,,-25.8297,-49.5132
br,sitio tereza lourenco,Sítio Tereza Lourenço,18,,-25.815833,-49.705278
br,sitio tereza sequeira,Sítio Tereza Sequeira,18,,-25.5574,-48.7998
br,sitio tereza silva,Sítio Tereza Silva,18,,-26.085404,-49.624811
br,sitio tereza silveira,Sítio Tereza Silveira,18,,-25.7586,-49.6205
br,sitio terezinha da s. pinto,Sítio Terezinha da S. Pinto,18,,-25.7452,-49.8661
br,sitio terezinha de paula,Sítio Terezinha de Paula,18,,-25.7249,-49.777
br,sitio terezinha knapi,Sítio Terezinha Knapi,26,,-26.1562,-49.3407
br,sitio terra boa,Sítio Terra Boa,18,,-25.224278,-48.906763
br,sitio terra boa,Sítio Terra Boa,27,,-24.508699,-48.089765
br,sitio terraco,Sítio Terraço,27,,-23.206667,-46.557222
br,sitio terra de marajo,Sítio Terra de Marajó,27,,-23.552675,-47.051004
br,sitio terra do alto,Sítio Terra do Alto,18,,-26.0699,-49.3737
br,sitio terra do sol,Sítio Terra do Sol,27,,-23.512032,-47.079688
br,sitio terra nova,Sítio Terra Nova,18,,-23.76985,-50.833218
br,sitio tervina b. dos santos,Sítio Tervina B. dos Santos,18,,-25.131159,-48.866178
br,sitio teshikazu suzuki,Sítio Teshikazu Suzuki,18,,-25.488406,-48.835997
br,sitio tetsunosuke ohata,Sítio Tetsunosuke Ohata,27,,-23.5181,-47.6583
br,sitio thiago j. ribeiro,Sítio Thiago J. Ribeiro,18,,-23.998324,-50.497082
br,sitio thomaz a. teixeira,Sítio Thomaz A. Teixeira,18,,-23.7234,-49.9301
br,sitio thomaz b. da silva,Sítio Thomaz B. da Silva,18,,-26.015319,-49.671517
br,sitio tia flavia,Sítio Tia Flávia,18,,-25.425276,-48.80966
br,sitio tia nezio,Sítio Tia Nézio,18,,-23.552363,-50.577329
br,sitio tibirica,Sítio Tibiriçá,27,,-23.572176,-47.209149
br,sitio tiburcio,Sítio Tibúrcio,27,,-23.7569,-47.1205
br,sitio tijuco,Sítio Tijuco,27,,-24.539081,-48.907392
br,sitio timbauba,Sítio Timbaúba,17,,-6.45,-36.5
br,sitio timburi,Sítio Timburi,18,,-23.232776,-49.795324
br,sitio timbuva,Sítio Timbuva,27,,-24.803,-48.1871
br,sitio timoteo f. de paiva,Sítio Timóteo F. de Paiva,18,,-23.277554,-50.179812
br,sitio tio afonso,Sítio Tio Afonso,18,,-23.483613,-49.806808
br,sitio tio joao,Sítio Tio João,18,,-25.240497,-48.926751
br,sitio tio patinhas,Sítio Tio Patinhas,18,,-23.076527,-52.116482
br,sitio tip top,Sítio Tip Top,18,,-25.173131,-48.99235
br,sitio tipuana,Sítio Tipuana,27,,-23.587268,-47.085996
br,sitio tirao comprido,Sítio Tirão Comprido,18,,-23.614014,-50.079845
br,sitio tito schultz,Sítio Tito Schultz,26,,-26.099,-49.9136
br,sitio tito,Sítio Tito,18,,-25.203852,-48.970777
br,sitio tito zielinscki,Sítio Tito Zielinscki,18,,-26.0058,-49.8057
br,sitio tobias dos santos,Sítio Tobias dos Santos,18,,-25.9719,-49.3645
br,sitio tobias lourenco,Sítio Tobias Lourenço,18,,-25.819167,-49.702778
br,sitio tobias n. da rocha,Sítio Tobias N. da Rocha,18,,-25.913056,-49.642222
br,sitio tobias pereira,Sítio Tobias Pereira,18,,-26.1443,-49.4866
br,sitio tobias t. de paula,Sítio Tobias T. de Paula,18,,-25.8737,-49.0214
br,sitio toca da onca,Sítio Toca da Onça,18,,-25.850491,-48.941798
br,sitio toca do comendador,Sítio Toca do Comendador,18,,-25.4525,-48.7265
br,sitio toca,Sítio Toca,27,,-23.221111,-46.577222
br,sitio toco preto,Sítio Tóco Prêto,22,,-5.478333,-36.0975
br,sitio todos os santos,Sítio Todos os Santos,18,,-23.274456,-49.986594
br,sitio tokio,Sítio Tókio,27,,-23.007019,-49.862614
br,sitio tomas b. neto,Sítio Tomás B. Neto,18,,-23.78506,-50.27822
br,sitio tomas pogseba,Sítio Tomás Pogseba,18,,-26.015009,-49.737015
br,sitio tomas pratica,Sítio Tomás Prática,18,,-23.886647,-50.398033
br,sitio tomaz bobna,Sítio Tomaz Bobna,18,,-23.533082,-50.034646
br,sitio tomaz kuseral,Sítio Tomaz Kuseral,18,,-25.7649,-49.4716
br,sitio tombo-de agua,Sítio Tombo-de Água,18,,-25.40034,-48.874683
br,sitio tome da silva,Sítio Tomé da Silva,18,,-23.6165,-49.8772
br,sitio toquio,Sítio Tóquio,18,,-23.7924,-50.9644
br,sitio toquio,Sítio Tóquio,27,,-23.720078,-47.215201
br,sitio torigoe,Sítio Torigoe,27,,-23.321318,-46.540626
br,sitio torino,Sítio Torino,18,,-23.060427,-52.217729
br,sitio tororao,Sítio Tororão,27,,-24.654111,-48.995842
br,sitio torrelandia,Sítio Torrelândia,18,,-23.754492,-50.198733
br,sitio torre,Sítio Tôrre,30,,-7.65,-40.216667
br,sitio torto,Sítio Torto,06,,-6.483333,-39.483333
br,sitio trajano portela,Sítio Trajano Portela,18,,-25.993611,-49.665278
br,sitio trajano saldanha,Sítio Trajano Saldanha,18,,-23.9654,-50.9221
br,sitio tres barras,Sítio Três Barras,18,,-23.420436,-50.125529
br,sitio tres conqueiros,Sítio Três Conqueiros,18,,-23.369058,-50.008611
br,sitio tres coqueiros,Sítio Três Coqueiros,18,,-23.1269,-50.1504
br,sitio tres coqueiros,Sitio Três Coqueiros,26,,-27.18391,-49.659429
br,sitio tres coracoes,Sítio Três Corações,27,,-23.216667,-46.731667
br,sitio tres figueiras,Sítio Três Figueiras,18,,-23.32687,-52.70918
br,sitio tres irmaos,Sítio Três Irmãos,18,,-23.0177,-50.0316
br,sitio tres irmaos,Sítio Três Irmãos,27,,-23.599089,-47.033641
br,sitio tres irmas,Sítio Três Irmãs,18,,-23.583778,-50.704029
br,sitio tres lagoinhas,Sítio Três Lagoinhas,27,,-23.7561,-46.7114
br,sitio tres laguas,Sítio Três Laguas,27,,-23.994,-47.1183
br,sitio tres mangueiras,Sítio Três Mangueiras,18,,-23.462103,-49.759307
br,sitio tres marias,Sítio Três Marias,18,,-23.164479,-49.863147
br,sitio tres marias,Sítio Três Marias,27,,-23.227778,-46.711944
br,sitio tres meninas,Sítio Três Meninas,18,,-23.198754,-49.98613
br,sitio tres meninas,Sítio Três Meninas,27,,-23.230833,-46.716667
br,sitio tres minas,Sítio Três Minas,18,,-23.749774,-50.668311
br,sitio tres minas,Sítio Três Minas,27,,-23.567114,-47.040756
br,sitio tres morenas,Sítio Três Morenas,27,,-24.538207,-48.031042
br,sitio tres mosqueteiros,Sítio Três Mosqueteiros,27,,-23.106111,-46.606111
br,sitio tres palmeiras,Sítio Três Palmeiras,18,,-23.0661,-50.2421
br,sitio tres pinheirinhos,Sítio Três Pinheirinhos,18,,-23.737344,-50.715438
br,sitio tres pinheiros,Sítio Três Pinheiros,18,,-23.5326,-50.5395
br,sitio tres poderes,Sítio Três Poderes,18,,-23.0913,-50.0845
br,sitio tres pontas,Sítio Três Pontas,27,,-23.185,-46.654167
br,sitio tres pontes,Sítio Três Pontes,27,,-23.179444,-46.570833
br,sitio tres reis,Sítio Três Reis,18,,-23.854716,-50.567185
br,sitio tres rios,Sítio Três Rios,27,,-24.721303,-48.16757
br,sitio tres,Sítio Três,06,,-3.6,-39.7
br,sitio triangulo de varzea alegre,Sítio Triangulo de Varzea Alegre,06,,-6.766667,-39.016667
br,sitio trita hampton,Sítio Trita Hampton,26,,-25.99437,-48.87397
br,sitio trompini,Sítio Trompini,26,,-26.1839,-49.8255
br,sitio tropeiro,Sítio Tropeiro,27,,-23.531284,-47.618622
br,sitio tropel,Sítio Tropel,27,,-23.636802,-47.132195
br,sitio tropical,Sítio Tropical,27,,-23.819188,-46.698556
br,sitio tutoia,Sítio Tutõia,27,,-23.725167,-47.223352
br,sitio uchoa,Sítio Uchôa,04,,-1.748333,-60.153333
br,sitio ugao,Sítio Ugão,27,,-23.8291,-46.7441
br,sitio uirapuru,Sítio Uirapuru,27,,-23.145,-46.686111
br,sitio ulisses juliato,Sítio Ulisses Juliato,18,,-25.5931,-48.8072
br,sitio umbelino de moraes,Sítio Umbelino de Moraes,18,,-23.7186,-49.8506
br,sitio um sonho a mais,Sítio Um Sonho a Mais,18,,-25.198205,-48.516864
br,sitio umuarama,Sítio Umuarama,27,,-23.035833,-46.528056
br,sitio uniao,Sítio União,18,,-23.698116,-50.150975
br,sitio uniao,Sítio União,27,,-24.8842,-48.5385
br,sitio urbano hirt,Sítio Urbano Hirt,18,,-26.174023,-49.575078
br,sitio uruoca,Sítio Uruoca,24,,-10.802222,-62.022222
br,sitio usina jacarezinho,Sítio Usina Jacarezinho,18,,-23.068,-50.0195
br,sitio uvaranas,Sítio Uvaranas,18,,-25.559097,-50.082917
br,sitio vaca voadora,Sítio Vaca Voadora,27,,-23.7991,-47.2067
br,sitio vagalume,Sítio Vagalume,27,,-23.915,-47.0689
br,sitio vai-quem-quer,Sítio Vai-Quem-Quer,18,,-23.993093,-50.432588
br,sitio valdecir de melo,Sítio Valdecir de Melo,18,,-23.792476,-50.806952
br,sitio valdemar brunnkell,Sítio Valdemar Brunnkell,18,,-26.034102,-49.51646
br,sitio valdemar da c. morais,Sítio Valdemar da C. Morais,18,,-23.821374,-50.57618
br,sitio valdemar de oliveira,Sítio Valdemar de Oliveira,18,,-23.839415,-50.05334
br,sitio valdemar korn,Sítio Valdemar Korn,18,,-25.957295,-48.819281
br,sitio valdemar moraes,Sítio Valdemar Moraes,18,,-23.88393,-50.583003
br,sitio valdemar padilha,Sítio Valdemar Padilha,18,,-25.9576,-49.1384
br,sitio valdemar pereira,Sítio Valdemar Pereira,18,,-25.9162,-49.289
br,sitio valdemar pitarello,Sítio Valdemar Pitarello,18,,-23.5384,-49.884
br,sitio valdemar r. ponde,Sítio Valdemar R. Pondé,18,,-23.6238,-49.9414
br,sitio valdemiro kolschaski,Sítio Valdemiro Kolschaski,26,,-26.0417,-49.9749
br,sitio valdemiro stafin,Sítio Valdemiro Stafin,18,,-26.0993,-49.4815
br,sitio valdevino moura,Sítio Valdevino Moura,18,,-23.532,-50.7111
br,sitio valdevino p. de souza,Sítio Valdevino P. de Sóuza,18,,-25.9319,-49.4871
br,sitio valdevino s. da silva,Sítio Valdevino S. da Silva,18,,-23.9631,-50.9324
br,sitio valdimiro rezende,Sítio Valdimiro Rezende,18,,-26.0981,-49.3939
br,sitio valdinei a. martins,Sítio Valdinei A. Martins,18,,-23.5449,-49.9783
br,sitio valdir baggio,Sítio Valdir Baggio,18,,-23.979584,-50.856509
br,sitio valdir braulino,Sítio Valdir Braulino,18,,-25.4393,-48.7335
br,sitio valdir ruthes,Sítio Valdir Ruthes,26,,-26.2111,-49.8363
br,sitio valdir v. da silva,Sítio Valdir V. da Silva,18,,-25.8599,-49.0425
br,sitio valdivino r. de almeida,Sítio Valdivino R. de Almeida,18,,-25.8616,-49.5557
br,sitio valdomiro abigalisk,Sítio Valdomiro Abigalisk,26,,-26.2258,-49.8391
br,sitio valdomiro a. da cruz,Sítio Valdomiro A. da Cruz,18,,-25.8678,-49.0343
br,sitio valdomiro amancio do nascimento,Sítio Valdomiro Amâncio do Nascimento,18,,-23.9536,-50.872
br,sitio valdomiro buba,Sítio Valdomiro Buba,18,,-26.062058,-49.539685
br,sitio valdomiro elias,Sítio Valdomiro Elias,18,,-23.6571,-49.8197
br,sitio valdomiro fagundes,Sítio Valdomiro Fagundes,18,,-26.114161,-49.604443
br,sitio valdomiro f. pereira,Sítio Valdomiro F. Pereira,18,,-23.9991,-50.8934
br,sitio valdomiro friedrich,Sítio Valdomiro Friedrich,26,,-26.1773,-49.3417
br,sitio valdomiro lozado,Sítio Valdomiro Lozado,18,,-23.27746,-50.24542
br,sitio valdomiro portela,Sítio Valdomiro Portela,18,,-26.048421,-49.602583
br,sitio valdomiro p. vidal,Sítio Valdomiro P. Vidal,18,,-23.691,-49.9864
br,sitio valdomiro,Sítio Valdomiro,18,,-23.0186,-50.1711
br,sitio valdomiro vilela,Sítio Valdomiro Vilela,18,,-23.720717,-50.576953
br,sitio valdovino m. dos santos,Sítio Valdovino M. dos Santos,18,,-25.926798,-49.98336
br,sitio valdovino oczkovski,Sítio Valdovino Oczkovski,26,,-26.0387,-49.9824
br,sitio vale da serra,Sítio Vale da Serra,21,,-22.306415,-42.961303
br,sitio vale das pedras,Sítio Vale das Pedras,27,,-23.536912,-47.051721
br,sitio vale das tres meninas,Sítio Vale das Três Meninas,27,,-23.659274,-47.118648
br,sitio vale de iabiquara,Sítio Vale de Iabiquara,27,,-23.363739,-46.597165
br,sitio vale do amor,Sítio Vale do Amor,18,,-23.2376,-50.0975
br,sitio vale do canha,Sítio Vale do Canha,27,,-24.722876,-48.000459
br,sitio vale doce,Sítio Vale Doce,27,,-23.804258,-46.711934
br,sitio vale do paturi,Sítio Vale do Paturi,27,,-23.214722,-46.528889
br,sitio vale do rio d'ouro,Sitio Vale do Rio d'Ouro,18,,-23.892867,-50.176941
br,sitio vale dos lagos,Sítio Vale dos Lagos,27,,-23.246111,-46.575556
br,sitio vale dos leais,Sítio Vale dos Leais,27,,-23.844227,-47.074646
br,sitio vale dos nogueiras,Sítio Vale dos Nogueiras,27,,-23.9479,-47.0956
br,sitio vale do sol,Sítio Vale do Sol,27,,-23.188056,-46.560833
br,sitio valentim derinevicz,Sítio Valentim Derinevicz,18,,-25.9537,-49.204
br,sitio valentim figueira,Sítio Valentim Figueira,18,,-25.791389,-49.648611
br,sitio valentim nossol,Sítio Valentim Nossol,18,,-26.0655,-49.2611
br,sitio valentim oliscoviskez,Sítio Valentim Oliscoviskez,26,,-26.1699,-49.3897
br,sitio valentim s. cortes,Sítio Valentim S. Cortes,18,,-25.7703,-49.5807
br,sitio valeria fantin,Sítio Valéria Fantin,18,,-25.7178,-49.9601
br,sitio valeria normann,Sítio Valéria Normann,26,,-26.1752,-49.3688
br,sitio valerio banak,Sítio Valério Banak,18,,-25.8474,-49.1463
br,sitio vale valquiria,Sítio Vale Valquiria,27,,-23.7711,-47.1701
br,sitio vale verde,Sítio Vale Verde,27,,-23.575285,-47.104964
br,sitio valfride farias,Sítio Valfride Farias,18,,-25.9839,-49.0392
br,sitio valfrido de souza,Sítio Valfrido de Souza,18,,-25.5014,-48.8468
br,sitio valfrido p. collaco,Sítio Valfrido P. Collaço,18,,-25.8942,-49.4733
br,sitio valfrido rodrigues,Sítio Valfrido Rodrigues,18,,-26.0895,-49.7673
br,sitio valfrido valerio,Sítio Valfrido Valério,18,,-26.072905,-49.738195
br,sitio valfrido zebonik,Sítio Valfrido Zebonik,18,,-25.845278,-49.7475
br,sitio valiano biscaia,Sítio Valiano Biscaia,18,,-25.967,-49.1324
br,sitio valo fundo,Sítio Valo Fundo,27,,-23.184722,-46.684167
br,sitio valtivio baila,Sítio Valtívio Baila,18,,-26.0027,-49.3429
br,sitio vanda,Sítio Vanda,18,,-25.853655,-49.219167
br,sitio vander c. de freitas,Sítio Vander C. de Freitas,18,,-26.0157,-49.919
br,sitio vanderlei cecilio guimaraes,Sítio Vanderlei Cecílio Guimarães,18,,-23.8751,-50.9783
br,sitio vanderlei m. ferreira,Sítio Vanderlei M. Ferreira,18,,-23.53444,-50.661931
br,sitio vanessa,Sítio Vanessa,04,,-1.516944,-60.251389
br,sitio vanil domingues,Sítio Vanil Domingues,18,,-23.826153,-50.090934
br,sitio varadouro,Sitio Varadouro,27,,-24.661934,-48.858813
br,sitio varas,Sítio Varas,06,,-6.833333,-39.3
br,sitio vardica da rosa,Sítio Vardica da Rosa,18,,-23.649,-49.9589
br,sitio vargas,Sítio Vargas,18,,-25.788787,-49.218396
br,sitio vargem comprida,Sítio Vargem Comprida,14,,-16.321667,-56.689722
br,sitio vargem grande,Sítio Vargem Grande,18,,-23.7821,-50.9663
br,sitio vargem grande,Sítio Vargem Grande,27,,-23.299679,-46.68532
br,sitio varginha,Sítio Varginha,27,,-23.8512,-46.6684
br,sitio varginha,Sítio Varginha,30,,-7.816667,-38.383333
br,sitio varjao branco,Sítio Varjão Branco,27,,-23.196944,-46.720278
br,sitio varsovia,Sítio Varsóvia,18,,-23.5412,-49.9451
br,sitio veadeiro,Sítio Veadeiro,18,,-25.759056,-49.768161
br,sitio veados,Sítio Veados,06,,-6.05,-39.633333
br,sitio veiga,Sítio Veiga,18,,-23.597066,-50.653066
br,sitio veinsek,Sítio Veinsek,18,,-25.7677,-49.3476
br,sitio velho mundo,Sítio Velho Mundo,18,,-23.952478,-50.451236
br,sitio velho oeste,Sítio Velho Oeste,27,,-23.054752,-46.681516
br,sitio velho sao beneditio,Sítio Velho São Beneditio,18,,-25.784582,-49.825453
br,sitio velho,Sítio Velho,06,,-7.1,-39.133333
br,sitio velho,Sítio Velho,13,,-3.712778,-42.748333
br,sitio velho,Sítio Velho,18,,-25.5485,-49.9213
br,sitio velho,Sítio Velho,20,,-4.733333,-41.683333
br,sitio velho,Sítio Velho,23,,-29.9734,-50.9281
br,sitio velho,Sítio Velho,26,,-25.9732,-48.6602
br,sitio velho,Sítio Velho,27,,-23.1314,-47.8345
br,sitio velho,Sítio Velho,31,,-6.833333,-48.116667
br,sitio vellio,Sitio Vellio,06,,-6.766667,-38.783333
br,sitio veludo azul,Sítio Veludo Azul,27,,-23.8553,-46.7326
br,sitio venancio ferreira,Sítio Venâncio Ferreira,18,,-23.892997,-50.169966
br,sitio venceslau gino,Sítio Venceslau Gino,18,,-23.4947,-49.7811
br,sitio venceslau paulak,Sítio Venceslau Paulak,18,,-25.5023,-49.9895
br,sitio vendinha,Sítio Vendinha,27,,-23.310151,-46.600626
br,sitio veni ribeiro,Sítio Veni Ribeiro,18,,-25.99,-49.151
br,sitio veno,Sítio Veno,27,,-23.717498,-47.117401
br,sitio ventania,Sítio Ventania,27,,-23.658582,-47.246762
br,sitio ventania,Sítio Ventania,30,,-7.583333,-40.416667
br,sitio vera cruz,Sítio Vera Cruz,04,,-1.582778,-60.214444
br,sitio vera cruz,Sítio Vera Cruz,18,,-23.154348,-52.109705
br,sitio vera cruz,Sítio Vera Cruz,27,,-23.124722,-46.600833
br,sitio veravinha,Sítio Veravinha,27,,-23.737009,-47.144962
br,sitio vermelho,Sítio Vermelho,18,,-23.536503,-50.218503
br,sitio veronica bill,Sítio Verônica Bill,18,,-25.809167,-49.650833
br,sitio veronica cleslensme,Sítio Verônica Cleslensme,18,,-26.0621,-49.3132
br,sitio veronica cochiba,Sítio Verônica Cochiba,18,,-25.7952,-49.5072
br,sitio veronica da cruz,Sítio Verônica da Cruz,18,,-25.9315,-49.1884
br,sitio veronica seve,Sítio Verônica Seve,18,,-25.818117,-49.787362
br,sitio viacao garcia,Sítio Viação Garcia,18,,-25.486706,-48.812731
br,sitio viana,Sítio Viana,27,,-23.26831,-46.652131
br,sitio vicente agostinho,Sítio Vicente Agostinho,18,,-23.955692,-50.101995
br,sitio vicente alfredo,Sítio Vicente Alfredo,18,,-23.2364,-50.1459
br,sitio vicente arlindo,Sítio Vicente Arlindo,18,,-23.6128,-49.9873
br,sitio vicente augusto,Sítio Vicente Augusto,18,,-23.827023,-50.05787
br,sitio vicente barao,Sítio Vicente Barão,18,,-25.6911,-49.8915
br,sitio vicente burniak,Sítio Vicente Burniak,18,,-25.805,-49.5379
br,sitio vicente celestino,Sítio Vicente Celestino,18,,-25.896667,-49.575556
br,sitio vicente c. ramalho,Sítio Vicente C. Ramalho,18,,-23.6383,-49.8214
br,sitio vicente dos santos,Sítio Vicente dos Santos,18,,-23.696742,-50.218534
br,sitio vicente dranka,Sítio Vicente Dránka,18,,-25.8468,-49.4051
br,sitio vicente f. de oliveira,Sítio Vicente F. de Oliveira,18,,-23.528573,-50.638979
br,sitio vicente felarz,Sítio Vicente Felarz,18,,-25.903889,-49.581389
br,sitio vicente figura,Sítio Vicente Figura,18,,-25.763889,-49.626389
br,sitio vicente gomes,Sítio Vicente Gomes,18,,-23.935875,-50.160004
br,sitio vicente hofmann,Sítio Vicente Hofmann,18,,-25.7296,-49.8003
br,sitio vicente hukan,Sítio Vicente Hukan,18,,-25.6935,-49.8962
br,sitio vicente konkl,Sítio Vicente Konkl,26,,-26.1471,-49.9437
br,sitio vicente kurovski,Sítio Vicente Kurovski,18,,-26.047769,-49.519023
br,sitio vicente l. da silva,Sítio Vicente L. da Silva,18,,-23.824987,-50.141214
br,sitio vicente leandro,Sítio Vicente Leandro,18,,-23.761162,-50.05943
br,sitio vicente lechinhoski,Sítio Vicente Lechinhoski,18,,-25.7736,-49.5165
br,sitio vicente leite,Sítio Vicente Leite,18,,-23.826819,-50.067515
br,sitio vicente lima,Sítio Vicente Lima,18,,-25.234175,-48.527738
br,sitio vicente mendes morais,Sítio Vicente Mendes Morais,18,,-23.687144,-50.103652
br,sitio vicente mendes,Sítio Vicente Mendes,18,,-25.898858,-49.92408
br,sitio vicente p. cordeiro,Sítio Vicente P. Cordeiro,18,,-25.343354,-48.961675
br,sitio vicente p. de azevedo,Sítio Vicente P. de Azevedo,18,,-23.814628,-50.087143
br,sitio vicente piratelo,Sítio Vicente Piratelo,18,,-23.566,-49.8917
br,sitio vicente posse,Sítio Vicente Posse,18,,-23.67898,-50.113041
br,sitio vicente pucuss,Sítio Vicente Pucuss,18,,-25.7838,-49.3603
br,sitio vicente pzibizoscki,Sítio Vicente Pzibizoscki,18,,-25.7794,-49.5572
br,sitio vicente sandesk,Sítio Vicente Sandesk,18,,-25.826512,-49.957946
br,sitio vicente senzoski,Sítio Vicente Senzoski,18,,-25.7682,-49.5199
br,sitio vicente,Sítio Vicente,06,,-6.766667,-39.35
br,sitio vicente,Sítio Vicente,18,,-23.454682,-50.246087
br,sitio vicente slusarz,Sítio Vicente Slusarz,18,,-25.854167,-49.628889
br,sitio vicente soares,Sítio Vicente Soares,18,,-23.737,-49.795
br,sitio vicente souza,Sítio Vicente Souza,18,,-25.808,-49.5349
br,sitio vicente stabach,Sítio Vicente Stabach,18,,-25.861493,-49.926124
br,sitio vicente telma,Sítio Vicente Telma,18,,-26.13499,-49.670087
br,sitio vicente wardzinski,Sítio Vicente Wardzinski,18,,-25.8159,-49.53
br,sitio vicente w. de camargo,Sítio Vicente W. de Camargo,18,,-25.90515,-49.793858
br,sitio vicente xavier,Sítio Vicente Xavier,18,,-23.5388,-49.9763
br,sitio victor cabax,Sítio Victor Cabax,18,,-25.9829,-49.4811
br,sitio victor konkl,Sítio Victor Konkl,26,,-26.1478,-49.9397
br,sitio victor l. e. john,Sítio Victor L. E. John,18,,-26.16403,-49.526888
br,sitio victor louce,Sítio Víctor Louce,18,,-25.764032,-49.21919
br,sitio victor widemann,Sítio Victor Widemann,18,,-25.953708,-48.815992
br,sitio vidal barbosa,Sítio Vidal Barbosa,18,,-26.084634,-49.554506
br,sitio vieira,Sítio Vieira,18,,-25.3769,-48.6186
br,sitio viena,Sítio Viena,18,,-23.702288,-50.549598
br,sitio vigano bayer,Sítio Vigano Bayer,18,,-26.183337,-49.51074
br,sitio vila cezar,Sítio Vila Cezar,27,,-23.9878,-47.0512
br,sitio vila dos brasoes,Sítio Vila dos Brasões,27,,-23.252365,-46.572047
br,sitio vila nana,Sítio Vila Nana,27,,-23.204167,-46.664722
br,sitio vila nina,Sítio Vila Nina,27,,-23.602648,-47.126957
br,sitio vila nova,Sítio Vila Nova,18,,-23.7708,-50.9939
br,sitio vila nova,Sítio Vila Nova,27,,-23.9533,-47.005
br,sitio vila rica,Sítio Vila Rica,27,,-23.205278,-47.601389
br,sitio vila verde,Sítio Vila Verde,27,,-23.2225,-46.581944
br,sitio village,Sítio Village,18,,-23.86935,-50.042674
br,sitio villon fabianski,Sítio Villon Fabianski,18,,-25.8409,-49.5755
br,sitio vilma glenks,Sítio Vilma Glenks,18,,-25.786667,-49.661111
br,sitio vilma ribeiro,Sítio Vilma Ribeiro,18,,-25.7833,-49.4347
br,sitio vilmar marins,Sítio Vilmar Marins,18,,-25.8971,-49.2652
br,sitio vilmar prismann,Sítio Vilmar Prismann,26,,-26.237288,-49.520882
br,sitio viloca,Sítio Viloca,18,,-23.62612,-50.724304
br,sitio vilson alves,Sítio Vilson Alves,18,,-26.128355,-49.623963
br,sitio vilson augustin,Sítio Vilson Augustin,18,,-26.095066,-49.527987
br,sitio vilson vilas boas,Sítio Vilson Vilas Boas,18,,-23.743407,-50.026624
br,sitio vinicius w. ramos,Sítio Vinicius W. Ramos,26,,-26.1784,-49.887
br,sitio vira-copos,Sítio Vira-Copos,27,,-23.729501,-47.171874
br,sitio virgilio ferreira,Sítio Virgílio Ferreira,18,,-23.891416,-50.051851
br,sitio virgilio lourenco,Sítio Virgílio Lourenço,26,,-26.207938,-49.735154
br,sitio virgilio pinto,Sítio Virgílio Pinto,18,,-23.895508,-50.236724
br,sitio virgilio,Sítio Virgílio,18,,-23.91923,-50.143741
br,sitio virginia ribeiro,Sítio Virgínia Ribeiro,18,,-23.449072,-49.804632
br,sitio virginia,Sítio Virginia,27,,-24.539636,-48.768949
br,sitio virginio r. fernandes,Sítio Virgínio R. Fernandes,18,,-23.7037,-49.9009
br,sitio virmundo poli,Sítio Virmundo Poli,18,,-25.202911,-48.994934
br,sitio visconde de sabugosa,Sítio Visconde de Sabugosa,27,,-23.656258,-47.132743
br,sitio vista alegre,Sítio Vista Alegre,18,,-23.0682,-50.2434
br,sitio vista alegre,Sítio Vista Alegre,27,,-23.098889,-46.603333
br,sitio vista linda,Sítio Vista Linda,27,,-23.8049,-46.6067
br,sitio vital f. de sousa,Sítio Vital F. de Sousa,27,,-24.709972,-48.016015
br,sitio vitalina miguel,Sítio Vitalina Miguel,18,,-25.983106,-49.853097
br,sitio vitalino telma,Sítio Vitalino Telma,26,,-26.1714,-49.3418
br,sitio vitoldo malszeviski,Sítio Vitoldo Malszeviski,18,,-25.464192,-48.869082
br,sitio vitor adriano rocha,Sítio Vítor Adriano Rocha,18,,-25.200137,-48.511459
br,sitio vitor camargo,Sítio Vítor Camargo,18,,-25.8843,-49.1793
br,sitio vitor franco,Sítio Vitor Franco,18,,-25.833,-49.4643
br,sitio vitor gomes,Sítio Vitor Gomes,18,,-23.839737,-50.072308
br,sitio vitoria botes,Sítio Vitória Botes,18,,-25.7976,-49.4498
br,sitio vitoria grepel,Sítio Vitória Grepel,18,,-26.1096,-49.3795
br,sitio vitoria juvinski,Sítio Vitória Juvinski,18,,-25.844,-49.5334
br,sitio vitoria mordaski,Sítio Vitória Mordaski,18,,-25.769167,-49.635833
br,sitio vitoria setleka,Sítio Vitória Setleka,18,,-25.8406,-49.4329
br,sitio vitoria,Sítio Vitória,18,,-25.562583,-50.182277
br,sitio vitoria,Sítio Vitória,27,,-23.7857,-47.2435
br,sitio vitoria vougth,Sítio Vitória Vougth,18,,-25.7876,-49.5087
br,sitio vitorino machado,Sítio Vitorino Machado,18,,-25.9897,-49.4032
br,sitio vitorio bonatti,Sítio Vitorio Bonatti,18,,-25.996667,-49.683333
br,sitio vitorio ianoviscki,Sítio Vitório Ianoviscki,26,,-26.1916,-49.9975
br,sitio vitorio martins,Sítio Vitório Martins,18,,-25.847616,-49.906184
br,sitio vitorio r. pacheco,Sítio Vitório R. Pacheco,18,,-25.049246,-48.946688
br,sitio vitorio s. bram,Sítio Vitório S. Bram,18,,-25.9009,-49.3999
br,sitio vitorio scrobot,Sítio Vitôrio Scrobot,18,,-25.8781,-49.5841
br,sitio vitorio setlik,Sítio Vitório Setlik,18,,-26.0897,-49.3807
br,sitio vitorio,Sítio Vitório,18,,-25.86808,-48.794694
br,sitio vitorio sustak,Sítio Vitório Sustak,18,,-23.5552,-49.9624
br,sitio vitorio zureck,Sítio Vitório Zureck,18,,-26.0292,-49.8653
br,sitio vitor p. da silva,Sítio Vitor P. da Silva,18,,-23.6898,-49.7667
br,sitio vitor pimenta,Sítio Vitor Pimenta,18,,-23.953685,-50.079499
br,sitio vitor rampava,Sítio Vitor Rampava,18,,-25.7593,-49.4556
br,sitio vitria,Sitio Vitria,21,,-22.430533,-42.882114
br,sitio vivaldo de s. lisboa,Sítio Vivaldo de S. Lisboa,18,,-26.0934,-49.3178
br,sitio vivaldo herbst,Sítio Vivaldo Herbst,26,,-26.0855,-49.8634
br,sitio viveiro paranaense,Sítio Viveiro Paranaense,18,,-23.5231,-49.9175
br,sitio vo judite,Sítio Vó Judite,18,,-25.2524,-48.7464
br,sitio volmir bruel,Sítio Volmir Bruel,18,,-25.5461,-49.7683
br,sitio volta grande,Sítio Volta Grande,27,,-23.2075,-46.666
br,sitio volta,Sítio Volta,17,,-7.35,-36.016667
br,sitio voni muniz,Sítio Voni Muniz,18,,-26.0601,-49.7907
br,sitio vo santos,Sítio Vô Santos,18,,-25.4546,-48.7329
br,sitio vossoroca,Sítio Vossoroca,18,,-25.8128,-49.1066
br,sitio votorantim,Sítio Votorantim,27,,-23.681865,-47.154657
br,sitio vovo cacilda,Sítio Vovó Cacilda,27,,-23.5585,-47.6646
br,sitio vovo nene,Sítio Vovó Nenê,27,,-23.264127,-46.51657
br,sitio vovo toninho,Sítio Vovó Toninho,27,,-23.186111,-46.694444
br,sitio vovo zico,Sítio Vovô Zico,27,,-23.183333,-46.580556
br,sitio wadislau sota,Sítio Wadislau Sota,18,,-25.7729,-49.5452
br,sitio wadislau zielinscki,Sítio Wadislau Zielinscki,18,,-26.0082,-49.8146
br,sitio wagner dionisio,Sítio Wagner Dionísio,18,,-23.861338,-50.46542
br,sitio walcir,Sítio Walcir,18,,-25.172726,-48.876824
br,sitio waldeir soares,Sítio Waldeir Soares,18,,-23.953533,-50.049626
br,sitio waldemar ferreira,Sítio Waldemar Ferreira,18,,-23.133444,-49.911564
br,sitio waldemar gobati,Sítio Waldemar Gobati,18,,-23.2421,-50.138
br,sitio waldemar liber,Sítio Waldemar Liber,26,,-26.1918,-49.8772
br,sitio waldemar schults,Sítio Waldemar Schults,26,,-26.1549,-49.3486
br,sitio waldemar semer,Sítio Waldemar Semer,18,,-25.998333,-49.711111
br,sitio waldemar,Sítio Waldemar,18,,-25.162226,-48.9895
br,sitio waldemar valesk,Sítio Waldemar Valesk,18,,-25.910556,-49.5475
br,sitio waldenio amaral,Sítio Waldênio Amaral,26,,-26.2414,-49.9371
br,sitio waldenor siqueira,Sítio Waldenor Siqueira,18,,-23.655034,-50.066787
br,sitio waldico cema,Sítio Waldico Cema,18,,-25.931389,-49.660278
br,sitio waldir a. de araujo,Sítio Waldir A. de Araújo,18,,-25.200568,-48.995317
br,sitio waldir moro,Sítio Waldir Moro,26,,-26.1405,-49.8398
br,sitio waldir roensig,Sítio Waldir Roensig,26,,-26.1503,-49.7683
br,sitio waldomiro a. silva,Sítio Waldomiro A. Silva,18,,-25.997,-49.4599
br,sitio waldomiro batista,Sítio Waldomiro Batista,18,,-26.154785,-49.585981
br,sitio waldomiro costa,Sítio Waldomiro Costa,18,,-23.625967,-50.009273
br,sitio waldomiro d. dos santos,Sítio Waldomiro D. dos Santos,18,,-25.123133,-48.800983
br,sitio waldomiro de souza,Sítio Waldomiro de Souza,18,,-23.6714,-49.8988
br,sitio waldomiro do valle,Sítio Waldomiro do Valle,18,,-25.8201,-49.5993
br,sitio waldomiro gruber,Sítio Waldomiro Gruber,18,,-26.146434,-49.464203
br,sitio waldomiro praxedes,Sítio Waldomiro Praxedes,18,,-23.923955,-50.309173
br,sitio waldomiro salvador,Sítio Waldomiro Salvador,18,,-23.223726,-49.826202
br,sitio waldomiro,Sítio Waldomiro,18,,-25.201462,-48.526753
br,sitio waldomiro soares,Sítio Waldomiro Soares,18,,-23.998807,-50.407123
br,sitio waldomiro virgendk,Sítio Waldomiro Virgendk,26,,-26.242463,-49.749331
br,sitio waldomiro xavier da silva,Sítio Waldomiro Xavier da Silva,18,,-23.8804,-50.986
br,sitio waldovino adanczesk,Sítio Waldovino Adanczesk,26,,-26.1484,-49.8773
br,sitio walfrido dos santos,Sítio Walfrido dos Santos,26,,-26.2169,-49.996
br,sitio walfrido sabatike,Sítio Walfrido Sabatike,26,,-26.0561,-49.9235
br,sitio walfrido schokel,Sítio Walfrido Schokel,26,,-26.2187,-49.3629
br,sitio walter czarnescki,Sítio Walter Czarnescki,18,,-25.923611,-49.632778
br,sitio walter dimas,Sítio Walter Dimas,18,,-23.1899,-50.1949
br,sitio walter l. roseira,Sítio Walter L. Roseira,18,,-25.917,-49.2328
br,sitio walter m. buachak,Sítio Walter M. Buachak,18,,-23.823333,-50.49147
br,sitio walter pereira,Sítio Walter Pereira,18,,-23.880204,-50.082274
br,sitio walter siqueira,Sítio Walter Siqueira,18,,-23.268161,-50.145786
br,sitio wandel da cruz,Sítio Wandel da Cruz,18,,-25.819,-49.34
br,sitio wanderlei figueira,Sítio Wanderlei Figueira,18,,-23.794718,-50.865975
br,sitio wanderlei padilha,Sítio Wanderlei Padilha,18,,-23.107294,-49.993849
br,sitio wanderley a. pereira,Sítio Wanderley A. Pereira,18,,-23.934213,-50.530521
br,sitio wanderley leonardo,Sítio Wanderley Leonardo,18,,-23.0257,-50.1341
br,sitio wander mendes,Sítio Wander Mendes,18,,-25.8559,-49.5073
br,sitio wenceslau soczek,Sítio Wenceslau Soczek,18,,-25.7844,-49.5904
br,sitio wendelino,Sítio Wendelino,18,,-25.860833,-49.740278
br,sitio werner henning,Sítio Werner Henning,18,,-26.161627,-49.506857
br,sitio wigando master,Sítio Wigando Master,18,,-26.0148,-49.3762
br,sitio wildner,Sítio Wildner,18,,-25.5168,-48.8874
br,sitio willis nascimento,Sítio Willis Nascimento,18,,-23.8667,-50.9651
br,sitio willy w. ttifke,Sítio Willy W. Ttifke,26,,-26.235188,-49.531099
br,sitio wilson betine,Sítio Wilson Betine,18,,-23.017083,-49.985509
br,sitio wilson b. monteiro,Sítio Wilson B. Monteiro,18,,-23.6693,-49.9145
br,sitio wilson casa grande,Sítio Wilson Casa Grande,18,,-23.663421,-50.670286
br,sitio wilson ferreira,Sítio Wilson Ferreira,18,,-23.1993,-50.0532
br,sitio wilson landgraff,Sítio Wilson Landgraff,18,,-23.531368,-50.673183
br,sitio wilson langnier,Sítio Wilson Langnier,18,,-23.902214,-50.252806
br,sitio wilson m. de oliveira,Sítio Wilson M. de Oliveira,18,,-23.96467,-50.516435
br,sitio wilson resende,Sítio Wilson Resende,18,,-23.374126,-50.116329
br,sitio wilson riba,Sítio Wilson Riba,18,,-25.8135,-49.5323
br,sitio wilson ribeiro amorim,Sítio Wilson Ribeiro Amorim,18,,-23.8712,-50.961
br,sitio wilson schader,Sítio Wilson Schader,26,,-26.217074,-49.634496
br,sitio wilson,Sítio Wilson,18,,-25.5174,-48.7651
br,sitio wilson tibes,Sítio Wilson Tibes,18,,-26.0095,-49.9249
br,sitio wilson tojimoto,Sítio Wilson Tojimoto,18,,-25.563,-48.8029
br,sitio wladislau neschioviski,Sítio Wladislau Neschioviski,18,,-25.776,-49.5169
br,sitio wolfgang g. theurer,Sítio Wolfgang G. Theurer,18,,-25.9528,-49.2292
br,sitio xamandu,Sítio Xamandu,27,,-23.221667,-46.574722
br,sitio xanadu,Sítio Xanadu,27,,-23.8765,-47.0825
br,sitio xangri-la,Sítio Xangri-La,27,,-23.349599,-46.570982
br,sitio xavier,Sítio Xavier,18,,-23.570638,-50.707242
br,sitio xavier,Sítio Xavier,27,,-25.013402,-48.506863
br,sitio xaxim,Sítio Xaxim,18,,-23.936202,-50.471091
br,sitio xereta,Sítio Xereta,27,,-23.9984,-47.068
br,sitio xodo,Sítio Xodó,27,,-23.204444,-46.636944
br,sitio yamacuchi,Sítio Yamacuchi,18,,-23.703955,-50.691463
br,sitio yamada,Sítio Yamada,18,,-23.530976,-50.041823
br,sitio yamada,Sítio Yamada,27,,-23.508876,-47.409193
br,sitio yamamoto,Sítio Yamamoto,18,,-23.0664,-50.1585
br,sitio yamamoto,Sítio Yamamoto,27,,-24.684377,-48.108033
br,sitio yk,Sítio YK,18,,-25.544483,-49.945125
br,sitio yolando nunes,Sítio Yolando Nunes,18,,-25.7857,-49.5793
br,sitio yoshida,Sítio Yoshida,18,,-23.527019,-50.665176
br,sitio yushizumi,Sítio Yushizumi,27,,-23.73059,-47.252744
br,sitio zacanas gardinos,Sítio Zacanas Gardinos,18,,-25.9737,-49.4871
br,sitio zacaria batista,Sítio Zacaria Batista,18,,-25.798889,-49.645278
br,sitio zacarias gomes,Sítio Zacarias Gomes,18,,-25.512,-48.8567
br,sitio zacarias m. de paula,Sítio Zacarias M. de Paula,18,,-25.902128,-49.92544
br,sitio zakicheski,Sítio Zakicheski,18,,-25.66364,-50.31885
br,sitio zamil z. de bastos,Sítio Zamil Z. de Bastos,18,,-26.021,-49.417
br,sitio zarauna,Sítio Zaraúna,27,,-23.690695,-47.090566
br,sitio zebedeu a. pereira,Sítio Zebedeu A. Pereira,18,,-25.5165,-48.7994
br,sitio zeferino dias,Sítio Zeferino Dias,18,,-23.6918,-49.807
br,sitio zeferino woxoicskoveky,Sítio Zeferino Woxoicskoveky,26,,-26.097,-49.2536
br,sitio zelai bandolim,Sítio Zelaí Bandolim,18,,-25.845069,-49.802011
br,sitio zelia,Sítio Zélia,18,,-23.793008,-50.132378
br,sitio zemundo rubresk,Sítio Zemundo Rubresk,18,,-25.815506,-49.808858
br,sitio zenobio a. de oliveira,Sítio Zenóbio A. de Oliveira,18,,-25.256997,-48.913711
br,sitio zenon westefal,Sítio Zenon Westefal,18,,-26.0042,-49.3046
br,sitio zeno rolim,Sítio Zeno Rolim,18,,-23.758296,-50.326469
br,sitio zezico,Sítio Zezico,27,,-23.645636,-47.487927
br,sitio ziguinel schelbauer,Sítio Ziguinel Schelbauer,26,,-26.228,-49.8424
br,sitio zilde franco,Sítio Zilde Franco,18,,-23.2826,-49.9101
br,sitio zildo,Sítio Zildo,18,,-23.917073,-50.294548
br,sitio zilo zanga,Sítio Zilo Zanga,18,,-25.8134,-49.3032
br,sitiozinho,Sítiozinho,20,,-6.55,-41.6
br,sitio ziso priolli,Sítio Ziso Priolli,18,,-23.5075,-49.9493
br,sitio zito pereira,Sítio Zito Pereira,18,,-23.5008,-49.8023
br,sitio zordo carvalho,Sítio Zordo Carvalho,18,,-25.906,-49.1652
br,sitio zuza,Sítio Zuza,18,,-23.596568,-50.646054
br,sito boa sorte,Síto Boa Sorte,18,,-25.837942,-48.779146
br,sito hiroshi,Síto Hiroshi,18,,-25.989429,-49.770775
br,sito mundo feliz,Sito Mundo Feliz,27,,-23.522168,-47.114431
br,sito vila pauliceia,Sito Vila Paulicéia,27,,-23.52354,-47.118869
br,sittio do meio,Sittio do Meio,05,,-12.85,-39.266667
br,situacao,Situacão,06,,-4.066667,-39.4
br,situacao,Situação,20,,-6.833333,-42.466667
br,situacao,Situacão,22,,-5.731944,-36.368056
br,situacao,Situação,30,,-8.2,-38.383333
br,siupe,Siupé,06,,-3.533333,-38.95
br,soares meireles,Soares Meireles,30,,-8.7,-35.266667
br,soares,Soares,06,,-5.466667,-40.433333
br,soares,Soares,11,,-22.383333,-54.75
br,soares,Soares,18,,-25.8,-50.616667
br,soares,Soares,26,,-26.35,-48.85
br,soares,Soares,27,,-23.783333,-47.883333
br,soares,Soares,30,,-8.133333,-37.266667
br,soberana,Soberana,30,,-8.85,-35.883333
br,sobradinho,Sobradinho,02,,-9.4,-36.566667
br,sobradinho,Sobradinho,05,19304,-12.5,-39.116667
br,sobradinho,Sobradinho,06,,-5.133333,-40.766667
br,sobradinho,Sobradinho,07,,-15.633333,-47.816667
br,sobradinho,Sobradinho,13,,-3.810556,-43.334722
br,sobradinho,Sobradinho,15,,-16.15,-39.866667
br,sobradinho,Sobradinho,16,,-5.733333,-57.066667
br,sobradinho,Sobradinho,18,,-24.95,-49.133333
br,sobradinho,Sobradinho,20,,-2.943611,-41.530833
br,sobradinho,Sobradinho,21,,-22.2,-42.916667
br,sobradinho,Sobradinho,22,,-6.233333,-38.283333
br,sobradinho,Sobradinho,23,13397,-29.4,-53.05
br,sobradinho,Sobradinho,27,,-22.383333,-47.416667
br,sobradinho,Sobradinho,31,,-11.381111,-47.239167
br,sobrado de cima,Sobrado de Cima,30,,-8.083333,-36.6
br,sobrado do quixaba,Sobrado do Quixaba,30,,-8.983333,-38.466667
br,sobrado grande,Sobrado Grande,20,,-7.216667,-41.6
br,sobrado quixaba,Sobrado Quixaba,30,,-8.983333,-38.466667
br,sobrado,Sobrado,04,,-2.505,-61.063056
br,sobrado,Sobrado,05,,-12.35,-39.05
br,sobrado,Sobrado,13,,-3.974167,-43.009444
br,sobrado,Sobrado,27,,-20.283333,-47.683333
br,sobrado,Sobrado,31,,-11.733333,-47.75
br,sobrado velho,Sobrado Velho,27,,-22.691111,-47.250833
br,sobrai,Sobrai,01,,-8.384722,-72.831111
br,sobralia,Sobrália,15,,-19.25,-42.1
br,sobral pinto,Sobral Pinto,15,,-21.266667,-42.9
br,sobral,Sobral,01,,-9.25,-70.316667
br,sobral,Sobral,04,,-7.133333,-70.066667
br,sobral,Sobral,06,157998,-3.7,-40.35
br,sobral,Sobral,24,,-8.5,-63.533333
br,sobrat,Sobrat,06,,-3.7,-40.35
br,sobreiro,Sobreiro,08,,-19.75,-40.883333
br,socamirim,Socamirim,27,,-23.616667,-47.2
br,socapo,Socapo,15,,-20.133333,-41.7
br,socavao,Socavao,13,,-6.083333,-43.483333
br,socavao,Socavão,18,,-24.783333,-49.716667
br,soccorro,Soccorro,27,,-22.6,-46.533333
br,soccorro,Soccorro,28,,-10.866667,-37.116667
br,socego,Socego,13,,-3.25,-45.166667
br,socopo,Socopo,20,,-5.033333,-42.766667
br,socorro do piaui,Socorro do Piauí,20,,-7.866667,-42.483333
br,socorro,Socorro,02,,-9.7,-37.533333
br,socorro,Socorro,05,,-12.683333,-38.583333
br,socorro,Socorro,06,,-4.75,-39.8
br,socorro,Socorro,13,,-6.033333,-43.733333
br,socorro,Socorro,15,,-19.983333,-43.583333
br,socorro,Socorro,17,,-7.35,-37.833333
br,socorro,Socorro,18,,-25.533333,-51.55
br,socorro,Socorro,20,,-7.083333,-40.616667
br,socorro,Socorro,23,,-28.366667,-50.816667
br,socorro,Socorro,27,24272,-22.6,-46.533333
br,socorro,Socorro,28,,-10.866667,-37.116667
br,socorro,Socorro,30,,-7.966667,-36.1
br,soco,Socó,25,,4.45,-60.166667
br,sodrelandia,Sodrelândia,21,,-22.15,-42.066667
br,sodrelia,Sodrélia,27,,-22.95,-49.55
br,sodre,Sodré,30,,-8.633333,-36.366667
br,sofia,Sofia,11,,-21.583333,-53.733333
br,sofre,Sofrê,05,,-12.116667,-39.283333
br,soinho,Soinho,20,,-6.416667,-41.95
br,solanea,Solânea,17,17031,-6.75,-35.65
br,sol de maio,Sol de Maio,18,,-25.05,-54.466667
br,soledad de rodeio,Soledad de Rodeio,21,,-22.549444,-43.683889
br,soledade de minas,Soledade de Minas,15,,-22.066667,-45.05
br,soledade do itajuba,Soledade do Itajubá,15,,-22.5,-45.283333
br,soledade,Soledade,04,,-2.916667,-68.633333
br,soledade,Soledade,05,,-13.533333,-42.8
br,soledade,Soledade,06,,-5.083333,-40.283333
br,soledade,Soledade,13,,-2.05,-44.8
br,soledade,Soledade,15,,-22.066667,-45.05
br,soledade,Soledade,17,8090,-7.05,-36.35
br,soledade,Soledade,20,,-6.783333,-40.666667
br,soledade,Soledade,21,,-21.15,-41.7
br,soledade,Soledade,22,,-5.583333,-37.816667
br,soledade,Soledade,23,24791,-28.833333,-52.5
br,soledade,Soledade,25,,3.7,-61.033333
br,soledad,Soledad,04,,-2.916667,-68.633333
br,soledad,Soledad,13,,-5.366667,-43.466667
br,soledale,Soledale,20,,-6.766667,-42.85
br,solemar,Solemar,27,,-24.083333,-46.6
br,solidao,Solidão,06,,-2.933333,-40.416667
br,solidao,Solidão,22,,-5.8925,-37.270833
br,solidao,Solidão,23,,-29.9909,-50.9834
br,solidao,Solidão,30,,-7.6,-37.666667
br,solista,Solista,22,,-5.678611,-36.138333
br,solonopole,Solonópole,06,,-5.733333,-39.016667
br,solonopolis,Solonópolis,06,,-5.733333,-39.016667
br,solta de dentro,Sôlta de Dentro,06,,-7.566667,-38.716667
br,solta,Sôlta,13,,-6.283333,-47.283333
br,soltas,Soltas,20,,-5.916667,-42.983333
br,solzinho,Solzinho,30,,-7.85,-39.3
br,somanuma,Somanuma,01,,-10.633333,-68.416667
br,sombra da tarde,Sombra da Tarde,15,,-16.233333,-40.45
br,sombras grandes,Sombras Grandes,22,,-5.900556,-36.473056
br,sombra,Sombra,22,,-5.916111,-37.012778
br,sombreiro,Sombreiro,22,,-5.1425,-37.161111
br,sombrio,Sombrio,22,,-5.474444,-37.419444
br,sombrio,Sombrio,26,14864,-29.116667,-49.666667
br,sonhem,Sonhém,05,,-11.633333,-40.833333
br,sopa,Sopa,15,,-18.2,-43.716667
br,sorocaba,Sorocaba,22,,-5.615278,-37.406389
br,sorocaba,Sorocaba,27,558874,-23.483333,-47.45
br,sorocabucu,Sorocabuçu,27,,-23.758823,-47.175149
br,soroca mirim,Soroca Mirim,27,,-23.577421,-47.15386
br,sorocamirim,Sorocamirim,27,,-23.803495,-47.036408
br,sororoca,Sororoca,04,,-2.95,-66.15
br,sororoca,Sororoca,06,,-3.516667,-40.2
br,sororoca,Sororoca,25,,.716667,-61.516667
br,sororo,Sororó,18,,-24.266667,-54.266667
br,sororo,Sororó,31,,-6.866667,-48.383333
br,sorvinha,Sorvinha,04,,-4.1725,-60.893333
br,so silvestre do jacare,So Silvestre do Jacare,27,,-23.3644,-46.0172
br,sossego,Sossêgo,05,,-12.233333,-40.816667
br,sossego,Sossêgo,06,,-4.766667,-38.633333
br,sossego,Sossêgo,11,,-20.85,-56.45
br,sossego,Sossêgo,13,,-3.25,-45.166667
br,sossego,Sossêgo,15,,-14.9,-43.516667
br,sossego,Sossêgo,17,,-6.533333,-38.566667
br,sossego,Sossego,20,,-3.41,-42.1425
br,sossego,Sossêgo,21,,-21.883333,-41.8
br,sossego,Sossêgo,22,,-5.464722,-37.253333
br,sotea,Sotea,23,,-31.766667,-53.8
br,sotero,Sotero,17,,-7.183333,-38.65
br,soturna,Soturna,27,,-22.033333,-48.883333
br,soure,Soure,05,,-11.233333,-38.483333
br,soure,Soure,06,,-3.7,-38.65
br,soure,Soure,16,18212,-.733333,-48.516667
br,sousania,Sousânia,29,,-16.183333,-49.083333
br,sousa peixoto,Sousa Peixoto,05,,-13,-39.516667
br,sousa,Sousa,17,47927,-6.75,-38.233333
br,sousa,Sousa,20,,-7.866667,-44.916667
br,sousa,Sousa,21,,-22.891258,-43.560935
br,sousa,Sousa,22,,-5.216667,-35.5
br,sousas,Sousas,15,,-20.183333,-44.316667
br,sousas,Sousas,27,,-22.866667,-46.983333
br,sousel,Sousel,16,,-2.65,-51.916667
br,souto,Souto,23,,-30.45,-53.8
br,souzania,Souzânia,29,,-16.183333,-49.083333
br,souza,Souza,13,,-3.753889,-43.181111
br,souza,Souza,17,,-6.75,-38.233333
br,souza,Souza,18,,-24.944,-48.7116
br,souza,Souza,23,,-29.333333,-52.1
br,souzas,Souzas,27,,-22.866667,-46.983333
br,souzel,Souzel,16,,-2.65,-51.916667
br,sovaco,Sovaco,06,,-5.8,-39.983333
br,sozinho,Sòzinho,14,,-17.25,-54.65
br,sozinho,Sòzinho,17,,-7.783333,-38.133333
br,s. simmer,S. Simmer,08,,-20.333333,-40.866667
br,station isadel,Station Isadel,16,,-6.116667,-48.316667
br,station terezinha do tauiry,Station Terezinha do Tauiry,16,,-5.133333,-49.3
br,stio a. colossal,Stio A. Colossal,27,,-23.387632,-46.162645
br,stio agenor,Stio Agenor,27,,-23.3413,-46.0273
br,stio aguas lucema,Stio Aguas Lucema,27,,-23.3615,-46.2476
br,stio alvorada,Stio Alvorada,27,,-23.3292,-46.117
br,stio amrico correa,Stio Amrico Correa,27,,-23.3459,-46.0567
br,stio ana maria conceio,Stio Ana Maria Conceio,27,,-23.3633,-46.0405
br,stio ana martins,Stio Ana Martins,27,,-23.2754,-46.0489
br,stio anibal rodrigues,Stio Anibal Rodrigues,27,,-23.256,-46.1381
br,stio antnio dionzio,Stio Antnio Dionzio,27,,-23.2614,-46.0301
br,stio antnio h. aquino,Stio Antnio H. Aquino,27,,-23.29,-46.0293
br,stio antnio luis siqueira,Stio Antnio Luis Siqueira,27,,-23.3299,-46.0153
br,stio antnio monteiro,Stio Antnio Monteiro,27,,-23.3521,-46.0677
br,stio antnio piral,Stio Antnio Piral,27,,-23.288546,-46.186008
br,stio augusto fernandes,Stio Augusto Fernandes,27,,-23.27408,-46.183326
br,stio aurora,Stio Aurora,27,,-23.4074,-46.0241
br,stio avelino motta,Stio Avelino Motta,27,,-23.3533,-46.0232
br,stio avelino rodrigues,Stio Avelino Rodrigues,27,,-23.2812,-46.1758
br,stio barna,Stio Barna,27,,-23.410457,-46.23089
br,stio beija-flor,Stio Beija-Flor,27,,-23.2866,-46.0863
br,stio bela vista,Stio Bela Vista,27,,-23.2805,-46.2367
br,stio benedito aparecido rodrigues,Stio Benedito Aparecido Rodrigues,27,,-23.252812,-46.090447
br,stio bernardo,Stio Bernardo,27,,-23.2514,-46.184
br,stio berro d' agua,Stio Berro d' Agua,27,,-23.3422,-46.2394
br,stio betnia,Stio Betnia,27,,-23.4429,-46.2466
br,stio boa esperana,Stio Boa Esperana,27,,-23.2706,-46.1378
br,stio boa vista,Stio Boa Vista,27,,-23.2637,-46.0827
br,stio bocaina,Stio Bocaina,27,,-23.4058,-46.0011
br,stio bom jesus,Stio Bom Jesus,27,,-23.4858,-46.0031
br,stio bonanza,Stio Bonanza,27,,-23.2887,-46.0173
br,stio botuquara,Stio Botuquara,27,,-23.3952,-46.0474
br,stio branca de neve,Stio Branca de Neve,27,,-23.3469,-46.1305
br,stio brejo seco,Stio Brejo Seco,27,,-23.3973,-46.0485
br,stio cachoeira,Stio Cachoeira,27,,-23.2779,-46.1821
br,stio camilo s. barbosa,Stio Camilo S. Barbosa,27,,-23.267952,-46.16761
br,stio cantagalo,Stio Cantagalo,27,,-23.3369,-46.2465
br,stio capelinha,Stio Capelinha,27,,-23.483129,-46.126873
br,stio caracol,Stio Caracol,27,,-23.452616,-46.240517
br,stio carlos rangue,Stio Carlos Rangue,27,,-23.290893,-46.170055
br,stio caverna,Stio Caverna,27,,-23.381267,-46.058631
br,stio cerro azul,Stio Cerro Azul,27,,-23.3696,-46.1808
br,stio chapado,Stio Chapado,27,,-23.3335,-46.0563
br,stio chegancia,Stio Chegancia,27,,-23.3454,-46.1821
br,stio clio jos dos santos,Stio Clio Jos dos Santos,27,,-23.258,-46.1136
br,stio cruzeiro,Stio Cruzeiro,27,,-23.4503,-46.1678
br,stio dacio piazza,Stio Dacio Piazza,27,,-23.3365,-46.0288
br,stio da colina,Stio da Colina,27,,-23.4625,-46.0869
br,stio da gara,Stio da Gara,27,,-23.4681,-46.1193
br,stio d' anna,Stio D' Anna,27,,-23.36,-46.2483
br,stio das flores,Stio das Flores,27,,-23.2725,-46.0401
br,stio das ilhas,Stio das Ilhas,27,,-23.3765,-46.0646
br,stio das laranjeiras,Stio das Laranjeiras,27,,-23.4234,-46.0717
br,stio das moendas,Stio das Moendas,27,,-23.325,-46.2418
br,stio das paineiras,Stio das Paineiras,27,,-23.4856,-46.0832
br,stio das palmeiras,Stio das Palmeiras,27,,-23.300037,-46.182707
br,stio divineas,Stio Divineas,27,,-23.3298,-46.0948
br,stio do barreiro,Stio do Barreiro,27,,-23.3883,-46.0599
br,stio do carmo,Stio do Carmo,27,,-23.4484,-46.2072
br,stio dois irmos,Stio Dois Irmos,27,,-23.4291,-46.185
br,stio do joca,Stio do Joca,27,,-23.3538,-46.1009
br,stio domingos elias de oliveira,Stio Domingos Elias de Oliveira,27,,-23.2672,-46.1095
br,stio do portugus,Stio do Portugus,27,,-23.348,-46.1657
br,stio do professor,Stio do Professor,27,,-23.4547,-46.2283
br,stio dos marrons,Stio dos Marrons,27,,-23.4107,-46.0562
br,stio dos piles,Stio dos Piles,27,,-23.2782,-46.2394
br,stio dos quatro sacis,Stio dos Quatro Sacis,27,,-23.4899,-46.0912
br,stio do valter,Stio do valter,27,,-23.3578,-46.0435
br,stio do vov,Stio do Vov,27,,-23.2658,-46.2277
br,stio do zizi,Stio do Zizi,27,,-23.488,-46.0135
br,stio edgar ramos,Stio Edgar Ramos,27,,-23.2727,-46.1629
br,stio edmundo sousa,Stio Edmundo Sousa,27,,-23.35,-46.0229
br,stio eldorado,Stio Eldorado,27,,-23.4625,-46.1125
br,stio euderico fernandes,Stio Euderico Fernandes,27,,-23.2644,-46.1719
br,stio florana,Stio Florana,27,,-23.4454,-46.2018
br,stio florida,Stio Florida,27,,-23.468,-46.1232
br,stio fonte da serra,Stio Fonte da Serra,27,,-23.399,-46.1263
br,stio francisco missina,Stio Francisco Missina,27,,-23.37,-46.0925
br,stio francisco ramos,Stio Francisco Ramos,27,,-23.2777,-46.1492
br,stio gacho,Stio Gacho,27,,-23.302037,-46.202088
br,stio geraldo a. alvino,Stio Geraldo A. Alvino,27,,-23.3019,-46.0595
br,stio geraldo monteiro,Stio Geraldo Monteiro,27,,-23.307,-46.1171
br,stio gluglu,Stio Gluglu,27,,-23.3781,-46.2448
br,stio gondim,Stio Gondim,27,,-23.4417,-46.2476
br,stio groto,Stio Groto,27,,-23.3912,-46.0419
br,stio guapor,Stio Guapor,27,,-23.3687,-46.0958
br,stio homero evangelista,Stio Homero Evangelista,27,,-23.2516,-46.1093
br,stio icari,Stio Icari,27,,-23.4229,-46.1804
br,stio ip,Stio Ip,27,,-23.3415,-46.2451
br,stio irineu h. aquino,Stio Irineu H. Aquino,27,,-23.2838,-46.0289
br,stio itapeti,Stio Itapeti,27,,-23.4986,-46.218
br,stio itapetizinho,Stio Itapetizinho,27,,-23.4476,-46.1172
br,stio jacarand,Stio Jacarand,27,,-23.4672,-46.0829
br,stio jandaia,Stio Jandaia,27,,-23.4504,-46.0486
br,stio jardim do edem,Stio Jardim do Edem,27,,-23.3921,-46.0032
br,stio joana da arc,Stio Joana da Arc,27,,-23.3177,-46.2469
br,stio joaquim fernandes,Stio Joaquim Fernandes,27,,-23.2571,-46.1801
br,stio joaquim nunes,Stio Joaquim Nunes,27,,-23.3667,-46.0385
br,stio joo b. camargo,Stio Joo B. Camargo,27,,-23.3193,-46.0739
br,stio joo c. morais,Stio Joo C. Morais,27,,-23.2874,-46.1655
br,stio joo felcio,Stio Joo Felcio,27,,-23.265541,-46.182626
br,stio joo salvador do prado,Stio Joo Salvador do Prado,27,,-23.2755,-46.1275
br,stio joo vayne,Stio Joo Vayne,27,,-23.2926,-46.0196
br,stio jos benedito de oliveira,Stio Jos Benedito de Oliveira,27,,-23.2555,-46.0209
br,stio josefa m. conceio,Stio Josefa M. Conceio,27,,-23.3586,-46.0415
br,stio josino b. santos,Stio Josino B. Santos,27,,-23.2584,-46.1288
br,stio jos marques,Stio Jos Marques,27,,-23.4005,-46.0134
br,stio jos pereira,Stio Jos Pereira,27,,-23.3034,-46.1087
br,stio jos raposo,Stio Jos Raposo,27,,-23.3052,-46.1063
br,stio jos silvrio neto,Stio Jos Silvrio Neto,27,,-23.2572,-46.1459
br,stio jos siqueira,Stio Jos Siqueira,27,,-23.3305,-46.0929
br,stio koki fukugana,Stio Koki Fukugana,27,,-23.2643,-46.0267
br,stio lagoa de itapeti,Stio Lagoa de Itapeti,27,,-23.4886,-46.181
br,stio maranata,Stio Maranata,27,,-23.467,-46.0765
br,stio marclio navarro,Stio Marclio Navarro,27,,-23.3587,-46.0242
br,stio maria b. vilela,Stio Maria B. Vilela,27,,-23.2803,-46.12
br,stio mariano de sousa,Stio Mariano de Sousa,27,,-23.2636,-46.0502
br,stio marianos,Stio Marianos,27,,-23.3489,-46.1333
br,stio maria r. soares,Stio Maria R. Soares,27,,-23.277,-46.16
br,stio marieta,Stio Marieta,27,,-23.4177,-46.1616
br,stio marli,Stio Marli,27,,-23.4502,-46.1339
br,stio merenda,Stio Merenda,27,,-23.4328,-46.0425
br,stio mine,Stio Mine,27,,-23.4623,-46.1073
br,stio moinho velho,Stio Moinho Velho,27,,-23.4701,-46.2268
br,stio morro grande,Stio Morro Grande,27,,-23.3236,-46.1953
br,stio morro verde,Stio Morro Verde,27,,-23.3854,-46.1883
br,stio mrcio silvrio,Stio Mrcio Silvrio,27,,-23.2509,-46.0963
br,stio nadir rustan,Stio Nadir Rustan,27,,-23.2861,-46.0362
br,stio narcsio de oliveira,Stio Narcsio de Oliveira,27,,-23.2518,-46.0228
br,stio nelson melo,Stio Nelson Melo,27,,-23.2967,-46.1232
br,stio noel ramos,Stio Noel Ramos,27,,-23.2786,-46.1669
br,stio nossa senhora aparecida,Stio Nossa Senhora Aparecida,27,,-23.3696,-46.1408
br,stio nossa senhora das brotas,Stio Nossa Senhora das Brotas,27,,-23.2826,-46.1112
br,stio nossa senhora de lourdes,Stio Nossa Senhora de Lourdes,27,,-23.4649,-46.0943
br,stio novo horizonte,Stio Novo Horizonte,27,,-23.2672,-46.214
br,stio oliveira,Stio Oliveira,27,,-23.3461,-46.0457
br,stio orlando dos santos,Stio Orlando dos Santos,27,,-23.3462,-46.0253
br,stio ouro fino,Stio Ouro Fino,27,,-23.2898,-46.247
br,stio ouro verde,Stio Ouro Verde,27,,-23.4644,-46.2272
br,stio pacincia,Stio Pacincia,27,,-23.3546,-46.0096
br,stio palmeiras,Stio Palmeiras,27,,-23.3716,-46.0556
br,stio papa-vento,Stio Papa-Vento,27,,-23.3977,-46.1808
br,stio paulo rodrigues,Stio Paulo Rodrigues,27,,-23.2607,-46.1527
br,stio pau torto,Stio Pau Torto,27,,-23.2587,-46.2013
br,stio pedro brasilio,Stio Pedro Brasilio,27,,-23.3702,-46.1216
br,stio pedro gandu,Stio Pedro Gandu,27,,-23.2645,-46.1203
br,stio pedro m. gonalves,Stio Pedro M. Gonalves,27,,-23.2605,-46.1176
br,stio pedro morais,Stio Pedro Morais,27,,-23.3665,-46.0091
br,stio pedro s. lima,Stio Pedro S. Lima,27,,-23.2851,-46.111
br,stio pequeno mundo,Stio Pequeno Mundo,27,,-23.2674,-46.2161
br,stio peras,Stio Peras,27,,-23.4739,-46.0922
br,stio pinga-pinga,Stio Pinga-Pinga,27,,-23.3238,-46.0315
br,stio piraraquara,Stio Piraraquara,27,,-23.375504,-46.059172
br,stio piratininga,Stio Piratininga,27,,-23.3561,-46.0111
br,stio porta do cu,Stio Porta do Cu,27,,-23.3343,-46.2467
br,stio portela,Stio Portela,27,,-23.3288,-46.187
br,stio pouso de iemanj,Stio Pouso de Iemanj,27,,-23.311,-46.1175
br,stio primavera,Stio Primavera,27,,-23.3084,-46.1396
br,stio quatro cantos,Stio Quatro Cantos,27,,-23.3155,-46.0283
br,stio quatro estrelas,Stio Quatro Estrelas,27,,-23.4805,-46.217
br,stio quintas da lagoa,Stio Quintas da Lagoa,27,,-23.2625,-46.2323
br,stio rancho fundo,Stio Rancho Fundo,27,,-23.3394,-46.2492
br,stio rancho grande,Stio Rancho Grande,27,,-23.4516,-46.1771
br,stio recanto alegre,Stio Recanto Alegre,27,,-23.4898,-46.0959
br,stio regina,Stio Regina,27,,-23.2533,-46.161
br,stio riacho,Stio Riacho,27,,-23.3771,-46.2293
br,stio rosa-dos-ventos,Stio Rosa-dos-Ventos,27,,-23.492,-46.2035
br,stio rosa maria santana,Stio Rosa Maria Santana,27,,-23.3321,-46.035
br,stio rosana,Stio Rosana,27,,-23.4226,-46.1769
br,stio rosane,Stio Rosane,27,,-23.4082,-46.2344
br,stio rumo certo,Stio Rumo Certo,27,,-23.3716,-46.0657
br,stio santa ceclia,Stio Santa Ceclia,27,,-23.3609,-46.1752
br,stio santa cruz,Stio Santa Cruz,27,,-23.3583,-46.2474
br,stio santa edwiges,Stio Santa Edwiges,27,,-23.295527,-46.200644
br,stio santa filomena,Stio Santa Filomena,27,,-23.284,-46.1695
br,stio santa gertrudes,Stio Santa Gertrudes,27,,-23.319352,-46.177125
br,stio santa helena,Stio Santa Helena,27,,-23.4611,-46.2264
br,stio santa isabel,Stio Santa Isabel,27,,-23.3739,-46.0592
br,stio santa luzia,Stio Santa Luzia,27,,-23.2661,-46.0596
br,stio santa maria,Stio Santa Maria,27,,-23.308,-46.1579
br,stio santa rita,Stio Santa Rita,27,,-23.2908,-46.2009
br,stio santa rosa,Stio Santa Rosa,27,,-23.4591,-46.0598
br,stio santa teresa,Stio Santa Teresa,27,,-23.3725,-46.0333
br,stio santa teresinha,Stio Santa Teresinha,27,,-23.3443,-46.2099
br,stio santo antnio da bela vista,Stio Santo Antnio da Bela Vista,27,,-23.32201,-46.204692
br,stio santo antnio,Stio Santo Antnio,27,,-23.3468,-46.2178
br,stio sawada,Stio Sawada,27,,-23.3269,-46.1164
br,stio schavoa,Stio Schavoa,27,,-23.2887,-46.1532
br,stio senhora do pranto,Stio Senhora do Pranto,27,,-23.3735,-46.146
br,stio serra do itapeti,Stio Serra do Itapeti,27,,-23.4934,-46.2174
br,stio sheiva anashiro,Stio Sheiva Anashiro,27,,-23.2816,-46.0448
br,stio so benedito,Stio So Benedito,27,,-23.3122,-46.0241
br,stio so bento,Stio So Bento,27,,-23.2544,-46.2469
br,stio so bernardino,Stio So Bernardino,27,,-23.3627,-46.2077
br,stio so carlos,Stio So Carlos,27,,-23.2898,-46.1182
br,stio so cristvo,Stio So Cristvo,27,,-23.3233,-46.1117
br,stio so francisco de assis,Stio So Francisco de Assis,27,,-23.4404,-46.0933
br,stio so francisco,Stio So Francisco,27,,-23.3477,-46.2471
br,stio sohiro fuji,Stio Sohiro Fuji,27,,-23.3265,-46.1006
br,stio so joo,Stio So Joo,27,,-23.4262,-46.0436
br,stio so jorge,Stio So Jorge,27,,-23.309335,-46.019608
br,stio so jos,Stio So Jos,27,,-23.2946,-46.1254
br,stio so judas tadeu,Stio So Judas Tadeu,27,,-23.3155,-46.0204
br,stio solidariedade,Stio Solidariedade,27,,-23.4462,-46.1924
br,stio so lus do salim,Stio So Lus do Salim,27,,-23.466,-46.0645
br,stio so lus,Stio So Lus,27,,-23.2944,-46.0574
br,stio so lzaro,Stio So Lzaro,27,,-23.4425,-46.1662
br,stio so martins,Stio So Martins,27,,-23.3581,-46.2009
br,stio sonezuzi ozeki,Stio Sonezuzi Ozeki,27,,-23.2845,-46.0054
br,stio so pedro,Stio So Pedro,27,,-23.311,-46.1643
br,stio so roque,Stio So Roque,27,,-23.258,-46.19
br,stio so sebastio,Stio So Sebastio,27,,-23.3504,-46.045
br,stio tabapu,Stio Tabapu,27,,-23.337,-46.0608
br,stio tapera,Stio Tapera,27,,-23.3954,-46.0748
br,stio toli,Stio Toli,27,,-23.4141,-46.1258
br,stio trs chicos,Stio Trs Chicos,27,,-23.3265,-46.1928
br,stio trs lagos,Stio Trs Lagos,27,,-23.408,-46.1209
br,stio trs mosqueteiros,Stio Trs Mosqueteiros,27,,-23.4183,-46.0515
br,stio trs netinhos,Stio Trs Netinhos,27,,-23.3716,-46.0863
br,stio turco,Stio Turco,27,,-23.3628,-46.131
br,stio veso ferreira,Stio Veso Ferreira,27,,-23.2706,-46.0185
br,stio vicente l. silva,Stio Vicente L. Silva,27,,-23.2623,-46.1113
br,stio vila real,Stio Vila Real,27,,-23.312769,-46.167489
br,stio vista alegre,Stio Vista Alegre,27,,-23.4301,-46.1049
br,stio vov joo,Stio Vov Joo,27,,-23.4218,-46.1645
br,stio xangri-l,Stio Xangri-l,27,,-23.465,-46.08
br,stio yoshio kinoghita,Stio Yoshio Kinoghita,27,,-23.266,-46.0519
br,suacurana,Suaçurana,06,,-6.3,-39.4
br,suape,Suape,05,,-12.733333,-38.616667
br,suassurana,Suassurana,06,,-6.3,-39.4
br,suatan,Suatan,22,,-5.508333,-37.457778
br,subaio,Subaio,21,,-22.438801,-42.764393
br,subauma,Subaúma,05,,-12.25,-37.8
br,subauma,Subaúma,27,,-24.816667,-47.75
br,subau-mirim,Subaú-Mirim,05,,-12.083333,-37.916667
br,subida,Subida,13,,-3.147778,-42.2475
br,subida,Subida,26,,-27.1,-49.45
br,sub-sede-iguacu,Sub-sede-Iguaçu,18,,-26.116667,-50.666667
br,sucatinga,Sucatinga,06,,-4.25,-38.05
br,sucavao de cima,Sucavão de Cima,22,,-5.933333,-35.95
br,sucessores,Sucessores,27,,-22.483333,-52.333333
br,sucesso,Sucesso,06,,-4.933333,-40.533333
br,sucuanha,Suçuanha,06,,-4.166667,-40.816667
br,sucuapara,Suçuapara,05,,-14.2,-44.633333
br,sucuapara,Suçuapara,13,,-9.333333,-45.9
br,sucuapara,Suçuapara,29,,-16.966667,-48.95
br,sucuarana de cima,Suçuarana de Cima,05,,-13.933333,-41.283333
br,sucuarana,Suçuarana,02,,-9.633333,-36.95
br,sucuarana,Suçuarana,05,,-12.333333,-40.666667
br,sucuarana,Suçuarana,06,,-6.3,-39.4
br,sucuarana,Suçuarana,13,,-5.05,-43.2
br,sucuarana,Suçuarana,20,,-4.083333,-41.883333
br,sucuarana,Suçuarana,22,,-5.166667,-37.216667
br,sucuba,Sucuba,25,,2.883333,-61.133333
br,sucui,Suçuí,27,,-22.816667,-50.3
br,sucupira do norte,Sucupira do Norte,13,,-6.45,-44.2
br,sucupira ii,Sucupira II,13,,-3.335556,-43.016111
br,sucupira i,Sucupira I,13,,-3.344444,-43.029722
br,sucupira,Sucupira,02,,-9.483333,-37.283333
br,sucupira,Sucupira,06,,-5.266667,-37.9
br,sucupira,Sucupira,13,,-6.416667,-43.533333
br,sucupira,Sucupira,15,,-19.3,-48.45
br,sucupira,Sucupira,20,,-9.583333,-45.2
br,sucupira,Sucupira,31,,-12.006111,-48.903333
br,sucupira torta,Sucupira Torta,17,,-6.983333,-35.083333
br,sucure,Sucuré,16,,-4.366667,-56.45
br,sucuriju,Sucuriju,03,,1.65,-49.95
br,sucuriju,Sucuriju,04,,-2.493889,-61.113611
br,sucuriju,Sucuriju,13,,-3.177222,-43.029444
br,sucuri,Sucuri,11,,-20.466667,-56.183333
br,sucuri,Sucuri,14,,-15.833333,-55.566667
br,sucuri,Sucuri,27,,-20.916667,-47.4
br,sucuri,Sucuri,29,,-16.466667,-51.75
br,sucuriu,Sucuriú,05,,-10.416667,-43.233333
br,sucuriu,Sucuriú,13,,-6.433333,-43.1
br,sucuriu,Sucuriú,14,,-15.833333,-55.566667
br,sucuriu,Sucuriú,15,,-17.05,-42.316667
br,sucurizinho,Sucurizinho,27,,-21.716667,-49.283333
br,sucurizinho,Sucurizinho,31,,-7.1,-48.133333
br,sucurui,Sucurui,14,,-15.833333,-55.566667
br,sucuruju,Sucuruju,13,,-3.757222,-42.814722
br,sucuruju,Sucuruju,20,,-3.85,-41.8
br,sucuru,Sucuru,17,,-7.666667,-36.783333
br,sudene,Sudene,20,,-3.488056,-42.0825
br,sud mennucci,Sud Mennucci,27,,-20.7,-50.916667
br,sud menucci,Sud Menucci,27,,-20.7,-50.916667
br,suez,Suez,11,,-21.9,-54.183333
br,suica carioca,Suiça Carioca,21,,-22.922789,-43.339285
br,suico,Suiço,15,,-19.833333,-41.866667
br,suinauma,Suinauma,16,,-6.333333,-57.833333
br,suisso,Suisso,15,,-20.666667,-41.983333
br,sulacap,Sulacap,21,,-22.889059,-43.386159
br,sulina,Sulina,18,,-25.7,-52.733333
br,sul mineira,Sul Mineira,18,,-23.8062,-50.0801
br,sumare,Sumaré,18,,-23.033333,-52.45
br,sumare,Sumaré,27,227982,-22.8,-47.283333
br,sumauma,Sumaúma,04,,-7.833333,-60.033333
br,sumauma,Sumaúma,13,,-5.716667,-45.866667
br,sumauma,Sumaúma,16,,-2.95,-51.916667
br,sumauna,Sumauna,04,,-7.833333,-60.033333
br,sume,Sumé,17,10441,-7.65,-36.916667
br,sumidor,Sumidor,05,,-12.466667,-39.133333
br,sumidouro de cima,Sumidouro de Cima,27,,-24,-47.9
br,sumidouro,Sumidouro,05,,-13.033333,-41.8
br,sumidouro,Sumidouro,14,,-14.116667,-56.683333
br,sumidouro,Sumidouro,15,,-17.45,-43.95
br,sumidouro,Sumidouro,18,,-24.951615,-48.952575
br,sumidouro,Sumidouro,20,,-9.223889,-45.283889
br,sumidouro,Sumidouro,21,,-22.05,-42.683333
br,sumidouro,Sumidouro,22,,-5.1,-37.683333
br,sumuri,Sumuri,11,,-21.283333,-56.583333
br,sungaru,Sungaru,01,,-7.85,-73.533333
br,sunira,Sunira,18,,-25.640793,-50.697851
br,superagui,Superagui,18,,-25.416667,-48.233333
br,superino,Superino,05,,-15.75,-39.25
br,supia,Supiá,04,,-4.910556,-62.632222
br,surara,Surara,04,,-4.123611,-61.540833
br,surdo,Surdo,20,,-7.166667,-43.466667
br,surpresa,Surprêsa,24,,-11.9,-64.983333
br,surrao,Surrão,05,,-13.116667,-40.083333
br,surrao,Surrão,13,,-3.323611,-43.326944
br,surrao,Surrão,17,,-7.283333,-38.316667
br,surra,Surra,30,,-7.866667,-39.916667
br,surubabel,Surubabel,05,,-8.883333,-38.716667
br,surubim,Surubim,04,,-2.55,-67.35
br,surubim,Surubim,05,,-12.6,-42.5
br,surubim,Surubim,13,,-3.244722,-42.053056
br,surubim,Surubim,30,34581,-7.833333,-35.75
br,surubi,Surubi,29,,-16.25,-47.783333
br,surucutinga,Surucutinga,20,,-5.416667,-42.066667
br,suruegua,Suruégua,20,,-3.443889,-42.326944
br,suruhy,Suruhy,21,,-22.660833,-43.121111
br,surui,Suruí,21,,-22.660833,-43.121111
br,sururua,Sururuá,04,,-4.373889,-69.716667
br,sururu,Sururu,04,,-5.699444,-61.289444
br,sururu,Sururu,05,,-12.833333,-39.383333
br,susano,Susano,27,,-23.533333,-46.333333
br,suspiro,Suspiro,23,,-30.633333,-54.366667
br,sussuanha,Sussuanha,06,,-4.166667,-40.816667
br,sussuapara,Sussuapara,05,,-14.2,-44.633333
br,sussuapara,Sussuapara,13,,-9.333333,-45.9
br,sussuapara,Sussuapara,29,,-16.966667,-48.95
br,sussuarana,Sussuarana,05,,-14.166667,-41.2
br,sussuarana,Sussuarana,06,,-5.483333,-38.016667
br,sussuarana,Sussuarana,13,,-5.05,-43.2
br,sussuarana,Sussuarana,20,,-6,-41.783333
br,sussuarana,Sussuarana,30,,-7.883333,-39.716667
br,sussuhy,Sussuhy,27,,-22.816667,-50.3
br,sussui,Sussui,06,,-5.116667,-39
br,sussui,Sussuí,27,,-22.816667,-50.3
br,sussupara,Sussupara,31,,-9.529167,-48.319722
br,sustino,Sustino,31,,-8.45,-49.416667
br,susto,Susto,20,,-7.366667,-43.05
br,suvenir,Suvenir,20,,-3.547778,-42.011667
br,suzana,Suzana,15,,-20.2397,-43.997
br,suzana,Suzana,30,,-8.85,-36.066667
br,suzano,Suzano,27,283319,-23.533333,-46.333333
br,sylverio nery,Sylverio Nery,04,,-3.116667,-58.15
br,sylvestre ferraz,Sylvestre Ferraz,15,,-22.116667,-45.133333
br,sylvianopolis,Sylvianopolis,15,,-22.033333,-45.833333
br,syria,Syria,04,,-2.633333,-67.016667
br,tabaco,Tabaco,02,,-9.716667,-36.2
br,tabaco,Tabaco,25,,3.65,-60.933333
br,tabaiana,Tabaiana,17,,-7.333333,-35.333333
br,tabaiana,Tabaiana,22,,-5.466667,-35.633333
br,tabainha,Tabainha,06,,-3.5,-40.85
br,tabai,Tabaí,23,,-29.633333,-51.733333
br,tabajara,Tabajara,05,,-14.983333,-42.316667
br,tabajara,Tabajara,17,,-7.05,-34.9
br,tabajara,Tabajara,22,,-5.883333,-35.466667
br,tabajara,Tabajara,24,,-8.933333,-62.133333
br,tabajara,Tabajara,27,,-21.316667,-51.15
br,tabao,Tabão,14,,-14.833333,-56.4
br,tabapira,Tabapira,23,,-28.3,-53.5
br,tabapuan,Tabapuan,27,,-20.966667,-49.033333
br,tabapua,Tabapuá,06,,-3.75,-38.616667
br,tabapua,Tabapuã,27,,-20.966667,-49.033333
br,tabaqueiro,Tabaqueiro,20,,-3.719444,-42.443056
br,tabatinga do alto do rodrigues,Tabatinga do Alto do Rodrigues,22,,-5.315278,-36.754444
br,tabatinga do alto do rodriques,Tabatinga do Alto do Rodriques,22,,-5.315278,-36.754444
br,tabatinga ii,Tabatinga II,13,,-3.224444,-42.988889
br,tabatinga i,Tabatinga I,13,,-3.276667,-43.017222
br,tabatinga,Tabatinga,04,28230,-4.240833,-69.942222
br,tabatinga,Tabatinga,05,,-13.966667,-38.933333
br,tabatinga,Tabatinga,06,,-3.95,-38.7
br,tabatinga,Tabatinga,13,,-3.3,-43.2
br,tabatinga,Tabatinga,15,,-14.766667,-43.633333
br,tabatinga,Tabatinga,22,,-5.315278,-36.754444
br,tabatinga,Tabatinga,27,11617,-21.716667,-48.683333
br,tabauna,Tabaúna,15,,-19.516667,-41.316667
br,taberoe,Taberoê,05,,-13.7,-39.1
br,tabira,Tabira,30,16926,-7.583333,-37.55
br,taboado,Taboado,05,,-10.8025,-45.940556
br,taboao da serra,Taboão da Serra,27,214527,-23.6,-46.766667
br,taboao,Taboão,15,,-21.983333,-44.033333
br,taboao,Taboão,26,,-27.2,-49.583333
br,taboas,Taboas,21,,-22.208333,-43.625278
br,taboa,Tabôa,05,,-11.083333,-41.083333
br,taboa,Taboa,11,,-20.966667,-57.733333
br,tabocais,Tabocais,15,,-19.216667,-45.316667
br,tabocal grande,Tabocal Grande,20,,-3.905278,-42.440556
br,tabocal,Tabocal,01,,-8.733333,-72.833333
br,tabocal,Tabocal,04,,-3.116667,-58.15
br,tabocal,Tabocal,16,,-3.016667,-55.1
br,tabocas,Tabocas,05,,-11.4,-41.183333
br,tabocas,Tabocas,08,,-19.933333,-40.7
br,tabocas,Tabocas,13,,-3.041667,-43.13
br,tabocas,Tabocas,15,,-19.216667,-45.316667
br,tabocas,Tabocas,20,,-3.780556,-42.532222
br,tabocas,Tabocas,30,,-7.416667,-39.833333
br,tabocas,Tabocas,31,,-10.916667,-47.35
br,taboca,Taboca,01,,-8.95,-71.666667
br,taboca,Taboca,04,,-1.75,-65.8
br,taboca,Taboca,05,,-12.983333,-39.3
br,taboca,Taboca,06,,-6.766667,-40.566667
br,taboca,Taboca,13,,-3.138056,-42.768889
br,taboca,Taboca,20,,-5.45,-41.433333
br,taboca,Taboca,27,,-20.416667,-47.916667
br,taboco,Taboco,11,,-20.083333,-55.616667
br,taboinha,Taboinha,05,,-13.65,-43.183333
br,taboleira,Taboleira,06,,-5.25,-38.116667
br,taboleiro alto,Taboleiro Alto,05,,-10.05,-42.216667
br,taboleiro alto,Taboleiro Alto,15,,-15.3,-42.183333
br,taboleiro comprido,Taboleiro Comprido,30,,-8.45,-38.533333
br,taboleiro d'area,Taboleiro d'Area,06,,-5.25,-38.116667
br,taboleiro de areia,Taboleiro de Areia,06,,-5.25,-38.116667
br,taboleiro do castro,Taboleiro do Castro,05,,-12.933333,-39.4
br,taboleiro grande,Taboleiro Grande,06,,-3.166667,-40.133333
br,taboleiro,Taboleiro,04,,-5.083333,-58.466667
br,taboleiro,Taboleiro,05,,-12.933333,-39.4
br,taboleiro,Taboleiro,06,,-2.816667,-40.283333
br,taboleiro,Taboleiro,15,,-21.366667,-43.25
br,taboleiro,Taboleiro,20,,-7.25,-40.8
br,taboleri,Taboleri,06,,-4.45,-38.683333
br,taboquinhas,Taboquinhas,05,,-14.35,-39.15
br,taboquinha,Taboquinha,04,,-3.017222,-61.664722
br,taboquinha,Taboquinha,11,,-21.366667,-56.766667
br,taboquinha,Taboquinha,13,,-3.664444,-43.190278
br,taboquinho,Taboquinho,11,,-21.366667,-56.766667
br,taborda,Taborda,22,,-5.966667,-35.25
br,tabuada,Tabuada,05,,-10.8025,-45.940556
br,tabua do reduto,Tábua do Reduto,22,,-5.133333,-35.683333
br,tabuado,Tabuado,28,,-10.3,-37.366667
br,tabual,Tabual,15,,-16.45,-43.6
br,tabuao da serra,Tabuão da Serra,27,,-23.6,-46.766667
br,tabuao sao lourenco,Tabuão São Lourenço,26,,-26.1179,-49.9074
br,tabuao,Tabuão,15,,-21.983333,-44.033333
br,tabuao,Tabuão,18,,-25.9675,-49.3645
br,tabuao,Tabuão,26,,-27.2,-49.583333
br,tabuao,Tabuão,27,,-22.875565,-45.002068
br,tabuas,Tábuas,15,,-16.5,-43.833333
br,tabuas,Tábuas,21,,-22.208333,-43.625278
br,tabua,Tábua,05,,-10.15,-43.766667
br,tabua,Tábua,15,,-14.516667,-43.916667
br,tabua,Tábua,20,,-5.8,-41.35
br,tabua,Tábua,21,,-21.5,-41.75
br,tabua,Tábua,22,,-5.483333,-35.5
br,tabuinha,Tabuinha,05,,-13.65,-43.183333
br,tabuleirao,Tabuleirão,13,,-8.353611,-45.699722
br,tabuleirinho,Tabuleirinho,06,,-2.95,-40.133333
br,tabuleirinho,Tabuleirinho,20,,-3.895556,-42.191944
br,tabuleirinho,Tabuleirinho,22,,-5.566667,-35.933333
br,tabuleiro alto,Tabuleiro Alto,15,,-15.3,-42.183333
br,tabuleiro alto,Tabuleiro Alto,30,,-7.95,-38.133333
br,tabuleiro bom,Tabuleiro Bom,20,,-7.35,-43.066667
br,tabuleiro comprido,Tabuleiro Comprido,30,,-8.45,-38.533333
br,tabuleiro da peruca,Tabuleiro da Peruca,06,,-5.45,-39.716667
br,tabuleiro das navalhas,Tabuleiro das Navalhas,05,,-12.8,-38.933333
br,tabuleiro da vitoria,Tabuleiro da Vitória,05,,-12.7,-39.1
br,tabuleiro de baixo,Tabuleiro de Baixo,17,,-6.35,-37.583333
br,tabuleiro de dentro,Tabuleiro de Dentro,06,,-6.6,-38.666667
br,tabuleiro de dentro,Tabuleiro de Dentro,20,,-3.720556,-42.276944
br,tabuleiro do baie,Tabuleiro do Baié,06,,-7.016667,-39.766667
br,tabuleiro do barreto,Tabuleiro do Barreto,22,,-5.483333,-35.6
br,tabuleiro do batista,Tabuleiro do Batista,13,,-3.935833,-43.413333
br,tabuleiro do castro,Tabuleiro do Castro,05,,-12.933333,-39.4
br,tabuleiro do meio,Tabuleiro do Meio,17,,-6.966667,-38.1
br,tabuleiro do norte,Tabuleiro do Norte,06,16633,-5.25,-38.116667
br,tabuleiro grande,Tabuleiro Grande,05,,-13.083333,-39.533333
br,tabuleiro grande,Tabuleiro Grande,06,,-5.466667,-38.783333
br,tabuleiro grande,Tabuleiro Grande,20,,-9.8,-44.633333
br,tabuleiro grande,Tabuleiro Grande,22,,-5.933333,-38.05
br,tabuleiro,Tabuleiro,04,,-5.083333,-58.466667
br,tabuleiro,Tabuleiro,05,,-12.45,-38.983333
br,tabuleiro,Tabuleiro,06,,-5.25,-38.116667
br,tabuleiro,Tabuleiro,13,,-3.733056,-43.458611
br,tabuleiro,Tabuleiro,14,,-7.7,-58.166667
br,tabuleiro,Tabuleiro,15,,-18.25,-42.6
br,tabuleiro,Tabuleiro,16,,-7.916667,-57.533333
br,tabuleiro,Tabuleiro,17,,-7.383333,-38.1
br,tabuleiro,Tabuleiro,20,,-3.546389,-42.297222
br,tabuleiro,Tabuleiro,22,,-5.25,-35.666667
br,tabuleiro,Tabuleiro,23,,-30.9,-54.1
br,tabuleiro,Tabuleiro,26,,-26.6193,-48.716
br,tabuleiro,Tabuleiro,28,,-9.666667,-37.8
br,tabuo,Tabuo,27,,-23.4212,-46.2398
br,tabu,Tabu,30,,-7.883333,-35.833333
br,tacaia,Tacaia,05,,-13.533333,-40.483333
br,tacaimbe,Tacaimbé,30,,-8.316667,-36.3
br,tacaimbo,Tacaimbó,30,,-8.316667,-36.3
br,tacale,Tacalé,16,,1.616667,-54.783333
br,tacanha grande,Tacanha Grande,05,,-13.266667,-39.35
br,tacanha,Tacanha,05,,-13.233333,-39.333333
br,tacaratu,Tacaratu,30,,-9.1,-38.166667
br,tacare,Tacaré,05,,-12.916667,-39.716667
br,tacema,Tacema,06,,-5.8,-38.3
br,tachama,Tachama,05,,-13.033333,-39.716667
br,tacho,Tacho,15,,-21.566667,-45.3
br,taciateua,Taciateua,16,,-1.316667,-47.433333
br,taciba,Taciba,27,,-22.383333,-51.3
br,tacihua,Tacihua,04,,-5.083333,-60.366667
br,tacima,Tacima,17,,-6.5,-35.65
br,tacimirim,Tacimirim,05,,-12.65,-38.05
br,tacitateua,Tacitatéua,16,,-1.316667,-47.433333
br,taciua,Taciuã,04,,-5.083333,-60.366667
br,tacuapiri,Tacuapiri,11,,-23.216667,-55.416667
br,tacuarichim,Tacuarichim,23,,-29.533333,-54.583333
br,tacururutendi,Tacururutendí,11,,-23.716667,-54.783333
br,tacuru,Tacuru,11,,-23.633333,-55.016667
br,tacuru tandi,Tacurú Tandi,11,,-23.716667,-54.783333
br,tacuru tandy,Tacurú Tandy,11,,-23.716667,-54.783333
br,tadelandia,Tadelândia,21,,-21.9,-41.933333
br,taderinha,Taderinha,16,,-2.533333,-54.283333
br,tadeu,Tadeu,29,,-17.233333,-53.05
br,tafona,Tafona,11,,-20.566667,-56.6
br,tafu,Tafu,21,,-22.083333,-41.416667
br,tagacaba de cima,Tagaçaba de Cima,18,,-25.200974,-48.531986
br,tagacaba,Tagaçaba,18,,-25.193415,-48.533022
br,tagi,Tagi,11,,-22.783333,-55.383333
br,tagi,Tagi,20,,-8.733333,-45.866667
br,taguai,Taguaí,27,,-23.45,-49.416667
br,taguaje,Taguajé,18,,-22.616667,-51.983333
br,taguapiri,Taguapiri,11,,-23.216667,-55.416667
br,taguaracu,Taguaraçu,15,,-19.666667,-43.683333
br,taguariaiva,Taguariaiva,27,,-23.933333,-48.683333
br,taguarussu,Taguarussú,15,,-19.666667,-43.683333
br,tagua,Taguá,05,,-11.733333,-44.516667
br,taguatinga,Taguatinga,31,9330,-12.465556,-46.366944
br,tahim,Tahim,23,,-32.5,-52.583333
br,taiacui,Taiaçuí,17,,-6.183333,-37.533333
br,taiacupeba,Taiaçupeba,27,,-23.666667,-46.183333
br,taiacu,Taiaçu,27,,-21.15,-48.533333
br,taiama,Taiama,11,,-18.283333,-55.5
br,taiba,Taíba,06,,-3.5,-38.9
br,taimbe,Taimbé,23,,-29.7714,-50.9892
br,taimbe,Taimbé,27,,-22.7,-47.5
br,taim,Taim,23,,-32.5,-52.583333
br,tainhas,Tainhas,23,,-29.266667,-50.3
br,taiobeiras,Taiobeiras,15,24351,-15.816667,-42.233333
br,taio,Taió,18,,-25.6294,-50.2931
br,taio,Taió,26,,-27.1,-49.983333
br,taipas de pedras,Taipas de Pedras,27,,-23.565606,-47.054599
br,taipas do tocantins,Taipas do Tocantins,31,,-12.251389,-46.891667
br,taipas,Taipas,31,,-12.251389,-46.891667
br,taipinha,Taipinha,23,,-28.866667,-52.533333
br,taipoca,Taipoca,05,,-13.016667,-38.616667
br,taipu,Taipu,05,,-12.633333,-38.083333
br,taipu,Taipú,17,,-7.25,-35.216667
br,taipu,Taipu,22,4606,-5.616667,-35.6
br,taireta,Tairetá,21,,-22.6,-43.7
br,tairucu,Tairuçu,31,,-10.791111,-48.006667
br,taitinga,Taitinga,05,,-12.983333,-39.133333
br,taititu,Taititu,04,,-4.360833,-66.539722
br,taiuva,Taiuva,27,,-21.133333,-48.45
br,tajatuba,Tajatuba,13,,-3.916667,-44.933333
br,taji,Taji,20,,-8.733333,-45.866667
br,tajuaba,Tajuaba,13,,-2.65,-43.95
br,talarem,Talarem,11,,-22.616667,-55.283333
br,talha da caatinga,Talha da Caatinga,02,,-9.4,-37.45
br,talhada,Talhada,02,,-9.4,-37.433333
br,talhada,Talhada,30,,-8.516667,-38.95
br,talhado,Talhado,02,,-9.4,-37.433333
br,talhado,Talhado,17,,-7.633333,-38.3
br,talhado,Talhado,20,,-3.718889,-42.26
br,talhado,Talhado,22,,-5.4125,-37.014444
br,talhado,Talhado,27,,-20.716667,-49.3
br,talima,Talimã,16,,1.966667,-55
br,talisma,Talismã,17,,-6.516667,-37.483333
br,tamanca,Tamanca,05,,-12.116667,-38.766667
br,tamanco,Tamanco,05,,-12.116667,-38.766667
br,tamandare,Tamandaré,04,,-3.7,-62.283333
br,tamandare,Tamandaré,05,,-14.633333,-42.3
br,tamandare,Tamandare,06,,-5.083333,-40.216667
br,tamandare,Tamandaré,14,,-16.083333,-55.866667
br,tamandare,Tamandaré,18,,-25.3,-49.316667
br,tamandare,Tamandaré,23,,-28.1,-52.916667
br,tamandare,Tamandaré,30,17954,-8.75,-35.1
br,tamandua,Tamanduá,02,,-9.816667,-36.483333
br,tamandua,Tamanduá,04,,-6.383333,-64.283333
br,tamandua,Tamanduá,05,,-13.216667,-40.633333
br,tamandua,Tamanduá,06,,-3.333333,-39.4
br,tamandua,Tamanduá,13,,-5.65,-43.166667
br,tamandua,Tamanduá,14,,-16.7,-55.8
br,tamandua,Tamanduá,15,,-16.6,-43.683333
br,tamandua,Tamanduá,17,,-7.066667,-38.5
br,tamandua,Tamanduá,18,,-25.533333,-52.55
br,tamandua,Tamanduá,20,,-4.1,-42.8
br,tamandua,Tamanduá,23,,-29.266667,-53.016667
br,tamandua,Tamanduá,26,,-26.583333,-50.583333
br,tamandua,Tamanduá,27,,-21.916667,-47.616667
br,tamandua,Tamanduá,28,,-10.233333,-37.2
br,tamandua,Tamanduá,30,,-7.9,-38.133333
br,tamaniqua,Tamaniquá,04,,-2.633333,-65.733333
br,tamanoua,Tamanouá,20,,-5.216667,-42.35
br,tamanqueira,Tamanqueira,16,,-4.166667,-56.366667
br,tamaquari,Tamaquarí,04,,1.033333,-69.25
br,tamarana,Tamarana,18,,-23.683333,-51.1
br,tamarati,Tamarati,02,,-9.883333,-37.183333
br,tamarindo,Tamarindo,13,,-3.326111,-43.106111
br,tamarindo,Tamarindo,20,,-2.988333,-41.405
br,tamarineiro,Tamarineiro,14,,-15.366667,-59.966667
br,tambahu,Tambahú,27,,-21.7,-47.266667
br,tambaqui,Tambaqui,03,,-.716667,-51.683333
br,tambaqui,Tambaqui,04,,-2.816667,-67.016667
br,tambari,Tambari,06,,-4.833333,-40.333333
br,tambau,Tambaú,17,,-7.116667,-34.816667
br,tambau,Tambaú,27,19957,-21.7,-47.266667
br,tambauzinho,Tambauzinho,17,,-6.998333,-34.875
br,tambequi,Tambequi,04,,-5.240556,-62.805278
br,tambe,També,30,,-7.416667,-35.1
br,tamboara,Tamboara,18,,-23.15,-52.55
br,tamboata,Tamboatá,30,,-7.816667,-35.7
br,tamboral,Tamboral,20,,-6.983333,-42.5
br,tambores,Tambores,30,,-8.5,-36.816667
br,tamboril grosso,Tamboril Grosso,13,,-3.911667,-43.237778
br,tamboril,Tamboril,05,,-10.6,-43.583333
br,tamboril,Tamboril,06,14292,-4.833333,-40.333333
br,tamboril,Tamboril,13,,-3.081111,-42.263056
br,tamboril,Tamboril,15,,-15.95,-43.833333
br,tamboril,Tamboril,20,,-3.995833,-42.248611
br,tamboril,Tamboril,30,,-7.8,-37.516667
br,tamborilzinho,Tamborilzinho,15,,-16.583889,-44.166944
br,tamborilzinho,Tamborilzinho,20,,-7.3,-40.6
br,tamborou,Tamboroú,05,,-13.233333,-41.766667
br,tambor,Tambor,13,,-3.790556,-43.105556
br,tambor,Tambor,17,,-6.65,-38.966667
br,tambor,Tambor,20,,-3.573611,-42.128611
br,tambor,Tambor,23,,-30.7377,-52.4699
br,tambor,Tambor,30,,-8.166667,-36.616667
br,tamburi,Tamburi,05,,-10.6,-43.583333
br,tamburi,Tamburi,30,,-7.666667,-39.483333
br,tamburi velho,Tamburi Velho,05,,-12.983333,-40.6
br,tambury,Tambury,05,,-13,-40.533333
br,tamoa,Tamoá,11,,-20.966667,-57.733333
br,tamoata,Tamoatá,02,,-9.633333,-36.25
br,tamoios,Tamoios,21,,-22.7,-42.033333
br,tanabi,Tanabi,27,18228,-20.616667,-49.616667
br,tanaby,Tanaby,27,,-20.616667,-49.616667
br,tancredinho,Tancredinho,08,,-19.633333,-40.75
br,tangara,Tangará,22,8067,-6.183333,-35.816667
br,tangara,Tangará,26,,-27.133333,-51.216667
br,tangente,Tangente,06,,-3.416667,-40.383333
br,tangerina,Tangerina,01,,-9.375,-71.095556
br,tangil,Tangil,02,,-9.433333,-36.3
br,tangua,Tanguá,21,23740,-22.733333,-42.716667
br,tangure,Tanguré,06,,-3.483333,-40.483333
br,tanhacu,Tanhaçu,05,6620,-14.016667,-41.283333
br,tanque bravo,Tanque Bravo,05,,-13.933333,-41.766667
br,tanque da pedra,Tanque da Pedra,28,,-9.95,-37.15
br,tanque d'arca,Tanque d'Arca,02,,-9.55,-36.416667
br,tanque d'areia,Tanque d'Areia,02,,-9.55,-36.416667
br,tanque d'arque,Tanque d'Arque,02,,-9.55,-36.416667
br,tanque de areia,Tanque de Areia,17,,-6.566667,-36.25
br,tanque de pedras,Tanque de Pedras,05,,-12.616667,-39.316667
br,tanque de pedra,Tanque de Pedra,28,,-9.95,-37.15
br,tanque de senzala,Tanque de Senzala,05,,-12.383333,-38.816667
br,tanque de terra,Tanque de Terra,20,,-7.516667,-41.466667
br,tanque do barreiro,Tanque do Barreiro,05,,-12.75,-38.933333
br,tanque do boi,Tanque do Boi,30,,-7.75,-37.916667
br,tanque do felipe preto,Tanque do Felipe Preto,13,,-3.770278,-43.039722
br,tanque do lajedo,Tanque do Lajedo,05,,-13.316667,-40.116667
br,tanque do lima,Tanque do Lima,06,,-4.806389,-37.394167
br,tanque do meio,Tanque do Meio,06,,-2.9,-39.966667
br,tanque do podoi,Tanque do Podói,06,,-5.516667,-41.05
br,tanque fundo,Tanque Fundo,14,,-15.933333,-56.233333
br,tanque grande,Tanque Grande,05,,-13.55,-39.966667
br,tanque grande,Tanque Grande,14,,-16.116667,-56.533333
br,tanque novo,Tanque Novo,05,,-10.8,-44.1
br,tanque novo,Tanque Novo,14,,-16.266667,-56.75
br,tanque novo,Tanque Novo,20,,-6.883333,-40.75
br,tanque novo,Tanque Novo,28,,-11.116667,-37.833333
br,tanques,Tanques,06,,-3.266667,-39.566667
br,tanques,Tanques,15,,-18.083333,-45.616667
br,tanques,Tanques,22,,-5.166667,-37.033333
br,tanques,Tanques,30,,-7.633333,-37.566667
br,tanque,Tanque,02,,-9.183333,-37.35
br,tanque,Tanque,05,,-10.233333,-41.716667
br,tanque,Tanque,06,,-4.083333,-38.783333
br,tanque,Tanque,08,,-20.5,-40.483333
br,tanque,Tanque,13,,-3.593056,-43.303056
br,tanque,Tanque,14,,-15.183333,-60.383333
br,tanque,Tanque,15,,-16.05,-46.5
br,tanque,Tanque,18,,-24.860625,-48.795997
br,tanque,Tanque,20,,-5.516667,-42.133333
br,tanque,Tanque,21,,-22.914763,-43.357578
br,tanque,Tanque,22,,-5.983333,-35.666667
br,tanque,Tanque,29,,-13.016667,-49.1
br,tanque velho,Tanque Velho,05,,-9.416667,-42.35
br,tanquinho de baixo,Tanquinho de Baixo,30,,-9.25,-37.133333
br,tanquinho de cima,Tanquinho de Cima,30,,-9.25,-37.15
br,tanquinho novo,Tanquinho Novo,20,,-3.976944,-42.538611
br,tanquinhos,Tanquinhos,22,,-5.816667,-35.9
br,tanquinho,Tanquinho,05,,-10.783333,-39.533333
br,tanquinho,Tanquinho,06,,-7.016667,-40.283333
br,tanquinho,Tanquinho,20,,-3.963889,-42.554444
br,tanquinho,Tanquinho,22,,-6.083333,-37.766667
br,tanquinho,Tanquinho,27,,-22.566667,-47.6
br,tanquinho,Tanquinho,30,,-9.233333,-37.133333
br,tanquiuho,Tanquiuho,05,,-12.566667,-42.25
br,tapada,Tapada,30,,-7.983333,-35.95
br,tapagem,Tapagem,04,,-4.1175,-59.915833
br,tapagem,Tapagem,05,,-13.966667,-41.166667
br,tapagem,Tapagem,13,,-3.872222,-43.491389
br,tapagem,Tapagem,20,,-7.466667,-41.85
br,tapaiuna,Tapaiuna,25,,-2.566667,-60.833333
br,tapajos,Tapajos,06,,-5.316667,-39.183333
br,tapana,Tapanã,16,,-1.333333,-48.483333
br,tapa-olho,Tapa-Ôlho,29,,-13.716667,-47.25
br,tapara,Tapará,16,,-1.633333,-52.083333
br,taparuba,Taparuba,15,,-19.75,-41.616667
br,tapa,Tapa,14,,-16.316667,-56.7
br,tapaua,Tapauá,04,13211,-5.620278,-63.1875
br,tapecu,Tapecu,08,,-20.083333,-40.4
br,tapejara,Tapejara,18,10726,-23.683333,-52.883333
br,tapejara,Tapejara,23,14064,-28.066667,-52
br,taperaba,Taperaba,03,,.083333,-51.966667
br,tapera camaiore,Tapera Camaioré,14,,-14.633333,-58.55
br,tapera chico antonio,Tapera Chico Antonio,14,,-14.7,-57.283333
br,tapera curare,Tapera Curaré,16,,-3.383333,-51.916667
br,tapera da aldeia piquirizal,Tapera da Aldeia Piquirizal,14,,-13.666667,-55.066667
br,tapera da lagoa,Tapera da Lagoa,27,,-23.8224,-46.7444
br,tapera da pedroso,Tapera da Pedroso,11,,-17.283333,-55.35
br,tapera de cima,Tapera de Cima,06,,-4.533333,-40.883333
br,tapera de parecis,Tapera de Parecis,14,,-14.233333,-56.766667
br,tapera de sao joaquim,Tapera de São Joaquim,02,,-9.966667,-36.633333
br,tapera do jeronimo,Tapera do Jerônimo,16,,.816667,-55.8
br,tapera do mathias,Tapera do Mathias,14,,-14.583333,-58.383333
br,tapera do matias,Tapera do Matias,14,,-14.583333,-58.383333
br,tapera do pedroao,Tapera do Pedroao,11,,-17.283333,-55.35
br,tapera do pedroso,Tapera do Pedroso,11,,-17.283333,-55.35
br,tapera do pedrozo,Tapera do Pedrozo,11,,-17.283333,-55.35
br,tapera do pindahyval,Tapera do Pindahyval,14,,-17.083333,-56.216667
br,tapera do pindaival,Tapera do Pindaìval,14,,-17.083333,-56.216667
br,tapera do retiro,Tapera do Retiro,24,,-9.8,-61.966667
br,tapera do valerio,Tapera do Valerio,14,,-17.316667,-55.866667
br,tapera do vicente,Tapera do Vicente,11,,-18.316667,-55.666667
br,tapera espirito santo,Tapera Espírito Santo,14,,-16.766667,-55.533333
br,taperao,Taperão,15,,-19.15,-48.75
br,tapera pequerizal,Tapera Pequerizal,14,,-13.666667,-55.066667
br,tapera pesoe,Tapera Pesoe,14,,-15.133333,-60.466667
br,tapera queimada,Tapera Queimada,23,,-29.8183,-51.47
br,tapera quinca de santana,Tapera Quinca de Santana,11,,-17.333333,-55.366667
br,tapera quinea do sao anna,Tapera Quinea do Sao Anna,11,,-17.333333,-55.366667
br,tapera rivani,Tapera Rivani,14,,-14.75,-58.05
br,tapera sao jose,Tapera São José,11,,-20.933333,-56.366667
br,tapera sertao de febre,Tapera Sertão de Febre,14,,-16.7,-55.283333
br,tapera,Tapera,02,,-10.15,-36.8
br,tapera,Tapera,04,,-.183333,-64.066667
br,tapera,Tapera,05,,-12.333333,-38.95
br,tapera,Tapera,06,,-3.55,-40.266667
br,tapera,Tapera,08,,-20.333333,-41.1
br,tapera,Tapera,11,,-22.2,-57.033333
br,tapera,Tapera,13,,-6.266667,-43.916667
br,tapera,Tapera,14,,-15.133333,-60.466667
br,tapera,Tapera,15,,-20.0015,-43.9417
br,tapera,Tapera,17,,-6.566667,-38.566667
br,tapera,Tapera,18,,-25.457392,-48.609617
br,tapera,Tapera,20,,-3.493056,-42.388056
br,tapera,Tapera,21,,-21.75,-41.816667
br,tapera,Tapera,22,,-5.483333,-35.533333
br,tapera,Tapera,23,,-28.133333,-51.183333
br,tapera,Tapera,25,,-.531667,-61.795556
br,tapera,Tapera,26,,-26.2706,-48.6073
br,tapera,Tapera,30,,-7.866667,-37.866667
br,tapera velha,Tapera Velha,06,,-3.133333,-40.133333
br,tapera vivani,Tapera Vivani,14,,-14.75,-58.05
br,tapereba,Taperebá,03,,3.65,-51.2
br,taperinha,Taperinha,06,,-5.016667,-39.95
br,taperinha,Taperinha,16,,-2.533333,-54.283333
br,taperoa,Taperoá,05,8095,-13.516667,-39.1
br,taperoa,Taperoá,17,8879,-7.2,-36.816667
br,taperuaba,Taperuaba,06,,-4.05,-39.916667
br,taperua,Taperuá,05,,-13.516667,-39.1
br,tapes,Tapes,23,18570,-30.666667,-51.383333
br,tape,Tape,05,,-13.133333,-41.816667
br,tapiara,Tapiará,04,,-7.2,-72.75
br,tapiira,Tapiira,04,,-3.906944,-62.558889
br,tapinas,Tapinas,27,,-21.45,-48.816667
br,tapiracanga,Tapiracanga,05,,-12.3,-44.533333
br,tapiraim,Tapiraim,30,,-8.416667,-36.166667
br,tapiraipe,Tapiraípe,05,,-12.216667,-40.75
br,tapirai,Tapiraí,15,,-19.866667,-46.016667
br,tapirai,Tapiraí,27,,-23.95,-47.483333
br,tapirama,Tapirama,05,,-14.2,-39.6
br,tapiramuta,Tapiramutá,05,16549,-11.85,-40.783333
br,tapiranga,Tapiranga,05,,-11.433333,-40.4
br,tapirapoa,Tapirapoã,14,,-14.85,-57.75
br,tapirapua,Tapirapuã,14,,-14.85,-57.75
br,tapira,Tapira,04,,1.383333,-68.016667
br,tapira,Tapira,15,,-19.916667,-46.816667
br,tapira,Tapira,17,,-6.95,-34.916667
br,tapiratiba,Tapiratiba,27,,-21.466667,-46.75
br,tapiruaba,Tapiruaba,06,,-4.05,-39.916667
br,tapirussu,Tapirussu,15,,-21.466667,-42.366667
br,tapiru,Tapiru,04,,-6.05,-64.216667
br,tapora,Tapora,02,,-9.95,-37.083333
br,tapuiara,Tapuiará,06,,-5.1,-38.916667
br,tapuias,Tapuias,05,,-13.566667,-38.983333
br,tapuia,Tapuia,02,,-9.533333,-36.216667
br,tapuia,Tapuia,05,,-14.1,-39.083333
br,tapuia,Tapuía,06,,-3.25,-39.966667
br,tapuia,Tapuia,13,,-9.85,-46.133333
br,tapuio,Tapuio,02,,-9.05,-37.466667
br,tapuio,Tapuio,06,,-4.433333,-37.916667
br,tapuio,Tapuio,13,,-6.6,-44.666667
br,tapuio,Tapuio,17,,-7.033333,-38.133333
br,tapuio,Tapuio,20,,-5.5,-41.333333
br,tapuio,Tapuio,22,,-5.801389,-36.410556
br,tapuio,Tapuio,30,,-7.766667,-37.366667
br,tapuirama,Tapuirama,15,,-19.15,-47.916667
br,tapui,Tapuí,18,,-25.133333,-52.983333
br,tapuracuara,Tapuracuara,04,,-.4,-65.033333
br,tapurucuara,Tapurucuara,04,,-.4,-65.033333
br,tapuruquara,Tapuruquára,04,,-.4,-65.033333
br,tapuruqua,Tapuruquá,04,,-.4,-65.033333
br,tapuru,Tapuru,04,,-4.305556,-61.775833
br,tapyra,Tapyra,15,,-19.916667,-46.816667
br,taquanduva,Taquanduva,18,,-25.353134,-48.476404
br,taquapary,Taquapary,11,,-23.216667,-55.416667
br,taquaperi,Taquaperi,11,,-23.216667,-55.416667
br,taquapery,Taquapery,11,,-23.216667,-55.416667
br,taquapiri,Taquapiri,11,,-23.216667,-55.416667
br,taquaracu,Taquaraçu,15,,-19.666667,-43.683333
br,taquaracu,Taquaraçu,23,,-27.4,-53.466667
br,taquara da tijuca,Taquara da Tijuca,21,,-22.968606,-43.297239
br,taquara lisa,Taquara Lisa,18,,-23.768215,-50.162376
br,taquaral,Taquaral,08,,-19.866667,-40.95
br,taquaral,Taquaral,11,,-20.716667,-56.166667
br,taquaral,Taquaral,14,,-15.966667,-56.316667
br,taquaral,Taquaral,15,,-18.883333,-42.85
br,taquaral,Taquaral,18,,-23.2807,-50.1629
br,taquaral,Taquaral,21,,-21.516667,-41.85
br,taquaral,Taquaral,24,,-9.933333,-65.316667
br,taquaral,Taquaral,27,,-20.55,-47.266667
br,taquaral,Taquaral,29,,-14.583333,-49.183333
br,taquaralto,Taquaralto,31,,-10.371389,-48.208333
br,taquaralzinho,Taquaralzinho,11,,-20.716667,-56.166667
br,taquaralzinho,Taquaralzinho,14,,-14.866667,-55.916667
br,taquaralzinho,Taquaralzinho,18,,-23.2557,-50.1622
br,taquarana,Taquarana,02,5288,-9.633333,-36.483333
br,taquarandi,Taquarandi,05,,-10.916667,-40.65
br,taquarassu,Taquarassú,15,,-19.666667,-43.683333
br,taquaras,Taquaras,08,,-18.066667,-40.15
br,taquaras,Taquaras,24,,-9.933333,-65.316667
br,taquara,Taquara,02,,-9.366667,-36.533333
br,taquara,Taquara,04,,.666667,-66.85
br,taquara,Taquara,05,,-13.05,-41.616667
br,taquara,Taquara,06,,-3.816667,-38.683333
br,taquara,Taquara,08,,-18.066667,-40.15
br,taquara,Taquara,16,,-5.283333,-56.75
br,taquara,Taquara,17,,-7.5,-34.85
br,taquara,Taquará,18,,-23.533333,-50.75
br,taquara,Taquara,21,,-22.925763,-43.379772
br,taquara,Taquara,23,48052,-29.65,-50.783333
br,taquara,Taquara,24,,-9.933333,-65.316667
br,taquara,Taquarã,31,,-10.95,-47.2
br,taquarati,Taquarati,27,,-24.552545,-48.145518
br,taquara verde,Taquara Verde,26,,-26.716667,-51.2
br,taquarembo,Taquarembó,23,,-29.383333,-53.683333
br,taquaretinga,Taquaretinga,30,,-7.9,-36.05
br,taquariaiva,Taquariaiva,27,,-23.933333,-48.683333
br,taquarichim,Taquarichim,23,,-29.533333,-54.583333
br,taquari de baixo,Taquari de Baixo,18,,-25.2372,-48.928165
br,taquaril,Taquaril,05,,-12.933333,-42.833333
br,taquarinhas,Taquarinhas,05,,-17.95,-40.2
br,taquarinha,Taquarinha,05,,-17.95,-40.2
br,taquarinha,Taquarinha,15,,-21.366667,-46.25
br,taquari,Taquari,01,,-9.873611,-67.910278
br,taquari,Taquari,05,,-12.6,-41.666667
br,taquari,Taquari,14,,-17.833333,-53.283333
br,taquari,Taquari,18,,-25.23084,-48.931496
br,taquari,Taquari,20,,-3.980833,-42.279722
br,taquari,Taquari,23,27108,-29.8,-51.85
br,taquari,Taquari,27,,-22.116667,-47.283333
br,taquari,Taquari,30,,-7.566667,-36.433333
br,taquari,Taquari,31,,-10.366667,-48.3
br,taquaritinga do norte,Taquaritinga do Norte,30,13379,-7.9,-36.05
br,taquaritinga,Taquaritinga,27,50099,-21.4,-48.5
br,taquaritinga,Taquaritinga,30,,-7.9,-36.05
br,taquarituba,Taquarituba,27,21493,-23.516667,-49.25
br,taquarivai,Taquarivaí,27,,-23.933333,-48.683333
br,taquarucu,Taquaruçu,11,,-20.716667,-56.516667
br,taquarucu,Taquaruçu,14,,-15.533333,-55.6
br,taquarucu,Taquaruçu,18,,-25.033333,-50.333333
br,taquarucu,Taquaruçu,27,,-24.544903,-48.889961
br,taquarussu do porto,Taquarussu do Porto,31,,-10.362778,-48.043889
br,taquarussu,Taquarussú,15,,-19.666667,-43.683333
br,taquary,Taquary,05,,-17.633333,-39.316667
br,taquary,Taquary,08,,-20.333333,-40.366667
br,taquary,Taquary,23,,-29.8,-51.85
br,taquary,Taquary,27,,-23.516667,-49.25
br,taquiri,Taquiri,06,,-7.55,-39.283333
br,tarabai,Tarabaí,27,,-22.3,-51.55
br,taracua,Taracua,04,,.1,-68.466667
br,tarame,Tarame,25,,3.65,-61.05
br,taraqua,Taraquá,04,,1.216667,-68.833333
br,tara,Tará,30,,-8.716667,-36.866667
br,tarauaca,Tarauacá,01,16526,-8.166667,-70.766667
br,tara velho,Tará Velho,30,,-8.666667,-36.816667
br,tareco,Tareco,05,,-11.416667,-41.366667
br,targinos,Targinos,06,,-4.616667,-39.283333
br,tariana,Tariana,04,,.266667,-68.616667
br,tariiman,Tariiman,11,,-19.233333,-57.7
br,tariquinho,Tariquinho,06,,-5.466667,-39.4
br,tarituba,Tarituba,21,,-23.033333,-44.583333
br,tarquinho,Tarquinho,05,,-9.433333,-41.383333
br,tarrafas,Tarrafas,06,,-6.683333,-39.766667
br,tarrafa,Tarrafa,17,,-7.666667,-36.133333
br,tarra vermelha,Tarra Vermelha,31,,-11.883333,-47
br,tartarem,Tartarem,11,,-22.616667,-55.283333
br,tartarugal grande,Tartarugal Grande,03,,1.4,-50.916667
br,tartarugalzinho,Tartarugalzinho,03,,1.516667,-50.9
br,tartaruga,Tartaruga,04,,-5.864167,-64.460278
br,tartaruga,Tartaruga,05,,-12.983333,-39.65
br,taruacu,Taruaçu,15,,-19.3,-42.083333
br,taru assu,Tarú Assú,15,,-21.616667,-42.933333
br,taruman,Taruman,11,,-19.233333,-57.7
br,taruma,Tarumã,04,,-2.9825,-60.054722
br,taruma,Tarumá,11,,-19.116667,-57.216667
br,taruma,Tarumã,27,10337,-22.75,-50.566667
br,tarumirim,Tarumirim,15,,-19.266667,-41.983333
br,tasso jobim,Tasso Jobim,23,,-29.9186,-50.7722
br,tataguacu,Tataguaçu,17,,-7.35,-35.916667
br,tataira,Tataira,06,,-5.8,-39.25
br,tataira,Tataíra,13,,-3.554167,-43.189722
br,tataira,Tataíra,17,,-7.2,-37.066667
br,tataira,Tataíra,29,,-13.1,-49.966667
br,tatajuba,Tatajuba,01,,-7.9,-72.766667
br,tatajuba,Tatajuba,06,,-2.856389,-40.683333
br,tatajuba,Tatajuba,20,,-5.316667,-41.8
br,tatarem,Tatarem,11,,-22.616667,-55.283333
br,tateco,Tateco,18,,-26.216667,-53.25
br,tateto,Tateto,18,,-24.918263,-48.684047
br,tatuamunha,Tatuamunha,02,,-9.233333,-35.35
br,tatu bola,Tatu Bola,22,,-6.583333,-37.133333
br,tatuhy,Tatuhy,27,,-23.346655,-47.848368
br,tatui,Tatuí,27,93582,-23.346655,-47.848368
br,tatupeba,Tatupeba,18,,-24.73009,-48.770188
br,tatuquara,Tatuquara,18,,-25.566667,-49.3
br,tatu,Tatu,05,,-12.833333,-41.616667
br,tatu,Tatu,20,,-6.283333,-41.55
br,tatu,Tatu,21,,-22.083333,-41.416667
br,tatu,Tatu,22,,-6.4,-38.066667
br,tatu,Tatu,25,,3.55,-60.4
br,tatu,Tatu,28,,-10.383333,-36.733333
br,tatutiva dois,Tatutiva Dois,26,,-26.7935,-49.1049
br,tatutiva iii,Tatutiva III,26,,-26.767,-49.103
br,tatutiva ii,Tatutiva II,26,,-26.7935,-49.1049
br,tatutiva i,Tatutiva I,26,,-26.8311,-49.1073
br,tatutiva iv,Tatutiva IV,26,,-26.7528,-49.102
br,tatutiva quatro,Tatutiva Quatro,26,,-26.7528,-49.102
br,tatutiva tres,Tatutiva Tres,26,,-26.767,-49.103
br,tatutiva um,Tatutiva Um,26,,-26.8311,-49.1073
br,taua-cana,Taua-cana,04,,.516667,-67.383333
br,taua-miri,Tauá-Miri,04,,-3.633333,-62.383333
br,tauapeacu,Tauapeaçu,04,,-2.616667,-60.95
br,tauapecacu,Tauapeçaçu,04,,-2.616667,-60.95
br,tauapecassu,Tauapeçassú,04,,-2.616667,-60.95
br,tauapessassu,Tauapessassu,04,,-2.616667,-60.95
br,tauape,Tauape,05,,-14.583333,-42.45
br,tauapicaca,Tauapiçaça,04,,-2.616667,-60.95
br,tauapiranga,Tauapiranga,30,,-8.166667,-38.233333
br,tauaquera,Tauaquera,04,,.383333,-64.05
br,tauaria grande,Tauaria Grande,04,,-5.580556,-63.9
br,tauarianzinha,Tauarianzinha,04,,-5.653611,-63.966944
br,tauaria,Tauariá,04,,-5.580556,-63.9
br,tauariazinho,Tauariazinho,04,,-5.653611,-63.966944
br,tauari,Tauari,04,,-.333333,-63.833333
br,tauari,Tauari,16,,-1.116667,-47.066667
br,tauarua,Tauaruã,04,,-7.216667,-64.733333
br,tauary,Tauary,16,,-1.116667,-47.066667
br,taua,Tauá,06,29189,-5.966667,-40.3
br,taua,Tauá,15,,-17.983333,-46.2
br,taua,Tauá,21,,-22.794352,-43.186332
br,tauatuba,Tauatuba,17,,-6.933333,-35.55
br,tauatu,Tauatu,04,,-2.255833,-61.028333
br,taubate,Taubaté,27,251647,-23.033333,-45.55
br,taucapecacu,Taucapeçaçu,04,,-2.616667,-60.95
br,tauha,Tauhá,06,,-6,-40.283333
br,tauha,Tauhá,15,,-17.983333,-46.2
br,tauipe,Tauípe,05,,-12.466667,-38.55
br,taumata,Taumata,17,,-6.733333,-35.3
br,taumaturgo,Taumaturgo,01,,-8.948333,-72.786944
br,tauna,Tauna,26,,-26.083333,-50.416667
br,taunay,Taunay,11,,-20.3,-56.083333
br,taunay,Taunay,26,,-26.083333,-50.416667
br,tauoa,Tauoá,11,,-20.966667,-57.733333
br,tavares,Tavares,13,,-3.968889,-42.863056
br,tavares,Tavares,15,,-19.833333,-44.583333
br,tavares,Tavares,17,4939,-7.633333,-37.9
br,tavares,Tavares,21,,-22.066667,-41.483333
br,tavares,Tavares,23,,-31.2,-51.016667
br,tavares,Tavares,27,,-23.320614,-47.75385
br,taveira,Taveira,06,,-7,-38.816667
br,taveira,Taveira,11,,-19.95,-54.866667
br,taxaquara,Taxaquara,27,,-23.539958,-47.037809
br,taxi do limao,Táxi do Limão,03,,.2,-52.15
br,tayassupeba,Tayassupeba,27,,-23.666667,-46.183333
br,tayassu,Tayassú,27,,-21.15,-48.533333
br,tayobeiras,Tayobeiras,15,,-15.816667,-42.233333
br,tayo,Tayo,26,,-27.1,-49.983333
br,tayuva,Tayuva,27,,-21.133333,-48.45
br,t. barra do guaracu,t. Barra do Guaracu,27,,-24.7956,-48.0414
br,tebaida,Tebaída,05,,-12.033333,-40.6
br,tebas,Tebas,15,,-21.583333,-42.733333
br,tecainda,Teçaindá,27,,-22.016667,-51.066667
br,tecol. sierra madre,Tecol. Sierra Madre,27,,-23.288067,-46.579536
br,tefe,Tefé,04,44943,-3.366667,-64.7
br,teffe,Teffé,04,,-3.366667,-64.7
br,teixeira leite,Teixeira Leite,21,,-22.316667,-43.6
br,teixeira soares,Teixeira Soares,18,,-25.370278,-50.459167
br,teixeiras,Teixeiras,15,,-20.65,-42.85
br,teixeiras,Teixeiras,21,,-22.907588,-43.417869
br,teixeira,Teixeira,01,,-8.5,-70.533333
br,teixeira,Teixeira,05,,-12.433333,-39.233333
br,teixeira,Teixeira,06,,-5.616667,-39.633333
br,teixeira,Teixeira,14,,-14.3,-56.283333
br,teixeira,Teixeira,17,9954,-7.216667,-37.25
br,teixeira,Teixeira,23,,-28.066667,-52
br,teixeiropolis,Teixeirópolis,24,,-10.933333,-62.252222
br,teixera,Teixera,01,,-8.5,-70.533333
br,tejessuoca,Tejessuoca,06,,-4.016667,-39.516667
br,tejipio,Tejipió,06,,-3.233333,-39.416667
br,tejipio,Tejipió,30,,-8.083333,-34.966667
br,tejucopapo,Tejucopapo,30,,-7.6,-34.883333
br,tejuco,Tejuco,15,,-18.25,-43.6
br,tejucuoca,Tejuçuoca,06,,-4.016667,-39.516667
br,tejucupapo,Tejucupapo,30,,-7.6,-34.883333
br,tejupa,Tejupá,27,,-23.35,-49.366667
br,tejussuoca,Tejussuoca,06,,-3.983333,-39.566667
br,telemaco borba,Telêmaco Borba,18,58880,-24.35,-50.616667
br,telemaco guimaraes,Telêmaco Guimarães,15,,-17.65,-41.916667
br,teleporto,Teleporto,21,,-22.910058,-43.20357
br,telha cima,Telha Cima,22,,-5.866667,-35.566667
br,telha,Telha,02,,-9.4,-36.083333
br,telha,Telha,05,,-11.483333,-45.116667
br,telha,Telha,06,,-6.366667,-39.3
br,telha,Telha,13,,-3.541944,-43.256389
br,telha,Telha,30,,-8.133333,-38.633333
br,telheiro,Telheiro,04,,-.033333,-64.016667
br,telmo fontoura,Telmo Fontoura,23,,-29.516667,-55.35
br,tem do,Tem do,17,,-7.2,-37.266667
br,temerante,Temerante,13,,-8.320833,-46.175833
br,tempera,Tempera,13,,-5.316667,-43.2
br,tempero,Tempero,13,,-5.25,-43.166667
br,tendal,Tendal,14,,-15.133333,-56.5
br,tenda,Tenda,20,,-7.816667,-42.566667
br,tenente ananias gomes,Tenente Ananias Gomes,22,,-6.466667,-38.183333
br,tenente ananias,Tenente Ananias,22,,-6.45,-38.166667
br,tenente portela,Tenente Portela,23,,-27.366667,-53.75
br,tenentes,Tenentes,15,,-22.8,-46.333333
br,tenente,Tenente,27,,-20.683333,-51.55
br,tenorio,Tenório,05,,-12.083333,-40.4
br,tenorio,Tenório,17,,-6.933333,-36.616667
br,tenorio,Tenório,30,,-8.05,-37.95
br,tentugal,Tentugal,16,,-1.316667,-46.983333
br,teodimiro,Teodimiro,15,,-15.133333,-45.183333
br,teodorico,Teodorico,30,,-8.733333,-36.883333
br,teodorinho,Teodorinho,15,,-17.233333,-41.133333
br,teodoro alvarenga,Teodoro Alvarenga,15,,-20.7,-45.366667
br,teodoro ribeiro,Teodoro Ribeiro,14,,-17.25,-54.366667
br,teodoro sampaio,Teodoro Sampaio,27,15193,-22.516667,-52.166667
br,teodoros,Teodoros,27,,-22.716667,-45.716667
br,teodoro,Teodoro,20,,-6.566667,-41.35
br,teofilo otoni,Teófilo Otoni,15,101172,-17.85,-41.5
br,teofilo,Teófilo,15,,-18.466667,-48.383333
br,teotonios,Teotônios,30,,-7.666667,-37.766667
br,teotonio,Teotônio,24,,-8.916667,-64
br,tercado,Terçado,25,,3.433333,-60.633333
br,terceira alianca,Terceira Aliança,27,,-20.933333,-51.05
br,terceiro acampamento,Terceiro Acampamento,03,,.75,-53.1
br,terenos,Terenos,11,6086,-20.433333,-54.833333
br,terere-que,Tereré-Qué,11,,-21.883333,-57.866667
br,terere,Tereré,11,,-21.316667,-55.033333
br,teresa cristina,Teresa Cristina,18,,-24.8,-51.116667
br,teresa,Teresa,05,,-13.2,-38.916667
br,teresa,Teresa,13,,-1.983333,-44.55
br,teresa,Teresa,23,,-29.716667,-52.5
br,teresina,Teresina,20,744526,-5.083333,-42.816667
br,teresinha,Teresinha,03,,.966667,-52.033333
br,teresinha,Teresinha,05,,-8.866667,-39.05
br,teresinha,Teresinha,08,,-19.466667,-39.9
br,teresinha,Teresinha,11,,-23.716667,-54.083333
br,teresinha,Teresinha,15,,-20.15,-41.783333
br,teresinha,Teresinha,16,,-2.066667,-49.05
br,teresinha,Teresinha,29,,-14.383333,-49.75
br,teresinha,Teresinha,30,,-9.066667,-36.616667
br,teresopolis,Teresópolis,21,123980,-22.424064,-42.968013
br,teresopolis,Teresópolis,23,,-30.0875,-51.211111
br,teresopolis,Teresópolis,26,,-27.733333,-48.933333
br,tereza cristina,Tereza Cristina,18,,-24.8,-51.116667
br,terezina,Terezina,18,,-24.8,-51.116667
br,terezina,Terezina,20,,-5.083333,-42.816667
br,terezinha,Terezinha,03,,.966667,-52.033333
br,terezinha,Terezinha,05,,-8.866667,-39.05
br,terezinha,Terezinha,08,,-19.466667,-39.9
br,terezinha,Terezinha,11,,-23.716667,-54.083333
br,terezinha,Terezinha,15,,-20.15,-41.783333
br,terezinha,Terezinha,16,,-2.066667,-49.05
br,terezinha,Terezinha,29,,-14.383333,-49.75
br,terezinha,Terezinha,30,,-9.066667,-36.616667
br,termas de ibira,Termas de Ibirá,27,,-21.116667,-49.2
br,termas do ibira,Termas do Ibirá,27,,-21.116667,-49.2
br,termopolis,Termópolis,15,,-20.95,-46.833333
br,ternura,Ternura,31,,-7.6,-48.1
br,terra alta de cima,Terra Alta de Cima,08,,-19.3,-40.45
br,terra alta,Terra Alta,05,,-17.516667,-39.3
br,terra alta,Terra Alta,16,,-1.033333,-47.916667
br,terra boa,Terra Boa,05,,-12.4,-38.616667
br,terra boa,Terra Boa,18,12958,-23.75,-52.45
br,terra boa,Terra Boa,27,,-23.812479,-47.080049
br,terra branca,Terra Branca,05,,-11.083333,-39.866667
br,terra branca,Terra Branca,15,,-17.316667,-43.2
br,terra branca,Terra Branca,18,,-24.55,-51.183333
br,terra caida,Terra Caída,28,,-11.433333,-37.416667
br,terra de areia,Terra de Areia,23,,-29.583333,-50.066667
br,terra de feijao,Terra de Feijão,15,,-16.116667,-41.666667
br,terra dura,Terra Dura,20,,-3.527222,-42.211111
br,terra firme de sao raimundo,Terra Firme de São Raimundo,04,,-3.15,-65.95
br,terra firme,Terra Firme,01,,-8.581111,-72.793056
br,terra firme,Terra Firme,03,,1.183333,-50.566667
br,terra firme,Terra Firme,04,,-8.75,-67.416667
br,terra firme,Terra Firme,05,,-15.533333,-39.016667
br,terra firme,Terra Firme,24,,-12.033333,-64.283333
br,terra fofa,Terra Fôfa,15,,-15.3,-43.666667
br,terra grande,Terra Grande,03,,1.066667,-50.033333
br,terra nova d'oeste,Terra Nova d'Oeste,27,,-21.316667,-51.683333
br,terra nova,Terra Nova,04,,-4.665278,-59.179167
br,terra nova,Terra Nova,05,11169,-12.366667,-40.666667
br,terra nova,Terra Nova,16,,-6.166667,-54.15
br,terra nova,Terra Nova,17,,-7.35,-38.283333
br,terra nova,Terra Nova,18,,-23.782541,-50.812894
br,terra nova,Terra Nova,20,,-7.733333,-40.816667
br,terra nova,Terra Nova,21,,-22.875832,-43.296766
br,terra nova,Terra Nova,30,,-7.783333,-38.683333
br,terra preta do pe branco,Terra Preta do Pé Branco,04,,-5.801667,-60.976944
br,terra preta,Terra Preta,04,,-4.301111,-59.744444
br,terra preta,Terra Preta,15,,-20.983333,-45.6
br,terra preta,Terra Preta,16,,-4.133333,-51.9
br,terra preta,Terra Preta,25,,-.867222,-61.9375
br,terra preta,Terra Preta,27,,-22.633333,-47.05
br,terra rica,Terra Rica,18,10346,-22.716667,-52.633333
br,terra roxa d'oeste,Terra Roxa d'Oeste,18,,-24.166667,-54.083333
br,terra roxa,Terra Roxa,18,10911,-23.855708,-50.031397
br,terra roxa,Terra Roxa,27,,-20.783333,-48.35
br,terra salgada,Terra Salgada,30,,-8.55,-36.4
br,terra santa,Terra Santa,16,13512,-2.1,-56.483333
br,terra santa,Terra Santa,22,,-5.274167,-36.080833
br,terra seca,Terra Seca,27,,-24.8949,-48.4701
br,terras,Terras,15,,-21.033333,-45.066667
br,terra,Terra,15,,-20.533333,-45.966667
br,terra vermelha,Terra Vermelha,04,,-4.711111,-62.312222
br,terra vermelha,Terra Vermelha,11,,-21.616667,-57.3
br,terra vermelha,Terra Vermelha,14,,-15.3,-56.166667
br,terra vermelha,Terra Vermelha,17,,-7.633333,-36.916667
br,terra vermelha,Terra Vermelha,18,,-25.863357,-50.247563
br,terra vermelha,Terra Vermelha,20,,-6.183333,-42.766667
br,terra vermelha,Terra Vermelha,30,,-8.366667,-35.983333
br,terra vermelha,Terra Vermelha,31,,-11.883333,-47
br,terra vermelho,Terra Vermelho,04,,-4.711111,-62.312222
br,terra virmelena,Terra Virmelena,04,,-4.711111,-62.312222
br,terreiro,Terreiro,05,,-12.916667,-40.95
br,terrenos,Terrenos,11,,-20.433333,-54.833333
br,terreno,Terreno,11,,-20.433333,-54.833333
br,terrinha,Terrinha,05,,-11.5,-43.3
br,tertuliano,Tertuliano,11,,-20.883333,-56.716667
br,tertuliano,Tertuliano,15,,-16.083333,-39.9
br,tesouras,Tesouras,05,,-14.066667,-39.633333
br,tesouras,Tesouras,23,,-28.116667,-53.083333
br,tesoura,Tesoura,18,,-25.883333,-50.266667
br,tesoura,Tesoura,22,,-6.083333,-38.116667
br,tesoura,Tesoura,23,,-28.116667,-53.083333
br,tesourinha,Tesourinha,05,,-14.1,-39.65
br,tesouro,Tesouro,14,,-16.066667,-53.566667
br,testa branca,Testa Branca,05,,-10.7,-42.716667
br,testa branca,Testa Branca,20,,-9.183333,-41.983333
br,testo central alto,Testo Central Alto,26,,-26.7508,-49.1736
br,testo salto,Testo Salto,26,,-26.8485,-49.1438
br,testo,Testo,26,,-26.75,-49.183333
br,tetequera,Tetequera,27,,-22.833333,-45.45
br,teteus,Tetéus,20,,-3.516667,-41.5
br,teteu,Tetéu,20,,-4.666667,-41.283333
br,teuini,Teuini,04,,-7.95,-67.233333
br,teuiny,Teuiny,04,,-7.95,-67.233333
br,teutonia,Teutônia,23,21834,-29.433333,-51.8
br,teutonia,Teutonia,26,,-27.05,-52.4
br,tezourinhas,Tezourinhas,05,,-14.1,-39.65
br,thebus,Thebus,15,,-21.583333,-42.733333
br,theobroma,Theobroma,24,,-10.25,-62.35
br,theogenes rocha,Theogenes Rocha,06,,-3.616667,-40.133333
br,theophilo ottoni,Theophilo Ottoni,15,,-17.85,-41.5
br,theotonio,Theotonio,24,,-8.916667,-64
br,theresina,Theresina,20,,-5.083333,-42.816667
br,therezina,Therezina,18,,-24.8,-51.116667
br,therezina,Therezina,20,,-5.083333,-42.816667
br,therezopolis,Therezopolis,21,,-22.424064,-42.968013
br,therezopolis,Therezopolis,26,,-27.733333,-48.933333
br,thomar,Thomar,04,,-.383333,-63.9
br,thomaz coelho,Thomaz Coelho,21,,-22.869167,-43.306111
br,thomazina,Thomazina,18,,-23.766667,-49.966667
br,tiago martins,Tiago Martins,15,,-17.083333,-41.85
br,tiago,Tiago,16,,-.983333,-57
br,tiaia de baixo,Tiaia de Baixo,06,,-3,-40.583333
br,tiangua,Tianguá,06,45697,-3.733333,-40.983333
br,tiaraju,Tiaraju,23,,-30.25,-54.383333
br,tibagi,Tibagi,18,12644,-24.5,-50.4
br,tibagy,Tibagy,18,,-24.5,-50.4
br,tibaia,Tibaia,14,,-16.416667,-55.966667
br,tibaji alta,Tibaji Alta,18,,-23.9549,-50.9311
br,tibaji,Tibaji,18,,-24.5,-50.4
br,tibau do sul,Tibaú do Sul,22,,-4.835833,-37.250833
br,tibau,Tibau,22,,-4.835833,-37.250833
br,tibicanga,Tibicanga,18,,-25.341076,-48.269712
br,tibirica,Tibiriça,27,,-21.816667,-52.166667
br,tibiri,Tibiri,05,,-12.533333,-38.9
br,tibiri,Tibiri,13,,-2.6,-44.25
br,tibiros,Tibiros,06,,-3.533333,-39.683333
br,tibi,Tibi,11,,-21.85,-56.316667
br,tibou do sul,Tiboú do Sul,22,,-4.835833,-37.250833
br,tibuna,Tibuna,15,,-19.066667,-43.933333
br,tiburcio miranda,Tibúrcio Miranda,15,,-18.916667,-48.05
br,tiete,Tietê,18,,-25.733333,-49.4
br,tiete,Tietê,27,32062,-23.100174,-47.714392
br,tifa de dentro,Tifa de Dentro,26,,-26.98531,-49.752246
br,tifa pauxfune,Tifa Pauxfune,26,,-26.8946,-49.1725
br,tigre de baixo,Tigre De Baixo,22,,-6.333333,-38.416667
br,tigre de cima,Tigre de Cima,17,,-8.083333,-36.866667
br,tigre,Tigre,04,,-6.866667,-60.3
br,tigre,Tigre,06,,-3.433333,-39.116667
br,tigre,Tigre,11,,-23.6,-54.616667
br,tigre,Tigre,15,,-18.583333,-43.85
br,tigre,Tigre,17,,-6.566667,-38.1
br,tigre,Tigre,23,,-29.333333,-53.1
br,tigre,Tigre,30,,-7.466667,-37.416667
br,tigrinho,Tigrinho,23,,-29.266667,-52.066667
br,tijipio,Tijipió,26,,-27.35,-48.9
br,tijipio,Tijipió,30,,-8.083333,-34.966667
br,tijoca,Tijoca,16,,-1.066667,-46.6
br,tijoleiros,Tijoleiros,27,,-23.522613,-47.006057
br,tijolo,Tijolo,06,,-3.25,-40.016667
br,tijuacu,Tijuaçu,05,,-10.616667,-40.133333
br,tijuca de baixo,Tijuca de Baixo,05,,-13.05,-38.95
br,tijucal,Tijucal,15,,-18.616667,-43.533333
br,tijucamar,Tijucamar,21,,-23.012386,-43.301379
br,tijucas do sul,Tijucas do Sul,18,,-25.925441,-49.178695
br,tijucas,Tijucas,18,,-25.925441,-49.178695
br,tijucas,Tijucas,20,,-4.75,-41.716667
br,tijucas,Tijucas,26,22482,-27.241111,-48.631389
br,tijuca,Tijuca,05,,-12.716667,-41.55
br,tijuca,Tijuca,21,,-22.416895,-42.956223
br,tijuca,Tijuca,22,,-5.716667,-35.683333
br,tijuca,Tijuca,27,,-22.216667,-47.483333
br,tijucopapo,Tijucopapo,30,,-7.6,-34.883333
br,tijuco preto,Tijuco Preto,18,,-23.0077,-50.0187
br,tijuco preto,Tijuco Prêto,27,,-22.216667,-47.483333
br,tijuco,Tijuco,05,,-10.65,-38.383333
br,tijuco,Tijuco,15,,-19.75,-44.15
br,tijuco,Tijuco,27,,-24.548138,-48.920514
br,tijucucu,Tijucuçu,05,,-11.65,-44.15
br,tijuquinhas,Tijuquinhas,26,,-27.416667,-48.633333
br,tijuquinha,Tijuquinha,26,,-27.416667,-48.633333
br,timaneira,Timaneira,18,,-25.3,-49.316667
br,timbahuba,Timbahuba,06,,-3.583333,-39.983333
br,timbauba dos batistas,Timbaúba dos Batistas,22,,-6.45,-37.283333
br,timbauba do tiao,Timbauba do Tião,17,,-6.95,-37.583333
br,timbauba,Timbaúba,02,,-9.35,-37.233333
br,timbauba,Timbaúba,06,,-3.583333,-39.983333
br,timbauba,Timbaúba,17,,-6.466667,-37.733333
br,timbauba,Timbaúba,22,,-5.902222,-36.635556
br,timbauba,Timbauba,23,,-29.95,-54.483333
br,timbauba,Timbaúba,30,45122,-7.516667,-35.316667
br,timbaubeira,Timbaubeira,17,,-7.116667,-36.683333
br,timbauva,Timbaúva,23,,-29.95,-54.483333
br,timbe,Timbé,26,,-28.816667,-49.85
br,timbiras,Timbiras,13,17875,-4.25,-43.95
br,timbora,Timbora,05,,-12.583333,-39.283333
br,timbore,Timboré,27,,-20.7,-51.383333
br,timborinha,Timborinha,05,,-12.583333,-39.3
br,timbosal,Timbosal,14,,-14.866667,-56.383333
br,timboteua,Timboteua,16,,-1.033333,-47.333333
br,timbo,Timbó,02,,-9.183333,-36.116667
br,timbo,Timbó,05,,-11.083333,-43.116667
br,timbo,Timbó,06,,-3.75,-38.8
br,timbo,Timbó,22,,-6.083333,-35.15
br,timbo,Timbó,26,33766,-26.833333,-49.3
br,timbo,Timbó,27,,-22.333333,-51.55
br,timbo,Timbó,28,,-10.533333,-36.7
br,timbo,Timbó,30,,-8.25,-35.55
br,timbozal,Timbòzal,14,,-14.866667,-56.383333
br,timbuhy,Timbuhy,08,,-20.016667,-40.416667
br,timbui,Timbuí,08,,-20.016667,-40.416667
br,timburai,Timburaí,27,,-23.2,-49.6
br,timburi,Timburi,27,,-23.2,-49.6
br,timbury,Timbury,27,,-23.2,-49.6
br,timbu,Timbu,18,,-25.3,-49.083333
br,timgui,Timgui,13,,-6.4,-43.45
br,timoneira,Timoneira,18,,-25.3,-49.316667
br,timonha,Timonha,06,,-3.166667,-41.1
br,timon,Timon,13,124429,-5.1,-42.816667
br,timorande,Timorande,30,,-7.866667,-38.45
br,timorante,Timorante,15,,-15.933333,-40.5
br,timorante,Timorante,20,,-3.737222,-42.021389
br,timorante,Timorante,30,,-7.683333,-39.783333
br,timoteo,Timóteo,15,91723,-19.583333,-42.666667
br,timoteo,Timóteo,20,,-3.4525,-42.308056
br,timothea,Timothea,15,,-19.583333,-42.666667
br,tine,Tiné,14,,-14.55,-57.433333
br,tinguatiba,Tinguatiba,05,,-12.433333,-39.1
br,tingua,Tinguá,21,,-22.591667,-43.418056
br,tinguis,Tinguis,20,,-3.665,-42.333889
br,tingui,Tingui,02,,-9.366667,-37.9
br,tingui,Tingui,05,,-12.233333,-39.733333
br,tingui,Tingui,18,,-24.980676,-48.949473
br,tingui,Tingui,20,,-3.585,-42.178333
br,tinguizeiro,Tinguizeiro,02,,-9.75,-37.183333
br,tipi de cima,Tipi de Cima,06,,-6.966667,-38.766667
br,tipis,Tipis,06,,-6.183333,-39.333333
br,tipi,Tipi,02,,-9.716667,-36.6
br,tipi,Tipi,06,,-6.966667,-38.816667
br,tipiti,Tipiti,15,,-18.333333,-41.266667
br,tipoi,Tipoí,23,,-28.55,-51.35
br,tipucu,Tipucú,25,,3.3,-60.366667
br,tiquarucu,Tiquaruçu,05,,-12.066667,-38.883333
br,tiquarussu,Tiquarussu,05,,-12.066667,-38.883333
br,tira barro,Tira Barro,05,,-13.266667,-40.583333
br,tira-cerveja,Tira-Cerveja,24,,-10.333333,-62.933333
br,tira chapeu,Tira Chapéu,21,,-21.216667,-41.966667
br,tiradentes,Tiradentes,06,,-7.233333,-39.283333
br,tiradentes,Tiradentes,11,,-19.45,-56.716667
br,tiradentes,Tiradentes,15,4439,-21.116667,-44.183333
br,tiradentes,Tiradentes,23,,-27.4,-54.083333
br,tira fogo,Tira Fogo,24,,-9.416667,-63.666667
br,tira-saia,Tira-Saia,27,,-23.095801,-47.884589
br,tira-teima,Tira-Teima,06,,-5.116667,-40.1
br,tirirca,Tirirca,20,,-5.916667,-41.216667
br,tiririca do assurua,Tiririca do Assuruá,05,,-11.633333,-42.033333
br,tirirical,Tirirical,13,,-2.566667,-44.233333
br,tiririca,Tiririca,05,,-11.033333,-38.716667
br,tiririca,Tiririca,13,,-9.983333,-45.866667
br,tiririca,Tiririca,20,,-7.166667,-40.75
br,tiririca,Tiririca,30,,-7.883333,-39.033333
br,tirol,Tirol,08,,-20.166667,-40.566667
br,tirol,Tirol,22,,-5.791667,-35.2
br,tiro seguro,Tiro Seguro,05,,-12.766667,-38.366667
br,tiros,Tiros,15,,-19,-45.966667
br,titaras,Titaras,13,,-3.945556,-42.827222
br,titaras,Titaras,20,,-3.758889,-42.648889
br,titara,Titara,13,,-3.54,-42.585556
br,titiarre,Titiarre,25,,-2.7,-61.2
br,titia,Titiá,25,,2.866667,-60.833333
br,titica,Titica,04,,-3.209167,-62.845
br,tiuba,Tiúba,13,,-3.783889,-43.417778
br,tiui,Tiui,16,,.966667,-54.55
br,tobati,Tobati,15,,-19.583333,-46.383333
br,toba,Tobá,05,,-12.8,-38.633333
br,tobiaras,Tobiaras,27,,-21.6,-49.933333
br,tobias barreto,Tobias Barreto,28,29741,-11.183333,-38.016667
br,tobi,Tobi,05,,-12.983333,-39.933333
br,tobocal,Tobocal,04,,-5.233333,-59.6
br,tobocas,Tobocas,20,,-6.516667,-42.2
br,toboco,Toboco,20,,-6.2,-42.7
br,tocaia,Tocaia,04,,-1.9,-65.483333
br,tocaia,Tocaia,20,,-4.583333,-42.3
br,tocandira,Tocandira,15,,-15.633333,-43.166667
br,tocanguira,Tocanguira,11,,-21.8,-57.633333
br,tocantinea,Tocantinea,31,,-9.542222,-48.228056
br,tocantinia,Tocantínia,31,,-9.542222,-48.228056
br,tocantinopolis,Tocantinópolis,31,23383,-6.324444,-47.277778
br,tocantins novos,Tocantins Novos,04,,-7.233333,-64.716667
br,tocantins novo,Tocantins Novo,04,,-7.233333,-64.716667
br,tocantins,Tocantins,04,,-2.783333,-67.783333
br,tocantins,Tocantins,15,12876,-21.166667,-43.033333
br,tocas,Tocas,27,,-24.640643,-48.840119
br,toca,Toca,05,,-13.983333,-43.666667
br,toca,Toca,27,,-21.3,-47.533333
br,toca,Toca,30,,-7.883333,-38.583333
br,toca vaca,Toca Vaca,14,,-16.266667,-58.366667
br,tocaya,Tocaya,04,,-1.9,-65.483333
br,tocos do mogi,Tocos do Mogi,15,,-22.366667,-46.1
br,tocos do moji,Tocos do Moji,15,,-22.366667,-46.1
br,todos os santos ii,Todos os Santos II,13,,-3.455833,-43.325833
br,todos os santos i,Todos os Santos I,13,,-3.445278,-43.3225
br,todos-os-santos,Todos-os-Santos,05,,-12.2,-40.216667
br,todos os santos,Todos os Santos,06,,-5.966667,-39.883333
br,todos os santos,Todos os Santos,08,,-18.65,-40.666667
br,todos os santos,Todos os Santos,11,,-19.583333,-56.966667
br,todos os santos,Todos os Santos,13,,-3.818611,-42.978333
br,todos-os-santos,Todos-os-Santos,16,,-4.5,-56.566667
br,todos os santos,Todos os Santos,20,,-4.316667,-42.9
br,todos os santos,Todos os Santos,21,,-22.894755,-43.278616
br,toeleu,Toeleu,16,,2.333333,-55.283333
br,toeo preto,Toeo Prêto,22,,-5.497222,-36.099444
br,toheroa,Tohêroa,14,,-14.266667,-57.333333
br,toldo erechim,Toldo Erechim,23,,-27.55,-52.533333
br,toldo erequim,Toldo Erequim,23,,-27.55,-52.533333
br,toldo,Tôldo,23,,-27.75,-52.166667
br,toledopolis,Toledópolis,27,,-23.5127,-47.609
br,toledos,Toledos,15,,-21.8,-43.6
br,toledos,Toledos,27,,-22.833333,-47.95
br,toledo,Toledo,04,,-5.883333,-73.116667
br,toledo,Toledo,15,,-20.166667,-41.816667
br,toledo,Toledo,18,97846,-24.733333,-53.75
br,toloiri,Toloiri,14,,-14.633333,-58.4
br,tomar do geru,Tomar do Geru,28,4394,-11.383333,-37.85
br,tomar do jeru,Tomar do Jeru,28,,-11.383333,-37.85
br,tomar,Tomar,04,,-.383333,-63.9
br,tomarutema,Tomarutema,16,,-.55,-47.733333
br,tomas coelho,Tomas Coelho,21,,-22.871338,-43.304539
br,tomas correia,Tomás Correia,13,,-3.108333,-42.361944
br,tomas gonzaga,Tomás Gonzaga,15,,-18.433333,-44.3
br,tomasia,Tomásia,06,,-3.35,-40.2
br,tomasina,Tomasina,18,,-23.766667,-49.966667
br,tomasio,Tomásio,15,,-14.3,-44.25
br,tomas,Tomás,31,,-10.290556,-48.301667
br,toma-toma,Toma-Toma,22,,-6.3,-37.966667
br,tomazelas,Tomazelas,27,,-23.036261,-47.991363
br,tomaz gonzaga,Tomaz Gonzaga,15,,-18.433333,-44.3
br,tomazina,Tomazina,18,,-23.766667,-49.966667
br,tomazinho,Tomazinho,21,,-22.807146,-43.39045
br,tombador do araujo,Tombador do Araújo,05,,-11.2,-40.7
br,tombador,Tombador,05,,-9.733333,-41.866667
br,tombador,Tombador,14,,-14.633333,-56.266667
br,tombador,Tombador,15,,-18.633333,-43.733333
br,tombadouro,Tombadouro,15,,-18.633333,-43.733333
br,tombos,Tombos,15,,-20.916667,-42.033333
br,tombo,Tombo,30,,-7.8,-39.566667
br,tome-acu,Tomé-Açu,16,34054,-2.416667,-48.15
br,tome afonso,Tomé Afonso,06,,-4.733333,-37.916667
br,tome de paripe,Tomé de Paripé,05,,-12.816667,-38.483333
br,tome do paripe,Tome do Paripé,05,,-12.816667,-38.483333
br,tome,Tomé,15,,-19.516667,-41.683333
br,tome vieira,Tomê Vieira,06,,-6.016667,-38.4
br,tomezinho,Tomèzinho,06,,-5.633333,-39.4
br,tonantins,Tonantins,04,4561,-2.783333,-67.783333
br,tonico,Tonico,05,,-13.833333,-40.083333
br,toniolo,Toniolo,23,,-29.75,-53.9
br,tonta,Tonta,20,,-7.233333,-41.666667
br,topazio,Topázio,15,,-17.666667,-41.416667
br,tope,Tope,06,,-4.366667,-39.066667
br,tope,Tope,23,,-28.566667,-52.3
br,toque de sangue,Toque de Sangue,30,,-8.183333,-36.616667
br,torcida,Torcida,05,,-17.233333,-39.75
br,toribate,Toribatê,15,,-18.866667,-48.866667
br,toriba,Toriba,27,,-23.75,-49.283333
br,toriparu,Toriparu,14,,-16.333333,-53.916667
br,toritama,Toritama,30,23941,-8.016667,-36.066667
br,torixoreu,Torixoreu,14,,-16.25,-52.433333
br,tormenta,Tormenta,18,,-25.233333,-53.25
br,tormentinha,Tormentinha,18,,-25.233333,-53.25
br,torneiras,Torneiras,15,,-19.883333,-44.733333
br,torneiros,Torneiros,15,,-19.883333,-44.733333
br,torninos,Torninos,27,,-23.2139,-47.9034
br,torno largo,Tôrno Largo,24,,-9.116667,-63.25
br,tornos do pinto,Tornos do Pinto,26,,-26.166667,-48.75
br,torno velho ii,Torno Velho II,13,,-3.113889,-42.130833
br,toropi,Toropi,23,,-29.483333,-54.233333
br,toropy,Toropy,23,,-29.483333,-54.233333
br,toroqua,Toroquá,23,,-29.466667,-54.933333
br,tororo,Tororó,05,,-12.8,-38.5
br,torquato severo,Torquato Severo,23,,-31.033333,-54.183333
br,torquato sousa,Torquato Sousa,15,,-15.716667,-46.716667
br,torquato,Torquato,17,,-7.316667,-38.383333
br,torrao,Torrão,02,,-9.65,-36.75
br,torrao,Torrão,03,,.183333,-51.216667
br,torrao,Torrão,06,,-7.083333,-40.016667
br,torreao,Torreão,13,,-3.133333,-44.783333
br,torre branca,Tôrre Branca,18,,-24.483333,-51.233333
br,torre de pedra,Tôrre de Pedra,27,,-23.25,-48.166667
br,torre embratel,Torre Embratel,06,,-4.216667,-39.033333
br,torreoes,Torreões,15,,-21.866667,-43.55
br,torres do rio bonito,Torres Do Rio Bonito,29,,-16.95,-51.816667
br,torre segura,Tôrre Segura,13,,-5.716667,-47.316667
br,torres,Tôrres,02,,-9.566667,-36.433333
br,torres,Tôrres,05,,-13.133333,-39.583333
br,torres,Torres,15,,-21.283333,-43.633333
br,torres,Tôrres,17,,-7.516667,-35.7
br,torres,Torres,20,,-6.283333,-41.166667
br,torres,Tôrres,23,32791,-29.35,-49.733333
br,torres,Torres,30,,-8.016667,-36.066667
br,torre,Tôrre,17,,-7.633333,-38.116667
br,torre,Tôrre,20,,-6.683333,-42.15
br,torrinha,Torrinha,05,,-11.5,-43.3
br,torrinha,Torrinha,27,,-22.433333,-48.15
br,torroes,Torrões,06,,-3.1,-40.116667
br,torroes,Torrões,17,,-6.6,-38.483333
br,torroes,Torrões,20,,-3.6,-42.056111
br,torroes,Torroes,22,,-6.133333,-38.216667
br,torroes,Torroes,30,,-7.75,-37.583333
br,torta,Torta,05,,-13.666667,-42.7
br,torta,Torta,06,,-5.75,-39.383333
br,torta,Torta,20,,-7.25,-41.666667
br,tortinho,Tortinho,16,,-5.566667,-49.95
br,torto,Torto,05,,-12.6,-39.1
br,torto,Torto,07,,-15.7,-47.9
br,torto,Torto,27,,-22.7343,-45.6796
br,totoia,Totóia,13,,-3.233056,-43.079444
br,totora,Totora,11,,-23.4,-55.5
br,tourada,Tourada,13,,-3.263611,-42.268333
br,tourao,Tourão,06,,-5.15,-40.6
br,tourao,Tourão,22,,-6,-37.65
br,touro de cimento,Touro de Cimento,20,,-5.616667,-42.866667
br,touro morto,Touro Morto,11,,-19.733333,-56.65
br,touros,Touros,22,7662,-5.2,-35.466667
br,touro,Touro,05,,-12.733333,-39.216667
br,touro,Touro,20,,-3.343056,-42.109167
br,trabiju,Trabiju,27,,-22.05,-48.3
br,tracoa,Tracoá,04,,-7.8,-70.133333
br,tracuateua,Tracuateua,16,,-1.083333,-46.9
br,tracua,Tracuá,03,,.483333,-51.283333
br,tracua,Tracuá,16,,-1.666667,-54.883333
br,tracunhaem,Tracunhaém,30,,-7.8,-35.233333
br,tracupa,Tracupá,05,,-11.116667,-38.816667
br,trahira,Trahira,16,,-6.7,-57.733333
br,trahiry,Trahiry,06,,-3.283333,-39.25
br,trahyras,Trahyras,15,,-19.016667,-44.016667
br,trahyras,Trahyras,29,,-14.483333,-48.566667
br,traicao,Traição,17,,-6.7,-34.933333
br,traipu,Traipu,02,8427,-9.966667,-36.983333
br,trairas,Traíras,02,,-9.916667,-36.633333
br,trairas,Traíras,03,,.483333,-51.95
br,trairas,Traíras,05,,-11.216667,-42.166667
br,trairas,Traíras,14,,-14.366667,-54.716667
br,trairas,Traíras,15,,-18.883333,-41.733333
br,trairas,Traíras,22,,-5.966667,-35.466667
br,trairas,Traíras,28,,-10.066667,-36.95
br,trairas,Trairas,29,,-14.483333,-48.566667
br,trairas,Trairas,30,,-7.85,-39.2
br,traira,Traíra,02,,-9.916667,-36.633333
br,traira,Traira,06,,-6.1,-40.55
br,traira,Traíra,16,,-6.7,-57.733333
br,traira,Traira,20,,-7.35,-43.4
br,trairi,Trairi,06,23135,-3.283333,-39.25
br,trairi,Trairi,22,,-6.25,-35.833333
br,traituba,Traituba,15,,-21.5,-45.866667
br,traitu,Traitu,27,,-21.25,-50.5
br,trajano de morais,Trajano de Morais,21,,-22.066667,-42.066667
br,trajano marques,Trajano Marques,13,,-1.683333,-45.15
br,trajano,Trajano,13,,-1.683333,-45.15
br,tramandahy,Tramandahy,23,,-29.966667,-50.133333
br,tramandai,Tramandaí,23,34735,-29.966667,-50.133333
br,trancogo,Trancogo,05,,-16.583333,-39.083333
br,trancoso,Trancoso,05,,-16.583333,-39.083333
br,tranqueira de cima,Tranqueira de Cima,20,,-5.3,-41.183333
br,tranqueira do cinobi,Tranqueira do Cinóbi,20,,-6.25,-41.733333
br,tranqueiras,Tranqueiras,05,,-13.85,-41.533333
br,tranqueira,Tranqueira,20,,-3.880833,-42.062778
br,tranquera,Tranquera,20,,-9.083333,-42.966667
br,transvaal,Transvaal,01,,-9.5,-72.333333
br,transval,Transval,06,,-4.383333,-39.183333
br,trapia,Trapiá,05,,-12.85,-39.533333
br,trapia,Trapiá,06,,-3.433333,-40.283333
br,trapia,Trapiá,22,,-5.375833,-37.102222
br,trapiche,Trapiche,02,,-9.033333,-37.4
br,trapiche,Trapiche,04,,-5.566667,-61.1
br,trapiche,Trapiche,21,,-21.516667,-41.6
br,trapizeiro,Trapizeiro,06,,-5.15,-39.866667
br,trapoa,Trapoa,06,,-3.733333,-40.666667
br,trapriche,Trapriche,04,,-5.566667,-61.1
br,traquateua,Traquatéua,16,,-1.083333,-46.9
br,traquinha,Traquinha,22,,-6.233333,-38.4
br,traripe,Traripe,05,,-12.4,-38.733333
br,traru,Traru,04,,-4.386944,-70.935
br,tras os montes,Tras Os Montes,06,,-4.083333,-40.383333
br,travesao,Travesão,20,,-9.266667,-43.283333
br,travessa aquidaban,Travessa Aquidaban,23,,-29.0055,-51.2144
br,travessa claro,Travessa Claro,23,,-29.0716,-51.1154
br,travessada,Travessada,02,,-9.416667,-36.616667
br,travessa garibaldi,Travessa Garibaldi,23,,-29.0547,-51.1788
br,travessa jacinto,Travessa Jacinto,23,,-29.0772,-51.2364
br,travessa jose bonifacio,Travessa José Bonifácio,23,,-29.1666,-51.1278
br,travessa lagoa bela,Travessa Lagoa Bela,23,,-29.0121,-51.2039
br,travessa martins,Travessa Martins,23,,-29.0211,-51.2308
br,travessao da barra,Travessão da Barra,21,,-21.316667,-41.066667
br,travessao de barro,Travessão de Barro,21,,-21.316667,-41.066667
br,travessao,Travessão,05,,-12.1,-41.233333
br,travessao,Travessão,06,,-5.866667,-39.666667
br,travessao,Travessão,13,,-3.418889,-43.358611
br,travessao,Travessão,15,,-19.066667,-42.533333
br,travessao,Travessão,17,,-7.7,-38.216667
br,travessao,Travessão,20,,-9.266667,-43.283333
br,travessao,Travessão,21,,-21.6,-41.316667
br,travessao,Travessão,29,,-15.516667,-50.7
br,travessao,Travessão,30,,-8.5,-37.033333
br,travessa santa tereza,Travessa Santa Tereza,23,,-29.2103,-51.1951
br,travessa,Travessa,05,,-12.1,-41.233333
br,travessa,Travessa,27,,-20.733333,-51.166667
br,travessa,Travessa,30,,-8.1,-38.333333
br,travessia do piquiri,Travessia do Piquirí,14,,-17.616667,-55.166667
br,travessia do piquiry,Travessia do Piquiry,14,,-17.616667,-55.166667
br,travessia dos henriques,Travessia dos Henriques,17,,-7.7,-38.25
br,travessia,Travessia,08,,-20.616667,-41.466667
br,travessia,Travessia,14,,-15.233333,-56.483333
br,travessia,Travessia,17,,-7.683333,-38.233333
br,travessia,Travessia,20,,-7.883333,-44.95
br,trazibulo,Trazibulo,15,,-17.1,-40.783333
br,traz monte,Traz Monte,17,,-7.133333,-38.55
br,trela,Trela,11,,-19.766667,-54.133333
br,tremedal,Tremedal,05,3252,-14.966667,-41.4
br,tremedal,Tremedal,14,,-16.466667,-58.366667
br,tremedal,Tremedal,15,,-15.15,-42.883333
br,tremedeira,Tremedeira,21,,-22.221111,-43.056944
br,tremembe,Tremembé,05,,-14.166667,-39.083333
br,tremembe,Tremembé,27,31720,-22.966667,-45.55
br,tremendal,Tremendal,14,,-16.466667,-58.366667
br,trempes,Trempes,20,,-7.933333,-42.933333
br,trempe,Trempe,30,,-7.7,-39.45
br,tres arroios,Três Arroios,23,,-27.483333,-52.183333
br,tres baixas,Três Baixas,20,,-7.816667,-41.516667
br,tres barras de baixo,Três Barras de Baixo,18,,-23.5924,-49.7871
br,tres barras,Três Barras,05,,-13.783333,-40.633333
br,tres barras,Três Barras,08,,-19.916667,-40.433333
br,tres barras,Três Barras,11,,-21.716667,-57.9
br,tres barras,Três Barras,13,,-6.583333,-43.15
br,tres barras,Três Barras,14,,-14.666667,-56.716667
br,tres barras,Três Barras,15,,-18.483333,-43.466667
br,tres barras,Três Barras,18,,-23.483333,-50.783333
br,tres barras,Três Barras,26,14855,-26.1,-50.316667
br,tres barras,Três Barras,27,,-20.733333,-47.816667
br,tres bicos,Três Bicos,18,,-24.7,-51.2
br,tres bocas,Três Bocas,01,,-7.866667,-73.05
br,tres bocas,Três Bocas,04,,-5.754722,-65.566111
br,tres bocas,Três Bôcas,05,,-12.733333,-39.066667
br,tres bocas,Três Bôcas,18,,-24.666667,-53.816667
br,tres bocas,Três Bôcas,22,,-5.414167,-36.935278
br,tres bocas,Três Bôcas,23,,-29.116667,-55.716667
br,tres boccas,Tres Boccas,01,,-7.866667,-73.05
br,tres boccas,Tres Boccas,04,,-6.616667,-69.316667
br,tres bodegas,Três Bodegas,06,,-6.316667,-38.733333
br,tres bracos,Três Braços,05,,-13.533333,-39.75
br,tres buritis,Três Buritis,24,,-12.166667,-60.083333
br,tres buritys,Tres Buritys,24,,-12.166667,-60.083333
br,tres cachoeiras,Três Cachoeiras,23,,-29.45,-49.933333
br,tres cancelas,Três Cancelas,05,,-12.866667,-41.483333
br,tres capoes,Três Capões,23,,-28.8,-53.5
br,tres casas,Três Casas,04,,-6.133333,-61.75
br,tres coracoes,Três Corações,15,63458,-21.7,-45.266667
br,tres coracoes,Três Corações,18,,-23.347913,-49.825216
br,tres coroas,Três Coroas,23,21051,-29.533333,-50.8
br,tres corregos,Três Córregos,18,,-25.233333,-49.666667
br,tres cruzes,Três Cruzes,08,,-20.516667,-40.883333
br,tres cruzes,Três Cruzes,15,,-22.366667,-45.633333
br,tres cruzes,Três Cruzes,27,,-23.116667,-47.366667
br,tres de agosto,Três de Agôsto,08,,-18.133333,-40.116667
br,tres de maio,Três de Maio,23,18278,-27.783333,-54.233333
br,tres de outubro,Três de Outubro,26,,-27.133333,-51.983333
br,tres estradas,Três Estradas,23,,-30.916667,-54.2
br,tres figueiras,Três Figueiras,23,,-29.9004,-50.789
br,tres fronteiras,Três Fronteiras,27,,-20.216667,-50.916667
br,tres galhos,Três Galhos,18,,-23.417896,-49.922653
br,tres ilhas,Três Ilhas,15,,-22.032222,-43.489444
br,tres irinoas,Tres Irinoas,20,,-5.683333,-42.6
br,tres irmanos,Três Irmãnos,22,,-5.3,-35.9
br,tres irmaos,Três Irmãos,04,,-7.783333,-68.45
br,tres irmaos,Três Irmãos,06,,-4.733333,-39.35
br,tres irmaos,Três Irmãos,11,,-17.25,-56.75
br,tres irmaos,Três Irmãos,18,,-25.966667,-53.583333
br,tres irmaos,Três Irmãos,21,,-21.633333,-42
br,tres irmaos,Três Irmãos,23,,-29.516667,-50.066667
br,tres irmaos,Três Irmãos,24,,-9.6,-64.883333
br,tres irmaos,Três Irmãos,27,,-20.75,-51.35
br,tres irmaos,Três Irmãos,30,,-8.166667,-38.533333
br,tres ladeiras,Três Ladeiras,30,,-7.75,-35
br,tres lagoas,Três Lagoas,05,,-12.5,-40.483333
br,tres lagoas,Três Lagoas,11,78714,-20.8,-51.716667
br,tres lagoas,Três Lagoas,13,,-4.816667,-44.866667
br,tres lagoas,Três Lagoas,20,,-3.566111,-42.097222
br,tres lagoas,Três Lagoas,24,,-9.016667,-61.616667
br,tres lagoas,Três Lagoas,31,,-1.233333,-47.65
br,tres lagoinhas,Três Lagoinhas,27,,-23.566776,-47.200866
br,tres lagos,Três Lagos,24,,-9.016667,-61.616667
br,tres marias,Três Marias,08,,-19.45,-40.166667
br,tres marias,Três Marias,11,,-19.133333,-55.35
br,tres marias,Três Marias,22,,-5.209167,-37.000833
br,tres morros,Três Morros,05,,-12.333333,-43.666667
br,tres morros,Três Morros,11,,-20.983333,-56.65
br,tres mulheres,Três Mulheres,13,,-3.623056,-43.3125
br,tres nacoes,Três Nações,27,,-21.566667,-50.7
br,tres olhos d'agua,Tres Olhos d'Agua,06,,-7.416667,-38.633333
br,tres palmeiras,Três Palmeiras,16,,-3.583333,-51.8
br,tres passagens,Três Passagens,30,,-7.833333,-38.45
br,tres passos,Três Passos,18,,-24.483333,-54.016667
br,tres passos,Três Passos,23,17286,-27.45,-53.933333
br,tres pedras,Três Pedras,15,,-16.95,-40.733333
br,tres pedras,Três Pedras,31,,-9.324167,-47.663056
br,tres pinheiros,Três Pinheiros,18,,-25.45,-51.966667
br,tres pinheiros,Três Pinheiros,23,,-28.133333,-51.7
br,tres placas,Três Placas,18,,-23.350454,-52.686837
br,tres pocos,Três Poços,13,,-4.433333,-44.966667
br,tres pocos,Três Poços,18,,-25.981086,-50.225105
br,tres pocos,Três Poços,21,,-22.5,-44.033333
br,tres poderes,Três Poderes,04,,-4.124444,-60.936389
br,tres pontas,Três Pontas,08,,-19.333333,-40.066667
br,tres pontas,Três Pontas,15,43750,-21.366667,-45.516667
br,tres pontes,Três Pontes,21,,-22.925193,-43.64724
br,tres pontoes,Três Pontões,18,,-24.783333,-50.416667
br,tres portoes,Três Portões,11,,-21.066667,-54.716667
br,tres ranchos,Três Ranchos,29,,-18.366667,-47.783333
br,tres rios,Três Rios,21,71945,-22.111389,-43.207778
br,tres unidos,Três Unidos,04,,-6.616667,-69.55
br,tres velhas,Três Velhas,02,,-9.233333,-37.833333
br,tres vendas,Três Vendas,05,,-12.55,-38.966667
br,tres vendas,Três Vendas,23,,-29.85,-53.016667
br,tres voltas,Três Voltas,06,,-6.266667,-38.666667
br,treviso,Treviso,26,,-28.516667,-49.466667
br,trez de maio,Trez de Maio,23,,-27.783333,-54.233333
br,treze de janeiro,Treze de Janeiro,23,,-28.516667,-55.233333
br,treze de maio,Treze de Maio,01,,-7.766667,-72.65
br,treze de maio,Treze de Maio,26,,-28.583333,-49.166667
br,treze tilias,Treze Tílias,26,,-27,-51.4
br,triagem,Triagem,21,,-22.898554,-43.239945
br,triangulo de lavras,Triangulo de Lavras,06,,-6.75,-38.866667
br,triangulo,Triângulo,11,,-20.983333,-56.166667
br,triangulo,Triângulo,17,,-7.2,-37.966667
br,triangulo,Triângulo,18,,-23.924413,-50.111435
br,triangulo,Triângulo,30,,-7.766667,-38.416667
br,tribiau,Tribiau,14,,-16.35,-54.733333
br,tribiu,Tribiú,14,,-16.35,-54.733333
br,tribobo,Tribobó,21,,-22.858611,-43.033889
br,trici,Trici,06,,-5.933333,-40.483333
br,trigolandia,Trigolândia,18,,-26.1177,-49.3822
br,trigueiro,Trigueiro,22,,-5.616667,-35.416667
br,trimonte,Trimonte,15,,-21.716667,-42.583333
br,trincheira,Trincheira,05,,-12.15,-40.95
br,trincheira,Trincheira,17,,-6.683333,-37.833333
br,trindade,Trindade,04,,-.2,-66.85
br,trindade,Trindade,05,,-10.533333,-38.383333
br,trindade,Trindade,06,,-3.066667,-39.966667
br,trindade,Trindade,13,,-9.268611,-46.700278
br,trindade,Trindade,15,,-17.9,-42.233333
br,trindade,Trindade,16,,-2.166667,-48.483333
br,trindade,Trindade,20,,-7.966667,-45.55
br,trindade,Trindade,21,,-22.1,-41.6
br,trindade,Trindade,23,,-27.45,-52.916667
br,trindade,Trindade,25,,1.05,-60.016667
br,trindade,Trindade,29,97523,-16.666667,-49.5
br,trindade,Trindade,30,19313,-7.8,-40.283333
br,trindade velha,Trindade Velha,06,,-6.083333,-38.516667
br,trinidade,Trinidade,04,,-.2,-66.85
br,trinidade,Trinidade,16,,-2.166667,-48.483333
br,trinidade,Trinidade,20,,-7.966667,-45.55
br,trinta de quatro,Trinta de Quatro,22,,-5.338889,-36.003333
br,trinta e cinco,Trinta e Cinco,23,,-28.4,-51.85
br,trintao,Trintão,24,,-11.216667,-61.95
br,trinta reis,Trinta Réis,15,,-18.533333,-43.583333
br,trios,Trios,16,,2.3,-55.266667
br,tristao camara,Tristão Câmara,21,,-22.215278,-43.048056
br,tristeza,Tristeza,23,,-30.1125,-51.245833
br,tritona,Tritona,11,,-23.766667,-54.7
br,triumfo,Triumfo,01,,-9.083333,-70.033333
br,triumfo,Triumfo,02,,-10.116667,-36.65
br,triumfo,Triumfo,23,,-29.933333,-51.716667
br,triumfo,Triumfo,24,,-11.95,-64.216667
br,triumpho,Triumpho,01,,-9.083333,-70.033333
br,triumpho,Triumpho,02,,-10.116667,-36.65
br,triumpho,Triumpho,05,,-10.75,-39.2
br,triumpho,Triumpho,11,,-21.433333,-56.483333
br,triumpho,Triumpho,18,,-25.683,-50.2974
br,triumpho,Triumpho,21,,-22.066667,-41.933333
br,triumpho,Triumpho,23,,-29.933333,-51.716667
br,triumpho,Triumpho,30,,-7.833333,-38.116667
br,triunfo do sincora,Triunfo do Sincorá,05,,-13.616667,-41.1
br,triunfo,Triunfo,01,,-9.083333,-70.033333
br,triunfo,Triunfo,02,,-10.116667,-36.65
br,triunfo,Triunfo,03,,.833333,-51.1
br,triunfo,Triunfo,04,,-2.466667,-66.566667
br,triunfo,Triunfo,05,,-10.316667,-38.4
br,triunfo,Triunfo,06,,-4.75,-38.733333
br,triunfo,Triunfo,11,,-20.766667,-55.783333
br,triunfo,Triunfo,15,,-17.416667,-44.05
br,triunfo,Triunfo,17,3871,-6.566667,-38.6
br,triunfo,Triunfo,21,,-22.066667,-41.933333
br,triunfo,Triunfo,22,,-5.690556,-36.478056
br,triunfo,Triunfo,23,14749,-29.933333,-51.716667
br,triunfo,Triunfo,24,,-11.95,-64.216667
br,triunfo,Triunfo,28,,-10.7,-37.116667
br,triunfo,Triunfo,30,,-7.833333,-38.116667
br,triunio,Triunio,20,,-7.566667,-43.05
br,trocadeiro,Trocadeiro,15,,-21.283333,-45.516667
br,trocana,Trocanã,04,,-4.246111,-59.520278
br,trocari,Trocari,04,,-3.883333,-62.85
br,trocary,Trocary,04,,-3.883333,-62.85
br,troia,Tróia,06,,-5.533333,-39.916667
br,tromba,Tromba,29,,-13.466667,-48.75
br,trombetas,Trombetas,04,,-7.4,-72.416667
br,trombucas,Trombucas,27,,-20.216667,-47.3
br,trombuca,Trombuca,15,,-21.2,-45.3
br,trombudo alto,Trombudo Alto,26,,-27.45,-49.85
br,trombudo central,Trombudo Central,26,,-27.3,-49.783333
br,trombudo,Trombudo,23,,-29.616667,-52.666667
br,trombudo,Trombudo,26,,-27.25,-49.7
br,tromomo,Tromomô,18,,-25.275759,-48.396506
br,tronco do vieira,Tronco do Vieira,13,,-3.121667,-42.161111
br,troncos,Troncos,20,,-7.15,-41.7
br,tronco,Tronco,13,,-6.833333,-44.75
br,tronco,Tronco,15,,-22.5417,-45.6385
br,tronco,Tronco,18,,-24.866667,-50.05
br,tronco,Tronco,20,,-7.733333,-43.15
br,tronqueira,Tronqueira,17,,-6.65,-38.4
br,trovao,Trovão,04,,.033333,-67.433333
br,troya,Troya,06,,-5.533333,-39.916667
br,trucuateua,Trucuateua,16,,-1.083333,-46.9
br,trucu,Truçu,06,,-6.166667,-39.783333
br,trumpho,Trumpho,30,,-7.833333,-38.116667
br,trussu,Trussu,06,,-6.166667,-39.783333
br,tubaca,Tubaca,27,,-20.416667,-47.916667
br,tubarao,Tubarão,05,,-12.833333,-38.466667
br,tubarao,Tubarão,08,,-20.283333,-40.233333
br,tubarao,Tubarão,16,,-3,-51.916667
br,tubarao,Tubarão,26,67246,-28.5,-49.016667
br,tubaroes,Tubarões,16,,-3,-51.916667
br,tubiacanga,Tubiacanga,21,,-22.785786,-43.224154
br,tubibau,Tubibau,22,,-5.255,-36.159722
br,tubibus,Tubibus,22,,-5.333333,-35.816667
br,tucana,Tucana,04,,.033333,-68.116667
br,tucandera,Tucandera,04,,-1.05,-62.8
br,tucanguira,Tucanguira,13,,-3.434167,-43.450833
br,tucaninho,Tucaninho,26,,-26.946605,-49.805775
br,tucano,Tucano,04,,.666667,-67.45
br,tucano,Tucano,05,31209,-10.966667,-38.8
br,tucano,Tucano,20,,-5.016667,-41.916667
br,tucumandeua,Tucumandeua,16,,-1.616667,-48.5
br,tucuman,Tucuman,04,,-6.783333,-59.083333
br,tucumare,Tucumare,16,,-5.3,-55.85
br,tucuma,Tucumã,03,,1.8,-50.783333
br,tucuma,Tucumã,04,,-6.783333,-59.083333
br,tucuma,Tucumã,16,15031,-.183333,-50.05
br,tucumduba,Tucumduba,06,,-3.85,-38.75
br,tucum,Tucum,05,,-12.25,-38.283333
br,tucum,Tucum,14,,-14.666667,-56.233333
br,tucum,Tucum,20,,-5.216667,-42.45
br,tucum,Tucum,31,,-11.7,-46.883333
br,tucunare,Tucunaré,03,,1.75,-50.833333
br,tucunare,Tucunaré,16,,-5.3,-55.85
br,tucunare,Tucunaré,25,,2.833125,-60.000222
br,tucunduba,Tucunduba,06,,-3.85,-38.75
br,tucunduba,Tucunduba,23,,-27.65,-54.45
br,tucunduva,Tucunduva,23,,-27.65,-54.45
br,tucune,Tucune,06,,-5.216667,-40.833333
br,tucuns ii,Tucuns II,20,,-3.337778,-42.003333
br,tucuns i,Tucuns I,20,,-3.374722,-42.113889
br,tucuns,Tucuns,06,,-2.946111,-40.591944
br,tucuns,Tucuns,13,,-3.591667,-42.678056
br,tucuns,Tucuns,20,,-3.643333,-42.101389
br,tucunzeiro,Tucunzeiro,06,,-2.933333,-40.066667
br,tucupare,Tucuparé,16,,-5.3,-55.85
br,tucuriba,Tucuriba,04,,-5.8,-59.2
br,tucuriu,Tucuriú,16,,-4.166667,-49.683333
br,tucurui,Tucuruí,16,76339,-3.7,-49.7
br,tucuruvi,Tucuruvi,27,,-21.633333,-51.1
br,tudelandia,Tudelândia,21,,-21.9,-41.933333
br,tugurio,Tugúrio,15,,-21.25,-43.583333
br,tuina,Tuina,04,,-.316667,-65.75
br,tuina,Tuína,06,,-3.6,-40.3
br,tuiti,Tuiti,05,,-16.05,-39.383333
br,tuiue,Tuiué,04,,-4.791111,-62.452222
br,tuiuiu,Tuiuiú,11,,-18.866667,-57.7
br,tuiuiu,Tuiuiú,16,,-.816667,-49.133333
br,tuiutinga,Tuiutinga,15,,-21.1,-42.716667
br,tuiuti,Tuiuti,15,,-21.283333,-46.366667
br,tuiuti,Tuiuti,27,,-22.816667,-46.7
br,tuive,Tuivé,04,,-4.791111,-62.452222
br,tujucue,Tujucué,27,,-22.483333,-46.933333
br,tulhas,Tulhas,18,,-23.433333,-50.55
br,tulu,Tulu,15,,-19.1,-41.3
br,tumiritinga,Tumiritinga,15,,-18.966667,-41.633333
br,tumtum,Tumtum,13,,-5.233333,-44.65
br,tunal,Tunal,14,,-16.083333,-60.2
br,tuna mirim,Tuna Mirim,11,,-23.716667,-55.2
br,tunas,Tunas,18,,-24.966667,-49.1
br,tunas,Tunas,23,,-29.05,-52.816667
br,tuna,Tuna,14,,-16.083333,-60.2
br,tuneiras d'oeste,Tuneiras d'Oeste,18,,-23.816667,-52.916667
br,tuneiras do oeste,Tuneiras do Oeste,18,,-23.816667,-52.916667
br,tuneiras,Tuneiras,18,,-23.816667,-52.916667
br,tuntum,Tuntum,13,16402,-5.233333,-44.65
br,tunuhy,Tunuhy,04,,1.4,-68.15
br,tunui,Tunuí,04,,1.4,-68.15
br,tuounare,Tuounaré,16,,-5.3,-55.85
br,tupaceretan,Tupaceretan,23,,-29.083333,-53.85
br,tupaciguara,Tupaciguara,15,24398,-18.583333,-48.7
br,tupacireta,Tupaciretã,23,,-29.083333,-53.85
br,tupacyguara,Tupacyguara,15,,-18.583333,-48.7
br,tupanaci,Tupanaci,30,,-8.266667,-38.583333
br,tupanaoca,Tupanaoca,25,,-1.266667,-61.816667
br,tupanatinga,Tupanatinga,30,5768,-8.75,-37.333333
br,tupana,Tupana,04,,-4.066944,-60.659722
br,tupancireta,Tupanciretã,23,17488,-29.083333,-53.85
br,tupanci,Tupanci,27,,-22.55,-48.166667
br,tupandi,Tupandi,23,,-29.466667,-51.416667
br,tupan,Tupan,27,,-21.933333,-50.5
br,tupaoca,Tupaoca,30,,-7.566667,-35.15
br,tuparandi,Tuparandi,18,,-24.466667,-53.8
br,tuparecetan,Tuparecetan,23,,-29.083333,-53.85
br,tuparece,Tuparecê,15,,-16.416667,-41.633333
br,tuparendi,Tuparendi,23,,-27.75,-54.5
br,tuparetama,Tuparetama,30,,-7.6,-37.316667
br,tupari,Tupari,25,,2.233333,-62.633333
br,tupa,Tupã,27,62036,-21.933333,-50.5
br,tupa,Tupã,30,,-7.6,-37.316667
br,tupenduba,Tupenduba,04,,-3.4,-68.983333
br,tupe,Tupé,04,,-2.516667,-65.9
br,tupim,Tupim,05,,-12.666667,-40.616667
br,tupinamba,Tupinambá,05,,-12.45,-38.983333
br,tupinamba,Tupinambá,18,,-23.283333,-51.7
br,tupinamba,Tupinambá,23,,-28.483333,-51.533333
br,tupinamba,Tupinambá,27,,-20,-50.216667
br,tupiniquins,Tupiniquins,27,,-24.25,-47.366667
br,tupipano,Tupipano,05,,-9.9,-38.833333
br,tupi paulista,Tupi Paulista,27,10877,-21.4,-51.566667
br,tupiracaba,Tupiraçaba,29,,-14.483333,-48.566667
br,tupirama,Tupirama,31,,-8.923056,-48.106667
br,tupirata,Tupiratã,31,,-8.228333,-48.381389
br,tupiratins,Tupiratins,31,,-8.388889,-48.001944
br,tupi silveira,Tupi Silveira,23,,-31.733333,-53.9
br,tupitinga,Tupitinga,26,,-27.5,-51.466667
br,tupi,Tupi,27,,-21.4,-51.566667
br,tupi,Tupi,30,,-8.983333,-36.2
br,tupuio,Tupuio,06,,-5.216667,-40.816667
br,turano,Turano,21,,-22.927413,-43.220334
br,turaru,Turaru,06,,-3.6,-39.433333
br,turco,Turco,15,,-17.25,-41.433333
br,turiaca,Turiaça,21,,-22.860993,-43.339428
br,turiacu,Turiaçu,04,,-5.083333,-62.85
br,turiacu,Turiaçu,13,10471,-1.683333,-45.35
br,turiacu,Turiaçu,21,,-22.860993,-43.339428
br,turiassu,Turiassú,13,,-1.683333,-45.35
br,turiba do sul,Turiba do Sul,27,,-23.75,-49.283333
br,turibai,Turibaí,15,,-20.316667,-44.2
br,turiba,Turiba,27,,-23.75,-49.283333
br,turiel,Turiel,16,,-1.133333,-46.65
br,turirana,Turirana,13,,-1.533333,-45.083333
br,turiuba,Turiúba,27,,-20.916667,-50.1
br,turmalina,Turmalina,15,8798,-17.283333,-42.75
br,turmalina,Turmalina,27,,-20.1,-50.483333
br,turno,Turno,23,,-28.416667,-51.5
br,turuman,Turuman,27,,-22.75,-50.566667
br,turuma,Turumá,11,,-21.283333,-57.866667
br,turuma,Turumã,27,,-22.75,-50.566667
br,tururu,Tururu,06,,-3.583333,-39.45
br,turvania,Turvânia,29,,-16.65,-50.15
br,turvinho,Turvinho,27,,-24,-47.933333
br,turvinia,Turvínia,27,,-21.016667,-48.65
br,turvo de cima,Turvo de Cima,18,,-25.73395,-50.49195
br,turvo dos gois,Turvo dos Góis,27,,-23.883333,-47.583333
br,turvo,Turvo,11,,-21.35,-55.516667
br,turvo,Turvo,15,,-19.633333,-43.366667
br,turvo,Turvo,18,,-25.05,-51.55
br,turvo,Turvo,21,,-22.35,-43.983333
br,turvo,Turvo,23,,-28.416667,-51.5
br,turvo,Turvo,26,,-28.933333,-49.683333
br,turvo,Turvo,27,,-23.281331,-47.949934
br,tury-acu,Tury-Açú,04,,-5.083333,-62.85
br,tury-assu,Tury-Assú,13,,-1.683333,-45.35
br,tutoia,Tutóia,13,12212,-2.75,-42.266667
br,tutoya,Tutoya,13,,-2.75,-42.266667
br,tuyutinga,Tuyutinga,15,,-21.1,-42.716667
br,tuyuti,Tuyuti,27,,-22.816667,-46.7
br,tuyuty,Tuyuty,15,,-21.283333,-46.366667
br,uacana,Uacanã,25,,4.483333,-60.083333
br,uacari,Uacari,04,,1.224444,-69.350556
br,uacoci,Uacoci,14,,-16.183333,-56.083333
br,uacorisal,Uacorisal,24,,-13.516667,-61.733333
br,uacurisal,Uacurisal,14,,-17.433333,-56.866667
br,uacurizal,Uacurizal,14,,-17.433333,-56.866667
br,uacurizal,Uacurizal,24,,-13.516667,-61.733333
br,uacurutuba de cima,Uacurutuba de Cima,14,,-16.4,-56.016667
br,uacurutuba,Uacurutuba,14,,-16.4,-56.016667
br,uainiame,Uainiame,25,,2.766667,-60.383333
br,uanaraca,Uanaraca,04,,-.316667,-66.183333
br,uarati,Uarati,04,,-.316667,-66.083333
br,uara,Uará,04,,-2.616667,-65.616667
br,uarini,Uarini,04,2796,-2.916667,-65.133333
br,uariramba,Uarirambá,04,,1.716667,-69.383333
br,uari,Uari,16,,-6.8,-57.35
br,uaruma,Uaruma,04,,.366667,-68.866667
br,uaruti,Uaruti,04,,-.316667,-66.083333
br,uaruty,Uaruty,04,,-.316667,-66.083333
br,uati,Uati,04,,-5.166667,-67.2
br,uaty,Uaty,04,,-5.166667,-67.2
br,uaua,Uauá,05,11425,-9.833333,-39.466667
br,ubaete,Ubaeté,21,,-22.985618,-43.429983
br,ubaia,Ubaia,22,,-5.783333,-36.060556
br,ubaieira,Ubaieira,22,,-5.222222,-36.307778
br,ubaira,Ubaíra,05,8069,-13.266667,-39.65
br,ubaitaba,Ubaitaba,05,28376,-14.3,-39.333333
br,ubai,Ubaí,15,,-16.283056,-44.778333
br,ubajara,Ubajara,06,13802,-3.85,-40.933333
br,ubaldinho,Ubaldinho,06,,-6.583333,-39.233333
br,ubanheira,Ubanheira,22,,-5.45,-35.433333
br,ubaporanga,Ubaporanga,15,,-19.633333,-42.1
br,ubarana,Ubarana,27,,-21.166667,-49.716667
br,ubari,Ubari,15,,-21.05,-43.066667
br,ubata,Ubatã,05,15605,-14.2,-39.516667
br,ubatiba,Ubatiba,21,,-22.883333,-42.8
br,ubatinga,Ubatinga,20,,-6.716667,-41.45
br,ubatuba,Ubatuba,06,,-3.366667,-41.266667
br,ubatuba,Ubatuba,22,,-5.833333,-35.866667
br,ubatuba,Ubatuba,26,,-26.2,-48.516667
br,ubatuba,Ubatuba,27,79008,-23.433333,-45.066667
br,uba,Ubá,06,,-3.966667,-40.216667
br,uba,Ubá,15,97829,-21.116667,-42.933333
br,ubauna,Ubaúna,06,,-3.733333,-40.666667
br,ubazinho,Ubàzinho,18,,-24.55,-51.25
br,uberaba,Uberaba,06,,-3.616667,-40.883333
br,uberaba,Uberaba,14,,-17.216667,-57.8
br,uberaba,Uberaba,15,260847,-19.75,-47.916667
br,uberaba,Uberaba,22,,-5.883333,-35.866667
br,uberaba,Uberaba,25,,-3.483333,-60.8
br,uberabinha,Uberabinha,27,,-20.533333,-47.716667
br,uberlandia,Uberlândia,05,,-12.433333,-39.1
br,uberlandia,Uberlândia,15,563545,-18.916667,-48.3
br,ubim,Ubim,04,,-7.325278,-71.0125
br,ubiracaba,Ubiraçaba,05,,-14.116667,-41.983333
br,ubiracu,Ubiraçu,06,,-4.383333,-39.633333
br,ubiraita,Ubiraitá,05,,-12.683333,-41.05
br,ubirajara,Ubirajara,27,,-22.566667,-49.65
br,ubirama,Ubirama,27,,-22.6,-48.783333
br,ubirataia,Ubirataia,05,,-14.066667,-39.633333
br,ubirata,Ubirata,22,,-5.6,-35.616667
br,ubiretama,Ubiretama,23,,-28.05,-54.683333
br,ubiricaba,Ubiriçaba,05,,-14.116667,-41.983333
br,uchoa,Uchoa,27,,-20.933333,-49.216667
br,uere,Uerê,11,,-21.7,-52.483333
br,uibai,Uibaí,05,,-11.333333,-42.133333
br,uibal,Uibal,05,,-11.333333,-42.133333
br,uichbine,Uichbiné,25,,2.583333,-60.133333
br,uichibine,Uichibine,25,,2.583333,-60.133333
br,uira paco,Uira Paço,04,,.183333,-69.533333
br,uiraponga,Uiraponga,06,,-5.283333,-38.4
br,uirapuru,Uirapuru,04,,-4.062222,-65.100278
br,uirauna,Uiraúna,17,7823,-6.516667,-38.416667
br,uiuna,Uiúna,23,,-31.4,-53.883333
br,uixibine,Uixibine,25,,2.583333,-60.133333
br,ulbio,Ulbio,01,,-10.333333,-70.366667
br,ultima casa,Última Casa,04,,.916667,-66.85
br,umaiba,Umaiba,16,,-2.05,-48.3
br,umaita,Umaita,16,,-2.05,-48.3
br,umararituba,Umararituba,06,,-3.666667,-38.983333
br,umari poco,Umari Poço,04,,1.283333,-68.95
br,umarituba,Umarituba,04,,.066667,-67.25
br,umarituba,Umarituba,06,,-3.666667,-38.983333
br,umari,Umari,04,,-3.616667,-62.633333
br,umari,Umarí,06,,-3.266667,-40.116667
br,umari,Umari,17,,-6.65,-35.616667
br,umari,Umari,22,,-5.131389,-37.26
br,umari,Umari,30,,-7.75,-39.6
br,umarizal,Umarizal,22,8781,-5.983333,-37.816667
br,umarizeiras,Umarizeiras,06,,-4,-38.716667
br,umarizeira,Umarizeira,06,,-6.566667,-39.316667
br,umarizeiro,Umarizeiro,06,,-4.566667,-38.7
br,umarizeiro,Umarizeiro,22,,-5.199444,-36.376667
br,umary,Umary,06,,-6.633333,-38.7
br,umas,Umãs,30,,-8.183333,-39.3
br,uma,Uma,06,,-3.666667,-38.983333
br,uma,Umã,30,,-8.183333,-39.3
br,umbaranas,Umbaranas,05,,-14.4,-42.616667
br,umbara,Umbará,18,,-25.583333,-49.283333
br,umbauba,Umbaúba,20,,-8.216667,-42.15
br,umbauba,Umbaúba,27,,-20.983333,-48.833333
br,umbauba,Umbaúba,28,12880,-11.366667,-37.65
br,umba,Umba,23,,-29.85,-54.633333
br,umbelino,Umbelino,29,,-16.483333,-52.016667
br,umbilino,Umbilino,29,,-16.483333,-52.016667
br,umbu do paulo,Umbu do Paulo,22,,-5.7,-35.9
br,umburana de cima,Umburana de Cima,05,,-14.033333,-41.383333
br,umburanas,Umburanas,05,,-10.533333,-43.283333
br,umburanas,Umburanas,06,,-4.5,-37.966667
br,umburanas,Umburanas,20,,-5.1,-41.533333
br,umburanas,Umburanas,30,,-7.366667,-37.183333
br,umburana,Umburana,05,,-10.633333,-42.666667
br,umburana,Umburana,06,,-5.533333,-39.816667
br,umburana,Umburana,17,,-7.8,-38.183333
br,umburana,Umburana,20,,-3.972778,-42.015556
br,umburana,Umburana,22,,-5.118333,-36.715556
br,umburana,Umburana,30,,-8.416667,-37.183333
br,umburaninha,Umburaninha,15,,-16.916667,-40.516667
br,umburatiba,Umburatiba,15,,-17.25,-40.583333
br,umburetama,Umburetama,30,,-7.7,-35.666667
br,umburuna,Umburuna,30,,-8.416667,-37.183333
br,umbus,Umbus,20,,-7.4,-41.5
br,umbu,Umbu,23,,-29.85,-54.633333
br,umbu,Umbu,26,,-27.5,-51.466667
br,umbuzeiro de baixo,Umbuzeiro de Baixo,05,,-9.7,-41.883333
br,umbuzeiro do miguel,Umbuzeiro do Miguel,05,,-13.866667,-40.65
br,umbuzeiro dos santos,Umbuzeiro dos Santos,05,,-13.516667,-41.733333
br,umbuzeiro,Umbuzeiro,05,,-11.65,-40.333333
br,umbuzeiro,Umbuzeiro,06,,-7.45,-38.8
br,umbuzeiro,Umbuzeiro,17,4588,-7.683333,-35.666667
br,umbuzeiro,Umbuzeiro,20,,-6.833333,-40.616667
br,umbuzeiro,Umbuzeiro,22,,-5.258611,-36.860556
br,umbuzeiro,Umbuzeiro,30,4588,-7.7,-35.666667
br,umirim,Umirim,06,12220,-3.683333,-39.333333
br,umiris,Umiris,04,,-5.927222,-59.0925
br,umuarama,Umuarama,14,,-13.179167,-59.875
br,umuarama,Umuarama,18,89688,-23.75,-53.333333
br,unahy,Unahy,15,,-16.383333,-46.883333
br,unai,Unaí,15,60203,-16.383333,-46.883333
br,una mirim,Una Mirim,05,,-13.35,-39.183333
br,una,Una,05,22650,-15.3,-39.066667
br,una,Una,08,,-20.183333,-40.333333
br,una,Una,15,,-18.916667,-43.333333
br,una,Una,16,,-1.416667,-48.491667
br,una,Una,26,,-26.3556,-48.6566
br,una,Una,27,,-23.654522,-47.218152
br,unha de gato,Unha de Gato,06,,-6.8,-38.783333
br,unha-de-gato,Unha-de-Gato,13,,-3.415833,-42.630833
br,unha de gato,Unha de Gato,17,,-7,-36.716667
br,unha de gato,Unha de Gato,20,,-6.283333,-41.483333
br,unha do gato,Unha do Gato,05,,-8.566667,-39.433333
br,unhao,Unhão,05,,-12.981667,-38.52
br,uniao baiana,União Baiana,05,,-16.133333,-39.85
br,uniao da victoria,União da Victoria,18,48741,-26.216667,-51.083333
br,uniao da vitoria,União da Vitória,18,,-26.216667,-51.083333
br,uniao de caete,União de Caeté,15,,-19.666667,-43.616667
br,uniao de marara,União de Marará,25,,-.947222,-61.865556
br,uniao dos palmares,União dos Palmares,02,41179,-9.166667,-36.033333
br,uniao feliz,União Feliz,27,,-20.883333,-49.883333
br,uniao marara,União Marará,25,,-.947222,-61.865556
br,uniao queimada,União Queimada,05,,-14.683333,-39.45
br,uniao,União,01,,-9.133333,-70.833333
br,uniao,União,02,,-9.166667,-36.033333
br,uniao,União,04,,-2.866667,-68.783333
br,uniao,União,05,,-12.233333,-40.533333
br,uniao,União,06,,-4.833333,-37.783333
br,uniao,União,08,,-20.916667,-41.083333
br,uniao,União,11,,-17.7,-55.783333
br,uniao,União,13,,-1.85,-45.116667
br,uniao,União,15,,-19.666667,-43.616667
br,uniao,União,20,15678,-4.583333,-42.866667
br,uniao,União,21,,-21.216667,-41.4
br,uniao,União,24,,-10.333333,-62.333333
br,uniao,União,25,,3.533333,-61.083333
br,uniao,União,26,,-26.25,-51.083333
br,uniao,União,27,,-20.883333,-49.883333
br,uniao,União,30,,-7.533333,-39.683333
br,unido,Unido,22,,-5.136111,-36.964444
br,uniflor,Uniflor,18,,-23.084867,-52.157853
br,unistalda,Unistalda,23,,-29.05,-55.15
br,universidade rural,Universidade Rural,21,,-22.766389,-43.691389
br,universo,Universo,27,,-21.9,-50.583333
br,unjao,Unjão,22,,-5.983333,-37.75
br,uomaloli,Uomaloli,14,,-14.666667,-58.333333
br,uomatati,Uomatatí,14,,-14.666667,-58.333333
br,uomataty,Uomataty,14,,-14.666667,-58.333333
br,uomatoti,Uomatoti,14,,-14.666667,-58.333333
br,upabucu,Upabuçu,05,,-13.466667,-40.166667
br,upabucu,Upabuçu,06,,-5.516667,-38.483333
br,upamirim,Upamirim,05,,-10.466667,-41.25
br,upanema,Upanema,22,6704,-5.644444,-37.257778
br,upatininga,Upatininga,30,,-7.666667,-35.183333
br,urai,Uraí,18,,-23.2,-50.816667
br,ura mirim,Ura Mirim,05,,-13.35,-39.183333
br,urandi,Urandi,05,,-12.716667,-41.066667
br,urandy,Urandy,05,,-14.766667,-42.633333
br,urania,Urânia,27,,-20.233333,-50.65
br,uraricoera,Uraricoera,25,,3.45,-60.983333
br,uraricuera,Uraricuera,25,,3.45,-60.983333
br,urbano santos,Urbano Santos,13,12268,-3.2,-43.383333
br,urca,Urca,21,,-22.945476,-43.159927
br,urias alvarenga,Urias Alvarenga,15,,-20.833333,-45.383333
br,urimaman,Urimaman,30,,-8.433333,-39.95
br,urimama,Urimamã,30,,-8.433333,-39.95
br,uriporanga,Uriporanga,05,,-13.366667,-40.183333
br,urtiga,Urtiga,02,,-9.783333,-36.45
br,urtiga,Urtiga,22,,-5.818611,-37.332778
br,urtigueira,Urtigueira,18,,-24.2,-50.916667
br,uruacu,Uruaçu,22,,-5.816667,-35.3
br,uruacu,Uruaçu,29,30088,-14.5,-49.166667
br,uruana,Uruana,29,10258,-15.5,-49.683333
br,uruau,Uruau,06,,-4.216667,-38.033333
br,urubici,Urubici,26,,-28.033333,-49.616667
br,urubicy,Urubicy,26,,-28.033333,-49.616667
br,urubioly,Urubioly,26,,-28.033333,-49.616667
br,urubu choco,Urubu Chôco,30,,-8.716667,-37.316667
br,urubuci,Urubuci,26,,-28.033333,-49.616667
br,urubucu,Urubuçu,13,,-2.383333,-45.616667
br,urubuquara,Urubuquara,04,,.25,-68.516667
br,uruburetama,Uruburetama,01,,-7.966667,-72.766667
br,uruburetama,Uruburetama,06,12076,-3.633333,-39.5
br,urubu,Urubu,02,,-9.416667,-37.783333
br,urubu,Urubú,13,,-4.25,-43.95
br,urubu,Urubu,15,,-19.883333,-46.05
br,urubu,Urubu,16,,-.866667,-48.883333
br,urubu,Urubu,17,,-7.033333,-38.266667
br,urubu,Urubu,30,,-7.833333,-39.4
br,urucanga da praia,Uruçanga da Praia,26,,-28.8,-49.2
br,urucanga de praia,Uruçanga de Praia,26,,-28.8,-49.2
br,urucanga,Uruçanga,18,,-25.283333,-54.25
br,urucanga,Uruçanga,26,,-28.516667,-49.316667
br,urucania,Urucânia,15,,-20.366667,-42.75
br,urucara,Urucará,04,8603,-2.536667,-57.758056
br,urucara,Urucara,06,,-3.916667,-38.683333
br,urucuba,Urucuba,30,,-7.733333,-35.416667
br,urucuca,Uruçuca,05,24414,-14.583333,-39.266667
br,urucuia,Urucuia,15,,-16.116667,-45.733333
br,urucui,Uruçuí,20,12243,-7.233333,-44.55
br,urucu macua,Urucu Macuã,24,,-12.216667,-60.690278
br,urucu-mirim,Uruçu-Mirim,30,,-8.3,-35.6
br,urucum,Urucum,11,,-19.15,-57.633333
br,urucuriteua,Urucuriteua,16,,-1.583333,-47.25
br,urucurituba,Urucurituba,04,10180,-2.683333,-57.666667
br,urucuri,Urucuri,04,,-6.766667,-64.583333
br,urucuri,Urucuri,16,,-1.516667,-47.566667
br,urucury,Urucury,04,,-6.766667,-64.583333
br,urucus,Urucus,20,,-3.565556,-42.508889
br,urucu,Urucu,02,,-9.116667,-35.75
br,urucu,Uruçu,05,,-13.266667,-39.733333
br,urucu,Urucú,15,,-17.716667,-40.75
br,urucu,Urucu,20,,-5.3,-42.433333
br,urucu,Uruçu,29,,-14.5,-49.166667
br,urucuzeiro,Urucuzeiro,13,,-3.863333,-42.842222
br,uruguaiana,Uruguaiana,05,,-16.183333,-39.3
br,uruguaiana,Uruguaiana,23,123482,-29.75,-57.083333
br,uruguaina,Uruguaina,22,,-5.812222,-37.440278
br,uruguai,Uruguai,26,,-27.45,-51.866667
br,uruguai,Uruguai,30,,-7.516667,-39.933333
br,uruguatuba,Uruguatuba,06,,-3.8,-38.633333
br,uruguayana,Uruguayana,23,,-29.75,-57.083333
br,uruguinha,Uruguinha,03,,1.083333,-50.466667
br,uruja,Urujá,27,,-23.4,-46.333333
br,urumajo,Urumajó,16,,-1.033333,-46.616667
br,urumbeba,Urumbeba,11,,-21.183333,-55.683333
br,uruoca,Uruoca,06,,-3.333333,-40.533333
br,uruou,Uruou,23,,-28.733333,-53.616667
br,urupema,Urupema,02,,-9.45,-35.933333
br,urupema,Urupema,26,,-27.95,-49.866667
br,urupes,Urupês,27,10745,-21.216667,-49.283333
br,urupu,Urupu,23,,-28.733333,-53.616667
br,uruque,Uruquê,06,,-5.15,-39.166667
br,ururahy,Ururahy,27,,-21.35,-48.883333
br,ururai,Ururai,21,,-21.8,-41.4
br,ururai,Ururaí,27,,-21.35,-48.883333
br,ururoses,Ururoses,24,,-12.866667,-62.2
br,urussanga da praia,Urussanga da Praia,26,,-28.8,-49.2
br,urussanga,Urussanga,18,,-25.283333,-54.25
br,urussanga,Urussanga,26,10670,-28.516667,-49.316667
br,urussuhy,Urussuhy,20,,-7.233333,-44.55
br,urussui,Urussuí,20,,-7.233333,-44.55
br,urutagua,Urutágua,29,,-14.566667,-47.066667
br,urutahy,Urutahy,29,,-17.466667,-48.2
br,urutai,Urutaí,29,,-17.466667,-48.2
br,urutu,Urutu,13,,-9.45,-46.05
br,uru,Uru,15,,-19.1,-48.166667
br,uru,Uru,26,,-26.95,-49.85
br,uru,Uru,27,,-21.783333,-49.266667
br,urycuca,Uryçuca,05,,-14.583333,-39.266667
br,usina arica,Usina Aricá,14,,-15.983333,-55.9
br,usina itaici,Usina Itaici,14,,-16.066667,-55.9
br,usina mucuna,Usina Mucuna,30,,-8.483333,-37.916667
br,usina recanto,Usina Recanto,02,,-9.3,-36.233333
br,usina santa anna,Usina Santa Anna,14,,-16.05,-55.866667
br,usina sant'ana,Usina Sant'Ana,14,,-16.05,-55.866667
br,usina sao jose,Usina São José,14,,-16.05,-55.9
br,usina sao lourenco,Usina São Lourenço,26,,-26.183503,-49.884768
br,usina serra grande,Usina Serra Grande,02,,-8.966667,-36.066667
br,usina sinimbu,Usina Sinimbú,02,,-9.916667,-36.133333
br,usina taparabo,Usina Taparabo,03,,4,-51.716667
br,usina,Usina,04,,-6.754722,-70.864167
br,usina,Usina,15,,-20.816667,-45.083333
br,usina,Usina,16,,-7.683333,-54.816667
br,usina,Usina,21,,-22.886622,-43.462442
br,utari,Utari,04,,-7.4,-65.133333
br,utary,Utary,04,,-7.4,-65.133333
br,utiariti,Utiariti,14,,-13.033333,-58.283333
br,utiarity,Utiarity,14,,-13.033333,-58.283333
br,utinga,Utinga,02,,-9.8,-36.05
br,utinga,Utinga,05,11949,-10.983333,-42.95
br,utinga,Utinga,22,,-5.8,-35.383333
br,utinga,Utinga,27,,-23.633333,-46.533333
br,uvaia,Uvaia,18,,-25.066667,-50.366667
br,uva,Uvá,29,,-15.883333,-50.416667
br,uxituba,Uxituba,16,,-4.2,-55.833333
br,uxi,Uxi,04,,-4.434722,-62.304167
br,uzina mucuna,Uzina Mucuna,30,,-8.483333,-37.916667
br,uzina taparabo,Uzina Taparabo,03,,4,-51.716667
br,uzina,Uzina,15,,-20.816667,-45.083333
br,vaca brava de cima,Vaca Brava de Cima,06,,-4.916667,-40.066667
br,vaca brava,Vaca Brava,06,,-4.883333,-38.133333
br,vaca brava,Vaca Brava,15,,-16.566667,-43.65
br,vaca brava,Vaca Brava,20,,-3.448056,-42.0725
br,vacacai,Vacacaí,23,,-30.433333,-54.366667
br,vaca morta,Vaca Morta,02,,-9.6,-37.05
br,vaca morta,Vaca Morta,05,,-13.016667,-44.25
br,vaca morta,Vaca Morta,06,,-4.616667,-38.4
br,vaca morta,Vaca Morta,17,,-7.1,-38.2
br,vaca morta,Vaca Morta,20,,-3.763333,-42.492778
br,vaca morta,Vaca Morta,22,,-6.133333,-38.333333
br,vacaria,Vacaria,05,,-10.65,-42.616667
br,vacaria,Vacaria,16,,-2.45,-49.516667
br,vacaria,Vacaria,23,56766,-28.5,-50.933333
br,vaca seca,Vaca Sêca,05,,-12.6,-41.683333
br,vaccacahy,Vaccacahy,23,,-30.433333,-54.366667
br,vaccaria,Vaccaria,16,,-2.45,-49.516667
br,vaccaria,Vaccaria,23,,-28.5,-50.933333
br,vagner,Vagner,05,,-12.216667,-41.183333
br,vai quem quer,Vai Quem Quer,22,,-5.2,-35.8
br,vai-volta,Vai-Volta,15,,-19.316667,-41.9
br,vajoia,Vajoia,22,,-5.133333,-36.45
br,valada sao paulo,Valada São Paulo,26,,-27.143126,-49.618
br,valada taboao,Valada Taboão,26,,-27.2319,-49.614
br,vala do sangue,Vala do Sangue,21,,-22.917138,-43.698624
br,vala do souza,Vala do Souza,08,,-20.783333,-41.4
br,valao da onca,Valão da Onça,21,,-21.733333,-42.033333
br,valao de barro,Valão de Barro,21,,-21.833333,-42.1
br,valao do barro,Valão do Barro,21,,-21.833333,-42.1
br,valao do ponto,Valão do Ponto,21,,-21.433333,-41.133333
br,valao dos porcos,Valão dos Porcos,21,,-21.75,-41.9
br,valao grande,Valão Grande,08,,-19.933333,-40.416667
br,valao,Valão,08,,-20.833333,-41.116667
br,valao,Valão,15,,-17.833333,-41.65
br,val de caens,Val de Caens,16,,-1.383333,-48.483333
br,val-de-caes,Val-de-Cães,16,,-1.383333,-48.483333
br,val de cas,Val de Cãs,16,,-1.383333,-48.483333
br,valdelandia,Valdelândia,27,,-22.4,-50.233333
br,valdelandia,Valdelândia,29,,-15.183333,-50.033333
br,valdelino,Valdelino,05,,-13.183333,-40.083333
br,valdez,Valdez,23,,-31.616667,-52.616667
br,vale das flores,Vale das Flores,27,,-23.395456,-46.646797
br,vale do agrio,Vale do Agrio,21,,-22.387016,-42.874722
br,vale do calharins,Vale do Calharins,21,,-22.926109,-43.423222
br,vale do flambuaia,Vale do Flambuaiã,27,,-23.151389,-46.538611
br,vale do guapore,Vale do Guaporé,14,,-14.420833,-59.595833
br,vale do paraiso,Vale do Paraiso,06,,-5.933333,-39.033333
br,vale do paraiso,Vale do Paraíso,22,,-5.320833,-36.395278
br,vale do paraiso,Vale do Paraíso,24,,-10.430556,-62.133333
br,vale do pariaso,Vale do Paríaso,21,,-22.398351,-42.96206
br,vale do selke,Vale do Selke,26,,-26.7652,-49.1404
br,vale do sol,Vale do Sol,15,,-20.1048,-43.9725
br,vale do sonho,Vale do Sonho,14,,-14.9,-57.15
br,vale dos orixas,Vale dos Orixás,27,,-23.9597,-47.1324
br,vale formoso,Vale Formoso,27,,-21.45,-49.4
br,vale fundo,Vale Fundo,15,,-18.5,-44.066667
br,valenca do piaui,Valença do Piauí,20,15881,-6.4,-41.75
br,valenca,Valença,05,63233,-13.366667,-39.083333
br,valenca,Valenca,06,,-7.1,-39.15
br,valenca,Valença,20,,-6.4,-41.75
br,valenca,Valença,21,61145,-22.241944,-43.701389
br,valenca,Valença,22,,-4.933889,-37.198889
br,valencia,Valência,06,,-5.366667,-39.216667
br,valencia,Valência,18,,-23.15,-51.933333
br,valente,Valente,05,12591,-11.566667,-39.45
br,valentim gentil,Valentim Gentil,27,,-20.416667,-50.083333
br,valentim riet,Valentim Riet,23,,-20.016667,-56.533333
br,valentim,Valentim,22,,-5.566667,-35.816667
br,valentim,Valentim,24,,-10.336111,-62.3
br,valentins,Valentins,15,,-22.5921,-45.6248
br,valentin,Valentin,22,,-6.083333,-38.283333
br,valeria,Valéria,05,,-12.85,-38.433333
br,valerio,Valério,03,,.316667,-51.2
br,valerio,Valério,08,,-18.983333,-40.366667
br,valerio,Valério,14,,-17.316667,-55.866667
br,valerio,Valério,31,,-11.633333,-48.233333
br,vale sedem,Vale Sedém,21,,-22.372766,-42.909568
br,vale verde,Vale Verde,05,,-16.416667,-39.3
br,valha-me deus,Valha-me Deus,02,,-9.35,-38.216667
br,valha-me deus,Valha-me Deus,13,,-1.433333,-44.85
br,valinhos,Valinhos,15,,-21.933333,-45.183333
br,valinhos,Valinhos,18,,-25.324722,-50.360556
br,valinhos,Valinhos,27,88631,-22.95,-47.016667
br,valla do souza,Valla do Souza,08,,-20.783333,-41.4
br,vallao,Vallão,15,,-17.833333,-41.65
br,vallinhos,Vallinhos,18,,-25.324722,-50.360556
br,vallinhos,Vallinhos,27,,-22.95,-47.016667
br,valloes,Vallões,26,,-26.2,-50.8
br,valoes,Valões,26,,-26.2,-50.8
br,valo fundo,Valo Fundo,15,,-18.5,-44.066667
br,valparaiba,Valparaíba,27,,-22.666667,-45.016667
br,valparaiso,Valparaiso,01,,-7.583333,-73.266667
br,valparaiso,Valparaíso,04,,-2.52,-60.859444
br,valparaiso,Valparaiso,17,,-6.366667,-37.75
br,valparaiso,Valparaíso,25,,3.316667,-59.85
br,valparaiso,Valparaíso,27,15939,-21.216667,-50.85
br,valqueire,Valqueire,21,,-22.885415,-43.36949
br,valverde,Valverde,05,,-8.9,-41.433333
br,vamiranga,Vamiranga,27,,-24.735448,-48.036043
br,vamos embora,Vamos Embora,20,,-3.855278,-42.585
br,vamos ver,Vamos Ver,31,,-7.916667,-48.4
br,vanderlei,Vanderlei,05,,-10.9,-42.983333
br,vanderley,Vanderley,05,,-10.9,-42.983333
br,vangloria,Vanglória,27,,-22.45,-48.783333
br,vanique,Vanique,05,,-11.816667,-42.45
br,vao do gato,Vao do Gato,17,,-7.05,-38.633333
br,vao,Vão,20,,-7.566667,-44.716667
br,vaquejador,Vaquejador,13,,-3.421111,-42.272222
br,vaquejador,Vaquejador,14,,-14.383333,-55.616667
br,vaquejador,Vaquejador,20,,-3.618056,-42.530278
br,varador,Varador,03,,.333333,-52.216667
br,varadouro,Varadouro,15,,-20.916667,-45.15
br,varadouro,Varadouro,27,,-23.2991,-46.1996
br,varaneira,Varaneira,26,,-26.8193,-49.948
br,varas,Varas,30,,-7.833333,-37.383333
br,vardem grande,Vardem Grande,21,,-22.970311,-43.482088
br,vardem pequena,Vardem Pequena,21,,-22.989412,-43.461795
br,varedao,Varedão,20,,-7.866667,-45.2
br,vareza do morro,Vareza do Morro,06,,-3.166667,-40.35
br,vargedinho,Vargedinho,27,,-24.616635,-48.085556
br,vargedo,Vargedo,26,,-27.516667,-49.3
br,vargedo,Vargedo,27,,-23.879683,-47.233495
br,vargem alegre,Vargem Alegre,08,,-20.05,-41.3
br,vargem alegre,Vargem Alegre,15,,-19.583333,-42.3
br,vargem alegre,Vargem Alegre,21,,-21.483333,-41.916667
br,vargem alta,Vargem Alta,08,4672,-20.666667,-41
br,vargem alta,Vargem Alta,15,,-20.15,-41.666667
br,vargem bonita,Vargem Bonita,13,,-5.583333,-45.883333
br,vargem bonita,Vargem Bonita,15,,-15.233333,-45.15
br,vargem bonita,Vargem Bonita,18,,-26.116667,-53.016667
br,vargem bonito,Vargem Bonito,15,,-15.233333,-45.15
br,vargem comprida,Vargem Comprida,05,,-9,-38.35
br,vargem comprida,Vargem Comprida,13,,-9.783333,-46.116667
br,vargem comprida,Vargem Comprida,20,,-7.233333,-40.616667
br,vargem d'agua,Vargem d'Agua,05,,-11.033333,-40.083333
br,vargem da onca,Vargem da Onça,06,,-4.466667,-38.683333
br,vargem da porta,Vargem da Porta,20,,-7.283333,-41.833333
br,vargem da roca,Vargem da Roça,05,,-11.616667,-40.15
br,vargem da sanfona,Vargem da Sanfona,15,,-20.383333,-44.083333
br,vargem das bestas,Vargem das Bestas,06,,-4.6,-38.916667
br,vargem das pedras,Vargem das Pedras,06,,-3.5,-40.033333
br,vargem de baixo,Vargem de Baixo,20,,-3.786389,-42.235
br,vargem de cima,Vargem de Cima,20,,-3.774167,-42.248333
br,vargem do capim,Vargem do Capim,05,,-12.766667,-42.366667
br,vargem do cedro,Vargem do Cedro,26,,-28.116667,-48.916667
br,vargem do cerro,Vargem do Cerro,26,,-28.116667,-48.916667
br,vargem do dantas,Vargem do Dantas,05,,-13.05,-40.916667
br,vargem do danta,Vargem do Danta,05,,-13.05,-40.916667
br,vargem do forno,Vargem do Forno,13,,-3.948333,-43.448333
br,vargem do lage,Vargem do Lage,15,,-22.133333,-44.816667
br,vargem do laje,Vargem do Laje,15,,-22.133333,-44.816667
br,vargem do meio,Vargem do Meio,15,,-15.633333,-46.2
br,vargem do sal,Vargem do Sal,05,,-10.416667,-40.7
br,vargem do santana,Vargem do Santana,15,,-20.383333,-44.083333
br,vargem dos bois,Vargem dos Bois,06,,-4.116667,-39.25
br,vargem formoso,Vargem Formoso,15,,-18.25,-41.516667
br,vargem grande do soturno,Vargem Grande do Soturno,08,,-20.783333,-41.05
br,vargem grande do sul,Vargem Grande do Sul,27,36214,-21.833333,-46.883333
br,vargem grande paulista,Vargem Grande Paulista,27,,-23.60511,-47.026761
br,vargem grande,Vargem Grande,04,,-3.283333,-67.833333
br,vargem grande,Vargem Grande,05,,-10.066667,-40.616667
br,vargem grande,Vargem Grande,08,,-20.666667,-40.983333
br,vargem grande,Vargem Grande,13,21420,-3.55,-43.933333
br,vargem grande,Vargem Grande,15,,-15.866667,-41.95
br,vargem grande,Vargem Grande,20,,-7.116667,-41.85
br,vargem grande,Vargem Grande,21,,-22.3389,-44.3952
br,vargem grande,Vargem Grande,27,,-21.833333,-46.883333
br,vargem limpa,Vargem Limpa,13,,-4.966667,-46.133333
br,vargem limpa,Vargem Limpa,15,,-20.0634,-43.7636
br,vargem limpa,Vargem Limpa,27,,-21.933333,-47.616667
br,vargem linda,Vargem Linda,15,,-19.933333,-42.933333
br,vargem mimosa,Vargem Mimosa,15,,-17.316667,-44.466667
br,vargem queimada,Vargem Queimada,20,,-7.533333,-41.233333
br,vargem redonda,Vargem Redonda,30,,-8.983333,-38.316667
br,vargem redondo,Vargem Redondo,30,,-8.983333,-38.316667
br,vargem,Vargem,05,,-12.083333,-41.866667
br,vargem,Vargem,13,,-3.565278,-42.791944
br,vargem,Vargem,15,,-19.7,-44.383333
br,vargem,Vargem,20,,-3.936111,-42.5875
br,vargem,Vargem,27,,-22.733333,-46.85
br,vargen alegre,Vargen Alegre,21,,-22.498611,-43.935556
br,vargens,Vargens,27,,-24.5193,-48.3738
br,vargen,Vargen,22,,-5.966667,-36.35
br,varginha,Varginha,05,,-11.166667,-38.366667
br,varginha,Varginha,06,,-5.1,-39.65
br,varginha,Varginha,13,,-3.924722,-42.888333
br,varginha,Varginha,15,116573,-21.55,-45.433333
br,varginha,Varginha,17,,-6.6,-38.4
br,varginha,Varginha,18,,-24.791536,-48.88876
br,varginha,Varginha,20,,-5.416667,-42.416667
br,varginha,Varginha,22,,-5.437778,-37.295278
br,varginha,Varginha,27,,-20.6,-47.316667
br,varginha,Varginha,30,,-7.65,-37.55
br,vargito,Vargito,05,,-15.45,-39.45
br,variante,Variante,06,,-5.85,-39.433333
br,variante,Variante,20,,-3.885,-42.641111
br,varjao da emendada,Varjão da Emendada,14,,-17.55,-54.233333
br,varjao,Varjão,29,,-17.05,-49.616667
br,varjoia,Varjoia,22,,-5.133333,-36.45
br,varjota de baixo,Varjota de Baixo,13,,-3.96,-43.432778
br,varjota de cima,Varjota de Cima,13,,-3.972222,-43.428333
br,varjota,Varjota,05,,-18.033333,-39.966667
br,varjota,Varjota,06,16462,-4.133333,-40.5
br,varjota,Varjota,17,,-7.516667,-38.466667
br,varjota,Varjota,20,,-3.783333,-42.509444
br,varjota,Varjota,22,,-5.133333,-36.45
br,varjota,Varjota,30,,-7.9,-37.783333
br,varnhagem,Varnhagem,27,,-23.433333,-47.6
br,varnhagen,Varnhagen,27,,-23.433333,-47.6
br,varpa,Varpa,27,,-22.066667,-50.516667
br,varre-sai,Varre-Sai,21,,-20.933333,-41.9
br,varre sarre,Varre Sarre,21,,-20.933333,-41.9
br,varzea alegra,Várzea Alegra,06,,-6.783333,-39.283333
br,varzea alegre,Várzea Alegre,06,21842,-5.35,-40.383333
br,varzea alegre,Várzea Alegre,30,,-7.85,-39.85
br,varzea alegre,Várzea Alegre,31,,-9.963056,-48.753889
br,varzea branca,Várzea Branca,20,,-9.233333,-42.933333
br,varzea comprida,Varzea Comprida,06,,-5.25,-40.783333
br,varzea comprida,Várzea Comprida,17,,-6.9,-37.733333
br,varzea comprida,Várzea Comprida,22,,-5.927222,-36.953333
br,varzea da cacimba,Várzea da Cacimba,06,,-5.3,-40.166667
br,varzea da canabrava,Várzea da Canabrava,05,,-12.166667,-41.65
br,varzea da carnauba,Várzea da Carnaúba,17,,-6.483333,-38.066667
br,varzea da cobra,Varzea da Cobra,06,,-3.85,-40.266667
br,varzea da cruz,Várzea da Cruz,06,,-5.95,-40.35
br,varzea da cruz,Várzea da Cruz,17,,-6.866667,-37.833333
br,varzea da cruz,Várzea da Cruz,20,,-7.266667,-41.783333
br,varzea da cruz,Várzea da Cruz,22,,-6.016667,-38.15
br,varzea da ema,Várzea da Ema,02,,-9.4,-37.283333
br,varzea da ema,Várzea da Ema,05,,-9.5,-38.983333
br,varzea da ema,Várzea da Ema,17,,-6.566667,-37.866667
br,varzea da fome,Varzea da Fome,06,,-6.483333,-39.1
br,varzea da ipueira,Várzea da Ipueira,06,,-4.983333,-39.683333
br,varzea da jurema,Varzea da Jurema,17,,-7.033333,-37.316667
br,varzea da palha,Varzea da Palha,20,,-5.8,-41.833333
br,varzea da palma,Várzea da Palma,15,28706,-17.6,-44.733333
br,varzea da serra,Várzea da Serra,06,,-6.616667,-38.75
br,varzea das negras,Várzea das Negras,02,,-9.016667,-37.516667
br,varzea das russas,Várzea das Russas,06,,-4.983333,-39.3
br,varzea da vaca,Várzea da Vaca,06,,-7.066667,-40.383333
br,varzea da volta,Varzea da Volta,17,,-7.233333,-37.75
br,varzea de baixo,Várzea de Baixo,06,,-6.2,-40.516667
br,varzea de baixo,Várzea de Baixo,13,,-6.483333,-43.866667
br,varzea de capim,Varzea de Capim,17,,-7.316667,-36.016667
br,varzea de dentro,Varzea de Dentro,17,,-6.9,-37.666667
br,varzea de flores,Várzea de Flôres,22,,-5.907778,-36.828611
br,varzea de fora,Várzea de Fora,05,,-11.033333,-41.083333
br,varzea do algodao,Várzea do Algodão,30,,-8.083333,-37.233333
br,varzea do barro,Várzea do Barro,30,,-8.683333,-36.466667
br,varzea do boco,Várzea do Bocó,06,,-6.4,-40.733333
br,varzea do boi,Várzea do Boi,06,,-5.9,-40.25
br,varzea do caicara,Várzea do Caicara,06,,-6.433333,-40.516667
br,varzea do caldas,Várzea do Caldas,05,,-12.533333,-41.716667
br,varzea do calda,Varzea do Calda,05,,-12.533333,-41.716667
br,varzea do canto,Varzea do Canto,20,,-6.266667,-42.083333
br,varzea do canto,Várzea do Canto,22,,-6.3,-38.15
br,varzea do cedro,Várzea do Cedro,23,,-29.216667,-50.466667
br,varzea do cerco,Várzea do Cêrco,05,,-12.05,-41.45
br,varzea doce,Várzea Doce,20,,-7.8,-41.95
br,varzea do coronzo,Várzea do Coronzó,06,,-6.433333,-40.583333
br,varzea do corre,Varzea do Corre,06,,-5.133333,-38.05
br,varzea do espinho,Várzea do Espinho,06,,-4.266667,-40.816667
br,varzea do gato,Várzea do Gato,02,,-9.133333,-37.433333
br,varzea do jenipapeiro,Várzea do Jenipapeiro,05,,-11.016667,-44.733333
br,varzea do jenipapo,Varzea do Jenipapo,20,,-6.766667,-42.7
br,varzea do juazeiro,Várzea do Juàzeiro,22,,-5.963333,-36.673611
br,varzea do mandau,Varzea do Mandau,06,,-3.25,-39.516667
br,varzea do meio,Varzea do Meio,20,,-6.333333,-42.133333
br,varzea do meio,Várzea do Meio,30,,-7.783333,-39.833333
br,varzea do mel,Várzea do Mel,20,,-6.316667,-41.866667
br,varzea do ovo,Várzea do Ôvo,17,,-7.083333,-37.666667
br,varzea do padre,Várzea do Padre,17,,-6.566667,-37.6
br,varzea do padre,Varzea do Padre,20,,-7.6,-41.866667
br,varzea do pau d'arco,Varzea do Pau d'Arco,20,,-6.233333,-41.766667
br,varzea do pinheiro,Varzea do Pinheiro,20,,-7.95,-41.533333
br,varzea do poco,Várzea do Poço,05,,-11.533333,-40.316667
br,varzea do saco,Várzea do Saco,17,,-6.666667,-37.9
br,varzea do sal,Várzea do Sal,17,,-7.533333,-38.416667
br,varzea dos martins,Várzea dos Martins,06,,-6.85,-38.933333
br,varzea dos ossos,Várzea dos Ossos,30,,-8.716667,-36.316667
br,varzeado,Varzeado,30,,-8.766667,-38.216667
br,varzea ema,Várzea Ema,02,,-9.4,-37.283333
br,varzea escondida,Várzea Escondida,30,,-8.083333,-35.766667
br,varzea fria,Varzea Fria,06,,-3.083333,-40.15
br,varzea funda,Várzea Funda,14,,-16.6,-57.766667
br,varzea grande,Várzea Grande,04,,-3.283333,-67.833333
br,varzea grande,Varzea Grande,06,,-3.85,-39.916667
br,varzea grande,Várzea Grande,14,249766,-15.65,-56.133333
br,varzea grande,Várzea Grande,17,,-7.2,-37.75
br,varzea grande,Várzea Grande,20,,-6.55,-42.216667
br,varzea grande,Várzea Grande,22,,-5.866667,-35.433333
br,varzea grande,Várzea Grande,23,,-29.05,-52.066667
br,varzea grande,Várzea Grande,30,,-7.933333,-38.083333
br,varzea limpa,Varzea Limpa,13,,-7.633333,-46.333333
br,varzea nova,Várzea Nova,05,,-11.25,-40.916667
br,varzea nova,Várzea Nova,17,,-7.1,-37.683333
br,varzea nova,Várzea Nova,22,,-6.1,-38.266667
br,varzea nova,Várzea Nova,30,,-8.583333,-37.633333
br,varzeao,Varzeão,18,,-24.566667,-49.433333
br,varzea paulista,Várzea Paulista,27,110938,-23.2,-46.833333
br,varzea redonda,Varzea Redonda,06,,-3.3,-40.15
br,varzea redonda,Várzea Redonda,30,,-8.983333,-38.316667
br,varzearia,Varzearia,14,,-14.166667,-57.166667
br,varzeas,Várzeas,05,,-12.416667,-44.616667
br,varzea,Várzea,05,,-12.166667,-41.65
br,varzea,Várzea,06,,-3.1,-41.533333
br,varzea,Várzea,17,,-6.766667,-37
br,varzea,Várzea,20,,-4.95,-41.966667
br,varzea,Várzea,21,,-22.408289,-42.970566
br,varzea,Várzea,22,,-5.058611,-36.8
br,varzea,Várzea,23,,-28.5,-49.75
br,varzea,Várzea,27,,-22.5,-44.766667
br,varzea,Várzea,30,,-7.9,-38.716667
br,varzea vermelha,Várzea Vermelha,02,,-9.033333,-37.483333
br,varzed grande,Várzed Grande,06,,-5.066667,-40.55
br,varzedo,Varzedo,05,,-12.983333,-39.4
br,varzelandia,Varzelândia,15,6398,-15.7,-44.033333
br,varzeota,Varzeota,30,,-8.6,-38.4
br,varzinha,Varzinha,06,,-5.516667,-40.366667
br,varzinha,Varzinha,30,,-7.85,-39.416667
br,vasantes,Vasantes,06,,-4.416667,-38.7
br,vasco alves,Vasco Alves,23,,-29.916667,-55.95
br,vasco da gama,Vasco da Gama,21,,-22.891769,-43.227817
br,vasconcellos,Vasconcellos,15,,-20.483333,-43.2
br,vasconcelos,Vasconcelos,23,,-30.6,-51.566667
br,vasco,Vasco,30,,-7.866667,-39.133333
br,vasques,Vasques,30,,-7.933333,-39.183333
br,vassoural,Vassoural,18,,-23.616667,-50.316667
br,vassouras,Vassouras,02,,-9.383333,-36.783333
br,vassouras,Vassouras,05,,-9.8,-38.866667
br,vassouras,Vassouras,06,,-3.45,-40.433333
br,vassouras,Vassouras,13,,-3.116944,-42.145278
br,vassouras,Vassouras,17,,-6.716667,-37.866667
br,vassouras,Vassouras,20,,-3.510556,-42.382222
br,vassouras,Vassouras,21,21175,-22.406111,-43.664167
br,vassouras,Vassouras,30,,-7.833333,-35.3
br,vassoura,Vassoura,17,,-7.066667,-38.216667
br,vassoura,Vassoura,18,,-24.55,-49.833333
br,vassoura,Vassoura,30,,-8.933333,-37.966667
br,vassourinha,Vassourinha,17,,-7.183333,-37.35
br,vassouro,Vassouro,17,,-7.433333,-38
br,vasto horizonte,Vasto Horizonte,22,,-6.266667,-38.05
br,vasto,Vasto,22,,-6.266667,-38.05
br,vatinga,Vatinga,27,,-23.7321,-47.9975
br,vau-acu,Vau-Açu,15,,-20.5,-42.9
br,vau novo,Vau Novo,05,,-11.85,-45.166667
br,vau,Vau,15,,-18.416667,-43.533333
br,vau,Vaú,18,,-24.616667,-50.866667
br,vauzinho,Vauzinho,05,,-11.9,-45.383333
br,vazamor,Vazamor,15,,-17.7,-46.833333
br,vazante grande,Vazante Grande,06,,-4.216667,-39.383333
br,vazantes do curu,Vazantes do Curu,06,,-4.416667,-39.616667
br,vazantes,Vazantes,06,,-4.416667,-38.7
br,vazante,Vazante,05,,-12.666667,-41.783333
br,vazante,Vazante,06,,-6.583333,-40.166667
br,vazante,Vazante,15,15459,-18,-46.9
br,vazante,Vazante,17,,-7.083333,-38.483333
br,vazante,Vazante,22,,-6.416667,-35.966667
br,vazantinho,Vazantinho,13,,-3.236667,-42.230278
br,vazea nova,Vázea Nova,20,,-5.966667,-41.483333
br,vazea,Vázea,06,,-7.15,-40.016667
br,vazea,Vázea,20,,-6.95,-41.433333
br,vazlandia,Vazlândia,05,,-12.7,-39.916667
br,vaz lobo,Vaz Lobo,21,,-22.856595,-43.329358
br,vazulmiro dutra,Vazulmiro Dutra,23,,-27.733333,-51.583333
br,veadao,Veadão,31,,-6.783333,-48.466667
br,veadeiros,Veadeiros,29,,-14.116667,-47.516667
br,veadinho do porto,Veadinho do Pôrto,27,,-19.983333,-49.666667
br,veadinhos,Veadinhos,18,,-24.913556,-48.968568
br,veadinho,Veadinho,15,,-19.583333,-41.766667
br,veadinho,Veadinho,27,,-19.983333,-49.666667
br,veado branco,Veado Branco,13,,-3.470278,-42.845556
br,veado branco,Veado Branco,16,,-6.183333,-57.583333
br,veado podre,Veado Podre,30,,-8.2,-36.35
br,veados,Veados,02,,-9.683333,-36.733333
br,veados,Veados,05,,-13.033333,-40.05
br,veados,Veados,06,,-3.866667,-40.383333
br,veados,Veados,20,,-6.833333,-43.483333
br,veado,Veado,15,,-16.616667,-43.983333
br,veado,Veado,20,,-6.833333,-43.5
br,veado,Veado,25,,2.866667,-60.883333
br,veiga cabral,Veiga Cabral,03,,2.05,-50.8
br,veiga,Veiga,25,,3.738028,-59.681904
br,veiros,Veiros,16,,-2.083333,-52.166667
br,velame,Velame,02,,-9.283333,-37.3
br,velame,Velame,05,,-9.55,-43.366667
br,velame,Velame,31,,-6.766667,-48.116667
br,velanie,Velanie,05,,-15.25,-41.1
br,velha boipeba,Velha Boipeba,05,,-13.616667,-38.933333
br,velhaco,Velhaco,23,,-30.9,-51.483333
br,velha de sao joao,Velha de São João,15,,-20.283333,-44.5
br,velha marachita,Velha Marachita,25,,2.533333,-60.6
br,velha,Velha,15,,-20.3,-45.683333
br,velha,Velha,26,,-26.9219,-49.1033
br,velha,Velha,27,,-21.366667,-47.083333
br,velho airao,Velho Airão,04,,-1.95,-61.366667
br,velho belo,Velho Belo,17,,-7.033333,-37.733333
br,velho iarumare,Velho Iarumare,04,,1.3,-67.233333
br,velho lucas,Velho Lucas,15,,-18.416667,-45.733333
br,velho mocambo de santana,Velho Mocambo de Santana,16,,-.316667,-56.016667
br,velho ne,Velho Nê,05,,-16.583333,-39.916667
br,velho porto seguro,Velho Pôrto Seguro,16,,-1.816667,-47.783333
br,velho severo,Velho Severo,16,,-6.75,-51.75
br,velho tapuio,Velho Tapuio,06,,-5.05,-38.616667
br,velho,Velho,06,,-5.8,-40.916667
br,velho,Velho,17,,-7.166667,-38.166667
br,velho,Velho,24,,-8.766667,-63.9
br,venancia ayres,Venancia Ayres,23,,-29.6,-52.183333
br,venancio aires,Venâncio Aires,23,40628,-29.6,-52.183333
br,venancio ayres,Venancio Ayres,23,,-29.6,-52.183333
br,venancio,Venâncio,15,,-15.316667,-46.833333
br,vencaia,Vencaia,18,,-23.066667,-50.55
br,vencedora,Vencedora,06,,-5.983333,-39.266667
br,vencedora,Vencedora,30,,-8.416667,-37.116667
br,vencedor,Vencedor,04,,-5.375556,-60.766667
br,venceslau bras,Venceslau Brás,18,,-23.85,-49.8
br,venceslau braz,Venceslau Braz,18,,-23.85,-49.8
br,venceslau,Venceslau,30,,-7.783333,-39.7
br,vencesleu-bras,Vencesleu-Brás,18,,-23.85,-49.8
br,venda botafogo,Venda Botafogo,18,,-23.46784,-52.625968
br,venda branca,Venda Branca,27,,-21.95,-47.133333
br,venda das flores,Venda das Flores,21,,-21.333333,-42.133333
br,venda do bispo,Venda do Bispo,18,,-23.454601,-52.659543
br,venda grande,Venda Grande,30,,-8.2,-34.916667
br,venda nova,Venda Nova,05,,-13.083333,-39.516667
br,venda nova,Venda Nova,15,,-19.816667,-43.966667
br,venda palmeirinhas sitio,Venda Palmeirinhas Sítio,18,,-23.450209,-52.637328
br,venda,Venda,05,,-14.183333,-43.633333
br,venda,Venda,15,,-20.2,-41.7
br,venda,Venda,21,,-21.233333,-41.733333
br,venda,Venda,23,,-29.033333,-53.65
br,vendinha,Vendinha,23,,-32.061667,-52.143333
br,veneno,Veneno,20,,-3.329722,-42.022778
br,veneno,Veneno,23,,-29.65,-53.516667
br,venesa,Venesa,30,,-8.55,-38.816667
br,veneto,Veneto,23,,-29.65,-53.516667
br,veneza,Veneza,01,,-9.1,-72.3
br,veneza,Veneza,04,,-3.286944,-62.926667
br,veneza,Veneza,05,,-12.3,-40.666667
br,veneza,Veneza,06,,-3.433333,-40.016667
br,veneza,Veneza,11,,-19.316667,-55.583333
br,veneza,Veneza,15,,-16.416667,-40.583333
br,veneza,Veneza,16,,-7.65,-57.583333
br,veneza,Veneza,17,,-6.9,-38.433333
br,veneza,Veneza,20,,-5.583333,-43.016667
br,veneza,Veneza,22,,-5.216667,-37.716667
br,veneza,Veneza,25,,3.183333,-60.383333
br,veneza,Veneza,30,,-7.85,-38.783333
br,veneza,Veneza,31,,-11.566667,-47.616667
br,venezuela,Venezuela,08,,-20.833333,-40.9
br,venezuela,Venezuela,20,,-7.116667,-41.866667
br,ventania,Ventania,18,,-24.266667,-50.233333
br,ventania,Ventania,27,,-21.766667,-46.666667
br,vento frio,Vento Frio,15,,-16.6,-40.466667
br,ventura,Ventura,05,,-11.683333,-40.983333
br,ventura,Ventura,06,,-3.533333,-40.516667
br,ventura,Ventura,13,,-3.644444,-43.498333
br,venturosa,Venturosa,21,,-21.566667,-41.666667
br,venturosa,Venturosa,30,,-8.566667,-36.9
br,veodos,Veodos,15,,-16.616667,-43.983333
br,vera cruz de itaparica,Vera Cruz de Itaparica,05,,-12.983333,-38.7
br,vera cruz do oeste,Vera Cruz do Oeste,18,,-25.0609,-53.8783
br,vera cruz,Vera Cruz,04,,-3.983333,-69.5
br,vera cruz,Vera Cruz,05,30557,-12.633333,-41.033333
br,vera cruz,Vera Cruz,06,,-2.95,-40.183333
br,vera cruz,Vera Cruz,11,,-21.816667,-56.983333
br,vera cruz,Vera Cruz,13,,-5.916667,-46.766667
br,vera cruz,Vera Cruz,15,,-19.7,-44.05
br,vera cruz,Vera Cruz,18,,-26.016667,-50.083333
br,vera cruz,Vera Cruz,21,,-22.489167,-43.434722
br,vera cruz,Vera Cruz,22,,-6.05,-35.433333
br,vera cruz,Vera Cruz,24,,-9.266667,-62.383333
br,vera cruz,Vera Cruz,27,,-22.233333,-49.833333
br,vera cruz,Vera Cruz,30,,-8.25,-40.333333
br,vera guarani,Vera Guarani,18,,-26.033333,-50.783333
br,vera guarany,Vera Guarany,18,,-26.033333,-50.783333
br,vera mendes,Vera Mendes,20,,-7.6,-41.466667
br,veraneio cury,Veraneio Cury,27,,-23.3564,-46.1926
br,veraneio icarai,Veraneio Icaraí,06,,-3.683333,-38.65
br,veranopolis,Veranópolis,23,19862,-28.95,-51.55
br,verava,Verava,27,,-23.7793,-47.102
br,verdadeira,Verdadeira,17,,-7.3,-36.816667
br,verdao,Verdão,02,,-9.266667,-38.016667
br,verdejante,Verdejante,30,,-7.916667,-38.983333
br,verde mar,Verde Mar,23,,-29.55,-49.9
br,verdes,Verdes,17,,-6.766667,-37.95
br,verde,Verde,29,,-14.783333,-50.016667
br,verde,Verde,30,,-8.583333,-35.683333
br,verdum,Verdum,04,,-5.571667,-61.078889
br,vereda alegre,Vereda Alegre,05,,-11.918333,-45.655278
br,vereda comprida,Vereda Comprida,15,,-15.433333,-46.65
br,vereda comprida,Vereda Comprida,20,,-6.416667,-41.85
br,vereda da casca,Vereda da Casca,05,,-10.233333,-43.516667
br,vereda da cobra,Vereda da Cobra,20,,-3.698333,-42.065278
br,vereda da mata,Vereda da Mata,20,,-10.35,-43.966667
br,vereda de sao domingos,Vereda de São Domingos,05,,-12.766667,-41.6
br,vereda do mato,Vereda do Mato,20,,-10.35,-43.966667
br,vereda do meio,Vereda do Meio,05,,-14.733333,-45.2
br,vereda do meio,Vereda do Meio,20,,-3.503333,-42.408333
br,vereda do paraiso,Vereda do Paraíso,15,,-15.466667,-41.45
br,vereda do porta,Vereda do Porta,20,,-7.15,-43.3
br,vereda do rocha,Vereda do Rocha,20,,-5.233333,-41.483333
br,vereda dos bois,Vereda dos Bois,06,,-5.316667,-41.016667
br,vereda grande,Vereda Grande,13,,-3.743611,-43.421944
br,vereda grande,Vereda Grande,17,,-7.516667,-36.05
br,vereda grande,Vereda Grande,20,,-6.916667,-43.083333
br,vereda nova,Vereda Nova,20,,-3.736389,-42.218333
br,veredao,Veredão,20,,-10.5,-44.216667
br,vereda seca,Vereda Sêca,05,,-12.866667,-41.683333
br,veredas,Veredas,15,,-18.133333,-45.766667
br,vereda,Vereda,05,,-12.95,-41.783333
br,vereda,Vereda,13,,-3.182222,-42.621667
br,vereda,Vereda,20,,-3.4975,-42.4775
br,vereda,Vereda,27,,-23.123604,-47.786058
br,veredinha,Veredinha,05,,-15.2,-41.083333
br,veredinha,Veredinha,13,,-3.4375,-43.198056
br,veredinha,Veredinha,15,,-14.8,-44.833333
br,veredinha,Veredinha,20,,-6.3,-42.833333
br,veremos,Veremos,20,,-6.633333,-40.633333
br,vere,Verê,18,,-25.883333,-52.916667
br,verga,Verga,13,,-3.740278,-42.684444
br,vergel,Vergel,21,,-22.15,-42.416667
br,vergueiro,Vergueiro,18,,-23.572335,-50.679745
br,verissimo,Veríssimo,15,,-19.7,-48.3
br,verissimo,Veríssimo,29,,-17.966667,-48.166667
br,vermelhas,Vermelhas,22,,-5.067222,-37.11
br,vermelha velha,Vermelha Velha,15,,-19.983333,-42.333333
br,vermelha,Vermelha,20,,-3.636944,-42.308611
br,vermelha,Vermelha,22,,-5.666667,-37.334167
br,vermelhinha,Vermelhinha,20,,-3.538889,-42.178333
br,vermelho novo,Vermelho Novo,15,,-20.016667,-42.283333
br,vermelhos novo,Vermelhos Novo,15,,-20.016667,-42.283333
br,vermelhos,Vermelhos,30,,-9.066667,-40.133333
br,vermelho velho,Vermelho Velho,15,,-19.983333,-42.333333
br,vermelho,Vermelho,13,,-4.283333,-43.15
br,vermelho,Vermelho,15,,-21.1,-42.45
br,vermelho,Vermelho,20,,-3.923611,-42.223333
br,vermelho,Vermelho,27,,-22.7,-51.366667
br,vermelho,Vermelho,30,,-9.2,-37.116667
br,vermes,Vermes,15,,-20.3,-41.95
br,verneque,Verneque,21,,-22.220833,-43.314444
br,verona casablanca,Verona Casablanca,21,,-22.900934,-43.685054
br,verrugas,Verrugas,15,,-21.416667,-44.583333
br,vertente iii,Vertente III,13,,-3.135833,-43.480556
br,vertente ii,Vertente II,13,,-3.176944,-43.359444
br,vertente i,Vertente I,13,,-3.1775,-43.385833
br,vertentes do lerio,Vertentes do Lério,30,,-7.8,-35.716667
br,vertentes,Vertentes,04,,-7.633333,-70.816667
br,vertentes,Vertentes,06,,-3.416667,-40.116667
br,vertentes,Vertentes,17,,-6.466667,-38.5
br,vertentes,Vertentes,30,,-7.9,-35.983333
br,vertente,Vertente,02,,-9.783333,-37.216667
br,vertente,Vertente,06,,-3.933333,-40.266667
br,vertice,Vértice,16,,-4.580278,-49.576111
br,verzearia,Verzearia,14,,-14.166667,-57.166667
br,vespasiano correa,Vespasiano Corrêa,23,,-29.066667,-51.866667
br,vespasiano correia,Vespasiano Correia,23,,-29.066667,-51.866667
br,vespasiano,Vespasiano,15,94750,-19.666667,-43.916667
br,vestea,Véstea,11,,-20.383333,-51.416667
br,vestia,Véstia,11,,-20.383333,-51.416667
br,viaducto,Viaducto,23,,-27.566667,-52.016667
br,viadutos,Viadutos,23,,-27.566667,-52.016667
br,viagem grande i,Viagem Grande I,13,,-3.251667,-42.184444
br,viamao,Viamão,23,285274,-30.083333,-51.033333
br,viana,Viana,05,,-11.466667,-42.533333
br,viana,Viana,08,55123,-20.383333,-40.5
br,viana,Viana,13,26690,-3.216667,-45
br,viana,Viana,17,,-7.25,-38.433333
br,viana,Viana,21,,-21.683333,-41.116667
br,vianna,Vianna,08,,-20.383333,-40.5
br,vianna,Vianna,13,,-3.216667,-45
br,viannopolis,Viannopolis,29,,-16.75,-48.533333
br,vianopolis,Vianópolis,29,7807,-16.75,-48.533333
br,vibracao,Vibracão,17,,-7.166667,-37.1
br,vicencia,Vicência,30,10378,-7.666667,-35.333333
br,vicentado,Vicentado,27,,-22.65,-47.983333
br,vicente alves,Vicente Alves,15,,-19.433333,-49.933333
br,vicente brito,Vicente Brito,15,,-21.966667,-45.7
br,vicente de carvalho,Vicente de Carvalho,21,,-22.856229,-43.316204
br,vicente de carvalho,Vicente de Carvalho,27,,-23.933333,-46.316667
br,vicente dutra,Vicente Dutra,23,,-27.133333,-53.4
br,vicente ferreira,Vicente Ferreira,15,,-18.583333,-41.35
br,vicente franco,Vicente Franco,16,,-2.216667,-47.833333
br,vicente hipolito,Vicente Hipólito,15,,-20.933333,-46.683333
br,vicente pereira,Vicente Pereira,15,,-18.583333,-41.35
br,vicente,Vicente,16,,-1.316667,-50.083333
br,vicentopolis,Vicentópolis,27,,-20.916667,-50.333333
br,vico emidio,Vico Emídio,15,,-16.3,-40.066667
br,vicosa do ceara,Viçosa do Ceará,06,16637,-3.566667,-41.083333
br,vicosa,Viçosa,02,19574,-9.4,-36.233333
br,vicosa,Viçosa,05,,-17.883333,-39.366667
br,vicosa,Viçosa,06,,-3.566667,-41.083333
br,vicosa,Viçosa,15,68681,-20.75,-42.883333
br,vicosa,Vicosa,22,,-5.983333,-37.933333
br,vicosa,Viçosa,25,,3.5,-61.016667
br,victoria do alto parnahyba,Victoria do Alto Parnahyba,13,,-9.1,-45.95
br,victoria do baixo mearim,Victoria do Baixo Mearim,13,,-3.466667,-44.883333
br,victoria velha,Victoria Velha,01,,-8.516667,-70.833333
br,victoria,Victoria,02,,-9.333333,-36.483333
br,victoria,Victoria,08,,-20.316667,-40.35
br,victoria,Victoria,13,,-9.1,-45.95
br,victoria,Victoria,15,,-21.233333,-44.416667
br,victoria,Victoria,16,,-2.9,-52.016667
br,victoria,Victoria,22,,-6.3,-38.166667
br,victoria,Victoria,27,,-22.783333,-48.4
br,victoria,Victoria,30,,-8.116667,-35.3
br,victorino,Victorino,11,,-20.566667,-52.216667
br,victorino,Victorino,14,,-16.1,-55.8
br,victor meireles,Victor Meireles,26,,-26.8804,-49.8333
br,vidal ramos,Vidal Ramos,26,,-27.383333,-49.366667
br,vidal,Vidal,18,,-23.790571,-50.083441
br,vida nova,Vida Nova,13,,-3.711944,-43.414444
br,vida nova,Vida Nova,16,,-1.15,-51.966667
br,vida nova,Vida Nova,18,,-23.832276,-50.505179
br,videiras,Videiras,21,,-22.429617,-42.967568
br,videira,Videira,26,42441,-27,-51.133333
br,videla,Videla,27,,-21.05,-47.216667
br,videu,Vidéu,05,,-10.566667,-41.566667
br,videu,Videu,06,,-4.7,-40.066667
br,videu,Vidéu,17,,-7.35,-38.416667
br,videu,Vidéu,22,,-5.655,-36.254167
br,vidigai,Vidigaí,18,,-23.566667,-52.566667
br,vidigal,Vidigal,21,,-22.993853,-43.240297
br,vidinha,Vidinha,15,,-22.133333,-44.95
br,viegas,Viegas,22,,-5.2,-35.5
br,vieira cortes,Vieira Cortês,21,,-22.183333,-43.433333
br,vieira cortez,Vieira Cortez,21,,-22.183333,-43.433333
br,vieira de cima,Vieira de Cima,15,,-20.3,-43.966667
br,vieira do sal,Vieira do Sal,06,,-3.2,-39.466667
br,vieira fazenda,Vieira Fazenda,21,,-22.889444,-43.253611
br,vieira gomes,Vieira Gomes,06,,-6.183333,-40.55
br,vieira machado,Vieira Machado,08,,-20.5,-41.333333
br,vieiras bravos,Vieiras Bravos,15,,-20.733333,-45.15
br,vieiras,Vieiras,02,,-9.166667,-38.05
br,vieiras,Vieiras,06,,-5.983333,-38.866667
br,vieiras,Vieiras,15,,-20.166667,-41.816667
br,vieiras,Vieiras,18,,-25.489444,-50.295
br,vieira,Vieira,06,,-4.983333,-37.816667
br,vieira,Vieira,20,,-3.891111,-42.369722
br,vieira,Vieira,21,,-22.216667,-42.716667
br,vieira,Vieira,23,,-32.1,-52.166667
br,vieiros bravos,Vieiros Bravos,15,,-20.733333,-45.15
br,vieja maracachita,Vieja Maracachita,25,,2.533333,-60.6
br,vigario geral,Vigário Geral,21,,-22.808694,-43.311015
br,vigario,Vigário,13,,-3.683333,-45.166667
br,vigia,Vigia,13,,-3.616389,-42.666667
br,vigia,Vigia,15,,-16.183333,-40.7
br,vigia,Vigia,16,29229,-.8,-48.133333
br,vigia,Vigia,20,,-7.45,-41.85
br,vigia,Vigia,26,,-28.083333,-50.533333
br,vigilancia,Vigilância,20,,-3.616111,-42.394444
br,vila albano,Vila Albano,21,,-22.907446,-43.352821
br,vila alda,Vila Alda,27,,-21.983333,-50.216667
br,vila alianca,Vila Aliança,21,,-22.870159,-43.47672
br,vila alice,Vila Alice,27,,-21.616667,-48.616667
br,vila alva,Vila Alva,01,,-8.916667,-70.683333
br,vila alves,Vila Alves,27,,-20.166667,-49.966667
br,vila alzira,Vila Alzira,21,,-22.910703,-43.630626
br,vila amanari,Vila Amanari,04,,-2.481111,-57.7
br,vila amazonia,Vila Amazonia,04,,-2.6,-56.65
br,vila ambe,Vila Ambé,16,,-3.15,-52.216667
br,vila amelia,Vila Amélia,16,,-1.116667,-50.266667
br,vila americana,Vila Americana,27,,-22.740278,-47.334444
br,vila amola flecha,Vila Amola Flecha,26,,-26.0962,-49.8285
br,vila ampere,Vila Ampere,18,,-25.783333,-53.433333
br,vila anastacio,Vila Anastácio,27,,-23.516667,-46.716667
br,vila andrada,Vila Andrada,01,,-8.535556,-72.808333
br,vila andrade,Vila Andrade,04,,-4.3,-63.433333
br,vila araca,Vila Aracá,20,,-7.2,-43.016667
br,vila arama,Vila Aramá,16,,-.95,-50.266667
br,vila arara,Vila Arará,21,,-22.889948,-43.240786
br,vila araujo,Vila Araujo,21,,-22.880086,-43.559747
br,vila arixi,Vila Arixi,04,,-3.48,-61.505833
br,vila assuncao,Vila Assunção,23,,-30.098611,-51.258333
br,vila audenia,Vila Audênia,27,,-22.216667,-50.233333
br,vila babi,Vila Babi,21,,-22.7125,-43.383889
br,vila balnearia,Vila Balneária,21,,-23.005896,-43.298978
br,vila balneario globo,Vila Balneário Globo,21,,-22.964494,-43.708042
br,vila bandeirantes,Vila Bandeirantes,27,,-23.344845,-47.858727
br,vila barbosa,Vila Barbosa,27,,-20.183333,-47.4
br,vila barra de icapara,Vila Barra de Icapara,27,,-24.683333,-47.466667
br,vila barra do icapara,Vila Barra do Icapara,27,,-24.683333,-47.466667
br,vila batista,Vila Batista,04,,-2.6,-56.65
br,vila batista,Vila Batista,27,,-24.3,-47.233333
br,vila bela da santissima trindade,Vila Bela da Santíssima Trindade,14,,-15,-59.95
br,vila bela de santo antonio das queimadas,Vila Bela de Santo Antônio das Queimadas,05,,-10.966667,-39.633333
br,vila bela do turvo,Vila Bela do Turvo,15,,-21.733333,-44.3
br,vila bela,Vila Bela,16,,-4.633333,-49.416667
br,vilabela,Vilabela,27,,-23.783333,-45.35
br,vila bela,Vila Bela,30,,-7.983333,-38.3
br,vila bela vista,Vila Bela Vista,27,,-23.466667,-46.65
br,vila betel,Vila Betel,27,,-23.359391,-47.859157
br,vila bitencort,Vila Bitencort,04,,-1.395833,-69.422222
br,vila bittencourt,Vila Bittencourt,04,,-1.395833,-69.422222
br,vila bolsom,Vila Bolsom,18,,-25.1937,-53.9409
br,vila borges,Vila Borges,21,,-22.834531,-43.321572
br,vila brabo,Vila Brabo,16,,-4.266667,-49.583333
br,vila braga,Vila Braga,16,,-4.416667,-56.283333
br,vila branca,Vila Branca,27,,-23.6617,-47.5454
br,vila brasilia,Vila Brasília,18,,-25.7847,-49.3211
br,vila brasil,Vila Brasil,11,,-22.366667,-54.566667
br,vila brasil,Vila Brasil,21,,-22.877823,-43.40944
br,vila brasil,Vila Brasil,25,,3.666667,-61.383333
br,vila brasil,Vila Brasil,27,,-22.7475,-47.420278
br,vila bras,Vila Brás,27,,-24.686396,-48.122647
br,vila brava,Vila Brava,16,,-4.416667,-56.283333
br,vila cajado,Vila Cajado,27,,-21.5,-48.733333
br,vila california,Vila Califórnia,21,,-22.864997,-43.765754
br,vila calmon,Vila Calmon,04,,-7.633333,-68.933333
br,vila camara,Vila Camará,04,,-3.921667,-62.618333
br,vila camorim,Vila Camorim,21,,-22.965898,-43.41389
br,vila campina,Vila Campina,18,,-25.876962,-49.482776
br,vila campinho,Vila Campinho,21,,-22.88576,-43.33968
br,vila cardoso,Vila Cardoso,27,,-21.333333,-49.166667
br,vila carioba,Vila Carioba,27,,-22.715,-47.324722
br,vila carvalho,Vila Carvalho,27,,-20.483333,-50.016667
br,vila castilho,Vila Castilho,27,,-20.783333,-50.333333
br,vila catiri,Vila Catiri,21,,-22.8481,-43.47122
br,vila clara,Vila Clara,23,,-29.55,-54.35
br,vila comari,Vila Comari,21,,-22.91782,-43.558356
br,vila comprida,Vila Comprida,20,,-6.416667,-41.833333
br,vila conceicao,Vila Conceição,04,,.116667,-63.95
br,vila conceicao,Vila Conceição,23,,-30.125,-51.254167
br,vila conrado,Vila Conrado,27,,-21.966667,-46.783333
br,vila corcundinha,Vila Corcundinha,21,,-22.88603,-43.583961
br,vila cosmos,Vila Cosmos,21,,-22.852989,-43.303186
br,vila costa,Vila Costa,27,,-20.933333,-49.7
br,vila costina,Vila Costina,15,,-20.366667,-45.816667
br,vila couto,Vila Couto,27,,-22.45,-49.766667
br,vila cristina,Vila Cristina,28,,-11.483333,-37.766667
br,vila croacia,Vila Croácia,21,,-22.876491,-43.494234
br,vila cruzeiro,Vila Cruzeiro,18,,-25.624715,-50.699013
br,vila cruzeiro,Vila Cruzeiro,21,,-22.850207,-43.281299
br,vila cunani,Vila Cunani,03,,2.866667,-51.1
br,vila da alegria,Vila da Alegria,23,,-30.116667,-51.316667
br,vila da esperanca,Vila da Esperança,05,,-12.433333,-40.75
br,vila dagmar,Vila Dagmar,21,,-22.766601,-43.401175
br,vila da grama,Vila da Grama,21,,-22.2,-42.133333
br,vila da penha,Vila da Penha,21,,-22.845091,-43.307947
br,vila da prata,Vila da Prata,04,,-4.035556,-60.617778
br,vila da saudade,Vila da Saudade,21,,-22.760354,-43.337495
br,vila da saude,Vila da Saúde,27,,-23.6,-46.633333
br,vila de carvalho,Vila de Carvalho,27,,-20.483333,-50.016667
br,vila de castelo,Vila de Castelo,20,,-5.333333,-41.55
br,vila deco,Vila Deco,27,,-24.680075,-48.142296
br,vila de floriano peixoto,Vila de Floriano Peixoto,04,,-9.05,-67.4
br,vila de nossa senhora aparecida,Vila de Nossa Senhora Aparecida,27,,-22.69067,-45.735505
br,vila de pernambuco,Vila de Pernambuco,16,,-1.466667,-48.033333
br,vila de sao roque do paraguacu,Vila de Sao Roque do Paraguacu,05,,-12.85,-38.85
br,vila diamantes,Vila Diamantes,21,,-22.846759,-43.351908
br,vila dias,Vila Dias,04,,-3.931667,-62.806944
br,vila do arari,Vila do Arari,04,,-2.474722,-57.221944
br,vila do carmo,Vila do Carmo,16,,-2.5,-49.416667
br,vila do ceu,Vila do Céu,21,,-22.90781,-43.608024
br,vila do clementino,Vila do Clementino,13,,-5.866667,-47.383333
br,vila do conde,Vila do Conde,17,,-7.266667,-34.9
br,vila do costao,Vila do Costão,27,,-24.71739,-48.15757
br,vila do felix,Vila do Félix,06,,-4.516667,-38.166667
br,vila do feliz,Vila do Feliz,06,,-4.516667,-38.166667
br,vila do iranduba,Vila do Iranduba,04,,-3.279167,-60.187778
br,vila do joao,Vila do João,21,,-22.873862,-43.240161
br,vila dora,Vila Dora,04,,-3.4775,-62.623056
br,vila dos anjos,Vila dos Anjos,15,,-17.766667,-42.3
br,vila dos remedios,Vila dos Remédios,30,,-3.85,-32.4
br,vila dossi,Vila Dossi,18,,-23.078918,-52.223103
br,vila dos targinos,Vila dos Targinos,06,,-4.633333,-39.233333
br,vila doutor laurindo,Vila Doutor Laurindo,27,,-23.342893,-47.836764
br,vila ede,Vila Ede,27,,-23.49119,-46.593398
br,vila elsa,Vila Elsa,23,,-30.133333,-51.316667
br,vila elza,Vila Elza,23,,-30.133333,-51.316667
br,vila equitativa,Vila Equitativa,21,,-22.626111,-43.236389
br,vila esmeralda,Vila Esmeralda,18,,-25.142,-53.9747
br,vila esperanca,Vila Esperança,21,,-22.823362,-43.337153
br,vila esperanca,Vila Esperança,27,,-23.774854,-46.718283
br,vila ester,Vila Ester,18,,-25.624658,-50.681467
br,vila eugenia,Vila Eugênia,21,,-22.851044,-43.375191
br,vila eunice,Vila Eunice,21,,-22.91858,-43.530844
br,vila fatima,Vila Fátima,18,,-25.291884,-48.154716
br,vila feijo,Vila Feijó,01,,-8.15,-70.35
br,vila ferreira,Vila Ferreira,27,,-22.551389,-47.410833
br,vila florenca,Vila Florença,21,,-22.856237,-43.305432
br,vila flores,Vila Flores,23,,-28.9,-51.566667
br,vila flor,Vila Flor,22,,-6.316667,-35.066667
br,vila franca,Vila Franca,16,,-2.333333,-55.033333
br,vila galmon,Vila Galmon,04,,-7.633333,-68.933333
br,vila galvao,Vila Galvão,27,,-23.453191,-46.567089
br,vila gaucha,Vila Gaúcha,11,,-21.533333,-56.566667
br,vilage da brisa,Vilage da Brisa,21,,-22.97783,-43.664689
br,vilagem do cachoeira,Vilagem do Cachoeira,16,,-3,-52.233333
br,vila geni,Vila Geni,21,,-22.913439,-43.633144
br,vila gestal,Vila Gestal,27,,-20.15,-49.683333
br,vila ghandi,Vila Ghandi,18,,-22.95,-51.15
br,vila gloria,Vila Glória,11,,-22.35,-54.216667
br,vila gomes,Vila Gomes,04,,-7.583333,-70.116667
br,vila gomez,Vila Gomez,04,,-7.583333,-70.116667
br,vila gopouva,Vila Gopoúva,27,,-23.466667,-46.533333
br,vila grande,Vila Grande,30,,-8.516667,-38.166667
br,vila guaira,Vila Guaira,18,,-23.333333,-52.083333
br,vila guai,Vila Guaí,18,,-23.700738,-50.229594
br,vila guanabara,Vila Guanabara,21,,-22.784333,-43.292715
br,vila guarani,Vila Guarani,18,,-23.782521,-50.058268
br,vila guari,Vila Guari,21,,-22.941258,-43.337624
br,vila guay,Vila Guay,18,,-23.700738,-50.229594
br,vila guedes,Vila Guedes,27,,-23.49077,-46.740752
br,vila gumercindo,Vila Gumercindo,27,,-23.3198,-46.2221
br,vila heliopolis,Vila Heliópolis,21,,-22.731893,-43.410652
br,vila hungaresa,Vila Hungaresa,27,,-23.401357,-46.744478
br,vila iara,Vila Iara,27,,-23.470894,-46.710394
br,vila ibirapitanga,Vila Ibirapitanga,21,,-22.853501,-43.760409
br,vila ideal,Vila Ideal,21,,-22.79413,-43.315747
br,vila ieda,Vila Iêda,21,,-22.887065,-43.59492
br,vila igarata,Vila Igaratá,21,,-22.905775,-43.614791
br,vila imaculada,Vila Imaculada,27,,-23.437965,-46.532381
br,vila inglesa,Vila Inglesa,27,,-22.7462,-45.5643
br,vila isabel,Vila Isabel,18,,-25.779571,-50.163442
br,vila isabel,Vila Isabel,21,,-22.913101,-43.247952
br,vila isabel,Vila Isabel,27,,-23.8649,-46.6564
br,vila itambi,Vila Itambi,21,,-22.891517,-43.433786
br,vila itangua,Vila Itangua,27,,-23.532092,-47.510754
br,vila itapua,Vila Itapua,27,,-23.425308,-46.534224
br,vila jacare,Vila Jacaré,21,,-22.877119,-43.503235
br,vila japonesa,Vila Japonesa,18,,-23.0053,-50.0755
br,vila jardim campo grande,Vila Jardim Campo Grande,21,,-22.916793,-43.536091
br,vila jatai,Vila Jataí,14,,-13.391667,-59.8625
br,vila joaniza,Vila Joaniza,21,,-22.814154,-43.230714
br,vilajoia,Vilajoia,23,,-28.65,-54.133333
br,vila kennedy,Vila Kennedy,21,,-22.856784,-43.488991
br,vila leopoldina,Vila Leopoldina,21,,-22.759105,-43.299461
br,vila leuza,Vila Leuza,27,,-21,-49.816667
br,vila lima,Vila Lima,27,,-24.724247,-48.044709
br,vila lurdes,Vila Lurdes,27,,-20.966667,-50.216667
br,vila macuco,Vila Macuco,27,,-23.95,-46.316667
br,vila maestra,Vila Maestra,23,,-29.1113,-51.1852
br,vila magali,Vila Magali,21,,-22.893187,-43.567321
br,vila mallet,Vila Mallet,21,,-22.881032,-43.412738
br,vila maranhao,Vila Maranhão,13,,-2.616667,-44.316667
br,vila mariana,Vila Mariana,27,,-23.583333,-46.633333
br,vila maria,Vila Maria,14,,-16.066667,-57.683333
br,vila maria,Vila Maria,15,,-22.6069,-45.5606
br,vila maria,Vila Maria,23,,-28.533333,-52.15
br,vila maria,Vila Maria,27,,-22.720278,-47.34
br,vila mariland,Vila Mariland,23,,-29.1426,-51.1423
br,vila mariopolis,Vila Mariópolis,21,,-22.824639,-43.411904
br,vila maripa,Vila Maripá,18,,-24.416667,-53.833333
br,vila martins,Vila Martins,27,,-22.083333,-51.166667
br,vila massenia,Vila Massenia,27,,-20.65,-49.95
br,vila matias,Vila Matias,15,,-18.566667,-41.883333
br,vila matias,Vila Matias,27,,-23.4839,-46.0793
br,vila medeiros,Vila Medeiros,21,,-22.7434,-43.400567
br,vila meriti,Vila Meriti,21,,-22.787926,-43.315029
br,vila militar,Vila Militar,18,,-25.4125,-50.0075
br,vila militar,Vila Militar,21,,-22.862276,-43.397098
br,vila modelo,Vila Modêlo,26,,-26.783333,-53.016667
br,vila molica,Vila Molica,27,,-22.794369,-45.208161
br,vila monjolo,Vila Monjolo,27,,-23.491748,-46.692844
br,vila monteiro lobato,Vila Monteiro Lobato,27,,-23.457155,-46.505608
br,vila monteiro,Vila Monteiro,27,,-20.316667,-49.9
br,vila moreti,Vila Moreti,21,,-22.864221,-43.467915
br,vila morungava,Vila Morungava,23,,-29.8523,-50.9081
br,vila mota,Vila Mota,18,,-24.67325,-48.901567
br,vila moura,Vila Moura,06,,-2.966667,-40.116667
br,vila muriqui,Vila Muriqui,21,,-22.922778,-43.945556
br,vila murtinho,Vila Murtinho,24,,-10.4,-65.366667
br,vila natal,Vila Natal,23,,-29.9285,-50.9957
br,vila neumann,Vila Neumann,26,,-26.209864,-49.719002
br,vila nobre,Vila Nobre,16,,-1.233333,-50.183333
br,vila nordestina,Vila Nordestina,27,,-21.066667,-51.566667
br,vila nosali,Vila Nosali,21,,-22.795833,-43.370278
br,vila nova cachoeirinha,Vila Nova Cachoeirinha,27,,-23.465366,-46.668476
br,vila nova conceicao,Vila Nova Conceição,06,,-6.333333,-38.966667
br,vila nova de buique,Vila Nova de Buíque,30,,-8.616667,-37.15
br,vila nova de imperatriz,Vila Nova de Imperatriz,13,,-5.533333,-47.483333
br,vila nova do bananal,Vila Nova do Bananal,08,,-19.683333,-41.133333
br,vila nova do poti,Vila Nova do Poti,20,,-5.083333,-42.816667
br,vila nova esperanca,Vila Nova Esperança,27,,-23.8692,-46.6571
br,vila novais,Vila Novais,27,,-20.983333,-48.933333
br,vila nova laranjeiras,Vila Nova Laranjeiras,18,,-25.3,-52.533333
br,vila nova timbo,Vila Nova Timbó,26,,-26.35,-50.866667
br,vila nova,Vila Nova,04,,-6.533333,-58.2
br,vila nova,Vila Nova,05,,-17.366667,-40.3
br,vila nova,Vila Nova,06,,-5.883333,-39.083333
br,vila nova,Vila Nova,08,,-19.683333,-41.133333
br,vila nova,Vila Nova,13,,-3.430278,-42.533056
br,vila nova,Vila Nova,14,,-16.8,-53.05
br,vila nova,Vila Nova,16,,-1.15,-51.966667
br,vila nova,Vila Nova,18,,-22.816667,-51.083333
br,vila nova,Vila Nova,20,,-6.766667,-41.416667
br,vila nova,Vila Nova,21,,-21.45,-41.4
br,vila nova,Vila Nova,22,,-4.983333,-37.55
br,vila nova,Vila Nova,23,,-29.8,-50.75
br,vila nova,Vila Nova,25,,3.333333,-61.316667
br,vila nova,Vila Nova,26,,-26.35,-50.866667
br,vila nova,Vila Nova,27,,-22.616667,-47.583333
br,vila nova,Vila Nova,28,,-10.3,-36.583333
br,vila novo do timbo,Vila Novo do Timbo,26,,-26.35,-50.866667
br,vila oeste,Vila Oeste,14,,-13.679167,-59.729167
br,vila olimpia,Vila Olímpia,27,,-23.574911,-47.443814
br,vila olinda,Vila Olinda,27,,-21.983333,-50.216667
br,vila oliva,Vila Oliva,23,,-29.233333,-50.883333
br,vila oliveira,Vila Oliveira,27,,-22.744444,-47.408056
br,vila osris,Vila Osris,27,,-23.3147,-46.2316
br,vilao,Vilão,20,,-7.566667,-41.133333
br,vila paciencia,Vila Paciência,21,,-22.932434,-43.648574
br,vila palmares,Vila Palmares,21,,-22.893113,-43.59388
br,vila palmeira,Vila Palmeira,18,,-25.066667,-50.166667
br,vila palmira,Vila Palmira,18,,-25.675239,-50.175858
br,vila pan americana,Vila Pan Americana,21,,-22.973531,-43.357087
br,vila paraiso,Vila Paraíso,21,,-22.92876,-43.369515
br,vila parecis,Vila Parecis,24,,-12.183333,-61.6
br,vila pedro ii,Vila Pedro II,21,,-22.806811,-43.35808
br,vila pereira barreto,Vila Pereira Barreto,27,,-23.486486,-46.721459
br,vila pereira,Vila Pereira,15,,-17.833333,-40.65
br,vila pereira,Vila Pereira,25,,4.216667,-60.766667
br,vila pinheiros,Vila Pinheiros,21,,-22.867146,-43.237262
br,vila piteira,Vila Piteira,15,,-17.883333,-41.333333
br,vila pompeia,Vila Pompeia,21,,-22.842189,-43.404698
br,vila primavera,Vila Primavera,21,,-22.86536,-43.315702
br,vila primavera,Vila Primavera,27,,-23.107778,-46.706944
br,vila progresso,Vila Progresso,05,,-10.4,-40.116667
br,vila progresso,Vila Progresso,06,,-2.95,-40.116667
br,vila progresso,Vila Progresso,18,,-22.766667,-51.5
br,vila proletaria,Vila Proletaria,21,,-22.861275,-43.371921
br,vila prota,Vila Prota,21,,-22.652778,-43.312778
br,vila queimado,Vila Queimado,18,,-25.7886,-49.3329
br,vila queiros,Vila Queiros,27,,-22.550556,-47.392222
br,vila rangel,Vila Rangel,21,,-22.844696,-43.314869
br,vila raquel,Vila Raquel,18,,-25.507686,-50.661122
br,vilar carioca,Vilar Carioca,21,,-22.92019,-43.602291
br,vilar dos teles,Vilar dos Teles,21,,-22.779325,-43.360431
br,vila real da praia grande,Vila Real da Praia Grande,21,,-22.90214,-43.130301
br,vila real do crato,Vila Real do Crato,06,,-7.233333,-39.383333
br,vila real do senhor bom jesus de cuiaba,Vila Real do Senhor Bom Jesus de Cuiabá,14,,-15.583333,-56.083333
br,vila remanso,Vila Remanso,04,,-4.904167,-60.183889
br,vila residencial da companhia paranaense de energia,Vila Residencial da Companhia Paranaense de Energia,18,,-23.754245,-50.901325
br,vila residencial da companhia paranaense do energia,Vila Residencial da Companhia Paranaense do Energia,18,,-23.855414,-50.392626
br,vilar guanabara,Vilar Guanabara,21,,-22.911486,-43.602225
br,vila rica,Vila Rica,04,,-3.666667,-61.083333
br,vila rica,Vila Rica,06,,-4.933333,-38.75
br,vila rica,Vila Rica,27,,-23.5271,-47.5053
br,vilarinho do monte,Vilarinho do Monte,16,,-1.616667,-52.016667
br,vila rio de janeiro,Vila Rio de Janeiro,27,,-23.44676,-46.541936
br,vila rondonia,Vila Rondônia,24,,-10.866667,-61.95
br,vila rosali,Vila Rosali,21,,-22.793415,-43.36995
br,vila rosario,Vila Rosario,21,,-22.740871,-43.315022
br,vila rosina,Vila Rosina,27,,-23.385579,-46.737508
br,vilar santa rosa,Vilar Santa Rosa,21,,-22.88341,-43.585413
br,vila ruthes,Vila Ruthes,26,,-26.2173,-49.8305
br,vilar,Vilar,22,,-5.85,-35.25
br,vila sabrina,Vila Sabrina,27,,-23.486635,-46.566508
br,vila sangamon,Vila Sangamon,27,,-23.2868,-46.2123
br,vila santa adelaide,Vila Santa Adelaide,27,,-22.7108,-45.531
br,vila santa cruz,Vila Santa Cruz,27,,-22.744162,-45.614297
br,vila santa isabel,Vila Santa Isabel,27,,-23.460086,-46.69276
br,vila santa luzia,Vila Santa Luzia,21,,-22.917741,-43.620969
br,vila santa maria,Vila Santa Maria,21,,-22.877957,-43.587071
br,vila santa maria,Vila Santa Maria,27,,-23.002629,-49.891228
br,vila santa rita,Vila Santa Rita,21,,-22.910363,-43.54279
br,vila santa tereza,Vila Santa Tereza,21,,-22.840861,-43.356955
br,vila santo antonio,Vila Santo António,21,,-22.789865,-43.546481
br,vila sao cristovao,Vila São Cristóvão,27,,-22.572778,-47.398611
br,vila sao domingos,Vila São Domingos,06,,-4.233333,-39.283333
br,vila sao jao,Vila São Jão,18,,-25.495,-50.645
br,vila sao joao,Vila São João,06,,-3.25,-39.916667
br,vila sao joao,Vila São João,20,,-7.116667,-41.083333
br,vila sao joao,Vila São João,21,,-22.765708,-43.357986
br,vila sao joao,Vila São João,27,,-22.560833,-47.410278
br,vila sao jorge,Vila São Jorge,21,,-22.833804,-43.331972
br,vila sao jose,Vila São José,04,,-4.938889,-60.230556
br,vila sao jose,Vila São José,21,,-22.901491,-43.542893
br,vila sao judas tadeu,Vila São Judas Tadeu,18,,-26.1174,-49.7739
br,vila sao lazaro,Vila São Lazaro,21,,-22.880062,-43.21706
br,vila sao lazaro,Vila São Lázaro,27,,-23.358194,-47.844022
br,vila sao luis,Vila São Luís,21,,-22.736895,-43.437355
br,vila sao miguel,Vila São Miguel,21,,-22.870535,-43.418248
br,vila sao pedro,Vila São Pedro,18,,-23.613834,-50.160015
br,vilas boas,Vilas Boas,15,,-20.8,-47.083333
br,vila seabra,Vila Seabra,01,,-8.166667,-70.766667
br,vila seca,Vila Sêca,23,,-28.7,-51.7
br,vila sena,Vila Sena,27,,-20.65,-49.95
br,vila siqueira,Vila Siqueira,23,,-32.15,-52.108333
br,vila soleriedade,Vila Soleriedade,26,,-26.0998,-49.8151
br,vila so paulo,Vila So Paulo,27,,-23.480645,-46.127158
br,vila sossego,Vila Sossego,27,,-24.648379,-48.288267
br,vila suia,Vila Suia,27,,-23.4991,-46.1452
br,vila tatu,Vila Tatu,27,,-24.8016,-48.2106
br,vila tepequem,Vila Tepequém,25,,3.75,-61.716667
br,vila teresa,Vila Teresa,21,,-22.739764,-43.327331
br,vila terezinha,Vila Terezinha,21,,-22.878145,-43.445068
br,vila timoteo,Vila Timoteo,27,,-23.478898,-46.695826
br,vila tiradentes,Vila Tiradentes,21,,-22.79286,-43.387126
br,vila trocaris,Vila Trocaris,04,,-3.893333,-62.8475
br,vila turismo,Vila Turismo,21,,-22.875128,-43.25711
br,vila universal,Vila Universal,21,,-22.945856,-43.667708
br,vila valqueire,Vila Valqueire,21,,-22.885415,-43.36949
br,vila vanessa,Vila Vanessa,27,,-22.539722,-47.426111
br,vila vargas,Vila Vargas,27,,-21.083333,-51.583333
br,vila velha do cacipore,Vila Velha do Caciporé,03,,3.216667,-51.216667
br,vila velha,Vila Velha,03,,3.216667,-51.216667
br,vila velha,Vila Velha,05,,-11.333333,-38.15
br,vila velha,Vila Velha,08,394937,-20.333333,-40.283333
br,vila velha,Vila Velha,13,,-4.283333,-44.733333
br,vila velha,Vila Velha,27,,-24.583333,-47.6
br,vila velha,Vila Velha,30,,-7.8,-34.85
br,vila verde,Vila Verde,05,,-16.416667,-39.3
br,vila verde,Vila Verde,08,,-18.983333,-40.883333
br,vila verde,Vila Verde,21,,-22.73441,-43.354958
br,vila verde,Vila Verde,27,,-23.215278,-46.571667
br,vila vintem,Vila Vintém,21,,-22.870907,-43.444742
br,vila yolanda,Vila Yolanda,21,,-22.878934,-43.550864
br,vila zaff,Vila Zaff,27,,-23.467757,-46.707064
br,vila zulmira,Vila Zulmira,18,,-26.166667,-51.133333
br,vila zulmira,Vila Zulmira,21,,-22.788909,-43.395318
br,vilela,Vilela,15,,-18.65,-48.25
br,vilhena,Vilhena,24,63237,-12.716667,-60.116667
br,vilia bittencort,Vilia Bittencort,04,,-1.395833,-69.422222
br,villa alba,Villa Alba,01,,-8.916667,-70.683333
br,villa alva,Villa Alva,01,,-8.916667,-70.683333
br,villa ambe,Villa Ambé,16,,-3.15,-52.216667
br,villa americana,Villa Americana,27,,-22.740278,-47.334444
br,villa anastacio,Villa Anastacio,27,,-23.516667,-46.716667
br,villa andrada,Villa Andrada,01,,-8.535556,-72.808333
br,villa antonina,Villa Antonina,27,,-20.566667,-50.616667
br,villa arama,Villa Arama,16,,-.95,-50.266667
br,villa baptista,Villa Baptista,04,,-2.6,-56.65
br,villa bella de santissima trinidade,Villa Bella de Santissima Trinidade,14,,-15,-59.95
br,villa bella,Villa Bella,27,,-23.783333,-45.35
br,villa bella,Villa Bella,30,,-7.983333,-38.3
br,villa bittencourt,Villa Bittencourt,04,,-1.395833,-69.422222
br,villa braga,Villa Braga,16,,-4.416667,-56.283333
br,villa calmon,Villa Calmon,04,,-7.633333,-68.933333
br,villa christina,Villa Christina,28,,-11.483333,-37.766667
br,villa de mafra,Villa de Mafra,26,,-26.1181,-49.8023
br,villa elizario,Villa Elizario,27,,-21.166667,-49.116667
br,villa engenho dodt,Villa Engenho Dodt,20,,-8.816667,-45.933333
br,villa feijo,Villa Feijo,01,,-8.15,-70.35
br,villa flor,Villa Flor,22,,-6.316667,-35.066667
br,village atlanta,Village Atlanta,21,,-22.904493,-43.697303
br,village champs elysee,Village Champs Elysée,27,,-23.385694,-46.649125
br,village marapendi,Village Marapendi,21,,-23.011389,-43.440387
br,villagem do cachoeira,Villagem do Cachoeira,16,,-3,-52.233333
br,village pavuna,Village Pavuna,21,,-22.815894,-43.379613
br,villa gomez,Villa Gomez,04,,-7.583333,-70.116667
br,villa humayta,Villa Humayta,01,,-8.261111,-72.738889
br,villa itapucura,Villa Itapucurá,16,,-4.383333,-56.1
br,villa maria,Villa Maria,27,,-23.516667,-46.6
br,villa militar,Villa Militar,21,,-22.862276,-43.397098
br,villa murtinho,Villa Murtinho,24,,-10.4,-65.366667
br,villa nova de garangola,Villa Nova de Garangola,21,,-21.45,-41.4
br,villa nova de resende,Villa Nova de Resende,15,,-21.133333,-46.416667
br,villa nova do timbo,Villa Nova do Timbo,26,,-26.35,-50.866667
br,villa novaes,Villa Novaes,27,,-20.983333,-48.933333
br,villa nova,Villa Nova,04,,-6.533333,-58.2
br,villa nova,Villa Nova,16,,-1.15,-51.966667
br,villa nova,Villa Nova,26,,-26.35,-50.866667
br,villa nova,Villa Nova,28,,-10.3,-36.583333
br,villa nuncio lima,Villa Nuncio Lima,01,,-7.616667,-72.9
br,villa preta,Villa Preta,18,,-24.183333,-50.283333
br,villa raffard,Villa Raffard,27,,-23.011389,-47.526111
br,villa real da praia grande,Villa Real da Praia Grande,21,,-22.90214,-43.130301
br,villarinho do monte,Villarinho do Monte,16,,-1.616667,-52.016667
br,villa rosa,Villa Rosa,06,,-4.333333,-38.516667
br,villa seabra,Villa Seabra,01,,-8.166667,-70.766667
br,villa siqueira,Villa Siqueira,23,,-32.183333,-52.166667
br,villa thaumaturgo,Villa Thaumaturgo,01,,-8.948333,-72.786944
br,villa thereza,Villa Thereza,23,,-29.716667,-52.5
br,villa velha,Villa Velha,05,,-13.65,-41.833333
br,villa verde,Villa Verde,05,,-16.416667,-39.3
br,vimeiro,Vimeiro,08,,-20.066667,-40.4
br,vinagreira,Vinagreira,20,,-4.466667,-42.533333
br,vinagre,Vinagre,17,,-6.133333,-37.533333
br,vinhaca,Vinhaça,15,,-16.05,-40.916667
br,vinhais,Vinhais,13,,-2.516667,-44.266667
br,vinhatico,Vinhático,08,,-18.2,-40.25
br,vinhedo,Vinhedo,27,56493,-23.016667,-46.983333
br,vinicola girardi,Vinicola Girardi,27,,-23.101944,-46.576389
br,vinte alqueires,Vinte Alqueires,15,,-20.6,-43.15
br,vinte e cinco de julho,Vinte e Cinco de Julho,08,,-19.766667,-40.6
br,vinte e cinco,Vinte e Cinco,18,,-23.302756,-52.556582
br,vinte e nove,Vinte e Nove,08,,-18.716667,-40.1
br,vinte e oito de setembro,Vinte e Oito de Setembro,23,,-29.1,-51.866667
br,vinte e seis,Vinte e Seis,18,,-23.296312,-52.525622
br,vinte e tres de julho,Vinte e Três de Julho,23,,-27.966667,-54.616667
br,vinte e tres,Vinte e Três,22,,-5.564722,-36.373056
br,vinte e um de abril,Vinte e Um de Abril,23,,-28.633333,-54.116667
br,vinte nove,Vinte Nove,08,,-18.716667,-40.1
br,violeta,Violeta,17,,-6.966667,-35.283333
br,violeta,Violeta,20,,-8.55,-43.933333
br,viracao grande,Viração Grande,16,,-5.616667,-49.316667
br,viracao,Viração,05,,-11.883333,-40.116667
br,viracao,Viração,06,,-5.383333,-39.466667
br,viracao,Viracão,22,,-5.733333,-35.95
br,viracao,Viração,30,,-7.5,-39.833333
br,viracao,Viração,31,,-11.683333,-47.333333
br,viracaozinha,Viraçãozinha,16,,-5.416667,-49.2
br,virador,Virador,27,,-20.483333,-50.183333
br,viradoura,Viradoura,27,,-20.883333,-48.3
br,viradouro,Viradouro,27,17172,-20.883333,-48.3
br,vira machado,Vira Machado,23,,-29.8134,-50.933
br,viramao,Viramão,11,,-21.45,-54.766667
br,vira mundo,Vira Mundo,22,,-6.233333,-37.833333
br,vira-saia,Vira-Saia,27,,-24.533473,-48.135722
br,vira sol,Vira Sol,15,,-20.45,-44.183333
br,virgaro geral,Virgaro Geral,21,,-22.808694,-43.311015
br,virgem da lapa,Virgem da Lapa,15,,-16.816667,-42.35
br,virgem maria,Virgem Maria,21,,-22.927543,-43.475837
br,virgilio arruda,Virgílio Arruda,11,,-20.483333,-56.283333
br,virgilio costa,Virgílio Costa,15,,-20.283333,-45.866667
br,virgilio de paula,Virgílio de Paula,15,,-20.7,-45.666667
br,virgilio firme,Virgílio Firme,08,,-20.033333,-41.283333
br,virginia,Virginia,08,,-20.7,-41.016667
br,virginia,Virgínia,15,,-22.333333,-45.1
br,virginopolis,Virginópolis,15,,-18.75,-42.75
br,virgolandia,Virgolândia,15,,-18.45,-42.3
br,virmond,Virmond,18,,-25.4,-52.233333
br,virtude,Virtude,13,,-5.833333,-47.166667
br,visada,Visada,14,,-16.4,-55.616667
br,visconde de imbe,Visconde de Imbé,21,,-22.083333,-42.166667
br,visconde de itaborai,Visconde de Itaboraí,21,,-22.716667,-42.933333
br,visconde de taunay,Visconde de Taunay,11,,-20.3,-56.083333
br,visconde-do-imbe,Visconde-do-Imbé,21,,-22.083333,-42.166667
br,visconde do rio branco,Visconde do Rio Branco,04,,-2.863889,-69.661944
br,visconde do rio branco,Visconde do Rio Branco,15,29010,-21.016667,-42.833333
br,visconde,Visconde,05,,-12.5,-38.15
br,visconde,Visconde,21,,-21.383333,-41.366667
br,viseu,Viseu,16,18958,-1.2,-46.116667
br,visita,Visita,04,,-7.852222,-58.3175
br,vista aleare,Vista Aleare,06,,-5,-40.816667
br,vista alegre do alto,Vista Alegre do Alto,27,,-21.183333,-48.616667
br,vista alegre,Vista Alegre,01,,-8.133333,-72.829167
br,vista alegre,Vista Alegre,04,,1.5,-68.183333
br,vista alegre,Vista Alegre,05,,-11.918333,-45.655278
br,vista alegre,Vista Alegre,06,,-4.266667,-39.283333
br,vista alegre,Vista Alegre,11,,-19.566667,-56.233333
br,vista alegre,Vista Alegre,14,,-7.753611,-58.186667
br,vista alegre,Vista Alegre,15,,-15.916667,-45.666667
br,vista alegre,Vista Alegre,16,,-1.016667,-49.716667
br,vista alegre,Vista Alegre,18,,-25.71148,-49.885677
br,vista alegre,Vista Alegre,20,,-5.05,-42.583333
br,vista alegre,Vista Alegre,21,,-20.866667,-41.833333
br,vista alegre,Vista Alegre,23,,-28.816667,-51.8
br,vista alegre,Vista Alegre,24,,-11.5,-61.466667
br,vista alegre,Vista Alegre,25,,1.733333,-61.133333
br,vista alegre,Vista Alegre,27,,-21.183333,-48.616667
br,vista alegre,Vista Alegre,30,,-7.566667,-39.583333
br,vista alegro,Vista Alegro,04,,-7.633333,-60.433333
br,vista alegro,Vista Alegro,20,,-6.75,-42.516667
br,vista bela,Vista Bela,11,,-18.483333,-57.383333
br,vista bela,Vista Bela,15,,-20.5,-41.966667
br,vista do ipiranga,Vista do Ipiranga,04,,-3.2,-66.016667
br,vista gaucha,Vista Gaúcha,23,,-27.283333,-53.716667
br,vista nova,Vista Nova,04,,-4.933333,-60.083333
br,vista nova,Vista Nova,05,,-14.4,-41.083333
br,vista nova,Vista Nova,20,,-10.016667,-44.05
br,vista,Vista,11,,-23.316667,-54.333333
br,vista,Vista,31,,-7.633333,-48.166667
br,vistosa,Vistosa,15,,-21.1,-45.283333
br,vital gomes,Vital Gomes,15,,-16.866667,-41.516667
br,vital-ramos,Vital-Ramos,26,,-27.383333,-49.366667
br,vitor hugo,Vítor Hugo,08,,-20.433333,-40.833333
br,vitoria brasil,Vitória Brasil,27,,-20.2,-50.483333
br,vitoria da conquista,Vitória da Conquista,05,253144,-14.85,-40.85
br,vitoria de santo antao,Vitória de Santo Antão,30,107385,-8.116667,-35.3
br,vitoria do alto parnaiba,Vitória do Alto Parnaíba,13,,-9.1,-45.95
br,vitoria do baixo mearim,Vitória do Baixo Mearim,13,,-3.466667,-44.883333
br,vitoria do mearim,Vitória do Mearim,13,15775,-3.466667,-44.883333
br,vitoria do paraguacu,Vitória do Paraguaçu,05,,-12.683333,-38.933333
br,vitoriana,Vitoriana,27,,-22.783333,-48.4
br,vitoriano,Vitoriano,04,,.7,-66.883333
br,vitoria paulista,Vitória Paulista,27,,-21.783333,-50.766667
br,vitoria velha,Vitória Velha,01,,-8.516667,-70.833333
br,vitoria,Vitória,01,,-8.363889,-72.759167
br,vitoria,Vitória,02,,-9.333333,-36.483333
br,vitoria,Vitória,04,,-8.066667,-67.266667
br,vitoria,Vitória,05,,-12.316667,-40.95
br,vitoria,Vitória,08,312662,-20.316667,-40.35
br,vitoria,Vitória,11,,-19.833333,-57.766667
br,vitoria,Vitória,16,,-2.9,-52.016667
br,vitoria,Vitória,18,,-25.516667,-51.433333
br,vitoria,Vitória,20,,-3.283333,-42.1
br,vitoria,Vitoria,22,,-5.243889,-36.3825
br,vitoria,Vitória,23,,-28.166667,-51.766667
br,vitoria,Vitória,25,,1.433333,-61.566667
br,vitoria,Vitória,27,,-20.383333,-51.15
br,vitoria,Vitória,30,,-7.583333,-37.6
br,vitoria,Vitória,31,,-5.966667,-48.033333
br,vitorina,Vitorina,14,,-16.1,-55.8
br,vitorino freire,Vitorino Freire,13,13267,-4.066667,-45.166667
br,vitorinopolis,Vitorinópolis,18,,-25.6013,-50.2901
br,vitorinos,Vitorinos,15,,-20.983333,-43.55
br,vitorino,Vitorino,05,,-13.583333,-39.883333
br,vitorino,Vitorino,11,,-20.566667,-52.216667
br,vitorino,Vitorino,14,,-16.1,-55.8
br,vitorino,Vitorino,18,,-26.216667,-52.816667
br,vitorio,Vitorio,11,,-19.833333,-57.766667
br,vitorio,Vitório,15,,-17.05,-40.816667
br,vitor tam,Vítor Tam,15,,-19.85,-46.05
br,vitor,Vítor,15,,-14.633333,-44.416667
br,vitor,Vítor,18,,-24.7,-49.016667
br,viuva alcibiades vargas,Viúva Alcibíades Vargas,11,,-23.383333,-54.65
br,viuva amaral,Viúva Amaral,11,,-23.716667,-55.2
br,viuva dias,Viúva Dias,08,,-20.216667,-40.25
br,viuva francisco bueno,Viúva Francisco Bueno,29,,-16.2,-49.583333
br,viuva halsback,Viúva Halsback,11,,-23.333333,-55.1
br,viuva holshak,Viúva Holshak,11,,-23.333333,-55.1
br,viuva mamedio,Viúva Mamédio,29,,-16.233333,-49.466667
br,viuva valentim riet,Viúva Valentim Riet,23,,-20.016667,-56.533333
br,viuva,Viúva,15,,-20,-45.066667
br,viveirinho,Viveirinho,11,,-17.833333,-56.05
br,viveiro de mudas,Viveiro de Mudas,26,,-26.292,-48.6213
br,viveiros,Viveiros,05,,-12.816667,-39.216667
br,viveiro,Viveiro,17,,-7.45,-36.783333
br,vivendas do sol,Vivendas do sol,21,,-23.009613,-43.458435
br,vizeu,Vizeu,16,,-1.2,-46.116667
br,v. matos,V. Matos,23,,-29.066667,-51.6
br,volta da serra,Volta da Serra,05,,-10.883333,-40.733333
br,volta de mutamba,Volta de Mutamba,06,,-4.616667,-37.766667
br,volta do campo largo,Volta do Campo Largo,20,,-7.583333,-41.766667
br,volta do enjeitado,Volta do Enjeitado,30,,-7.9,-38.016667
br,volta do morro,Volta do Morro,20,,-3.570278,-42.321111
br,volta do moxoto,Volta do Moxoto,30,,-9.25,-38.183333
br,volta do padre,Volta do Padre,16,,-4.453889,-52.648333
br,volta do rio,Volta do Rio,06,,-2.85,-39.95
br,volta do rio,Volta do Rio,20,,-6.983333,-40.616667
br,volta do rio,Volta do Rio,30,,-8.633333,-36.166667
br,volta dos paraos,Volta dos Paraos,04,,-7.633333,-60.5
br,volta dos porcos,Volta dos Porcos,04,,-7.633333,-60.5
br,volta grande,Volta Grande,13,,-3.325556,-43.479444
br,volta grande,Volta Grande,14,,-17.133333,-56.933333
br,volta grande,Volta Grande,15,,-18.533333,-48.583333
br,volta grande,Volta Grande,18,,-25.25,-49.083333
br,volta grande,Volta Grande,20,,-8.05,-45.25
br,volta grande,Volta Grande,23,,-27.15,-53.066667
br,volta grande,Volta Grande,26,,-26.873394,-49.64341
br,volta grande,Volta Grande,27,,-20.933333,-49.883333
br,volta grande,Volta Grande,30,,-8.833333,-36.933333
br,volta mofina,Volta Mofina,20,,-2.976944,-41.458611
br,volta redonda,Volta Redonda,21,249584,-22.533333,-44.116667
br,volta redonda,Volta Redonda,22,,-6.433333,-38.35
br,voltas,Voltas,02,,-9.566667,-36.55
br,volta triste,Volta Triste,26,,-26.5334,-49.8497
br,volta,Volta,02,,-9.1,-37.766667
br,volta,Volta,05,,-10.066667,-40.066667
br,volta,Volta,06,,-4.366667,-38.733333
br,volta,Volta,17,,-7.216667,-37.75
br,volta,Volta,20,,-6.083333,-42.9
br,volta,Volta,22,,-5.491111,-37.171667
br,volta,Volta,28,,-10.733333,-37.416667
br,volta,Volta,30,,-7.5,-37.4
br,voluntarios da patria,Voluntários da Pátria,27,,-23.911987,-46.622154
br,voluntario,Voluntário,11,,-21.683333,-55.616667
br,vora,Vorá,18,,-24.7,-52.066667
br,vora,Vorá,26,,-26.933333,-53.516667
br,vota fuego,Vota Fuego,04,,-5.7,-63.266667
br,vota,Vota,06,,-5.383333,-38.233333
br,votorantim,Votorantim,27,99392,-23.541318,-47.444671
br,votouro,Votouro,23,,-27.416667,-52.666667
br,votuporanga,Votuporanga,27,,-20.4,-49.983333
br,voturantim,Voturantim,27,,-23.541318,-47.444671
br,voturuna,Voturuna,05,,-10.033333,-37.9
br,votuverava,Votuverava,18,,-25.133333,-49.3
br,v. veneto,V. Veneto,23,,-29.65,-53.516667
br,wagner,Wagner,05,,-12.216667,-41.183333
br,wagner,Wagner,26,,-26.533333,-49.833333
br,waldes,Waldes,27,,-23.556036,-47.193724
br,waldheim,Waldheim,26,,-26.9385,-49.8428
br,wanderlandia,Wanderlândia,31,6545,-6.835833,-47.799167
br,warnow pequeno,Warnow Pequeno,26,,-26.9711,-49.2365
br,warnow,Warnow,26,,-26.966667,-49.283333
br,washington luiz,Washington Luiz,18,,-23.412809,-49.979241
br,wenceslau braz,Wenceslau Braz,18,15726,-23.85,-49.8
br,werneck,Werneck,21,,-22.220833,-43.314444
br,werneck,Werneck,30,,-8.083333,-34.933333
br,wfazenda maia,wFazenda Maia,27,,-22,-52.066667
br,winchester,Winchester,26,,-26.676627,-49.988756
br,witmarsum,Witmarsum,26,,-26.925,-49.7918
br,witmarsun,Witmarsun,26,,-26.925,-49.7918
br,xambioa,Xambioá,31,9281,-6.4325,-48.381944
br,xambioazinho,Xambioàzinho,31,,-6.4325,-48.381944
br,xambre,Xambrê,18,,-23.7,-53.566667
br,xandico de oliveira,Xandico de Oliveira,15,,-19.366667,-48.433333
br,xanere,Xaneré,26,,-26.883333,-52.383333
br,xanxere,Xanxerê,26,32958,-26.883333,-52.383333
br,xapeco,Xapecó,26,,-27.1,-52.6
br,xapetuba,Xapetuba,15,,-18.866667,-48.566667
br,xapuri,Xapuri,01,5721,-10.65,-68.516667
br,xapuri,Xapuri,05,,-15.25,-39.416667
br,xapury,Xapury,01,,-10.65,-68.516667
br,xaraco,Xaraco,04,,.583333,-67.233333
br,xareu,Xaréu,02,,-8.95,-35.183333
br,xarqueada,Xarqueada,23,,-29.266667,-56.583333
br,xarqueada,Xarqueada,27,,-22.5,-47.766667
br,xarqueada,Xarqueada,31,,-8.905,-48.162778
br,xarqueda,Xarqueda,23,,-29.966667,-51.633333
br,xatelodo,Xatelodo,11,,-20.333333,-56.933333
br,xavantes,Xavantes,27,,-23.033333,-49.716667
br,xavantina,Xavantina,11,,-21.25,-52.8
br,xavantina,Xavantina,14,,-14.666667,-52.35
br,xavantina,Xavantina,26,,-27.083333,-52.333333
br,xavier,Xavier,05,,-12.2,-41.65
br,xavier,Xavier,06,,-5.15,-40.816667
br,xavier,Xavier,17,,-6.983333,-37.966667
br,xavier,Xavier,20,,-7.816667,-41.633333
br,xavier,Xavier,21,,-23.026325,-43.552435
br,xavier,Xavier,27,,-22.366667,-48
br,xaxim cercado,Xaxim Cercado,18,,-25.483333,-49.266667
br,xaxim,Xaxim,18,,-24.733333,-53.816667
br,xaxim,Xaxim,26,21376,-26.933333,-52.516667
br,xera,Xerá,18,,-23.443014,-52.580717
br,xerem,Xerém,21,,-22.585556,-43.295
br,xerente,Xerente,31,,-9.529167,-48.319722
br,xereu,Xeréu,02,,-8.95,-35.183333
br,xexeu,Xexéu,30,,-8.816667,-35.616667
br,xibaua,Xibauá,04,,-4.879167,-66.898056
br,xilili,Xilili,30,,-8.416667,-37.216667
br,ximbo,Ximbó,27,,-23.1106,-47.9506
br,xingo,Xingó,02,,-9.4,-37.966667
br,xingo,Xingó,05,,-9.566667,-38.066667
br,xingu,Xingu,04,,-7.733333,-68.716667
br,xingu,Xingu,20,,-9.633333,-45.433333
br,xinxo,Xinxó,17,,-7.766667,-36.866667
br,xique-xique,Xique-Xique,05,35435,-10.833333,-42.733333
br,xiquexique,Xiquexique,06,,-4.833333,-41.033333
br,xique-xique,Xique-Xique,20,,-6.683333,-42.15
br,xiquexique,Xiquexique,22,,-6.25,-37.966667
br,xiquexique,Xiquexique,30,,-7.7,-37.283333
br,xique-xique,Xique-Xique,30,,-8.35,-38
br,xiririca,Xiririca,27,,-23.153903,-47.609165
br,xiriri,Xiriri,25,,3.233333,-60.516667
br,xiru,Xiru,11,,-21.183333,-56.433333
br,xixas,Xixás,13,,-3.825833,-42.809167
br,xixa,Xixá,05,,-10.066667,-43.133333
br,xixa,Xixá,29,,-15.583333,-49.983333
br,xixebal,Xixebal,31,,-7.25,-48.216667
br,xonim,Xonim,15,,-18.633333,-42.05
br,xorroxo,Xorroxó,05,,-8.983333,-39.1
br,xoto,Xotó,21,,-22.290608,-42.812839
br,xucuru,Xucuru,30,,-8.25,-36.6
br,xui,Xuí,23,,-33.683333,-53.45
br,xupe,Xupê,13,,-4.533333,-45.35
br,xuque,Xuquê,05,,-10.033333,-38.583333
br,yacy,Yacy,27,,-20.883333,-49.55
br,yaramonta,Yaramonta,25,,4.6,-60.4
br,yara,Yara,25,,3.483333,-60.083333
br,yata,Yata,24,,-10.583333,-65.383333
br,yauacana,Yauacaná,04,,.516667,-67.383333
br,yauarete,Yauareté,04,,.633333,-69.2
br,yaurare,Yauraré,16,,-7.883333,-57.183333
br,yepe,Yepé,27,,-22.666667,-51.083333
br,yitapuga,Yitapuga,04,,.3,-68.65
br,yi-tapuya,Yi-Tapuya,04,,.3,-68.65
br,ypiranga,Ypiranga,04,,-2.931944,-69.695
br,ypiranga,Ypiranga,15,,-18.75,-44.366667
br,ypiranga,Ypiranga,18,,-25.016667,-50.583333
br,ypiranga,Ypiranga,20,,-6.816667,-41.75
br,ypiranga,Ypiranga,24,,-10.016667,-62.866667
br,yporanga,Yporanga,27,,-24.584536,-48.592226
br,yucatan,Yucatan,16,,-6.466667,-54.05
br,zabele,Zabelê,05,,-12.366667,-39.683333
br,zabele,Zabelê,06,,-7.183333,-39.583333
br,zabele,Zabelê,17,,-8.066667,-37.1
br,zacarias,Zacarias,21,,-22.95,-42.833333
br,zacarias,Zacarias,27,,-21.05,-50.066667
br,zadilinos,Zadilinos,22,,-5.391111,-36.995833
br,zamaicare,Zamaicaré,14,,-14.633333,-58.55
br,zamba,Zamba,17,,-7.133333,-38.166667
br,zandavali,Zandavali,26,,-27.066667,-52.75
br,zanette,Zanette,11,,-19.316667,-57.566667
br,zanetti,Zanetti,11,,-19.316667,-57.566667
br,zanetti,Zanetti,23,,-29.0778,-51.0171
br,zarzuela,Zarzuela,24,,-13.55,-60.6
br,ze araujo,Zé Araújo,22,,-5.6,-35.983333
br,zebele,Zebelé,05,,-12.016667,-40.75
br,zebele,Zebelé,17,,-8.066667,-37.1
br,zebelezinho,Zebelèzinho,17,,-8.066667,-37.133333
br,zebelizinho,Zebèlizinho,17,,-8.066667,-37.133333
br,ze brito,Zé Brito,05,,-13.033333,-39.683333
br,zeca botelho,Zeca Botelho,15,,-16.533333,-40.416667
br,zeca,Zeca,05,,-16.083333,-39.483333
br,zedeque,Zedeque,25,,.720556,-61.670833
br,zeferino,Zeferino,15,,-17,-41.933333
br,ze ferreira,Zé Ferreira,20,,-6.166667,-42.65
br,ze gomes,Zé Gomes,13,,-3.666667,-42.790833
br,ze gomes,Zé Gomes,17,,-7.966667,-37.1
br,zelandia,Zelândia,13,,-8.516667,-45.766667
br,zelandia,Zelândia,15,,-19.533333,-47.416667
br,zelia,Zélia,05,,-10.4,-39.216667
br,ze rodrigues,Zé Rodrigues,13,,-3.829167,-42.796111
br,zezito,Zèzito,06,,-7.283333,-40.066667
br,zimbros,Zimbros,26,,-27.179722,-48.533889
br,zimbro,Zimbro,20,,-8.066667,-42.283333
br,zita bernardes,Zita Bernardes,15,,-21.733333,-46.533333
br,zito soares,Zito Soares,15,,-20.183333,-42.766667
br,zogaias,Zogaias,15,,-20.133333,-46.95
br,zombaria,Zombaria,30,,-8.216667,-36.7
br,zona andreaza,Zona Andreaza,23,,-29.2105,-51.0137
br,zona dapra,Zona Dapra,23,,-29.0686,-51.0518
br,zonas,Zonas,23,,-28.733333,-55.6
br,zona,Zona,23,,-28.733333,-55.6
br,zororo,Zororó,18,,-24.266667,-54.266667
br,zoro,Zoro,05,,-13.7,-41.283333
br,zorra,Zorra,06,,-5.866667,-39.55
br,zumbi,Zumbi,05,,-12.933333,-38.9
br,zumbi,Zumbi,06,,-6.383333,-40.2
br,zumbi,Zumbi,08,,-20.85,-41.116667
br,zumbi,Zumbi,13,,-5.233333,-43.2
br,zumbi,Zumbi,17,,-7.1,-35.683333
br,zumbi,Zumbi,21,,-22.822483,-43.176257
br,zumbi,Zumbi,22,,-5.333333,-35.366667
br,zundao,Zundão,20,,-5.15,-41.916667

CITY

return $world_city_maxmind;
}

1;
